@@ -3,12 +3,12 @@
 
 #include <QTimer>
 #include <QPainter>
-
 #include <QLabel>
-#include <QtGui/QDesktopWidget>
+#include <QDesktopWidget>
 #include <QGroupBox>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
+#include <QDBusInterface>
 
 #include <KDialog>
 #include <KMessageBox>
@@ -19,6 +19,7 @@
 #include <KConfig>
 #include <KGlobal>
 #include <KLocale>
+#include <KUrl>
 #include <netwm.h>
 #include <KShortcut>
 #include <kwindowsystem.h>
@@ -30,8 +31,8 @@
 #include <X11/keysymdef.h>
 
 
-#include "kaccess.moc"
-#include <QX11Info>
+#include "moc_kaccess.cpp"
+#include <QtGui/qx11info_x11.h>
 #include <kvbox.h>
 
 struct ModifierKey {
@@ -95,9 +96,9 @@ static ModifierKey modifierKeys[] = {
 /********************************************************************/
 
 
-KAccessApp::KAccessApp(bool allowStyles, bool GUIenabled)
-  : KUniqueApplication(allowStyles, GUIenabled),
-  overlay(0), _player(0)
+KAccessApp::KAccessApp(bool allowStyles)
+  : KUniqueApplication(allowStyles),
+  overlay(0)
 {
   _activeWindow = KWindowSystem::activeWindow();
   connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(activeWindowChanged(WId)));
@@ -443,9 +444,7 @@ void KAccessApp::xkbBellNotify(XkbBellNotifyEvent *event)
       if (_visibleBellInvert)
         {
 	  QPixmap screen = QPixmap::grabWindow(id, 0, 0, window.size.width, window.size.height);
-#ifdef __GNUC__
 #warning is this the best way to invert a pixmap?
-#endif
 //	  QPixmap invert(window.size.width, window.size.height);
 	  QImage i = screen.toImage();
 	  i.invertPixels();
@@ -472,14 +471,10 @@ void KAccessApp::xkbBellNotify(XkbBellNotifyEvent *event)
       flush();
     }
 
-  // ask Phonon to ring a nice bell
+  // ring a nice bell
   if (_artsBell) {
-    if (!_player) { // as creating the player is expensive, delay the creation
-      _player = Phonon::createPlayer(Phonon::AccessibilityCategory);
-      _player->setParent(this);
-      _player->setCurrentSource(_currentPlayerSource);
-    }
-    _player->play();
+    QDBusInterface kaudioplayer("org.kde.kded", "/modules/kaudioplayer", "org.kde.kaudioplayer");
+    kaudioplayer.call("play", _currentPlayerSource, QString::fromLatin1("kaccess"));
   }
 }
 
@@ -593,10 +588,8 @@ void KAccessApp::createDialogContents() {
 
       KVBox *topcontents = new KVBox (dialog);
       topcontents->setSpacing(KDialog::spacingHint()*2);
-#ifdef __GNUC__
 #warning "kde4 fixme"
-#endif
-	  //topcontents->setMargin(KDialog::marginHint());
+      //topcontents->setMargin(KDialog::marginHint());
 
       QWidget *contents = new QWidget(topcontents);
       QHBoxLayout * lay = new QHBoxLayout(contents);
