@@ -17,21 +17,18 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
  ***************************************************************************/
 
-#ifndef _AUTOSTARTITEM_H_
-#define _AUTOSTARTITEM_H_
+#ifndef AUTOSTARTITEM_H
+#define AUTOSTARTITEM_H
 
+#include <QTreeWidget>
 #include <QTreeWidgetItem>
 #include <QObject>
 #include <KUrl>
 
-class QComboBox;
-class QTreeWidget;
-class Autostart;
-
 class AutoStartItem : public QTreeWidgetItem, public QObject
 {
 public:
-    AutoStartItem( const QString &service, QTreeWidgetItem *parent, Autostart* );
+    AutoStartItem(const QString &service, QTreeWidgetItem *parent);
     ~AutoStartItem();
 
     KUrl fileName() const;
@@ -42,34 +39,4 @@ private:
     KUrl m_fileName;
 };
 
-class DesktopStartItem : public AutoStartItem
-{
-public:
-    DesktopStartItem( const QString &service, QTreeWidgetItem *parent, Autostart* );
-    ~DesktopStartItem();
-};
-
-
-class ScriptStartItem : public AutoStartItem
-{
-    Q_OBJECT
-
-public:
-    enum ENV { START=0, SHUTDOWN=1, PRE_START=2}; //rename
-    ScriptStartItem( const QString &service, QTreeWidgetItem *parent, Autostart* );
-    ~ScriptStartItem();
-
-    void changeStartup( ScriptStartItem::ENV type );
-
-signals:
-    void askChangeStartup(ScriptStartItem* item, int index);
-
-private slots:
-
-    void slotStartupChanged(int index);
-
-private:
-    QComboBox *m_comboBoxStartup;
-};
-
-#endif
+#endif // AUTOSTARTITEM_H
