@@ -43,8 +43,6 @@
 #include <KPluginFactory>
 #include <KStandardDirs>
 #include <kio/netaccess.h>
-#include <knewstuff3/downloaddialog.h>
-#include <knewstuff3/uploaddialog.h>
 
 K_PLUGIN_FACTORY( KolorFactory, registerPlugin<KColorCm>(); )
 K_EXPORT_PLUGIN( KolorFactory("kcmcolors") )
@@ -91,8 +89,6 @@ KColorCm::KColorCm(QWidget *parent, const QVariantList &)
     m_config = KSharedConfig::openConfig("kdeglobals");
 
     setupUi(this);
-    schemeKnsButton->setIcon( KIcon("get-hot-new-stuff") );
-    schemeKnsUploadButton->setIcon( KIcon("get-hot-new-stuff") );
     connect(colorSet, SIGNAL(currentIndexChanged(int)), this, SLOT(updateColorTable()));
     connect(schemeList, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
             this, SLOT(loadScheme(QListWidgetItem*,QListWidgetItem*)));
@@ -267,7 +263,6 @@ void KColorCm::loadScheme(QListWidgetItem *currentItem, QListWidgetItem *previou
         if (name == i18nc("Default color scheme", "Default"))
         {
             schemeRemoveButton->setEnabled(false);
-            schemeKnsUploadButton->setEnabled(false);
 
             KSharedConfigPtr config = m_config;
             config->setReadDefaults(true);
@@ -279,7 +274,6 @@ void KColorCm::loadScheme(QListWidgetItem *currentItem, QListWidgetItem *previou
         else if (name == i18nc("Current color scheme", "Current"))
         {
             schemeRemoveButton->setEnabled(false);
-            schemeKnsUploadButton->setEnabled(false);
             loadInternal(false);
         }
         else
@@ -291,7 +285,6 @@ void KColorCm::loadScheme(QListWidgetItem *currentItem, QListWidgetItem *previou
             const bool canWrite = (permissions & QFile::WriteUser);
             kDebug() << "checking permissions of " << path;
             schemeRemoveButton->setEnabled(canWrite);
-            schemeKnsUploadButton->setEnabled(true);
 
             KSharedConfigPtr config = KSharedConfig::openConfig(path);
             loadScheme(config);
@@ -395,45 +388,6 @@ void KColorCm::on_schemeImportButton_clicked()
     }
 }
 
-void KColorCm::on_schemeKnsButton_clicked()
-{
-    KNS3::DownloadDialog dialog("colorschemes.knsrc", this);
-    dialog.exec();
-    if ( ! dialog.changedEntries().isEmpty() )
-    {
-        populateSchemeList();
-    }
-}
-
-void KColorCm::on_schemeKnsUploadButton_clicked()
-{
-    if (schemeList->currentItem() != NULL)
-    {
-        // check if the currently loaded scheme has unsaved changes
-        if (m_loadedSchemeHasUnsavedChanges)
-        {
-            KMessageBox::sorry(this, i18n("Please save the color scheme before uploading it."),
-                               i18n("Please save"));
-            return;
-        }
-
-        // find path
-        const QString basename = schemeList->currentItem()->data(Qt::UserRole).toString();
-        const QString path = KGlobal::dirs()->findResource("data",
-            "color-schemes/" + basename + ".colors");
-        if (path.isEmpty() ) // if the color scheme file wasn't found
-        {
-            kDebug() << "path for color scheme " << basename << " couldn't be found";
-            return;
-        }
-
-        // upload
-        KNS3::UploadDialog dialog("colorschemes.knsrc", this);
-        dialog.setUploadFile(KUrl(path) );
-        dialog.exec();
-    }
-}
-
 void KColorCm::on_schemeSaveButton_clicked()
 {
     QString previousName;
@@ -845,8 +799,7 @@ void KColorCm::updateColorTable()
         stackColors->setCurrentIndex(0);
         stackPreview->setCurrentIndex(0);
 
-        KColorButton * button;
-        foreach (button, m_commonColorButtons)
+        foreach (KColorButton *button, m_commonColorButtons)
         {
             button->blockSignals(true);
         }
@@ -882,7 +835,7 @@ void KColorCm::updateColorTable()
         m_commonColorButtons[24]->setColor(m_wmColors.color(WindecoColors::InactiveForeground));
         m_commonColorButtons[25]->setColor(m_wmColors.color(WindecoColors::InactiveBlend));
 
-        foreach (button, m_commonColorButtons)
+        foreach (KColorButton *button, m_commonColorButtons)
         {
             button->blockSignals(false);
         }
@@ -1098,7 +1051,6 @@ void KColorCm::changeColor(int row, const QColor &newColor)
     KConfigGroup group(m_config, "General");
     group.writeEntry("ColorScheme", m_currentColorScheme);
     schemeRemoveButton->setEnabled(false);
-    schemeKnsUploadButton->setEnabled(false);
     schemeList->blockSignals(true); // don't emit changed signals
     schemeList->setCurrentRow(0);
     schemeList->blockSignals(false);
@@ -1260,7 +1212,7 @@ void KColorCm::save()
     displayGroup.writeEntry("exportKDEColors", applyToAlien->isChecked());
     cfg.sync();
 
-    runRdb(KRdbExportQtColors | KRdbExportGtkTheme | ( applyToAlien->isChecked() ? KRdbExportColors : 0 ) );
+    runRdb(KRdbExportQtColors | ( applyToAlien->isChecked() ? KRdbExportColors : 0 ) );
 
     emit changed(false);
 }
@@ -1466,4 +1418,4 @@ void KColorCm::on_disabledContrastSlider_valueChanged(int value)
     emit changed(true);
 }
 
-#include "colorscm.moc"
+#include "moc_colorscm.cpp"
