@@ -31,30 +31,27 @@
 #include <sys/types.h>
 
 #include <QComboBox>
-#include <QtGui/QGroupBox>
+#include <QGroupBox>
 #include <QPushButton>
 #include <QPainter>
-#include <QTimeEdit>
-
+#include <QDateTimeEdit>
 #include <QCheckBox>
-#include <QPaintEvent>
+#include <QtGui/qevent.h>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
+
 #include <kdebug.h>
 #include <klocale.h>
-#include <kprocess.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kdialog.h>
 #include <kconfig.h>
-#include <kcolorscheme.h>
 #include <ksystemtimezone.h>
-#include <KTreeWidgetSearchLine>
 
 #include <Plasma/Svg>
 
-#include "dtime.moc"
+#include "moc_dtime.cpp"
 
 #include "helper.h"
 
@@ -144,9 +141,11 @@ void Dtime::serverTimeCheck() {
 
 void Dtime::findNTPutility()
 {
-    const QString exePath = QLatin1String("/usr/sbin:/usr/bin:/sbin:/bin");
-    foreach(const QString &possible_ntputility, QStringList() << "ntpdate" << "rdate" ) {
-        ntpUtility = KStandardDirs::findExe(possible_ntputility, exePath);
+    static const QStringList possible_ntputilities = QStringList()
+        << QString::fromLatin1("ntpdate")
+        << QString::fromLatin1("rdate");
+    foreach(const QString &possible_ntputility, possible_ntputilities) {
+        ntpUtility = KStandardDirs::findRootExe(possible_ntputility);
         if (!ntpUtility.isEmpty()) {
             return;
         }
