@@ -21,31 +21,29 @@
 #ifndef CLOCK_HELPER_H
 #define CLOCK_HELPER_H
 
-#include <kauth.h>
+#include <kauthorization.h>
 
-using namespace KAuth;
-
-class ClockHelper : public QObject
+class ClockHelper : public KAuthorization
 {
     Q_OBJECT
 
     public:
-        enum
-        {
-            CallError       = 1 << 0,
-            TimezoneError   = 1 << 1,
-            NTPError        = 1 << 2,
-            DateError       = 1 << 3
+        enum CH_Error {
+            NoError         = 0,
+            CallError       = 1,
+            TimezoneError   = 2,
+            NTPError        = 4,
+            DateError       = 8
         };
 
     public slots:
-        ActionReply save(const QVariantMap &map);
+        int save(const QVariantMap &map);
 
     private:
-        int ntp(const QStringList& ntpServers, bool ntpEnabled);
-        int date(const QString& newdate, const QString& olddate);
-        int tz(const QString& selectedzone);
-        int tzreset();
+        CH_Error ntp(const QStringList& ntpServers, bool ntpEnabled);
+        CH_Error date(const QString& newdate, const QString& olddate);
+        CH_Error tz(const QString& selectedzone);
+        CH_Error tzreset();
 };
 
 #endif // CLOCK_HELPER_H
