@@ -9,24 +9,23 @@
 #include <config-workspace.h>
 
 #include "fonts.h"
-#include "fonts.moc"
+#include "moc_fonts.cpp"
 
 #include <stdlib.h>
 
+#include <QProcess>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QSpinBox>
-#include <qplatformdefs.h>
-
-//Added by qt3to4:
 #include <QPixmap>
 #include <QByteArray>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QFormLayout>
+#include <qplatformdefs.h>
 
 #include <KFontDialog>
 #include <KAcceleratorManager>
@@ -34,7 +33,6 @@
 #include <KGlobalSettings>
 #include <KMessageBox>
 #include <KNumInput>
-#include <KProcess>
 #include <KConfig>
 #include <KStandardDirs>
 #include <KDebug>
@@ -62,76 +60,21 @@
 #undef None
 #endif
 
-static const char * const aa_rgb_xpm[]={
-"12 12 3 1",
-"a c #0000ff",
-"# c #00ff00",
-". c #ff0000",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa"};
-static const char * const aa_bgr_xpm[]={
-"12 12 3 1",
-". c #0000ff",
-"# c #00ff00",
-"a c #ff0000",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa",
-"....####aaaa"};
-static const char * const aa_vrgb_xpm[]={
-"12 12 3 1",
-"a c #0000ff",
-"# c #00ff00",
-". c #ff0000",
-"............",
-"............",
-"............",
-"............",
-"############",
-"############",
-"############",
-"############",
-"aaaaaaaaaaaa",
-"aaaaaaaaaaaa",
-"aaaaaaaaaaaa",
-"aaaaaaaaaaaa"};
-static const char * const aa_vbgr_xpm[]={
-"12 12 3 1",
-". c #0000ff",
-"# c #00ff00",
-"a c #ff0000",
-"............",
-"............",
-"............",
-"............",
-"############",
-"############",
-"############",
-"############",
-"aaaaaaaaaaaa",
-"aaaaaaaaaaaa",
-"aaaaaaaaaaaa",
-"aaaaaaaaaaaa"};
-
-static const char* const * const aaPixmaps[]={ aa_rgb_xpm, aa_bgr_xpm, aa_vrgb_xpm, aa_vbgr_xpm };
+static QPixmap aaPixmap(const int t)
+{
+    static const char* const aaPixmaps[] = {
+        "kcminput/pics/aa_rgb.png",
+        "kcminput/pics/aa_bgr.png",
+        "kcminput/pics/aa_vrgb.png",
+        "kcminput/pics/aa_vbgr.png",
+    };
+    const QString pixmapfilepath = KGlobal::dirs()->findResource("data", aaPixmaps[t]);
+    if (pixmapfilepath.isEmpty()) {
+        kWarning() << "No image for" << aaPixmaps[t];
+        return QPixmap();
+    }
+    return QPixmap(pixmapfilepath);
+}
 
 /**** DLL Interface ****/
 K_PLUGIN_FACTORY(FontFactory, registerPlugin<KFonts>(); )
@@ -212,9 +155,7 @@ void FontUseItem::applyFontDiff( const QFont &fnt, int fontDiffFlags )
     _font.setWeight( fnt.weight() );
     _font.setStyle( fnt.style() );
     _font.setUnderline( fnt.underline() );
-#if QT_VERSION >= 0x040800
     _font.setStyleName( fnt.styleName() );
-#endif
   }
 
   setFont( _font, isFixedOnly() );
@@ -268,7 +209,7 @@ FontAASettings::FontAASettings(QWidget *parent)
   subPixelType->setWhatsThis( subPixelWhatsThis );
 
   for(int t=KXftConfig::SubPixel::None+1; t<=KXftConfig::SubPixel::Vbgr; ++t)
-    subPixelType->addItem(QPixmap(aaPixmaps[t-1]), i18n(KXftConfig::description((KXftConfig::SubPixel::Type)t).toUtf8()));
+    subPixelType->addItem(aaPixmap(t-1), i18n(KXftConfig::description((KXftConfig::SubPixel::Type)t).toUtf8()));
 
   QLabel *hintingLabel=new QLabel(i18n("Hinting style: "), mw);
   hintingStyle=new QComboBox(mw);
@@ -337,7 +278,7 @@ bool FontAASettings::load()
     xft.apply();  // Save this setting
     KConfigGroup(&kglobals, "General").writeEntry("XftHintStyle", KXftConfig::toStr(hStyle));
     kglobals.sync();
-    runRdb(KRdbExportXftSettings | KRdbExportGtkTheme);
+    runRdb(KRdbExportXftSettings);
   }
 
   hintingStyle->setCurrentIndex(getIndex(hStyle));
@@ -516,22 +457,12 @@ KFonts::KFonts(QWidget *parent, const QVariantList &args)
 
   // NOTE: keep in sync with kdelibs/kdeui/kernel/kglobalsettings.cpp
 
-#ifdef Q_WS_MAC
-  QFont f0("Lucida Grande", 13); // general/menu/desktop
-  QFont f1("Monaco", 10);
-  QFont f2("Lucida Grande", 11); // toolbar
-#elif defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
-  QFont f0("Sans Serif", 16); // general/menu/desktop
-  QFont f1("Monospace", 16;
-  QFont f2("Sans Serif", 16); // toolbar
-#else
-  QFont f0("Sans Serif", 9); // general/menu/desktop
-  QFont f1("Monospace", 9);
-  QFont f2("Sans Serif", 8); // toolbar
-#endif
-  QFont f3("Sans Serif", 8); // window title
-  QFont f4("Sans Serif", 9); // taskbar
-  QFont f5("Sans Serif", 8); // smallestReadableFont
+  QFont f0(KDE_DEFAULT_FONT, 9); // general/menu/desktop
+  QFont f1(KDE_DEFAULT_FIXED_FONT, 9);
+  QFont f2(KDE_DEFAULT_FONT, 8); // toolbar
+  QFont f3(KDE_DEFAULT_FONT, 8); // window title
+  QFont f4(KDE_DEFAULT_FONT, 9); // taskbar
+  QFont f5(KDE_DEFAULT_FONT, 8); // smallestReadableFont
 
   defaultFontList << f0 << f1 << f5 << f2 << f0 << f3 << f4 << f0;
 
@@ -766,9 +697,8 @@ void KFonts::save()
   // if the setting is reset in the module, remove the dpi value,
   // otherwise don't explicitly remove it and leave any possible system-wide value
   if( dpi == 0 && dpi_original != 0 ) {
-      KProcess proc;
-      proc << "xrdb" << "-quiet" << "-remove" << "-nocpp";
-      proc.start();
+      QProcess proc;
+      proc.start("xrdb", QStringList() << "-quiet" << "-remove" << "-nocpp");
       if (proc.waitForStarted()) {
         proc.write( QByteArray( "Xft.dpi\n" ) );
         proc.closeWriteChannel();
@@ -809,7 +739,7 @@ void KFonts::save()
   }
 #endif
 #endif
-  runRdb(KRdbExportXftSettings | KRdbExportGtkTheme);
+  runRdb(KRdbExportXftSettings);
 
   emit changed(false);
 }
