@@ -73,7 +73,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <kglobalsettings.h>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 #undef Below
 
@@ -353,26 +353,35 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
       { 0, 0, 0, 0, 0 }
   };
 
-  usb_init();
-  usb_find_busses();
-  usb_find_devices();
+  libusb_init(NULL);
 
-  struct usb_bus *bus;
-  struct usb_device *dev;
+  libusb_device **list;
+  ssize_t cnt = libusb_get_device_list(NULL, &list);
 
-  for (bus = usb_busses; bus; bus = bus->next) {
-      for (dev = bus->devices; dev; dev = dev->next) {
-	  for (int n = 0; device_table[n].idVendor; n++)
-	      if ( (device_table[n].idVendor == dev->descriptor.idVendor) &&
-		   (device_table[n].idProduct == dev->descriptor.idProduct) ) {
-		  // OK, we have a device that appears to be one of the ones we support
-		  LogitechMouse *mouse = new LogitechMouse( dev, device_table[n].flags, this, device_table[n].Name );
-		  settings->logitechMouseList.append(mouse);
-		  tabwidget->addTab( (QWidget*)mouse, device_table[n].Name );
-	      }
+  if (cnt >= 0) {
+    for (int i = 0; i < cnt; i++) {
+      libusb_device_descriptor descriptor;
+
+      libusb_device *device = list[i];
+      libusb_get_device_descriptor(device, &descriptor);
+
+      for (int n = 0; device_table[n].idVendor; n++) {
+        if ( (device_table[n].idVendor == descriptor.idVendor) &&
+          (device_table[n].idProduct == descriptor.idProduct) ) {
+          // OK, we have a device that appears to be one of the ones we support
+          LogitechMouse *mouse = new LogitechMouse( device, device_table[n].flags, this, device_table[n].Name );
+          settings->logitechMouseList.append(mouse);
+          tabwidget->addTab( (QWidget*)mouse, device_table[n].Name );
+        }
       }
+    }
   }
 
+  // passing true to free the refs, is that safe given the pointer passing to LogitechMouse()?
+  libusb_free_device_list(list, true);
+  // TODO: should the default context be exited?
+  libusb_exit(NULL);
+
 #endif
 
   KAboutData* about = new KAboutData("kcmmouse", 0, ki18n("Mouse"), 0, KLocalizedString(),
@@ -663,9 +672,7 @@ void MouseSettings::load(KConfig *config)
     handed = RIGHT_HANDED;
   else if (key == "LeftHanded")
     handed = LEFT_HANDED;
-#ifdef __GNUC__
 #warning was key == NULL how was this working? is key.isNull() what the coder meant?
-#endif
   else if (key.isNull())
     handed = h;
   reverseScrollPolarity = group.readEntry( "ReverseScrollPolarity", false);
@@ -770,8 +777,7 @@ void MouseSettings::apply(bool force)
 
   // This iterates through the various Logitech mice, if we have support.
   #ifdef HAVE_LIBUSB
-  LogitechMouse *logitechMouse;
-  Q_FOREACH( logitechMouse, logitechMouseList ) {
+  Q_FOREACH( LogitechMouse *logitechMouse, logitechMouseList ) {
       logitechMouse->applyChanges();
   }
   #endif
@@ -798,8 +804,7 @@ void MouseSettings::save(KConfig *config)
   group.writeEntry("ChangeCursor", changeCursor,KConfig::Persistent|KConfig::Global);
   // This iterates through the various Logitech mice, if we have support.
 #ifdef HAVE_LIBUSB
-  LogitechMouse *logitechMouse;
-  Q_FOREACH( logitechMouse, logitechMouseList ) {
+  Q_FOREACH( LogitechMouse *logitechMouse, logitechMouseList ) {
       logitechMouse->save(config);
   }
 #endif
@@ -818,4 +823,4 @@ void MouseConfig::slotSmartSliderEnabling()
   generalTab->slAutoSelect->setEnabled(enabled);
 }
 
-#include "mouse.moc"
+#include "moc_mouse.cpp"
