@@ -21,7 +21,6 @@
 #include <KConfig>
 #include <KLocale>
 #include <KStandardDirs>
-
 #include <KGlobalSettings>
 #include <KToolInvocation>
 #include <KMessageBox>
@@ -29,10 +28,8 @@
 #include <KIO/Job>
 #include <KIO/DeleteJob>
 #include <KIO/NetAccess>
-#include <knewstuff3/downloaddialog.h>
-
-
-#include <KTar>
+#include <KArchive>
+#include <KDebug>
 
 #include <klauncher_iface.h>
 #include "../../krdb/krdb.h"
@@ -40,10 +37,10 @@
 #include <QWidget>
 #include <QPushButton>
 #include <QDir>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 #include "themepage.h"
-#include "themepage.moc"
+#include "moc_themepage.cpp"
 
 #include "thememodel.h"
 #include "itemdelegate.h"
@@ -57,12 +54,12 @@
 #  include <X11/extensions/Xfixes.h>
 #endif
 
+#include <sys/stat.h>
 
 ThemePage::ThemePage(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
-    installKnsButton->setIcon(KIcon("get-hot-new-stuff"));
     installButton->setIcon(KIcon("document-import"));
     removeButton->setIcon(KIcon("edit-delete"));
 
@@ -100,10 +97,8 @@ ThemePage::ThemePage(QWidget *parent)
     // or Xcursor isn't set up to look for cursor themes there.
     if (!model->searchPaths().contains(QDir::homePath() + "/.icons") || !iconsIsWritable()) {
             installButton->setEnabled(false);
-            installKnsButton->setEnabled(false);
     }
 
-    connect(installKnsButton, SIGNAL(clicked()), SLOT(getNewClicked()));
     connect(installButton, SIGNAL(clicked()), SLOT(installClicked()));
     connect(removeButton,  SIGNAL(clicked()), SLOT(removeClicked()));
 }
@@ -140,7 +135,6 @@ void ThemePage::updateSizeComboBox()
         QIcon m_icon;
         if (sizes.size() > 1)  // only refill the combobox if there is more that 1 size
         {
-            int i;
             QList<int> comboBoxList;
             QPixmap m_pixmap;
 
@@ -155,7 +149,7 @@ void ThemePage::updateSizeComboBox()
                 i18nc("@item:inlistbox size", "resolution dependent"),
                 0);
             comboBoxList << 0;
-            foreach (i, sizes)
+            foreach (int i, sizes)
             {
                 m_pixmap = theme->createIcon(i);
                 if (m_pixmap.width() > maxIconWidth)
@@ -389,7 +383,7 @@ void ThemePage::load()
 void ThemePage::defaults()
 {
     view->selectionModel()->clear();
-    QModelIndex defaultIndex = proxy->findIndex("Oxygen_Black");
+    QModelIndex defaultIndex = proxy->findIndex("Oxygen_White");
     view->setCurrentIndex(defaultIndex);
     preferredSize = 0;
     updateSizeComboBox();
@@ -428,16 +422,6 @@ void ThemePage::preferredSizeChanged()
         preferredSize = 0;
 }
 
-void ThemePage::getNewClicked()
-{
-    KNS3::DownloadDialog dialog("xcursor.knsrc", this);
-    if (dialog.exec()) {
-        KNS3::Entry::List list = dialog.changedEntries();
-        if (list.count() > 0)
-            model->refreshList();
-    }
-}
-
 void ThemePage::installClicked()
 {
     // Get the URL for the theme we're going to install
@@ -514,33 +498,38 @@ void ThemePage::removeClicked()
 
 bool ThemePage::installThemes(const QString &file)
 {
-    KTar archive(file);
+    KArchive archive(file);
 
-    if (!archive.open(QIODevice::ReadOnly))
+    if (!archive.isReadable())
         return false;
 
-    const KArchiveDirectory *archiveDir = archive.directory();
     QStringList themeDirs;
 
     // Extract the dir names of the cursor themes in the archive, and
     // append them to themeDirs
-    foreach(const QString &name, archiveDir->entries())
+    QList<KArchiveEntry> entries = archive.list();
+    foreach(const KArchiveEntry &entry, entries)
     {
-        const KArchiveEntry *entry = archiveDir->entry(name);
-        if (entry->isDirectory() && entry->name().toLower() != "default")
+        if (entry.pathname.contains("/cursors/"))
         {
-            const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(entry);
-            if (dir->entry("index.theme") && dir->entry("cursors"))
-                themeDirs << dir->name();
+            QString entryDir = QFileInfo(QFile::decodeName(entry.pathname)).path();
+            entryDir = entryDir.replace(QLatin1String("/cursors"), QString());
+            if (!archive.entry(entryDir + "/index.theme").isNull()) {
+                if (QFileInfo(entryDir).filePath().toLower() == QLatin1String("default")) {
+                    kDebug() << "ignoring default theme";
+                    continue;
+                }
+                themeDirs << entryDir;
+            }
         }
     }
+    themeDirs.removeDuplicates();
 
     if (themeDirs.isEmpty())
         return false;
 
     // The directory we'll install the themes to
     QString destDir = QDir::homePath() + "/.icons/";
-    KStandardDirs::makeDir(destDir); // Make sure the directory exists
 
     // Process each cursor theme in the archive
     foreach (const QString &dirName, themeDirs)
@@ -562,20 +551,28 @@ bool ThemePage::installThemes(const QString &file)
             //     will cause cursor inconsistencies in newly started apps.
         }
 
+        
+        KStandardDirs::makeDir(destDir + dirName); // Make sure the directory exists
+
         // ### Should we check if a theme with the same name exists in a global theme dir?
         //     If that's the case it will effectively replace it, even though the global theme
         //     won't be deleted. Checking for this situation is easy, since the global theme
         //     will be in the listview. Maybe this should never be allowed since it might
         //     result in strange side effects (from the average users point of view). OTOH
         //     a user might want to do this 'upgrade' a global theme.
-
-        const KArchiveDirectory *dir = static_cast<const KArchiveDirectory*>
-                        (archiveDir->entry(dirName));
-        dir->copyTo(dest.path());
+        QStringList themeFiles;
+        entries = archive.list(dirName);
+        foreach(const KArchiveEntry &entry, entries)
+        {
+            themeFiles << QFile::decodeName(entry.pathname);
+        }
+        if (!archive.extract(themeFiles, destDir)) {
+            kWarning() << archive.errorString();
+            return false;
+        }
         model->addTheme(dest);
     }
 
-    archive.close();
     return true;
 }
 
