@@ -24,13 +24,14 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kglobalsettings.h>
+#include <kicon.h>
 
 #include <QtGui/QMessageBox>
 #include <QtGui/QWidget>
 #include <QtGui/QCheckBox>
 #include <QtGui/QPixmap>
 #include <QtGui/QVBoxLayout>
-#include <QtGui/QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 #include "keyboard_config.h"
 #include "preview/keyboardpainter.h"
