@@ -18,12 +18,12 @@
 #ifndef SELECT_SCHEME_DIALOG_H
 #define SELECT_SCHEME_DIALOG_H
 
-#include "KDialog"
+#include <KDialog>
+#include <KUrl>
 
-namespace Ui
-{
-class SelectSchemeDialog;
-}
+QT_BEGIN_NAMESPACE
+class Ui_SelectSchemeDialog;
+QT_END_NAMESPACE
 
 class SelectSchemeDialog : public KDialog
 {
@@ -39,7 +39,7 @@ private slots:
     void slotUrlChanged(const QString &);
 
 private:
-    Ui::SelectSchemeDialog *ui;
+    Ui_SelectSchemeDialog *ui;
     QStringList m_schemes;
 }; // SelectSchemeDialog
 
