@@ -27,22 +27,20 @@
 #include <QtCore/QSettings>
 #include <QtCore/QTextCodec>
 #include <QToolTip>
-//Added by qt3to4:
 #include <QPixmap>
 #include <QByteArray>
 #include <QTextStream>
 #include <QDateTime>
-#include <QtDBus/QtDBus>
+#include <QProcess>
+
 #include <ktoolinvocation.h>
 #include <klauncher_iface.h>
-
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kdebug.h>
 #include <kglobalsettings.h>
 #include <kstandarddirs.h>
-#include <kprocess.h>
 #include <ksavefile.h>
 #include <ktemporaryfile.h>
 #include <klocale.h>
@@ -51,7 +49,7 @@
 #include "krdb.h"
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #endif
 inline const char * gtkEnvVar(int version)
 {
@@ -105,7 +103,7 @@ static void applyGtkStyles(bool active, int version)
 
 // -----------------------------------------------------------------------------
 
-static void applyQtColors( KSharedConfigPtr kglobalcfg, QSettings& settings, QPalette& newPal )
+static void applyQtColors( QSettings& settings, QPalette& newPal )
 {
   QStringList actcg, inactcg, discg;
   /* export kde color settings */
@@ -120,49 +118,9 @@ static void applyQtColors( KSharedConfigPtr kglobalcfg, QSettings& settings, QPa
      discg   << newPal.color(QPalette::Disabled,
                 (QPalette::ColorRole) i).name();
 
-  settings.setValue("/qt/Palette/active", actcg);
-  settings.setValue("/qt/Palette/inactive", inactcg);
-  settings.setValue("/qt/Palette/disabled", discg);
-
-  // export kwin's colors to qtrc for kstyle to use
-  KConfigGroup wmCfgGroup(kglobalcfg, "WM");
-
-  // active colors
-  QColor clr = newPal.color( QPalette::Active, QPalette::Background );
-  clr = wmCfgGroup.readEntry("activeBackground", clr);
-  settings.setValue("/qt/KWinPalette/activeBackground", clr.name());
-  if (QPixmap::defaultDepth() > 8)
-    clr = clr.dark(110);
-  clr = wmCfgGroup.readEntry("activeBlend", clr);
-  settings.setValue("/qt/KWinPalette/activeBlend", clr.name());
-  clr = newPal.color( QPalette::Active, QPalette::HighlightedText );
-  clr = wmCfgGroup.readEntry("activeForeground", clr);
-  settings.setValue("/qt/KWinPalette/activeForeground", clr.name());
-  clr = newPal.color( QPalette::Active,QPalette::Background );
-  clr = wmCfgGroup.readEntry("frame", clr);
-  settings.setValue("/qt/KWinPalette/frame", clr.name());
-  clr = wmCfgGroup.readEntry("activeTitleBtnBg", clr);
-  settings.setValue("/qt/KWinPalette/activeTitleBtnBg", clr.name());
-
-  // inactive colors
-  clr = newPal.color(QPalette::Inactive, QPalette::Background);
-  clr = wmCfgGroup.readEntry("inactiveBackground", clr);
-  settings.setValue("/qt/KWinPalette/inactiveBackground", clr.name());
-  if (QPixmap::defaultDepth() > 8)
-    clr = clr.dark(110);
-  clr = wmCfgGroup.readEntry("inactiveBlend", clr);
-  settings.setValue("/qt/KWinPalette/inactiveBlend", clr.name());
-  clr = newPal.color(QPalette::Inactive, QPalette::Background).dark();
-  clr = wmCfgGroup.readEntry("inactiveForeground", clr);
-  settings.setValue("/qt/KWinPalette/inactiveForeground", clr.name());
-  clr = newPal.color(QPalette::Inactive, QPalette::Background);
-  clr = wmCfgGroup.readEntry("inactiveFrame", clr);
-  settings.setValue("/qt/KWinPalette/inactiveFrame", clr.name());
-  clr = wmCfgGroup.readEntry("inactiveTitleBtnBg", clr);
-  settings.setValue("/qt/KWinPalette/inactiveTitleBtnBg", clr.name());
-
-  KConfigGroup kdeCfgGroup(kglobalcfg, "KDE");
-  settings.setValue("/qt/KDE/contrast", kdeCfgGroup.readEntry("contrast", 7));
+  settings.setValue("Qt/Palette/active", actcg);
+  settings.setValue("Qt/Palette/inactive", inactcg);
+  settings.setValue("Qt/Palette/disabled", discg);
 }
 
 // -----------------------------------------------------------------------------
@@ -170,29 +128,30 @@ static void applyQtColors( KSharedConfigPtr kglobalcfg, QSettings& settings, QPa
 static void applyQtSettings( KSharedConfigPtr kglobalcfg, QSettings& settings )
 {
   /* export font settings */
-  settings.setValue("/qt/font", KGlobalSettings::generalFont().toString());
+  KConfigGroup fontgrp( kglobalcfg, "General" );
+  QString font = fontgrp.readEntry("font", QString());
+  settings.setValue("Qt/font", font);
 
   /* export effects settings */
-  KConfigGroup kdeCfgGroup(kglobalcfg, "General");
-  bool effectsEnabled = kdeCfgGroup.readEntry("EffectsEnabled", false);
-  bool fadeMenus = kdeCfgGroup.readEntry("EffectFadeMenu", false);
-  bool fadeTooltips = kdeCfgGroup.readEntry("EffectFadeTooltip", false);
-  bool animateCombobox = kdeCfgGroup.readEntry("EffectAnimateCombo", false);
+  KConfigGroup guigrp( kglobalcfg, "KDE-Global GUI Settings" );
+  int graphicEffects = guigrp.readEntry("GraphicEffectsLevel", int(KGlobalSettings::graphicEffectsLevelDefault()));
+  KGlobalSettings::GraphicEffects graphicEffectsFlags = KGlobalSettings::GraphicEffects(graphicEffects);
+  bool effectsEnabled = (graphicEffectsFlags != KGlobalSettings::NoEffects);
+  bool complexEffects = (graphicEffectsFlags & KGlobalSettings::ComplexAnimationEffects);
 
   QStringList guieffects;
   if (effectsEnabled) {
     guieffects << QString("general");
-    if (fadeMenus)
+    // the fade effect requires compositor and as such is enabled only when complex animation is on
+    if (complexEffects) {
       guieffects << QString("fademenu");
-    if (animateCombobox)
-      guieffects << QString("animatecombo");
-    if (fadeTooltips)
       guieffects << QString("fadetooltip");
-  }
-  else
+    }
+  } else {
     guieffects << QString("none");
+  }
 
-  settings.setValue("/qt/GUIEffects", guieffects);
+  settings.setValue("Qt/GUIEffects", guieffects);
 }
 
 // -----------------------------------------------------------------------------
@@ -235,14 +194,15 @@ static QString color( const QColor& col )
     return QString( "{ %1, %2, %3 }" ).arg( item( col.red() ) ).arg( item( col.green() ) ).arg( item( col.blue() ) );
 }
 
-static void createGtkrc( bool exportColors, const QPalette& cg, bool exportGtkTheme, const QString& gtkTheme, int version )
+static void createGtkrc( bool exportColors, const QPalette& cg, int version )
 {
     // lukas: why does it create in ~/.kde/share/config ???
     // pfeiffer: so that we don't overwrite the user's gtkrc.
     // it is found via the GTK_RC_FILES environment variable.
     KSaveFile saveFile( KStandardDirs::locateLocal( "config", 2==version?"gtkrc-2.0":"gtkrc" ) );
-    if ( !saveFile.open() )
+    if ( !saveFile.open() ) {
         return;
+    }
 
     QTextStream t ( &saveFile );
     t.setCodec( QTextCodec::codecForLocale () );
@@ -262,64 +222,6 @@ static void createGtkrc( bool exportColors, const QPalette& cg, bool exportGtkTh
         t << endl;
     }
 
-    if (exportGtkTheme)
-    {
-        QString gtkStyle;
-        if (gtkTheme.toLower() == "oxygen")
-            gtkStyle = QString("oxygen-gtk");
-        else
-            gtkStyle = gtkTheme;
-
-        bool exist_gtkrc = false;
-        QByteArray gtkrc = getenv(gtkEnvVar(version));
-        QStringList listGtkrc = QFile::decodeName(gtkrc).split(":");
-        if (listGtkrc.contains(saveFile.fileName()))
-            listGtkrc.removeAll(saveFile.fileName());
-        listGtkrc.append(QDir::homePath() + userGtkrc(version));
-        listGtkrc.append(QDir::homePath() + "/.gtkrc-2.0-kde");
-        listGtkrc.append(QDir::homePath() + "/.gtkrc-2.0-kde4");
-        listGtkrc.removeAll("");
-        listGtkrc.removeDuplicates();
-        for (int i = 0; i < listGtkrc.size(); ++i)
-        {
-            if ((exist_gtkrc = QFile::exists(listGtkrc.at(i))))
-                break;
-        }
-
-        if (!exist_gtkrc)
-        {
-            QString gtk2ThemeFilename;
-            gtk2ThemeFilename = QString("%1/.themes/%2/gtk-2.0/gtkrc").arg(QDir::homePath()).arg(gtkStyle);
-            if (!QFile::exists(gtk2ThemeFilename)) {
-                QStringList gtk2ThemePath;
-                gtk2ThemeFilename.clear();
-                QByteArray xdgDataDirs = getenv("XDG_DATA_DIRS");
-                gtk2ThemePath.append(QDir::homePath() + "/.local");
-                gtk2ThemePath.append(QFile::decodeName(xdgDataDirs).split(":"));
-                gtk2ThemePath.removeDuplicates();
-                for (int i = 0; i < gtk2ThemePath.size(); ++i)
-                {
-                    gtk2ThemeFilename = QString("%1/themes/%2/gtk-2.0/gtkrc").arg(gtk2ThemePath.at(i)).arg(gtkStyle);
-                    if (QFile::exists(gtk2ThemeFilename))
-                        break;
-                    else
-                        gtk2ThemeFilename.clear();
-                }
-            }
-
-            if (!gtk2ThemeFilename.isEmpty())
-            {
-                t << "include \"" << gtk2ThemeFilename << "\"" << endl;
-                t << endl;
-                t << "gtk-theme-name=\"" << gtkStyle << "\"" << endl;
-                t << endl;
-                if (gtkStyle == "oxygen-gtk")
-                    exportColors = false;
-            }
-        }
-
-    }
-
     if (exportColors)
     {
         t << "style \"default\"" << endl;
@@ -390,7 +292,6 @@ void runRdb( uint flags )
   bool exportQtColors    = flags & KRdbExportQtColors;
   bool exportQtSettings  = flags & KRdbExportQtSettings;
   bool exportXftSettings = flags & KRdbExportXftSettings;
-  bool exportGtkTheme    = flags & KRdbExportGtkTheme;
 
   KSharedConfigPtr kglobalcfg = KSharedConfig::openConfig( "kdeglobals" );
   KConfigGroup kglobals(kglobalcfg, "KDE");
@@ -403,17 +304,10 @@ void runRdb( uint flags )
     exit(0);
   }
 
-
   KConfigGroup generalCfgGroup(kglobalcfg, "General");
 
-  QString gtkTheme;
-  if (generalCfgGroup.hasKey("widgetStyle"))
-    gtkTheme = generalCfgGroup.readEntry("widgetStyle");
-  else
-    gtkTheme = "oxygen";
-
-  createGtkrc( exportColors, newPal, exportGtkTheme, gtkTheme, 1 );
-  createGtkrc( exportColors, newPal, exportGtkTheme, gtkTheme, 2 );
+  createGtkrc( exportColors, newPal, 1 );
+  createGtkrc( exportColors, newPal, 2 );
 
   // Export colors to non-(KDE/Qt) apps (e.g. Motif, GTK+ apps)
   if (exportColors)
@@ -421,6 +315,7 @@ void runRdb( uint flags )
     KGlobal::dirs()->addResourceType("appdefaults", "data", "kdisplay/app-defaults/");
     KGlobal::locale()->insertCatalog("krdb");
 
+#warning FIXME: KGlobalSettings race, palette settings may not be reloaded yet
     QString preproc;
     QColor backCol = newPal.color( QPalette::Active, QPalette::Background );
     addColorDef(preproc, "FOREGROUND"         , newPal.color( QPalette::Active, QPalette::Foreground ) );
@@ -520,9 +415,8 @@ void runRdb( uint flags )
       contents += "Xft.dpi: " + cfgfonts.readEntry( "forceFontDPI" ) + '\n';
     else
     {
-      KProcess proc;
-      proc << "xrdb" << "-quiet" << "-remove" << "-nocpp";
-      proc.start();
+      QProcess proc;
+      proc.start("xrdb", QStringList() << "-quiet" << "-remove" << "-nocpp");
       if (proc.waitForStarted())
       {
         proc.write( QByteArray( "Xft.dpi\n" ) );
@@ -537,54 +431,51 @@ void runRdb( uint flags )
 
   tmpFile.flush();
 
-  KProcess proc;
+  QStringList procargs;
 #ifndef NDEBUG
-  proc << "xrdb" << "-merge" << tmpFile.fileName();
+  procargs << "-merge" << tmpFile.fileName();
 #else
-  proc << "xrdb" << "-quiet" << "-merge" << tmpFile.fileName();
+  procargs << "-quiet" << "-merge" << tmpFile.fileName();
 #endif
-  proc.execute();
+  QProcess::execute("xrdb", procargs);
 
   applyGtkStyles(exportColors, 1);
   applyGtkStyles(exportColors, 2);
 
-  /* Qt exports */
+  /* Katie exports */
   if ( exportQtColors || exportQtSettings )
   {
-    QSettings* settings = new QSettings(QLatin1String("Trolltech"));
+    {
+      QSettings settings(QLatin1String("Katie"), QSettings::NativeFormat);
 
-    if ( exportQtColors )
-      applyQtColors( kglobalcfg, *settings, newPal );    // For kcmcolors
+      if ( exportQtColors )
+        applyQtColors( settings, newPal );    // For kcmcolors
 
-    if ( exportQtSettings )
-      applyQtSettings( kglobalcfg, *settings );          // For kcmstyle
+      if ( exportQtSettings )
+        applyQtSettings( kglobalcfg, settings );          // For kcmstyle
+    }
 
-    delete settings;
     QApplication::flush();
 #ifdef Q_WS_X11
     // We let KIPC take care of ourselves, as we are in a KDE app with
     // QApp::setDesktopSettingsAware(false);
     // Instead of calling QApp::x11_apply_settings() directly, we instead
     // modify the timestamp which propagates the settings changes onto
-    // Qt-only apps without adversely affecting ourselves.
+    // Katie-only apps without adversely affecting ourselves.
 
     // Cheat and use the current timestamp, since we just saved to qtrc.
     QDateTime settingsstamp = QDateTime::currentDateTime();
 
-    static Atom qt_settings_timestamp = 0;
-    if (!qt_settings_timestamp) {
-	 QString atomname("_QT_SETTINGS_TIMESTAMP_");
-	 atomname += XDisplayName( 0 ); // Use the $DISPLAY envvar.
-	 qt_settings_timestamp = XInternAtom( QX11Info::display(), atomname.toLatin1(), False);
-    }
+    static const QByteArray atomname("_QT_SETTINGS_TIMESTAMP");
+    static Atom qt_settings_timestamp = XInternAtom( QX11Info::display(), atomname.constData(), False);
 
     QBuffer stamp;
     QDataStream s(&stamp.buffer(), QIODevice::WriteOnly);
     s << settingsstamp;
     XChangeProperty( QX11Info::display(), QX11Info::appRootWindow(), qt_settings_timestamp,
-		     qt_settings_timestamp, 8, PropModeReplace,
-		     (unsigned char*) stamp.buffer().data(),
-		     stamp.buffer().size() );
+                     qt_settings_timestamp, 8, PropModeReplace,
+                     (unsigned char*) stamp.buffer().data(),
+                     stamp.buffer().size() );
     QApplication::flush();
 #endif
   }
