@@ -43,14 +43,13 @@
 #include <kautostart.h>
 #include <KDebug>
 #include <KNotification>
-#include <KLibrary>
 #include <KColorScheme>
 #include <KStandardDirs>
-#include <knewstuff3/downloaddialog.h>
 #ifdef Q_WS_X11
 #include <kdecoration.h>
 #endif
-
+#include <kpluginfactory.h>
+#include <kpluginloader.h>
 
 #include <QtCore/QFile>
 #include <QtCore/QSettings>
@@ -63,9 +62,10 @@
 #include <QtGui/QStandardItemModel>
 #include <QtGui/QStyle>
 #include <QtDBus/QtDBus>
+#include <QtCore/qlibraryinfo.h>
 
 #ifdef Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #endif
 
 #include "../krdb/krdb.h"
@@ -82,9 +82,6 @@
 
 /**** DLL Interface for kcontrol ****/
 
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-
 K_PLUGIN_FACTORY(KCMStyleFactory, registerPlugin<KCMStyle>();)
 K_EXPORT_PLUGIN(KCMStyleFactory("kcmstyle"))
 
@@ -93,7 +90,7 @@ extern "C"
 {
     KDE_EXPORT void kcminit_style()
     {
-        uint flags = KRdbExportQtSettings | KRdbExportQtColors | KRdbExportXftSettings | KRdbExportGtkTheme;
+        uint flags = KRdbExportQtSettings | KRdbExportQtColors | KRdbExportXftSettings;
         KConfig _config( "kcmdisplayrc", KConfig::NoGlobals  );
         KConfigGroup config(&_config, "X11");
 
@@ -102,24 +99,6 @@ extern "C"
         if (exportKDEColors)
             flags |= KRdbExportColors;
         runRdb( flags );
-
-        // Write some Qt root property.
-#ifdef Q_WS_X11
-#ifndef __osf__      // this crashes under Tru64 randomly -- will fix later
-        QByteArray properties;
-        QDataStream d(&properties, QIODevice::WriteOnly);
-        d.setVersion( 3 );      // Qt2 apps need this.
-        d << kapp->palette() << KGlobalSettings::generalFont();
-        Atom a = XInternAtom(QX11Info::display(), "_QT_DESKTOP_PROPERTIES", false);
-
-        // do it for all root windows - multihead support
-        int screen_count = ScreenCount(QX11Info::display());
-        for (int i = 0; i < screen_count; i++)
-            XChangeProperty(QX11Info::display(), RootWindow(QX11Info::display(), i),
-                            a, a, 8, PropModeReplace,
-                            (unsigned char*) properties.data(), properties.size());
-#endif
-#endif
     }
 }
 
@@ -252,11 +231,8 @@ KCMStyle::KCMStyle( QWidget* parent, const QVariantList& )
     fineTuningUi.comboGraphicEffectsLevel->setObjectName( "cbGraphicEffectsLevel" );
     fineTuningUi.comboGraphicEffectsLevel->setEditable( false );
     fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("Low display resolution and Low CPU"), KGlobalSettings::NoEffects);
-    fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("High display resolution and Low CPU"), KGlobalSettings::GradientEffects);
     fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("Low display resolution and High CPU"), KGlobalSettings::SimpleAnimationEffects);
-    fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("High display resolution and High CPU"), (int) (KGlobalSettings::SimpleAnimationEffects | KGlobalSettings::GradientEffects));
-    fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("Low display resolution and Very High CPU"), KGlobalSettings::ComplexAnimationEffects);
-    fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("High display resolution and Very High CPU"), (int) (KGlobalSettings::ComplexAnimationEffects | KGlobalSettings::GradientEffects));
+    fineTuningUi.comboGraphicEffectsLevel->addItem(i18n("High display resolution and High CPU"), static_cast<int>(KGlobalSettings::SimpleAnimationEffects | KGlobalSettings::ComplexAnimationEffects));
 
     connect(cbStyle, SIGNAL(activated(int)), this, SLOT(setStyleDirty()));
     connect(fineTuningUi.cbIconsOnButtons,     SIGNAL(toggled(bool)),   this, SLOT(setEffectsDirty()));
@@ -264,13 +240,29 @@ KCMStyle::KCMStyle( QWidget* parent, const QVariantList& )
     connect(fineTuningUi.comboGraphicEffectsLevel, SIGNAL(activated(int)),   this, SLOT(setEffectsDirty()));
     connect(fineTuningUi.comboToolbarIcons,    SIGNAL(activated(int)), this, SLOT(setEffectsDirty()));
     connect(fineTuningUi.comboSecondaryToolbarIcons,    SIGNAL(activated(int)), this, SLOT(setEffectsDirty()));
-    connect(fineTuningUi.comboMenubarStyle,    SIGNAL(activated(int)), this, SLOT(setEffectsDirty()));
 
-    addWhatsThis();
-
-    if (!QFile::exists(QLibraryInfo::location(QLibraryInfo::PluginsPath) + "/menubar/libappmenu-qt.so")) {
-        fineTuningUi.menubarBox->hide();
-    }
+    // Page1
+    cbStyle->setWhatsThis( i18n("Here you can choose from a list of"
+                            " predefined widget styles (e.g. the way buttons are drawn) which"
+                            " may or may not be combined with a theme (additional information"
+                            " like a marble texture or a gradient).") );
+    stylePreview->setWhatsThis( i18n("This area shows a preview of the currently selected style "
+                            "without having to apply it to the whole desktop.") );
+    // Page2
+    page2->setWhatsThis( i18n("This page allows you to choose details about the widget style options") );
+    fineTuningUi.comboToolbarIcons->setWhatsThis( i18n( "<p><b>No Text:</b> Shows only icons on toolbar buttons. "
+                            "Best option for low resolutions.</p>"
+                            "<p><b>Text Only: </b>Shows only text on toolbar buttons.</p>"
+                            "<p><b>Text Beside Icons: </b> Shows icons and text on toolbar buttons. "
+                            "Text is aligned beside the icon.</p>"
+                            "<b>Text Below Icons: </b> Shows icons and text on toolbar buttons. "
+                            "Text is aligned below the icon.") );
+    fineTuningUi.cbIconsOnButtons->setWhatsThis( i18n( "If you enable this option, KDE Applications will "
+                            "show small icons alongside some important buttons.") );
+    fineTuningUi.cbIconsInMenus->setWhatsThis( i18n( "If you enable this option, KDE Applications will "
+                            "show small icons alongside most menu items.") );
+    fineTuningUi.comboGraphicEffectsLevel->setWhatsThis( i18n( "If you enable this option, KDE Applications will "
+                            "run internal animations.") );
 
     // Insert the pages into the tabWidget
     tabWidget->addTab(page1, i18nc("@title:tab", "&Applications"));
@@ -301,7 +293,8 @@ void KCMStyle::styleSpecificConfig()
 {
     QString libname = styleEntries[currentStyle()]->configPage;
 
-    KLibrary library(libname, KCMStyleFactory::componentData());
+#warning port loader to KPluginLoader
+    QLibrary library(libname); // , KCMStyleFactory::componentData());
     if (!library.load()) {
         KMessageBox::detailedError(this,
             i18n("There was an error loading the configuration dialog for this style."),
@@ -310,7 +303,7 @@ void KCMStyle::styleSpecificConfig()
         return;
     }
 
-    KLibrary::void_function_ptr allocPtr = library.resolveFunction("allocate_kstyle_config");
+    void *allocPtr = library.resolve("allocate_kstyle_config");
 
     if (!allocPtr)
     {
@@ -394,14 +387,15 @@ void KCMStyle::save()
     }
 
     // Save effects.
-        KConfig      _config("kdeglobals", KConfig::NoGlobals);
-        KConfigGroup config(&_config, "KDE");
+    KConfig      _config("kdeglobals", KConfig::NoGlobals);
+    KConfigGroup config(&_config, "KDE");
     // Effects page
     config.writeEntry( "ShowIconsOnPushButtons", fineTuningUi.cbIconsOnButtons->isChecked());
     config.writeEntry( "ShowIconsInMenuItems", fineTuningUi.cbIconsInMenus->isChecked());
     KConfigGroup g( &_config, "KDE-Global GUI Settings" );
     g.writeEntry( "GraphicEffectsLevel", fineTuningUi.comboGraphicEffectsLevel->itemData(fineTuningUi.comboGraphicEffectsLevel->currentIndex()));
 
+
     KConfigGroup generalGroup(&_config, "General");
     generalGroup.writeEntry("widgetStyle", currentStyle());
 
@@ -411,96 +405,14 @@ void KCMStyle::save()
     toolbarStyleGroup.writeEntry("ToolButtonStyleOtherToolbars",
                             toolbarButtonText(fineTuningUi.comboSecondaryToolbarIcons->currentIndex()));
 
-    // menubar page
-    KConfigGroup menuBarStyleGroup(&_config, "Appmenu Style");
-
-    // load kded module if needed
-    bool load = false;
-    QList<QVariant> args;
-
-    QString style = menuBarStyleText(fineTuningUi.comboMenubarStyle->currentIndex());
-
-    QString previous = menuBarStyleGroup.readEntry("Style", "InApplication");
-    menuBarStyleGroup.writeEntry("Style", style);
     _config.sync();
 
-    QDBusMessage method = QDBusMessage::createMethodCall("org.kde.kded",
-                                                         "/modules/appmenu",
-                                                         "org.kde.kded",
-                                                         "reconfigure");
-    QDBusConnection::sessionBus().asyncCall(method);
-
-    if (previous == "InApplication" && style != "InApplication") {
-        load = true;
-        KNotification *notification = new KNotification("reload", 0);
-        notification->setComponentData(KComponentData("kcmstyle"));
-        notification->setText(i18n("Settings changes will take effect only on application restart"));
-        notification->sendEvent();
-    }
-
-#ifdef Q_WS_X11
-    // If user select ButtonVertical, we add (if needed) a button to titlebar
-    if (style == "ButtonVertical") {
-        KConfig _kwinConfig("kwinrc", KConfig::NoGlobals);
-        KConfigGroup kwinConfig(&_kwinConfig, "Style");
-        QString buttonsOnLeft = kwinConfig.readEntry("ButtonsOnLeft", KDecorationOptions::defaultTitleButtonsLeft());
-        QString buttonsOnRight = kwinConfig.readEntry("ButtonsOnRight", KDecorationOptions::defaultTitleButtonsRight());
-        qDebug() << buttonsOnLeft << buttonsOnRight;
-        if (!buttonsOnLeft.contains("N") && !buttonsOnRight.contains("N")) {
-            buttonsOnLeft = "N" + buttonsOnLeft;
-        }
-        kwinConfig.writeEntry("ButtonsOnLeft", buttonsOnLeft);
-        kwinConfig.writeEntry("CustomButtonPositions", "true");
-    }
-#endif
-
-    args = QList<QVariant>() << "appmenu" << (style != "InApplication");
-    method = QDBusMessage::createMethodCall("org.kde.kded",
-                                            "/kded",
-                                            "org.kde.kded",
-                                            "setModuleAutoloading");
-    method.setArguments(args);
-    QDBusConnection::sessionBus().asyncCall(method);
-
-    args = QList<QVariant>() << "appmenu";
-    if (load) {
-        method = QDBusMessage::createMethodCall("org.kde.kded",
-                                                "/kded",
-                                                "org.kde.kded",
-                                                "loadModule");
-        QDBusMessage method = QDBusMessage::createMethodCall("org.kde.kded", "/modules/appmenu", "org.kde.kded", "reconfigure");
-        QDBusConnection::sessionBus().asyncCall(method);
-    } else if (style == "InApplication") {
-        method = QDBusMessage::createMethodCall("org.kde.kded",
-                                                "/kded",
-                                                "org.kde.kded",
-                                                "unloadModule");
-    }
-    method.setArguments(args);
-    QDBusConnection::sessionBus().asyncCall(method);
-
-    // Export the changes we made to qtrc, and update all qt-only
-    // applications on the fly, ensuring that we still follow the user's
-    // export fonts/colors settings.
-    if (m_bStyleDirty | m_bEffectsDirty)    // Export only if necessary
-    {
-        uint flags = KRdbExportQtSettings | KRdbExportGtkTheme;
-        KConfig _kconfig( "kcmdisplayrc", KConfig::NoGlobals  );
-        KConfigGroup kconfig(&_kconfig, "X11");
-        bool exportKDEColors = kconfig.readEntry("exportKDEColors", true);
-        if (exportKDEColors)
-            flags |= KRdbExportColors;
-        runRdb( flags );
-    }
-
     // Now allow KDE apps to reconfigure themselves.
     if ( m_bStyleDirty )
         KGlobalSettings::self()->emitChange(KGlobalSettings::StyleChanged);
 
     if ( m_bEffectsDirty ) {
         KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged, KGlobalSettings::SETTINGS_STYLE);
-        // ##### FIXME - Doesn't apply all settings correctly due to bugs in
-        // KApplication/KToolbar
         KGlobalSettings::self()->emitChange(KGlobalSettings::ToolbarStyleChanged);
 
 #ifdef Q_WS_X11
@@ -511,6 +423,20 @@ void KCMStyle::save()
 #endif
     }
 
+    // Export the changes we made to qtrc, and update all qt-only
+    // applications on the fly, ensuring that we still follow the user's
+    // export fonts/colors settings.
+    if (m_bStyleDirty | m_bEffectsDirty)    // Export only if necessary
+    {
+        uint flags = KRdbExportQtSettings;
+        KConfig _kconfig( "kcmdisplayrc", KConfig::NoGlobals  );
+        KConfigGroup kconfig(&_kconfig, "X11");
+        bool exportKDEColors = kconfig.readEntry("exportKDEColors", true);
+        if (exportKDEColors)
+            flags |= KRdbExportColors;
+        runRdb( flags );
+    }
+
     // Clean up
     m_bStyleDirty    = false;
     m_bEffectsDirty  = false;
@@ -548,13 +474,11 @@ void KCMStyle::defaults()
 
     found = findStyle( KStyle::defaultStyle(), item );
     if (!found)
-        found = findStyle( "plastique", item );
+        found = findStyle( "oxygen", item );
+    if (!found)
+        found = findStyle( "cleanlooks", item );
     if (!found)
         found = findStyle( "windows", item );
-    if (!found)
-        found = findStyle( "platinum", item );
-    if (!found)
-        found = findStyle( "motif", item );
 
     cbStyle->setCurrentIndex( item );
 
@@ -564,10 +488,9 @@ void KCMStyle::defaults()
     // Effects
     fineTuningUi.comboToolbarIcons->setCurrentIndex(toolbarButtonIndex("TextBesideIcon"));
     fineTuningUi.comboSecondaryToolbarIcons->setCurrentIndex(toolbarButtonIndex("TextBesideIcon"));
-    fineTuningUi.comboMenubarStyle->setCurrentIndex(menuBarStyleIndex("InApplication"));
     fineTuningUi.cbIconsOnButtons->setChecked(true);
     fineTuningUi.cbIconsInMenus->setChecked(true);
-    fineTuningUi.comboGraphicEffectsLevel->setCurrentIndex(fineTuningUi.comboGraphicEffectsLevel->findData(((int) KGlobalSettings::graphicEffectsLevelDefault())));
+    fineTuningUi.comboGraphicEffectsLevel->setCurrentIndex(fineTuningUi.comboGraphicEffectsLevel->findData(static_cast<int>(KGlobalSettings::graphicEffectsLevelDefault())));
     emit changed(true);
 }
 
@@ -618,10 +541,6 @@ void KCMStyle::loadStyle( KConfig& config )
         entry->desc = configGroup.readEntry("Comment", i18n("No description available."));
         entry->configPage = configGroup.readEntry("ConfigPage", QString());
 
-        // Check if this style should be shown
-        configGroup = config.group("Desktop Entry");
-        entry->hidden = configGroup.readEntry("Hidden", false);
-
         // Insert the entry into our dictionary.
         styleEntries.insert(strWidgetStyle.toLower(), entry);
     }
@@ -629,7 +548,7 @@ void KCMStyle::loadStyle( KConfig& config )
     // Obtain all style names
     QStringList allStyles = QStyleFactory::keys();
 
-    // Get translated names, remove all hidden style entries.
+    // Get translated names
     QStringList styles;
     StyleEntry* entry;
     for (QStringList::iterator it = allStyles.begin(); it != allStyles.end(); ++it)
@@ -638,10 +557,6 @@ void KCMStyle::loadStyle( KConfig& config )
         // Find the entry.
         if ( (entry = styleEntries[id]) != 0 )
         {
-            // Do not add hidden entries
-            if (entry->hidden)
-                continue;
-
             styles += entry->name;
 
             nameToStyleKey[entry->name] = id;
@@ -786,33 +701,6 @@ int KCMStyle::toolbarButtonIndex(const QString &text)
     return 0;
 }
 
-QString KCMStyle::menuBarStyleText(int index)
-{
-    switch (index) {
-        case 1:
-            return "ButtonVertical";
-        case 2:
-            return "TopMenuBar";
-        case 3:
-            return "Others";
-    }
-
-    return "InApplication";
-}
-
-int KCMStyle::menuBarStyleIndex(const QString &text)
-{
-    if (text == "ButtonVertical") {
-        return 1;
-    } else if (text == "TopMenuBar") {
-        return 2;
-    } else if (text == "Others") {
-        return 3;
-    }
-
-    return 0;
-}
-
 void KCMStyle::loadEffects( KConfig& config )
 {
     // KDE's Part via KConfig
@@ -823,10 +711,6 @@ void KCMStyle::loadEffects( KConfig& config )
     tbIcon = configGroup.readEntry("ToolButtonStyleOtherToolbars", "TextBesideIcon");
     fineTuningUi.comboSecondaryToolbarIcons->setCurrentIndex(toolbarButtonIndex(tbIcon));
 
-    configGroup = config.group("Appmenu Style");
-    QString menuBarStyle = configGroup.readEntry("Style", "InApplication");
-    fineTuningUi.comboMenubarStyle->setCurrentIndex(menuBarStyleIndex(menuBarStyle));
-
     configGroup = config.group("KDE");
     fineTuningUi.cbIconsOnButtons->setChecked(configGroup.readEntry("ShowIconsOnPushButtons", true));
     fineTuningUi.cbIconsInMenus->setChecked(configGroup.readEntry("ShowIconsInMenuItems", true));
@@ -837,32 +721,6 @@ void KCMStyle::loadEffects( KConfig& config )
     m_bEffectsDirty = false;
 }
 
-void KCMStyle::addWhatsThis()
-{
-    // Page1
-    cbStyle->setWhatsThis( i18n("Here you can choose from a list of"
-                            " predefined widget styles (e.g. the way buttons are drawn) which"
-                            " may or may not be combined with a theme (additional information"
-                            " like a marble texture or a gradient).") );
-    stylePreview->setWhatsThis( i18n("This area shows a preview of the currently selected style "
-                            "without having to apply it to the whole desktop.") );
-    // Page2
-    page2->setWhatsThis( i18n("This page allows you to choose details about the widget style options") );
-    fineTuningUi.comboToolbarIcons->setWhatsThis( i18n( "<p><b>No Text:</b> Shows only icons on toolbar buttons. "
-                            "Best option for low resolutions.</p>"
-                            "<p><b>Text Only: </b>Shows only text on toolbar buttons.</p>"
-                            "<p><b>Text Beside Icons: </b> Shows icons and text on toolbar buttons. "
-                            "Text is aligned beside the icon.</p>"
-                            "<b>Text Below Icons: </b> Shows icons and text on toolbar buttons. "
-                            "Text is aligned below the icon.") );
-    fineTuningUi.cbIconsOnButtons->setWhatsThis( i18n( "If you enable this option, KDE Applications will "
-                            "show small icons alongside some important buttons.") );
-    fineTuningUi.cbIconsInMenus->setWhatsThis( i18n( "If you enable this option, KDE Applications will "
-                            "show small icons alongside most menu items.") );
-    fineTuningUi.comboGraphicEffectsLevel->setWhatsThis( i18n( "If you enable this option, KDE Applications will "
-                            "run internal animations.") );
-}
-
-#include "kcmstyle.moc"
+#include "moc_kcmstyle.cpp"
 
 // vim: set noet ts=4:
