@@ -45,4 +45,4 @@ void StyleConfigDialog::setDirty(bool dirty)
   m_dirty = dirty;
 }
 
-#include "styleconfdialog.moc"
+#include "moc_styleconfdialog.cpp"
