@@ -13,12 +13,8 @@
 #include "action_data/action_data_group.h"
 #include "action_data/menuentry_shortcut_action_data.h"
 #include "actions/actions.h"
-
 #include "shortcuts_handler.h"
 
-#include "triggers/gestures.h"
-
-
 #include <kdebug.h>
 #include <kglobalaccel.h>
 #include <kpluginfactory.h>
@@ -98,13 +94,6 @@ void KHotKeysModule::reread_configuration()
     // Load the settings
     _settings.reread_settings(true);
 
-    KHotKeys::gesture_handler->set_mouse_button( _settings.gestureMouseButton() );
-    KHotKeys::gesture_handler->set_timeout( _settings.gestureTimeOut() );
-    kDebug() << _settings.areGesturesDisabled();
-    KHotKeys::gesture_handler->enable( !_settings.areGesturesDisabled() );
-    KHotKeys::gesture_handler->set_exclude( _settings.gesturesExclude() );
-    // FIXME: SOUND
-    // KHotKeys::voice_handler->set_shortcut( _settings.voice_shortcut );
     actions_root = _settings.actions();
     KHotKeys::khotkeys_set_active( true );
     }
@@ -149,7 +138,7 @@ QString KHotKeysModule::get_menuentry_shortcut(const QString &storageId)
     Q_ASSERT(shortcutTrigger);
     if (shortcutTrigger == NULL) return "";
 
-    return shortcutTrigger->shortcut().primary();
+    return shortcutTrigger->shortcut().primary().toString();
     }
 
 
@@ -197,7 +186,7 @@ QString KHotKeysModule::register_menuentry_shortcut(
         _settings.write();
 
         // Return the real shortcut
-        return newAction->trigger()->shortcut().primary();
+        return newAction->trigger()->shortcut().primary().toString();
         }
     // We found a action
     else
@@ -224,7 +213,7 @@ QString KHotKeysModule::register_menuentry_shortcut(
             _settings.write();
 
             // Remove the resulting real shortcut
-            return shortcutTrigger->shortcut().primary();
+            return shortcutTrigger->shortcut().primary().toString();
             }
         }
 
@@ -246,4 +235,4 @@ void KHotKeysModule::save()
     KHotKeys::khotkeys_set_active( true );
     }
 
-#include "kded.moc"
+#include "moc_kded.cpp"
