@@ -27,9 +27,9 @@
 
 #include <QMimeData>
 
-#include <KDE/KDebug>
-#include <KDE/KLocale>
-#include <KDE/KIcon>
+#include <KDebug>
+#include <KLocale>
+#include <KIcon>
 
 
 static KHotKeys::ActionDataBase *findElement(
@@ -267,9 +267,9 @@ bool KHotkeysModel::dropMimeData(
     QList<quintptr> ptrs;
     while (!stream.atEnd())
         {
-        quintptr ptr;
+        qulonglong ptr;
         stream >> ptr;
-        ptrs << ptr;
+        ptrs << quintptr(ptr);
         }
 
     // No pointers, nothing to do
@@ -491,7 +491,7 @@ QMimeData *KHotkeysModel::mimeData(const QModelIndexList &indexes) const
             {
             KHotKeys::ActionDataBase *element = indexToActionDataBase(index);
             // We use the pointer as id.
-            stream << reinterpret_cast<quintptr>(element);
+            stream << qulonglong(reinterpret_cast<quintptr>(element));
             }
         }
 
@@ -602,6 +602,7 @@ bool KHotkeysModel::removeRows( int row, int count, const QModelIndex &parent )
         list = _actions;
         }
     Q_ASSERT(list);
+    Q_UNUSED(list);
 
     KHotKeys::ActionDataBase *action = indexToActionDataBase(index(row,0,parent));
 
