@@ -33,7 +33,7 @@ class KDE_EXPORT ConditionsVisitor
     {
 public:
 
-    ConditionsVisitor( bool recurse = true );
+    ConditionsVisitor();
     virtual ~ ConditionsVisitor();
 
     virtual void visitCondition( Condition *condition ) = 0;
@@ -42,8 +42,6 @@ public:
 
 private:
 
-    bool _recurse;
-
     }; // class ConditionsVisitor
 
 
