@@ -15,10 +15,11 @@
 #define KHOTKEYS_CONFIG_FILE "khotkeysrc"
 
 #include <klocale.h>
+#include <kdemacros.h>
 
 #include <QtCore/QPointer>
 
-class QObject;
+#include <QObject>
 
 namespace KHotKeys
 {
@@ -33,8 +34,6 @@ extern QPointer<WindowsHandler> windows_handler;
 KDE_EXPORT bool khotkeys_active();
 KDE_EXPORT void khotkeys_set_active( bool active_P );
 
-QString get_menu_entry_from_path( const QString& path_P );
-
 KDE_EXPORT void init_global_data( bool active_P, QObject* owner_P );
 
 const char* const MENU_EDITOR_ENTRIES_GROUP_NAME = I18N_NOOP( "Menu Editor entries" );
