@@ -28,7 +28,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <QProcess>
 #include <QTextStream>
 #include <QTreeWidget>
-#include <QTreeWidgetItem>
+#include <QtGui/qtreewidget.h>
 
 #include <kiconloader.h>
 #include <kglobal.h>
@@ -330,15 +330,15 @@ static bool GetInfo_XServer_Generic(QTreeWidget *lBox) {
 }
 
 /* Helper-function to read output from an external program */
-static int GetInfo_ReadfromPipe(QTreeWidget* tree, const char *FileName, bool WithEmptyLines = true) {
+static bool GetInfo_ReadfromPipe(QTreeWidget* tree, const char *FileName, bool WithEmptyLines = true) {
 	QProcess proc;
-	QTreeWidgetItem* olditem= NULL;
+	QTreeWidgetItem* olditem = NULL;
 	QString s;
 
 	proc.start(FileName, QIODevice::ReadOnly);
 	if (!proc.waitForFinished()) {
 		// Process hanged or did not start
-		return 0;
+		return false;
 	}
 
 	QTextStream t(&proc);
@@ -352,7 +352,9 @@ static int GetInfo_ReadfromPipe(QTreeWidget* tree, const char *FileName, bool Wi
 		olditem = new QTreeWidgetItem(tree, list);
 	}
 
-	return tree->topLevelItemCount();
+	// compiler warning
+	Q_UNUSED(olditem)
+	return (tree->topLevelItemCount() > 0);
 }
 
 #endif /*OS_BASE_H_*/
