@@ -71,12 +71,17 @@ void SolDevice::setDefaultDeviceText()
   if(deviceSet) {
     ddtString = tiedDevice.product();
     if (tiedDevice.isDeviceInterface(Solid::DeviceInterface::StorageVolume) ||
-          tiedDevice.isDeviceInterface(Solid::DeviceInterface::SerialInterface) ||
           tiedDevice.isDeviceInterface(Solid::DeviceInterface::Battery)) {
       QString label = SolDevice::udi().section("/", -1, -1);
       if (!label.isEmpty()) {
           ddtString = label;
       }
+    } else if(tiedDevice.isDeviceInterface(Solid::DeviceInterface::Button) && ddtString.isEmpty()) {
+      // button that is not on keyboard for example does not have product/vendor
+      QString label = SolDevice::udi().section("/", -1, -1);
+      if (!label.isEmpty()) {
+          ddtString = label;
+      }
     }
   }
   setText(0,ddtString);
