@@ -23,6 +23,7 @@
 #include "soldevicetypes.h"
 
 #include <kcapacitybar.h>
+#include <kdiskfreespaceinfo.h>
 // ---- Processor
 
 SolProcessorDevice::SolProcessorDevice(QTreeWidgetItem *parent, const Solid::Device &device) :
@@ -120,28 +121,27 @@ void SolStorageDevice::setDefaultDeviceText()
   const Solid::StorageDrive *stodev = interface<const Solid::StorageDrive>();
   if(!stodev) return;
   
-  QString storageType;
+  QString deviceText;
   switch (stodev->driveType())
   {
     case Solid::StorageDrive::HardDisk: 
-      storageType = i18n("Hard Disk Drive");  break;
+      deviceText = i18n("Hard Disk Drive");  break;
     case Solid::StorageDrive::CompactFlash:
-      storageType = i18n("Compact Flash Reader");  break;
+      deviceText = i18n("Compact Flash Reader");  break;
     case Solid::StorageDrive::SmartMedia:
-      storageType = i18n("Smart Media Reader");  break;
+      deviceText = i18n("Smart Media Reader");  break;
     case Solid::StorageDrive::SdMmc:
-      storageType = i18n("SD/MMC Reader"); break;
+      deviceText = i18n("SD/MMC Reader"); break;
     case Solid::StorageDrive::CdromDrive:
-      storageType = i18n("Optical Drive"); break;
+      deviceText = i18n("Optical Drive"); break;
     case Solid::StorageDrive::MemoryStick:
-      storageType = i18n("Memory Stick Reader"); break;
+      deviceText = i18n("Memory Stick Reader"); break;
     case Solid::StorageDrive::Xd:
-      storageType = i18n("xD Reader"); break;
+      deviceText = i18n("xD Reader"); break;
     default:
-      storageType = i18n("Unknown Drive"); 
+      deviceText = i18n("Unknown Drive");
   }
   
-  QString deviceText = storageType;
   setDeviceText(deviceText);
 }
 
@@ -247,8 +247,10 @@ QVListLayout *SolNetworkDevice::infoPanelLayout()
   labels << i18n("Hardware Address: ")
   << InfoPanel::friendlyString(netdev->hwAddress())
   << i18n("Wireless?")
-  << InfoPanel::convertTf(netdev->isWireless());
-  
+  << InfoPanel::convertTf(netdev->isWireless())
+  << i18n("Loopback?")
+  << InfoPanel::convertTf(netdev->isLoopback());
+
   deviceInfoLayout->applyQListToLayout(labels); 
   return deviceInfoLayout;
 }
@@ -662,33 +664,27 @@ QVListLayout *SolBatteryDevice::infoPanelLayout()
   QString type;
   switch(batdev->type()) 
   {
-      case Solid::Battery::PdaBattery:
-	type = i18n("PDA"); break;
-      case Solid::Battery::UpsBattery:
-	type = i18n("UPS"); break;
-      case Solid::Battery::MouseBattery:
-	type = i18n("Mouse"); break;
       case Solid::Battery::PrimaryBattery:
-	type = i18n("Primary"); break;
-      case Solid::Battery::KeyboardBattery:
-	type = i18n("Keyboard"); break;
-      case Solid::Battery::KeyboardMouseBattery:
-	type = i18n("Keyboard + Mouse"); break;
-      case Solid::Battery::CameraBattery:
-	type = i18n("Camera"); break;
+        type = i18n("Primary"); break;
+      case Solid::Battery::UpsBattery:
+        type = i18n("UPS"); break;
+      case Solid::Battery::UsbBattery:
+        type = i18n("USB"); break;
       default:
-	type = i18nc("unknown battery type", "Unknown");
+        type = i18nc("unknown battery type", "Unknown");
   }
   
   QString state;
-    switch(batdev->type())
+    switch(batdev->chargeState())
     {
       case Solid::Battery::Charging:
-	state = i18n("Charging"); break;
+        state = i18n("Charging"); break;
       case Solid::Battery::Discharging:
-	state = i18n("Discharging"); break;
+        state = i18n("Discharging"); break;
+      case Solid::Battery::FullyCharged:
+        state = i18n("Fully Charged"); break;
       default:
-	state = i18n("No Charge"); 
+        state = i18nc("unknown battery charge", "Unknown");
     }
   
   labels << i18n("Battery Type: ")
@@ -738,173 +734,6 @@ QVListLayout *SolAcAdapterDevice::infoPanelLayout()
   return deviceInfoLayout;
 }
 
-// DVB
-
-SolDvbDevice::SolDvbDevice(QTreeWidgetItem *parent, const Solid::Device &device) :
-  SolDevice(parent, device) 
-{
-  deviceTypeHolder = Solid::DeviceInterface::DvbInterface;
-}
-
-SolDvbDevice::SolDvbDevice(const Solid::DeviceInterface::Type &type) :
-  SolDevice(type)
-{ 
-  deviceTypeHolder = Solid::DeviceInterface::DvbInterface;
-
-  setDeviceIcon(KIcon("kde"));
-  setDeviceText(i18n("Digital Video Broadcasting Devices"));
-  setDefaultListing(type);
-}
-
-void SolDvbDevice::setDefaultListing(const Solid::DeviceInterface::Type &type) 
-{ 
-  createDeviceChildren<SolDvbDevice>(this,QString(),type);
-}
-
-QVListLayout *SolDvbDevice::infoPanelLayout() 
-{  
-  QStringList labels;
-  const Solid::DvbInterface *dvbdev = interface<const Solid::DvbInterface>(); 
-  
-  if(!dvbdev) return NULL;
-  deviceInfoLayout = new QVListLayout();
-  
-  QString type;
-  switch(dvbdev->deviceType()) 
-  {
-    case Solid::DvbInterface::DvbAudio:
-      type = i18n("Audio"); break;
-    case Solid::DvbInterface::DvbCa:
-      type = i18n("Conditional access system"); break;
-    case Solid::DvbInterface::DvbDemux:
-      type = i18n("Demux"); break;
-    case Solid::DvbInterface::DvbDvr:
-      type = i18n("Digital video recorder"); break;
-    case Solid::DvbInterface::DvbFrontend:
-      type = i18n("Front end"); break;
-    case Solid::DvbInterface::DvbNet:
-      type = i18n("Network"); break;
-    case Solid::DvbInterface::DvbOsd:
-      type = i18n("On-Screen display"); break;
-    case Solid::DvbInterface::DvbSec:
-      type = i18n("Security and content protection"); break;
-    case Solid::DvbInterface::DvbVideo:
-      type = i18n("Video"); break;
-    case Solid::DvbInterface::DvbUnknown:
-    default:
-      type = i18nc("unknown device type", "Unknown"); 
-  }
-  
-  labels << i18n("Device Type: ")
-  << type;
-  
-  deviceInfoLayout->applyQListToLayout(labels);
-  return deviceInfoLayout;
-}
-
-// Serial
-
-SolSerialDevice::SolSerialDevice(QTreeWidgetItem *parent, const Solid::Device &device) :
-  SolDevice(parent, device) 
-{
-  deviceTypeHolder = Solid::DeviceInterface::SerialInterface;
-}
-
-SolSerialDevice::SolSerialDevice(const Solid::DeviceInterface::Type &type) :
-  SolDevice(type)
-{ 
-  deviceTypeHolder = Solid::DeviceInterface::SerialInterface;
-  
-  setDeviceIcon(KIcon("printer"));
-  setDeviceText(i18n("Serial Devices"));
-  setDefaultListing(type);
-}
-
-void SolSerialDevice::setDefaultListing(const Solid::DeviceInterface::Type &type) 
-{ 
-  createDeviceChildren<SolSerialDevice>(this,QString(),type);
-}
-
-QVListLayout *SolSerialDevice::infoPanelLayout() 
-{  
-  QStringList labels;
-  const Solid::SerialInterface *serdev = interface<const Solid::SerialInterface>(); 
-  
-  if(!serdev) return NULL;
-  deviceInfoLayout = new QVListLayout();
-  
-  QString type;
-  switch(serdev->serialType())
-  {
-    case Solid::SerialInterface::Platform:
-      type = i18nc("platform serial interface type", "Platform"); break;
-    case Solid::SerialInterface::Usb:
-      type = i18n("USB"); break;
-    default:
-      type = i18nc("unknown serial interface type", "Unknown"); 
-  }
-  
-  QString port = i18nc("unknown port", "Unknown");
-  if(serdev->port() != -1) port = QString::number(serdev->port());
-
-  labels << i18n("Serial Type: ")
-  << type
-  << i18n("Port: ")
-  << port;
-  
-  deviceInfoLayout->applyQListToLayout(labels);
-  return deviceInfoLayout;
-}
-
-//  Smartcard
-
-SolSmartCardDevice::SolSmartCardDevice(QTreeWidgetItem *parent, const Solid::Device &device) :
-  SolDevice(parent, device) 
-{
-  deviceTypeHolder = Solid::DeviceInterface::SmartCardReader;
-}
-
-SolSmartCardDevice::SolSmartCardDevice(const Solid::DeviceInterface::Type &type) :
-  SolDevice(type)
-{ 
-  deviceTypeHolder = Solid::DeviceInterface::SmartCardReader;
-
-  setDeviceIcon(KIcon("kde"));
-  setDeviceText(i18n("Smart Card Devices"));
-  setDefaultListing(type);
-}
-
-void SolSmartCardDevice::setDefaultListing(const Solid::DeviceInterface::Type &type) 
-{ 
-  createDeviceChildren<SolSmartCardDevice>(this,QString(),type);
-}
-
-QVListLayout *SolSmartCardDevice::infoPanelLayout() 
-{  
-  QStringList labels;
-  const Solid::SmartCardReader *scdev = interface<const Solid::SmartCardReader>(); 
-  
-  if(!scdev) return NULL;
-  deviceInfoLayout = new QVListLayout();
-  
-  QString type;
-  switch(scdev->readerType())
-  {
-    case Solid::SmartCardReader::CardReader:
-      type = i18n("Card Reader"); break;
-    case Solid::SmartCardReader::CryptoToken:
-      type = i18n("Crypto Token"); break;
-    default:
-      type = i18nc("unknown smart card type", "Unknown"); 
-  }
- 
-  labels << i18n("Smart Card Type: ")
-  << type;
-  
-  deviceInfoLayout->applyQListToLayout(labels);
-  return deviceInfoLayout;
-}
-
 // Video
 
 SolVideoDevice::SolVideoDevice(QTreeWidgetItem *parent, const Solid::Device &device) :
@@ -944,3 +773,41 @@ QVListLayout *SolVideoDevice::infoPanelLayout()
   deviceInfoLayout->applyQListToLayout(labels);
   return deviceInfoLayout;
 }
+
+// Graphic
+
+SolGraphicDevice::SolGraphicDevice(QTreeWidgetItem *parent, const Solid::Device &device) :
+  SolDevice(parent, device)
+{
+  deviceTypeHolder = Solid::DeviceInterface::Video;
+}
+
+SolGraphicDevice::SolGraphicDevice(const Solid::DeviceInterface::Type &type) :
+  SolDevice(type)
+{
+  deviceTypeHolder = Solid::DeviceInterface::Video;
+  
+  setDeviceIcon(KIcon("video-display"));
+  setDeviceText(i18n("Graphic Displays"));
+  setDefaultListing(type);
+}
+
+void SolGraphicDevice::setDefaultListing(const Solid::DeviceInterface::Type &type)
+{
+  createDeviceChildren<SolGraphicDevice>(this,QString(),type);
+}
+
+QVListLayout *SolGraphicDevice::infoPanelLayout()
+{
+  QStringList labels;
+  const Solid::Graphic *graphdev = interface<const Solid::Graphic>();
+
+  if(!graphdev) return NULL;
+  deviceInfoLayout = new QVListLayout();
+
+  labels << i18n("Driver: ")
+  << graphdev->driver();
+  
+  deviceInfoLayout->applyQListToLayout(labels);
+  return deviceInfoLayout;
+}
