@@ -12,7 +12,7 @@
 #include "chartWidget.h"
 
 #include <QVBoxLayout>
-#include <QLinearGradient>
+#include <QtGui/qbrush.h>
 #include <QLabel>
 #include <QPainter>
 #include <QPen>
@@ -75,7 +75,7 @@ bool Chart::drawChart(t_memsize total, const QList<t_memsize>& used, const QList
 		else
 			localheight = startline;
 
-		//kDebug() << "Count : " <<  count << " Percent : " << percent << "%" << " Localheight:" << localheight << endl;
+		//kDebug() << "Count : " <<  count << " Percent : " << percent << "%" << " Localheight:" << localheight;
 		
 		if (localheight>0) {
 			QLinearGradient gradient(QPointF(1, startline), QPointF(width()-2, -localheight));
@@ -117,6 +117,7 @@ ChartWidget::ChartWidget(const QString& title, const QString& hint, Chart* chart
 	QVBoxLayout* mainLayout = new QVBoxLayout(this);
 	
 	titleLabel = new QLabel("<strong>" + title + "</strong>", this);
+	titleLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
 	titleLabel->setAlignment(Qt::AlignHCenter);
 	titleLabel->setToolTip(hint);
 	mainLayout->addWidget(titleLabel);
@@ -126,6 +127,7 @@ ChartWidget::ChartWidget(const QString& title, const QString& hint, Chart* chart
 	mainLayout->addWidget(chart);
 	
 	freeMemoryLabel = new QLabel("", this);
+	freeMemoryLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
 	freeMemoryLabel->setAlignment(Qt::AlignHCenter);
 	freeMemoryLabel->setToolTip(hint);
 	mainLayout->addWidget(freeMemoryLabel);
