@@ -29,7 +29,7 @@
 #include <QPixmap>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QLinearGradient>
+#include <QtGui/qbrush.h>
 #include <QTreeWidget>
 
 #include <kaboutdata.h>
@@ -137,8 +137,7 @@ QGroupBox* KCMMemory::initializeText() {
 		case FREE_MEM:
 			title = i18n("Free physical memory:");
 			break;
-#if !defined(__svr4__) || !defined(sun)
-#if !defined(__NetBSD__) && !defined(__OpenBSD__)
+#if !defined(Q_OS_SOLARIS) && !defined(Q_OS_NETBSD) && !defined(Q_OS_OPENBSD)
 		case SHARED_MEM:
 			title = i18n("Shared memory:");
 			break;
@@ -152,7 +151,6 @@ QGroupBox* KCMMemory::initializeText() {
 			case INACTIVE_MEM:
 			title = i18n("Inactive memory:");
 			break;
-#endif
 #endif
 		case CACHED_MEM:
 			title = i18n("Disk cache:");
@@ -296,22 +294,14 @@ void KCMMemory::updateMemoryGraphics() {
 
 /* Include system-specific code */
 
-#ifdef __linux__
+#ifdef Q_OS_LINUX
 #include "memory_linux.cpp"
-#elif defined(__APPLE__)
-#include "memory_osx.cpp"
-#elif defined(sgi) && sgi
-#include "memory_sgi.cpp"
-#elif defined(__svr4__) && defined(sun)
+#elif defined(Q_OS_SOLARIS)
 #include "memory_solaris.cpp"
-#elif defined(__FreeBSD__) || defined(__DragonFly__)
+#elif defined(Q_OS_FREEBSD) || defined(Q_OS_DRAGONFLY)
 #include "memory_fbsd.cpp"
-#elif defined(__hpux)
-#include "memory_hpux.cpp"
-#elif defined(__NetBSD__) || defined(__OpenBSD__)
+#elif defined(Q_OS_NETBSD) || defined(Q_OS_OPENBSD)
 #include "memory_netbsd.cpp"
-#elif defined(__osf__)
-#include "memory_tru64.cpp"
 #else
 
 /* Default for unsupported systems */
@@ -324,4 +314,4 @@ void KCMMemory::fetchValues() {
 
 #endif
 
-#include "memory.moc"
+#include "moc_memory.cpp"
