@@ -8,36 +8,34 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _KCMUSB_H
-#define _KCMUSB_H
+#ifndef KCMUSB_H
+#define KCMUSB_H
 
 #include <QMap>
 
 #include <kcmodule.h>
 
-class QTreeWidget;
-class QTreeWidgetItem;
-class QTextEdit;
-
-class USBViewer : public KCModule {
-Q_OBJECT
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
+#include <QTextEdit>
 
+class USBViewer : public KCModule
+{
+    Q_OBJECT
 public:
+    explicit USBViewer(QWidget *parent = 0L, const QVariantList &list=QVariantList());
 
-	explicit USBViewer(QWidget *parent = 0L, const QVariantList &list=QVariantList());
-
-	void load();
+    void load();
 
 protected Q_SLOTS:
-
-	void selectionChanged(QTreeWidgetItem *item);
-	void refresh();
+    void selectionChanged(QTreeWidgetItem *item);
+    void refresh();
 
 private:
-
-	QMap<int, QTreeWidgetItem*> _items;
-	QTreeWidget *_devices;
-	QTextEdit *_details;
+    int _lastdevicecount;
+    QMap<int, QTreeWidgetItem*> _items;
+    QTreeWidget *_devices;
+    QTextEdit *_details;
 };
 
 #endif
