@@ -23,10 +23,10 @@
 
 #include "klipper.h"
 
-#include <zlib.h>
-
+#include <QtCore/QProcess>
 #include <QtGui/QMenu>
 #include <QtDBus/QDBusConnection>
+#include <QtNetwork/QCryptographicHash>
 
 #include <KAboutData>
 #include <KLocale>
@@ -41,6 +41,9 @@
 #include <KTextEdit>
 #include <KApplication>
 #include <KIcon>
+#include <KTemporaryFile>
+#include <KImageIO>
+#include <KFileDialog>
 
 #include "configdialog.h"
 #include "klippersettings.h"
@@ -51,12 +54,6 @@
 #include "historystringitem.h"
 #include "klipperpopup.h"
 
-#ifdef HAVE_PRISON
-#include <prison/BarcodeWidget>
-#include <prison/DataMatrixBarcode>
-#include <prison/QRCodeBarcode>
-#endif
-
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -168,6 +165,8 @@ Klipper::Klipper(QObject* parent, const KSharedConfigPtr& config)
         loadHistory();
     }
 
+    m_qrencodeexe = KStandardDirs::findExe("qrencode");
+
     m_clearHistoryAction = m_collection->addAction( "clear-history" );
     m_clearHistoryAction->setIcon( KIcon("edit-clear-history") );
     m_clearHistoryAction->setText( i18n("C&lear Clipboard History") );
@@ -196,13 +195,13 @@ Klipper::Klipper(QObject* parent, const KSharedConfigPtr& config)
     m_editAction->setGlobalShortcut(KShortcut());
     connect(m_editAction, SIGNAL(triggered()), SLOT(slotEditData()));
 
-#ifdef HAVE_PRISON
-    // add barcode for mobile phones
-    m_showBarcodeAction = m_collection->addAction("show-barcode");
-    m_showBarcodeAction->setText(i18n("&Show Barcode..."));
-    m_showBarcodeAction->setGlobalShortcut(KShortcut());
-    connect(m_showBarcodeAction, SIGNAL(triggered()), SLOT(slotShowBarcode()));
-#endif
+    if (!m_qrencodeexe.isEmpty()) {
+        // add barcode for mobile phones
+        m_showBarcodeAction = m_collection->addAction("show-barcode");
+        m_showBarcodeAction->setText(i18n("&Show Barcode..."));
+        m_showBarcodeAction->setGlobalShortcut(KShortcut());
+        connect(m_showBarcodeAction, SIGNAL(triggered()), SLOT(slotShowBarcode()));
+    }
 
     // Cycle through history
     m_cycleNextAction = m_collection->addAction("cycleNextAction");
@@ -229,9 +228,9 @@ Klipper::Klipper(QObject* parent, const KSharedConfigPtr& config)
     popup->plugAction( m_configureAction );
     popup->plugAction( m_repeatAction );
     popup->plugAction( m_editAction );
-#ifdef HAVE_PRISON
-    popup->plugAction( m_showBarcodeAction );
-#endif
+    if (!m_qrencodeexe.isEmpty()) {
+        popup->plugAction( m_showBarcodeAction );
+    }
     if ( !isApplet() ) {
         popup->plugAction( m_quitAction );
     }
@@ -368,7 +367,7 @@ bool Klipper::loadHistory() {
     static const char* const failed_load_warning =
         "Failed to load history resource. Clipboard history cannot be read.";
     // don't use "appdata", klipper is also a kicker applet
-    QString history_file_name = KStandardDirs::locateLocal( "data", "klipper/history2.lst" );
+    QString history_file_name = KStandardDirs::locateLocal( "data", "klipper/history4.lst" );
     QFile history_file( history_file_name );
     if ( !history_file.exists() ) {
         kWarning() << failed_load_warning << ": " << "History file does not exist" ;
@@ -384,17 +383,16 @@ bool Klipper::loadHistory() {
         return false;
     }
     QByteArray data;
-    quint32 crc;
-    file_stream >> crc >> data;
-    if( crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() ) != crc ) {
-        kWarning() << failed_load_warning << ": " << "CRC checksum does not match" ;
+    QByteArray hash;
+    file_stream >> hash >> data;
+    if( QCryptographicHash::hash( data, KlipperHashAlgorithm ).toHex() != hash ) {
+        kWarning() << failed_load_warning << ": " << "Hash does not match" ;
         return false;
     }
     QDataStream history_stream( &data, QIODevice::ReadOnly );
 
-    char* version;
+    qint8 version;
     history_stream >> version;
-    delete[] version;
 
     // The list needs to be reversed, as it is saved
     // youngest-first to keep the most important clipboard
@@ -428,7 +426,7 @@ void Klipper::saveHistory(bool empty) {
     static const char* const failed_save_warning =
         "Failed to save history. Clipboard history cannot be saved.";
     // don't use "appdata", klipper is also a kicker applet
-    QString history_file_name( KStandardDirs::locateLocal( "data", "klipper/history2.lst" ) );
+    QString history_file_name( KStandardDirs::locateLocal( "data", "klipper/history4.lst" ) );
     if ( history_file_name.isNull() || history_file_name.isEmpty() ) {
         kWarning() << failed_save_warning ;
         return;
@@ -440,7 +438,7 @@ void Klipper::saveHistory(bool empty) {
     }
     QByteArray data;
     QDataStream history_stream( &data, QIODevice::WriteOnly );
-    history_stream << klipper_version; // const char*
+    history_stream << klipper_version_int;
 
     if (!empty) {
         const HistoryItem *item = history()->first();
@@ -452,9 +450,9 @@ void Klipper::saveHistory(bool empty) {
         }
     }
 
-    quint32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
+    QByteArray hash = QCryptographicHash::hash( data, KlipperHashAlgorithm ).toHex();
     QDataStream ds ( &history_file );
-    ds << crc << data;
+    ds << hash << data;
 }
 
 // save session on shutdown. Don't simply use the c'tor, as that may not be called.
@@ -641,6 +639,22 @@ void Klipper::slotCheckPending()
     newClipData( QClipboard::Selection ); // always selection
 }
 
+void Klipper::slotSaveBarcode()
+{
+    const QString path = KFileDialog::getSaveFileName(
+        KUrl("kfiledialog:///qrcode"),
+        KImageIO::pattern(KImageIO::Writing),
+        nullptr,
+        QString(),
+        KFileDialog::ConfirmOverwrite
+    );
+    if (!path.isEmpty()) {
+        if (!m_qrpixmap.save(path)) {
+            KMessageBox::error(nullptr, i18n("Could not save QR Code image"));
+        };
+    }
+}
+
 void Klipper::checkClipData( bool selectionMode )
 {
     if ( ignoreClipboardChanges() ) // internal to klipper, ignoring QSpinBox selections
@@ -662,8 +676,7 @@ void Klipper::checkClipData( bool selectionMode )
 
     kDebug() << "====== c h e c k C l i p D a t a ============================"
               << kBacktrace()
-              << "====== c h e c k C l i p D a t a ============================"
-              << endl;;
+              << "====== c h e c k C l i p D a t a ============================";
 
 
     if ( sender() ) {
@@ -674,7 +687,7 @@ void Klipper::checkClipData( bool selectionMode )
 
     kDebug() << "\nselectionMode=" << selectionMode
               << "\nowning (sel,cli)=(" << m_clip->ownsSelection() << "," << m_clip->ownsClipboard() << ")"
-              << "\ntext=" << m_clip->text( selectionMode ? QClipboard::Selection : QClipboard::Clipboard) << endl;
+              << "\ntext=" << m_clip->text( selectionMode ? QClipboard::Selection : QClipboard::Clipboard);
 #endif
 
     const QMimeData* data = m_clip->mimeData( selectionMode ? QClipboard::Selection : QClipboard::Clipboard );
@@ -984,30 +997,58 @@ void Klipper::slotEditData()
 
 }
 
-#ifdef HAVE_PRISON
 void Klipper::slotShowBarcode()
 {
-    using namespace prison;
     const HistoryStringItem* item = dynamic_cast<const HistoryStringItem*>(m_history->first());
 
+    m_qrpixmap = QPixmap();
+
     KDialog dlg;
     dlg.setModal( true );
     dlg.setCaption( i18n("Mobile Barcode") );
-    dlg.setButtons( KDialog::Ok );
+    dlg.setButtons( KDialog::User1 | KDialog::Ok );
+    dlg.setButtonText( KDialog::User1, i18nc("@action:button", "Save as"));
+    dlg.setButtonIcon( KDialog::User1, KIcon("document-save"));
+    connect(&dlg, SIGNAL(user1Clicked()), this, SLOT(slotSaveBarcode()));
 
     QWidget* mw = new QWidget(&dlg);
     QHBoxLayout* layout = new QHBoxLayout(mw);
 
-    BarcodeWidget* qrcode = new BarcodeWidget(new QRCodeBarcode());
-    BarcodeWidget* datamatrix = new BarcodeWidget(new DataMatrixBarcode());
+    QLabel* qrcode = new QLabel(mw);
 
     if (item) {
-        qrcode->setData( item->text() );
-        datamatrix->setData( item->text() );
+        QString qrpath;
+        {
+            KTemporaryFile ktempfile;
+            ktempfile.open();
+            qrpath = ktempfile.fileName();
+        }
+        QString qrtext = item->text();
+
+        QProcess qrproc(this);
+        qrproc.start(m_qrencodeexe, QStringList() << "-o" << qrpath << "-t" << "PNG");
+        if (qrproc.waitForStarted()) {
+            qrproc.write(qrtext.toLocal8Bit());
+            qrproc.closeWriteChannel();
+        }
+        qrproc.waitForFinished();
+        if (qrproc.exitCode() == 0) {
+            m_qrpixmap = QPixmap(qrpath);
+        } else {
+            qrtext = qrproc.readAllStandardError();
+        }
+
+        qrcode->setText( qrtext );
+        if (!m_qrpixmap.isNull()) {
+            qrcode->setPixmap( m_qrpixmap );
+        }
+
+        if (!qrpath.isEmpty()) {
+            QFile::remove(qrpath);
+        }
     }
 
-    layout->addWidget(qrcode);
-    layout->addWidget(datamatrix);
+    layout->addWidget(qrcode, 0, Qt::AlignHCenter | Qt::AlignVCenter);
 
     mw->setFocus();
     dlg.setMainWidget( mw );
@@ -1015,7 +1056,6 @@ void Klipper::slotShowBarcode()
 
     dlg.exec();
 }
-#endif //HAVE_PRISON
 
 void Klipper::slotAskClearHistory()
 {
@@ -1089,4 +1129,4 @@ QString Klipper::cycleText() const
     return result;
 }
 
-#include "klipper.moc"
+#include "moc_klipper.cpp"
