@@ -21,24 +21,27 @@
 #ifndef KLIPPER_H
 #define KLIPPER_H
 
-#include <QtCore/QTime>
-#include <QtCore/QTimer>
-#include <QtGui/QClipboard>
+#include <QTime>
+#include <QAction>
+#include <QMenu>
+#include <QMimeData>
+#include <QDateTime>
+#include <QTimer>
+#include <QClipboard>
+#include <QCryptographicHash>
 
 #include <KGlobal>
 
 #include "urlgrabber.h"
 
+static const QCryptographicHash::Algorithm KlipperHashAlgorithm = QCryptographicHash::KAT;
+
 class KAction;
 class KToggleAction;
 class KAboutData;
 class KActionCollection;
 class URLGrabber;
-class QTime;
 class History;
-class QAction;
-class QMenu;
-class QMimeData;
 class HistoryItem;
 class KlipperSessionManager;
 
@@ -80,9 +83,7 @@ public Q_SLOTS:
     void slotHistoryTopChanged();
     void slotConfigure();
     void slotEditData();
-#ifdef HAVE_PRISON
     void slotShowBarcode();
-#endif
     void slotCycleNext();
     void slotCyclePrev();
 
@@ -145,6 +146,8 @@ private Q_SLOTS:
     void slotClearOverflow();
     void slotCheckPending();
 
+    void slotSaveBarcode();
+
     void loadSettings();
 
 private:
@@ -162,9 +165,7 @@ private:
     KAction* m_clearHistoryAction;
     KAction* m_repeatAction;
     KAction* m_editAction;
-#ifdef HAVE_PRISON
     KAction* m_showBarcodeAction;
-#endif
     KAction* m_configureAction;
     KAction* m_quitAction;
     KAction* m_cycleNextAction;
@@ -196,6 +197,8 @@ private:
     QTimer m_overflowClearTimer;
     QTimer m_pendingCheckTimer;
     bool m_pendingContentsCheck;
+    QString m_qrencodeexe;
+    QPixmap m_qrpixmap;
     static KAboutData* m_about_data;
 
     bool blockFetchingNewData();
