@@ -179,4 +179,4 @@ int PopupProxy::insertFromSpill( int index ) {
     return count;
 
 }
-#include "popupproxy.moc"
+#include "moc_popupproxy.cpp"
