@@ -36,14 +36,12 @@
 #include <KUrlRequester>
 #include <KShell>
 
-#ifndef Q_WS_WIN
 #include "khotkeys.h"
-#endif
 
 #include "klinespellchecking.h"
 #include "menuinfo.h"
 
-#include "basictab.moc"
+#include "moc_basictab.cpp"
 
 BasicTab::BasicTab( QWidget *parent )
     : KTabWidget(parent)
@@ -234,10 +232,8 @@ BasicTab::BasicTab( QWidget *parent )
     advancedLayout->addItem(new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding));
 
     addTab(advanced, i18n("Advanced"));
-#ifndef Q_WS_WIN
     if (!KHotKeys::present())
         general_group_keybind->hide();
-#endif
     slotDisableAction();
 }
 
@@ -367,7 +363,6 @@ void BasicTab::setEntryInfo(MenuEntryInfo *entryInfo)
     _iconButton->setIcon(df->readIcon());
 
     // key binding part
-#ifndef Q_WS_WIN
     if( KHotKeys::present())
     {
         if ( !entryInfo->shortcut().isEmpty() )
@@ -375,7 +370,6 @@ void BasicTab::setEntryInfo(MenuEntryInfo *entryInfo)
         else
             _keyEdit->clearKeySequence();
     }
-#endif
     QString temp = df->desktopGroup().readEntry("Exec");
     if (temp.startsWith(QLatin1String("ksystraycmd ")))
     {
@@ -525,7 +519,6 @@ void BasicTab::slotCapturedKeySequence(const QKeySequence& seq)
     if (signalsBlocked())
        return;
     KShortcut cut(seq, QKeySequence());
-#ifndef Q_WS_WIN
     if (_menuEntryInfo->isShortcutAvailable( cut ) && KHotKeys::present() )
     {
        _menuEntryInfo->setShortcut( cut );
@@ -535,7 +528,6 @@ void BasicTab::slotCapturedKeySequence(const QKeySequence& seq)
        // We will not assign the shortcut so reset the visible key sequence
        _keyEdit->setKeySequence(QKeySequence());
     }
-#endif
     if (_menuEntryInfo)
        emit changed( _menuEntryInfo );
 }
