@@ -19,7 +19,7 @@
 #include "klinespellchecking.h"
 
 #include <QMenu>
-#include <QContextMenuEvent>
+#include <QtGui/qevent.h>
 
 #include <KStandardAction>
 #include <KActionCollection>
@@ -103,6 +103,6 @@ void KLineSpellChecking::contextMenuEvent(QContextMenuEvent *e)
 
 
 
-#include "klinespellchecking.moc"
+#include "moc_klinespellchecking.cpp"
 
 
