@@ -23,6 +23,7 @@
 
 #include <KAction>
 #include <KActionCollection>
+#include <KActionMenu>
 #include <KConfig>
 #include <KDebug>
 #include <KGlobal>
@@ -40,7 +41,7 @@
 #include "preferencesdlg.h"
 #include "kmenueditadaptor.h"
 
-#include "kmenuedit.moc"
+#include "moc_kmenuedit.cpp"
 
 KMenuEdit::KMenuEdit ()
     : KXmlGuiWindow (0)
@@ -73,19 +74,45 @@ void KMenuEdit::setupActions()
 {
     KAction *action = 0;
 
-    action = actionCollection()->addAction("newsubmenu");
+    action = actionCollection()->addAction(NEW_SUBMENU_ACTION_NAME);
     action->setIcon(KIcon("menu_new"));
     action->setText(i18n("&New Submenu..."));
     action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_N));
-    action = actionCollection()->addAction("newitem");
+    action = actionCollection()->addAction(NEW_ITEM_ACTION_NAME);
     action->setIcon(KIcon("document-new")) ;
     action->setText(i18n("New &Item..."));
     action->setShortcuts(KStandardShortcut::openNew());
-    action = actionCollection()->addAction("newsep");
+    action = actionCollection()->addAction(NEW_SEPARATOR_ACTION_NAME);
     action->setIcon(KIcon("menu_new_sep"));
     action->setText(i18n("New S&eparator"));
     action->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_I));
 
+    // "sort selection" menu
+    KActionMenu* sortMenu = new KActionMenu(KIcon("view-sort-ascending"), i18n("&Sort"), this);
+    sortMenu->setDelayed(false);
+    actionCollection()->addAction(SORT_ACTION_NAME, sortMenu);
+    action = actionCollection()->addAction(SORT_BY_NAME_ACTION_NAME);
+    action->setText(i18n("&Sort selection by Name"));
+    sortMenu->addAction(action);
+    action = actionCollection()->addAction(SORT_BY_DESCRIPTION_ACTION_NAME);
+    action->setText(i18n("&Sort selection by Description"));
+    sortMenu->addAction(action);
+    sortMenu->addSeparator();
+    action = actionCollection()->addAction(SORT_ALL_BY_NAME_ACTION_NAME);
+    action->setText(i18n("&Sort all by Name"));
+    sortMenu->addAction(action);
+    action = actionCollection()->addAction(SORT_ALL_BY_DESCRIPTION_ACTION_NAME);
+    action->setText(i18n("&Sort all by Description"));
+    sortMenu->addAction(action);
+
+    // move up/down
+    action = actionCollection()->addAction(MOVE_UP_ACTION_NAME);
+    action->setIcon(KIcon("go-up"));
+    action->setText(i18n("Move &Up"));
+    action = actionCollection()->addAction(MOVE_DOWN_ACTION_NAME);
+    action->setIcon(KIcon("go-down"));
+    action->setText(i18n("Move &Down"));
+
     actionCollection()->addAction(KStandardAction::Save, this, SLOT(slotSave()));
     actionCollection()->addAction(KStandardAction::Quit, this, SLOT(close()));
     actionCollection()->addAction(KStandardAction::Cut);
@@ -170,7 +197,7 @@ void KMenuEdit::slotChangeView()
 
     delete m_actionDelete;
 
-    m_actionDelete = actionCollection()->addAction("delete");
+    m_actionDelete = actionCollection()->addAction(DELETE_ACTION_NAME);
     m_actionDelete->setIcon(KIcon("edit-delete"));
     m_actionDelete->setText(i18n("&Delete"));
     m_actionDelete->setShortcut(QKeySequence(Qt::Key_Delete));
@@ -197,7 +224,7 @@ bool KMenuEdit::queryClose()
     int result;
     result = KMessageBox::warningYesNoCancel(this,
                                              i18n("You have made changes to the menu.\n"
-                         "Do you want to save the changes or discard them?"),
+                                                  "Do you want to save the changes or discard them?"),
                                              i18n("Save Menu Changes?"),
                                              KStandardGuiItem::save(), KStandardGuiItem::discard() );
 
