@@ -17,12 +17,12 @@
  *
  */
 
-#ifndef kmenuedit_h
-#define kmenuedit_h
+#ifndef KMENUEDIT_H
+#define KMENUEDIT_H
 
 #include <KXmlGuiWindow>
 
-class QSplitter;
+#include <QSplitter>
 class KAction;
 class BasicTab;
 class TreeView;
