@@ -26,9 +26,7 @@
 #include <KConfigGroup>
 
 #include "menufile.h"
-#ifndef Q_WS_WIN
 #include "khotkeys.h"
-#endif
 
 //
 // MenuFolderInfo
@@ -177,7 +175,6 @@ void MenuFolderInfo::save(MenuFile *menuFile)
 {
    if (s_deletedApps)
    {
-#ifndef Q_WS_WIN
       // Remove hotkeys for applications that have been deleted
       for(QStringList::ConstIterator it = s_deletedApps->constBegin();
           it != s_deletedApps->constEnd(); ++it)
@@ -185,7 +182,6 @@ void MenuFolderInfo::save(MenuFile *menuFile)
          // The shorcut is deleted if we set a empty sequence
          KHotKeys::changeMenuEntryShortcut(*it, "");
       }
-#endif
       delete s_deletedApps;
       s_deletedApps = 0;
    }
@@ -330,7 +326,6 @@ void MenuEntryInfo::save()
       m_desktopFile->sync();
       dirty = false;
    }
-#ifndef Q_WS_WIN
    if (shortcutDirty)
    {
       if( KHotKeys::present())
@@ -339,7 +334,6 @@ void MenuEntryInfo::save()
       }
       shortcutDirty = false;
    }
-#endif
 }
 
 void MenuEntryInfo::setCaption(const QString &_caption)
@@ -372,7 +366,6 @@ void MenuEntryInfo::setIcon(const QString &_icon)
 
 KShortcut MenuEntryInfo::shortcut()
 {
-#ifndef Q_WS_WIN
    if (!shortcutLoaded)
    {
       shortcutLoaded = true;
@@ -381,7 +374,6 @@ KShortcut MenuEntryInfo::shortcut()
          shortCut = KShortcut(KHotKeys::getMenuEntryShortcut( service->storageId() ));
       }
    }
-#endif
    return shortCut;
 }
 
