@@ -29,7 +29,7 @@
 #include <QPainter>
 #include <QRegExp>
 #include <QPixmap>
-#include <QDropEvent>
+#include <QtGui/qevent.h>
 #include <QMenu>
 #include <QApplication>
 #include <QtDBus/QtDBus>
@@ -52,7 +52,7 @@
 #include <KStandardDirs>
 #include <KIO/NetAccess>
 
-#include "treeview.moc"
+#include "moc_treeview.cpp"
 #include "menufile.h"
 #include "menuinfo.h"
 
@@ -227,13 +227,6 @@ bool TreeItem::isLayoutDirty() const
 static QPixmap appIcon(const QString &iconName)
 {
     QPixmap normal = KIconLoader::global()->loadIcon(iconName, KIconLoader::Small, 0, KIconLoader::DefaultState, QStringList(), 0L, true);
-    // make sure they are not larger than 20x20
-    if (normal.width() > 20 || normal.height() > 20)
-    {
-       QImage tmp = normal.toImage();
-       tmp = tmp.scaled(20, 20, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-       normal = QPixmap::fromImage(tmp);
-    }
     return normal;
 }
 
@@ -258,37 +251,37 @@ TreeView::TreeView( KActionCollection *ac, QWidget *parent, const char *name )
     header()->hide();
 
     // listen for creation
-    connect(m_ac->action(NEW_ITEM_ACTION_NAME), SIGNAL(activated()), SLOT(newitem()));
-    connect(m_ac->action(NEW_SUBMENU_ACTION_NAME), SIGNAL(activated()), SLOT(newsubmenu()));
-    connect(m_ac->action(NEW_SEPARATOR_ACTION_NAME), SIGNAL(activated()), SLOT(newsep()));
+    connect(m_ac->action(NEW_ITEM_ACTION_NAME), SIGNAL(triggered()), SLOT(newitem()));
+    connect(m_ac->action(NEW_SUBMENU_ACTION_NAME), SIGNAL(triggered()), SLOT(newsubmenu()));
+    connect(m_ac->action(NEW_SEPARATOR_ACTION_NAME), SIGNAL(triggered()), SLOT(newsep()));
 
     // listen for copy
-    connect(m_ac->action(CUT_ACTION_NAME), SIGNAL(activated()), SLOT(cut()));
-    connect(m_ac->action(COPY_ACTION_NAME), SIGNAL(activated()), SLOT(copy()));
-    connect(m_ac->action(PASTE_ACTION_NAME), SIGNAL(activated()), SLOT(paste()));
+    connect(m_ac->action(CUT_ACTION_NAME), SIGNAL(triggered()), SLOT(cut()));
+    connect(m_ac->action(COPY_ACTION_NAME), SIGNAL(triggered()), SLOT(copy()));
+    connect(m_ac->action(PASTE_ACTION_NAME), SIGNAL(triggered()), SLOT(paste()));
 
     // listen for deleting
-    connect(m_ac->action(DELETE_ACTION_NAME), SIGNAL(activated()), SLOT(del()));
+    connect(m_ac->action(DELETE_ACTION_NAME), SIGNAL(triggered()), SLOT(del()));
 
     // listen for sorting
     m_sortSignalMapper = new QSignalMapper(this);
     QAction *action = m_ac->action(SORT_BY_NAME_ACTION_NAME);
-    connect(action, SIGNAL(activated()), m_sortSignalMapper, SLOT(map()));
+    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
     m_sortSignalMapper->setMapping(action, SortByName);
     action = m_ac->action(SORT_BY_DESCRIPTION_ACTION_NAME);
-    connect(action, SIGNAL(activated()), m_sortSignalMapper, SLOT(map()));
+    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
     m_sortSignalMapper->setMapping(action, SortByDescription);
     action = m_ac->action(SORT_ALL_BY_NAME_ACTION_NAME);
-    connect(action, SIGNAL(activated()), m_sortSignalMapper, SLOT(map()));
+    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
     m_sortSignalMapper->setMapping(action, SortAllByName);
     action = m_ac->action(SORT_ALL_BY_DESCRIPTION_ACTION_NAME);
-    connect(action, SIGNAL(activated()), m_sortSignalMapper, SLOT(map()));
+    connect(action, SIGNAL(triggered()), m_sortSignalMapper, SLOT(map()));
     m_sortSignalMapper->setMapping(action, SortAllByDescription);
     connect(m_sortSignalMapper, SIGNAL(mapped(const int)), this, SLOT(sort(const int)));
 
     // connect moving up/down actions
-    connect(m_ac->action(MOVE_UP_ACTION_NAME), SIGNAL(activated()), SLOT(moveUpItem()));
-    connect(m_ac->action(MOVE_DOWN_ACTION_NAME), SIGNAL(activated()), SLOT(moveDownItem()));
+    connect(m_ac->action(MOVE_UP_ACTION_NAME), SIGNAL(triggered()), SLOT(moveUpItem()));
+    connect(m_ac->action(MOVE_DOWN_ACTION_NAME), SIGNAL(triggered()), SLOT(moveDownItem()));
 
     // listen for selection
     connect(this, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
@@ -818,7 +811,8 @@ void TreeView::startDrag(Qt::DropActions supportedActions)
     }
 
     QDrag *drag = new QDrag(this);
-    drag->setPixmap(selectedItem()->icon(0).pixmap(24, 24));
+    int iconSize = KIconLoader::global()->currentSize(KIconLoader::Small);
+    drag->setPixmap(selectedItem()->icon(0).pixmap(iconSize, iconSize));
     drag->setMimeData(data);
     drag->exec(supportedActions, Qt::MoveAction);
 }
@@ -840,7 +834,7 @@ static QString createDesktopFile(const QString &file, QString *menuId, QStringLi
    QRegExp r("(.*)(?=-\\d+)");
    base = (r.indexIn(base) > -1) ? r.cap(1) : base;
 
-   QString result = KService::newServicePath(true, base, menuId, excludeList);
+   QString result = KService::newServicePath(base, menuId, excludeList);
    excludeList->append(*menuId);
    // Todo for Undo-support: Undo menuId allocation:
 
