@@ -26,7 +26,7 @@
 #include <QDesktopWidget>
 #include <QGraphicsView>
 #include <QHBoxLayout>
-#include <QHideEvent>
+#include <QtGui/qevent.h>
 #include <QLabel>
 #include <QShortcut>
 #include <QToolButton>
@@ -268,7 +268,7 @@ void Interface::updateSystemActivityToolTip()
 {
     /* Set the tooltip for the Show System Activity button to include the global shortcut */
     KRunnerApp *krunnerApp = KRunnerApp::self();
-    KAction *showSystemActivityAction = dynamic_cast<KAction *>(krunnerApp->actionCollection()->action(QLatin1String( "Show System Activity" )));
+    KAction *showSystemActivityAction = qobject_cast<KAction *>(krunnerApp->actionCollection()->action(QLatin1String( "Show System Activity" )));
     if (showSystemActivityAction) {
         QString shortcut = showSystemActivityAction->globalShortcut().toString();
         if (shortcut.isEmpty()) {
@@ -661,4 +661,4 @@ void Interface::resetResultsArea()
     resize(qMax(minimumSizeHint().width(), m_defaultSize.width()), minimumSizeHint().height());
 }
 
-#include "interface.moc"
+#include "moc_interface.cpp"
