@@ -21,19 +21,19 @@
 #ifndef INTERFACE_H
 #define INTERFACE_H
 
-#include <QMultiMap>
+#include <QtCore/qmap.h>
 #include <QTimer>
 
 // local includes
 #include "krunnerdialog.h"
 #include "resultitem.h"
 
-class QGraphicsView;
-class QGraphicsItem;
-class QLabel;
-class QToolButton;
-class QHBoxLayout;
-class QVBoxLayout;
+#include <QGraphicsView>
+#include <QGraphicsItem>
+#include <QLabel>
+#include <QToolButton>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 class KCompletion;
 class KrunnerHistoryComboBox;
