@@ -30,11 +30,11 @@
 #include <QGraphicsItemAnimation>
 #include <QGraphicsLinearLayout>
 #include <QGraphicsScene>
-#include <QGraphicsSceneMouseEvent>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QGraphicsView>
 #include <QPainter>
 #include <QPropertyAnimation>
-#include <QStyleOptionGraphicsItem>
+#include <QtGui/qstyleoption.h>
 #include <QTimeLine>
 #include <QTimer>
 
@@ -50,8 +50,6 @@
 
 //#define NO_GROW_ANIM
 
-void shadowBlur(QImage &image, int radius, const QColor &color);
-
 ResultItem::ResultItem(const SharedResultData *sharedData, QGraphicsWidget *parent)
     : QGraphicsWidget(parent),
       m_match(0),
@@ -652,5 +650,5 @@ void ResultItem::calculateSize(int sceneWidth)
     resize(newSize);
 }
 
-#include "resultitem.moc"
+#include "moc_resultitem.cpp"
 
