@@ -23,8 +23,8 @@
 #include "resultscene.h"
 
 #include <QtCore/QDebug>
-#include <QtGui/QKeyEvent>
-#include <QtCore/QMutexLocker>
+#include <QtGui/qevent.h>
+#include <QtCore/qmutex.h>
 #include <QtGui/QPainter>
 #include <QtCore/QTimeLine>
 #include <QtGui/QGraphicsGridLayout>
@@ -32,9 +32,9 @@
 #include <QtGui/QGraphicsProxyWidget>
 #include <QtCore/QCoreApplication>
 
-#include <KDE/KDebug>
-#include <KDE/KIconLoader>
-#include <KDE/KLineEdit>
+#include <KDebug>
+#include <KIconLoader>
+#include <KLineEdit>
 
 #include <Plasma/AbstractRunner>
 #include <Plasma/RunnerManager>
@@ -132,7 +132,7 @@ int ResultScene::viewableHeight() const
 
 void ResultScene::setQueryMatches(const QList<Plasma::QueryMatch> &m)
 {
-    //kDebug() << "============================" << endl << "matches retrieved: " << m.count();
+    //kDebug() << "============================\n" << "matches retrieved: " << m.count();
     /*
     foreach (const Plasma::QueryMatch &match, m) {
         kDebug() << "    " << match.id() << match.text();
@@ -418,5 +418,5 @@ void ResultScene::updateItemMargins()
     }
 }
 
-#include "resultscene.moc"
+#include "moc_resultscene.cpp"
 
