@@ -184,11 +184,6 @@ void QsDialog::display(const QString &term)
     adjustSize();
     m_matchView->setFocus();
 
-    int screen = 0;
-    if (QApplication::desktop()->numScreens() > 1) {
-        screen = QApplication::desktop()->screenNumber(QCursor::pos());
-    }
-
     //positionOnScreen will call QWidget::show anyways so we don't need to call it here
     positionOnScreen();
     KWindowSystem::forceActiveWindow(winId());
@@ -255,7 +250,7 @@ void QsDialog::setMatches(const QList<Plasma::QueryMatch> &matches)
         temp.insert(match.id(), match);
         // Do not create new MatchItems for existing matches when the query hasn't changed
         if (!m_newQuery && m_matches.find(match.id()) != end) {
-            // kDebug() << "A match with id " << match.id() << " already exists." << endl;
+            // kDebug() << "A match with id " << match.id() << " already exists.";
             QList<Plasma::QueryMatch> duplicates = m_matches.values(match.id());
             bool exists = false;
             foreach (const Plasma::QueryMatch &m, duplicates) {
@@ -290,7 +285,7 @@ void QsDialog::setMatches(const QList<Plasma::QueryMatch> &matches)
 
         items.append(m);
     }
-    // kDebug() << "Add " << items.size() << " matches. Append?" << !m_newQuery << endl;
+    // kDebug() << "Add " << items.size() << " matches. Append?" << !m_newQuery;
     m_matchView->setItems(items, true, !m_newQuery);
     m_matches = temp;
     // If new matches are obtained for the same query, append them to the list
@@ -308,7 +303,7 @@ void QsDialog::updateSystemActivityToolTip()
 {
     /* Set the tooltip for the Show System Activity button to include the global shortcut */
     KRunnerApp *krunnerApp = KRunnerApp::self();
-    KAction *showSystemActivityAction = dynamic_cast<KAction *>(krunnerApp->actionCollection()->action(QLatin1String( "Show System Activity" )));
+    KAction *showSystemActivityAction = qobject_cast<KAction *>(krunnerApp->actionCollection()->action(QLatin1String( "Show System Activity" )));
     if (showSystemActivityAction) {
         QString shortcut = showSystemActivityAction->globalShortcut().toString();
         if (shortcut.isEmpty()) {
@@ -318,4 +313,4 @@ void QsDialog::updateSystemActivityToolTip()
         }
     }
 }
-#include "qs_dialog.moc"
+#include "moc_qs_dialog.cpp"
