@@ -20,13 +20,13 @@
 #include <cmath>
 
 #include <QBoxLayout>
-#include <QFocusEvent>
+#include <QtGui/qevent.h>
 #include <QGraphicsItemAnimation>
-#include <QGraphicsPixmapItem>
+#include <QtGui/qgraphicsitem.h>
 #include <QGraphicsView>
 #include <QGraphicsWidget>
-#include <QKeyEvent>
-#include <QResizeEvent>
+#include <QtGui/qevent.h>
+#include <QtGui/qevent.h>
 #include <QStackedWidget>
 #include <QTimeLine>
 #include <QTimer>
@@ -244,7 +244,7 @@ void QsMatchView::setItems(const QList<MatchItem*> &items, bool popup, bool appe
     setItemCount(d->m_items.size());
 
     if (d->m_selectionMade) {
-        //kDebug() << "A user selection was already made" << endl;
+        //kDebug() << "A user selection was already made";
         return;
     }
 
@@ -690,4 +690,4 @@ void QsMatchView::keyPressEvent(QKeyEvent *e)
 
 } // namespace QuickSand
 
-#include "qs_matchview.moc"
+#include "moc_qs_matchview.cpp"
