@@ -29,7 +29,6 @@
 #include <KAction>
 #include <KActionCollection>
 #include <KCrash>
-#include <KAuthorized>
 #include <KLocale>
 #include <KWindowSystem>
 
@@ -42,14 +41,11 @@
 #include "ksystemactivitydialog.h"
 #include "interfaces/default/interface.h"
 #include "interfaces/quicksand/qs_dialog.h"
-#ifdef Q_WS_X11
-#include "startupid.h"
-#endif
-#include "klaunchsettings.h"
 #include "krunnersettings.h"
 
 #ifdef Q_WS_X11
-#include <X11/extensions/Xrender.h>
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
 #endif
 
 KRunnerApp* KRunnerApp::self()
@@ -65,7 +61,6 @@ KRunnerApp::KRunnerApp()
     : KUniqueApplication(),
       m_interface(0),
       m_tasks(0),
-      m_startupId(NULL),
       m_firstTime(true)
 {
     initialize();
@@ -84,10 +79,8 @@ void KRunnerApp::cleanUp()
     m_interface = 0;
     delete m_runnerManager;
     m_runnerManager = 0;
-#ifndef Q_WS_WIN
     delete m_tasks;
     m_tasks = 0;
-#endif
     KGlobal::config()->sync();
 }
 
@@ -102,7 +95,6 @@ void KRunnerApp::initialize()
 
     setQuitOnLastWindowClosed(false);
     KCrash::setFlags(KCrash::AutoRestart);
-    initializeStartupNotification();
 
     connect(KRunnerSettings::self(), SIGNAL(configChanged()), this, SLOT(reloadConfig()));
 
@@ -115,34 +107,27 @@ void KRunnerApp::initialize()
     m_actionCollection = new KActionCollection(this);
     KAction* a = 0;
 
-    if (KAuthorized::authorize(QLatin1String("run_command"))) {
-        a = m_actionCollection->addAction(QLatin1String("Run Command"));
-        a->setText(i18n("Run Command"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::Key_F2));
-        connect(a, SIGNAL(triggered(bool)), SLOT(displayOrHide()));
+    a = m_actionCollection->addAction(QLatin1String("Run Command"));
+    a->setText(i18n("Run Command"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::Key_F2));
+    connect(a, SIGNAL(triggered(bool)), SLOT(displayOrHide()));
 
-        a = m_actionCollection->addAction(QLatin1String("Run Command on clipboard contents"));
-        a->setText(i18n("Run Command on clipboard contents"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_F2));
-        connect(a, SIGNAL(triggered(bool)), SLOT(displayWithClipboardContents()));
-    }
+    a = m_actionCollection->addAction(QLatin1String("Run Command on clipboard contents"));
+    a->setText(i18n("Run Command on clipboard contents"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_F2));
+    connect(a, SIGNAL(triggered(bool)), SLOT(displayWithClipboardContents()));
 
     a = m_actionCollection->addAction(QLatin1String("Show System Activity"));
     a->setText(i18n("Show System Activity"));
     a->setGlobalShortcut(KShortcut(Qt::CTRL+Qt::Key_Escape));
     connect(a, SIGNAL(triggered(bool)), SLOT(showTaskManager()));
 
-    if (KAuthorized::authorize(QLatin1String("switch_user"))) {
-        a = m_actionCollection->addAction(QLatin1String("Switch User"));
-        a->setText(i18n("Switch User"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_Insert));
-        connect(a, SIGNAL(triggered(bool)), SLOT(switchUser()));
-    }
+    a = m_actionCollection->addAction(QLatin1String("Switch User"));
+    a->setText(i18n("Switch User"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_Insert));
+    connect(a, SIGNAL(triggered(bool)), SLOT(switchUser()));
 
     //Setup the interface after we have set up the actions
-    //TODO: if !KAuthorized::authorize("run_comand") (and !"switch_user" i suppose?)
-    //      then we probably don't need the interface at all. would be another place
-    //      for some small improvements in footprint in that case
     switch (KRunnerSettings::interface()) {
         default:
         case KRunnerSettings::EnumInterface::CommandOriented:
@@ -154,9 +139,6 @@ void KRunnerApp::initialize()
     }
 
 #ifdef Q_WS_X11
-    //FIXME: if argb visuals enabled Qt will always set WM_CLASS as "qt-subapplication" no matter what
-    //the application name is we set the proper XClassHint here, hopefully won't be necessary anymore when
-    //qapplication will manage apps with argvisuals in a better way
     XClassHint classHint;
     classHint.res_name = const_cast<char*>("krunner");
     classHint.res_class = const_cast<char*>("krunner");
@@ -165,19 +147,17 @@ void KRunnerApp::initialize()
 
 
     m_actionCollection->readSettings();
-    if (KAuthorized::authorize(QLatin1String("run_command"))) {
-        //m_runnerManager->setAllowedRunners(QStringList() << "shell");
-        m_runnerManager->reloadConfiguration(); // pre-load the runners
+    //m_runnerManager->setAllowedRunners(QStringList() << "shell");
+    m_runnerManager->reloadConfiguration(); // pre-load the runners
 
-        // Single runner mode actions shortcuts
+    // Single runner mode actions shortcuts
 
-        foreach (const QString &runnerId, m_runnerManager->singleModeAdvertisedRunnerIds()) {
-            a = m_actionCollection->addAction(runnerId);
-            a->setText(i18nc("Run krunner restricting the search only to runner %1", "Run Command (runner \"%1\" only)",
-                       m_runnerManager->runnerName(runnerId)));
-            a->setGlobalShortcut(KShortcut());
-            connect(a, SIGNAL(triggered(bool)), SLOT(singleRunnerModeActionTriggered()));
-        }
+    foreach (const QString &runnerId, m_runnerManager->singleModeAdvertisedRunnerIds()) {
+        a = m_actionCollection->addAction(runnerId);
+        a->setText(i18nc("Run krunner restricting the search only to runner %1", "Run Command (runner \"%1\" only)",
+                    m_runnerManager->runnerName(runnerId)));
+        a->setGlobalShortcut(KShortcut());
+        connect(a, SIGNAL(triggered(bool)), SLOT(singleRunnerModeActionTriggered()));
     }
 }
 
@@ -191,10 +171,6 @@ void KRunnerApp::singleRunnerModeActionTriggered()
 
 void KRunnerApp::querySingleRunner(const QString& runnerId, const QString &term)
 {
-    if (!KAuthorized::authorize(QLatin1String("run_command"))) {
-        return;
-    }
-
     m_runnerManager->setSingleModeRunnerId(runnerId);
     m_runnerManager->setSingleMode(!runnerId.isEmpty());
 
@@ -208,24 +184,6 @@ QStringList KRunnerApp::singleModeAdvertisedRunnerIds() const
     return m_runnerManager->singleModeAdvertisedRunnerIds();
 }
 
-void KRunnerApp::initializeStartupNotification()
-{
-    // Startup notification
-    KLaunchSettings::self()->readConfig();
-#ifdef Q_WS_X11
-    if (!KLaunchSettings::busyCursor()) {
-        delete m_startupId;
-        m_startupId = NULL;
-    } else {
-        if (m_startupId == NULL ) {
-            m_startupId = new StartupId;
-        }
-
-        m_startupId->configure();
-    }
-#endif
-}
-
 void KRunnerApp::showTaskManager()
 {
     showTaskManagerWithFilter(QString());
@@ -233,8 +191,7 @@ void KRunnerApp::showTaskManager()
 
 void KRunnerApp::showTaskManagerWithFilter(const QString &filterText)
 {
-#ifndef Q_WS_WIN
-    //kDebug(1204) << "Launching KSysGuard...";
+    //kDebug() << "Launching KSysGuard...";
     if (!m_tasks) {
         m_tasks = new KSystemActivityDialog;
         connect(m_tasks, SIGNAL(finished()),
@@ -247,25 +204,16 @@ void KRunnerApp::showTaskManagerWithFilter(const QString &filterText)
 
     m_tasks->run();
     m_tasks->setFilterText(filterText);
-#endif
 }
 
 void KRunnerApp::display()
 {
-    if (!KAuthorized::authorize(QLatin1String("run_command"))) {
-        return;
-    }
-
     m_runnerManager->setSingleMode(false);
     m_interface->display();
 }
 
 void KRunnerApp::displaySingleRunner(const QString &runnerId)
 {
-    if (!KAuthorized::authorize(QLatin1String("run_command"))) {
-        return;
-    }
-
     m_runnerManager->setSingleModeRunnerId(runnerId);
     m_runnerManager->setSingleMode(!runnerId.isEmpty());
     m_interface->display();
@@ -273,11 +221,6 @@ void KRunnerApp::displaySingleRunner(const QString &runnerId)
 
 void KRunnerApp::displayOrHide()
 {
-    if (!KAuthorized::authorize(QLatin1String("run_command"))) {
-        m_interface->hide();
-        return;
-    }
-
     if (!m_interface->isVisible()) {
         m_runnerManager->setSingleMode(false);
     }
@@ -297,19 +240,11 @@ void KRunnerApp::displayOrHide()
 
 void KRunnerApp::query(const QString &term)
 {
-    if (!KAuthorized::authorize(QLatin1String("run_command"))) {
-        return;
-    }
-
     m_interface->display(term);
 }
 
 void KRunnerApp::displayWithClipboardContents()
 {
-    if (!KAuthorized::authorize(QLatin1String("run_command"))) {
-        return;
-    }
-
     QString clipboardData = QApplication::clipboard()->text(QClipboard::Selection);
     m_interface->display(clipboardData);
 }
@@ -348,10 +283,8 @@ void KRunnerApp::clearHistory()
 
 void KRunnerApp::taskDialogFinished()
 {
-#ifndef Q_WS_WIN
     m_tasks->deleteLater();
     m_tasks = 0;
-#endif
 }
 
 int KRunnerApp::newInstance()
@@ -387,4 +320,4 @@ void KRunnerApp::reloadConfig()
     display();
 }
 
-#include "krunnerapp.moc"
+#include "moc_krunnerapp.cpp"
