@@ -19,15 +19,13 @@
 #include "krunnerdialog.h"
 
 #include <QPainter>
-#include <QSvgRenderer>
-#include <QResizeEvent>
-#include <QMouseEvent>
-#ifdef Q_WS_X11
-#include <QX11Info>
-#endif
+#include <QtGui/qevent.h>
 #include <QBitmap>
 #include <QTimer>
 #include <QDesktopWidget>
+#ifdef Q_WS_X11
+#include <QtGui/qx11info_x11.h>
+#endif
 
 #include <KDebug>
 #include <KWindowSystem>
@@ -36,8 +34,6 @@
 #include <NETRootInfo>
 #endif
 
-#include <QtCore/QStringBuilder> // % operator for QString
-
 #include "kworkspace/kdisplaymanager.h"
 
 #include <Plasma/AbstractRunner>
@@ -59,7 +55,6 @@ KRunnerDialog::KRunnerDialog(Plasma::RunnerManager *runnerManager, QWidget *pare
     : QWidget(parent, f),
       m_runnerManager(runnerManager),
       m_configWidget(0),
-      m_shadows(new PanelShadows(this)),
       m_background(new Plasma::FrameSvg(this)),
       m_shownOnScreen(-1),
       m_offset(.5),
@@ -203,14 +198,17 @@ void KRunnerDialog::updatePresentation()
     if (m_floating) {
         KWindowSystem::setType(winId(), NET::Normal);
 
-        //m_shadows->setImagePath(QLatin1String("dialogs/krunner"));
         m_background->setImagePath(QLatin1String("dialogs/krunner"));
         m_background->setElementPrefix(QString());
 
         themeUpdated();
     } else {
-        //m_shadows->setImagePath(QLatin1String("widgets/panel-background"));
-        m_background->setImagePath(QLatin1String("widgets/panel-background"));
+        if (KWindowSystem::compositingActive()) {
+            m_background->setImagePath(QLatin1String("widgets/translucentbackground"));
+        }
+        if (!m_background->isValid()) {
+            m_background->setImagePath(QLatin1String("widgets/panel-background"));
+        }
         m_background->resizeFrame(size());
         m_background->setElementPrefix("north-mini");
         // load the positions for each screen from our config
@@ -285,35 +283,27 @@ void KRunnerDialog::configCompleted()
 
 void KRunnerDialog::themeUpdated()
 {
-    m_shadows->addWindow(this);
-
-    bool useShadowsForMargins = false;
     if (m_floating) {
         // recalc the contents margins
         m_background->blockSignals(true);
         if (KWindowSystem::compositingActive()) {
             m_background->setEnabledBorders(Plasma::FrameSvg::NoBorder);
-            useShadowsForMargins = true;
         } else {
             m_background->setEnabledBorders(Plasma::FrameSvg::AllBorders);
         }
         m_background->blockSignals(false);
     }
 
-    if (useShadowsForMargins) {
-        m_shadows->getMargins(m_topBorderHeight, m_rightBorderWidth, m_bottomBorderHeight, m_leftBorderWidth);
-    } else {
-        m_leftBorderWidth = qMax(0, int(m_background->marginSize(Plasma::LeftMargin)));
-        m_rightBorderWidth = qMax(0, int(m_background->marginSize(Plasma::RightMargin)));
-        m_bottomBorderHeight = qMax(0, int(m_background->marginSize(Plasma::BottomMargin)));
-        // the -1 in the non-floating case is not optimal, but it gives it a bit of a "more snug to the
-        // top" feel; best would be if we could tell exactly where the edge/shadow of the frame svg was
-        // but this works nicely
-        m_topBorderHeight = m_floating ? qMax(0, int(m_background->marginSize(Plasma::TopMargin)))
-                                       : Plasma::Theme::defaultTheme()->windowTranslucencyEnabled()
-                                            ? qMax(1, m_bottomBorderHeight / 2)
-                                            : qMax(1, m_bottomBorderHeight - 1);
-    }
+    m_leftBorderWidth = qMax(0, int(m_background->marginSize(Plasma::LeftMargin)));
+    m_rightBorderWidth = qMax(0, int(m_background->marginSize(Plasma::RightMargin)));
+    m_bottomBorderHeight = qMax(0, int(m_background->marginSize(Plasma::BottomMargin)));
+    // the -1 in the non-floating case is not optimal, but it gives it a bit of a "more snug to the
+    // top" feel; best would be if we could tell exactly where the edge/shadow of the frame svg was
+    // but this works nicely
+    m_topBorderHeight = m_floating ? qMax(0, int(m_background->marginSize(Plasma::TopMargin)))
+                                    : Plasma::Theme::defaultTheme()->windowTranslucencyEnabled()
+                                        ? qMax(1, m_bottomBorderHeight / 2)
+                                        : qMax(1, m_bottomBorderHeight - 1);
 
     kDebug() << m_leftBorderWidth << m_topBorderHeight << m_rightBorderWidth << m_bottomBorderHeight;
     // the +1 gives us the extra mouseMoveEvent needed to always reset the resize cursor
@@ -334,7 +324,7 @@ void KRunnerDialog::paintEvent(QPaintEvent *e)
 
 void KRunnerDialog::showEvent(QShowEvent *)
 {
-    unsigned long state = NET::SkipTaskbar | NET::KeepAbove | NET::StaysOnTop;
+    unsigned long state = NET::SkipTaskbar | NET::KeepAbove;
     if (m_floating) {
         KWindowSystem::clearState(winId(), state);
     } else {
@@ -362,9 +352,6 @@ void KRunnerDialog::updateMask()
 
     if (KWindowSystem::compositingActive()) {
         clearMask();
-        const QRegion mask = m_background->mask();
-        Plasma::WindowEffects::enableBlurBehind(winId(), true, mask);
-        Plasma::WindowEffects::overrideShadow(winId(), true);
     } else {
         setMask(m_background->mask());
     }
@@ -552,4 +539,4 @@ bool KRunnerDialog::checkCursor(const QPoint &pos)
     return false;
 }
 
-#include "krunnerdialog.moc"
+#include "moc_krunnerdialog.cpp"
