@@ -24,10 +24,34 @@
  to connect to X, 2 when it's not possible to connect to X.
 */
 int main()
-    {
-    Display* dpy = XOpenDisplay( NULL );
-    if( dpy == NULL )
+{
+    Display* dpy = XOpenDisplay(NULL);
+    if (dpy == NULL) {
         return 2;
-    Atom atom = XInternAtom( dpy, "_KDE_RUNNING", False );
-    return XGetSelectionOwner( dpy, atom ) != None ? 0 : 1;
     }
+    Atom atom = XInternAtom(dpy, "_KDE_RUNNING", False);
+    if (XGetSelectionOwner(dpy, atom) != None) {
+        XCloseDisplay(dpy);
+        return 0;
+    }
+    // if ksmserver is not started yet check for the X11 atom that startkde sets
+    Atom type = None;
+    int format = 0;
+    unsigned long nitems = 0;
+    unsigned long after = 0;
+    unsigned char* data = NULL;
+    const int kde_full_session_status = XGetWindowProperty(
+        dpy, RootWindow(dpy, 0),
+        XInternAtom(dpy, "KDE_FULL_SESSION", False),
+        0, 0, False, AnyPropertyType, &type, &format, &nitems, &after, &data
+    );
+    const bool kde_running = (kde_full_session_status == Success && data);
+    if (data) {
+        XFree(data);
+    }
+    XCloseDisplay(dpy);
+    if (kde_running) {
+        return 0;
+    }
+    return 1;
+}
