@@ -35,18 +35,15 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "ksmserverinterfaceadaptor.h"
 
 #include <config-workspace.h>
-#include <config-unix.h> // HAVE_LIMITS_H
+#include <config-unix.h>
 #include <config-ksmserver.h>
-#include <pwd.h>
+
 #include <sys/types.h>
 #include <sys/param.h>
 #include <sys/stat.h>
-#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#endif
 #include <sys/socket.h>
 #include <sys/un.h>
-
 #include <unistd.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -55,21 +52,18 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <string.h>
 #include <assert.h>
 #include <fcntl.h>
-#include <kdefakes.h>
-
-#ifdef HAVE_LIMITS_H
 #include <limits.h>
-#endif
 
 #include <QFile>
 #include <QPushButton>
 #include <QRegExp>
 #include <QtDBus/QtDBus>
 #include <QSocketNotifier>
+#include <QtCore/QFileInfo>
+#include <QtGui/qx11info_x11.h>
 
 #include <kaction.h>
 #include <kactioncollection.h>
-#include <kauthorized.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <kconfig.h>
@@ -81,18 +75,11 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kprocess.h>
 #include <kdebug.h>
 #include <kshell.h>
-
-#include "server.moc"
-
-// must go after #include <config-ksmserver.h>
-#ifdef COMPILE_SCREEN_LOCKER
-#include "screenlocker/ksldapp.h"
-#endif
-
+#include <kuser.h>
 #include <kworkspace/kdisplaymanager.h>
-#include <QX11Info>
 #include <krandom.h>
 #include <klauncher_iface.h>
+#include <kde_file.h>
 
 KSMServer* the_server = 0;
 
@@ -104,19 +91,19 @@ KSMServer* KSMServer::self()
 /*! Utility function to execute a command on the local machine. Used
  * to restart applications.
  */
-KProcess* KSMServer::startApplication( const QStringList& cmd, const QString& clientMachine,
-    const QString& userId, bool wm )
+bool KSMServer::startApplication( const QStringList& cmd, const QString& clientMachine,
+    const QString& userId )
 {
     QStringList command = cmd;
     if ( command.isEmpty() )
-        return NULL;
+        return false;
     if ( !userId.isEmpty()) {
-        struct passwd* pw = getpwuid( getuid());
-        if( pw != NULL && userId != QString::fromLocal8Bit( pw->pw_name )) {
+        const KUser kuser(::getuid());
+        if( kuser.isValid() && userId != kuser.loginName() ) {
             command.prepend( "--" );
             command.prepend( userId );
             command.prepend( "-u" );
-            command.prepend( KStandardDirs::findExe("kdesu") );
+            command.prepend( KStandardDirs::findExe("kdesudo") );
         }
     }
     if ( !clientMachine.isEmpty() && clientMachine != "localhost" ) {
@@ -124,28 +111,15 @@ KProcess* KSMServer::startApplication( const QStringList& cmd, const QString& cl
         command.prepend( xonCommand ); // "xon" by default
     }
 
-// TODO this function actually should not use KProcess at all and use klauncher (kdeinit) instead.
-// Klauncher should also have support for tracking whether the launched process is still alive
-// or not, so this should be redone. For now, use KProcess for wm's, as they need to be tracked,
-// klauncher for the rest where ksmserver doesn't care.
-    if( wm ) {
-        KProcess* process = new KProcess( this );
-        *process << command;
-        // make it auto-delete
-        connect( process, SIGNAL(error(QProcess::ProcessError)), process, SLOT(deleteLater()));
-        connect( process, SIGNAL(finished(int,QProcess::ExitStatus)), process, SLOT(deleteLater()));
-        process->start();
-        return process;
-    } else {
-        int n = command.count();
-        org::kde::KLauncher klauncher("org.kde.klauncher", "/KLauncher", QDBusConnection::sessionBus());
-        QString app = command[0];
-        QStringList argList;
-        for ( int i=1; i < n; i++)
-           argList.append( command[i]);
-        klauncher.exec_blind(app, argList );
-        return NULL;
-    }
+
+    int n = command.count();
+    org::kde::KLauncher klauncher("org.kde.klauncher", "/KLauncher", QDBusConnection::sessionBus());
+    QString app = command[0];
+    QStringList argList;
+    for ( int i=1; i < n; i++)
+        argList.append( command[i]);
+    klauncher.exec_blind(app, argList );
+    return true;
 }
 
 /*! Utility function to execute a command on the local machine. Used
@@ -156,7 +130,9 @@ void KSMServer::executeCommand( const QStringList& command )
     if ( command.isEmpty() )
         return;
 
-    KProcess::execute( command );
+    QStringList args = command;
+    QString program = args.takeAt(0);
+    QProcess::execute( program, args );
 }
 
 IceAuthDataEntry *authDataEntries = 0;
@@ -454,16 +430,14 @@ Status SetAuthentication (int count, IceListenObj *listenObjs,
     fclose(addAuthFile);
     fclose(remAuthFile);
 
-    QString iceAuth = KGlobal::dirs()->findExe("iceauth");
+    QString iceAuth = KStandardDirs::findExe("iceauth");
     if (iceAuth.isEmpty())
     {
         qWarning("KSMServer: could not find iceauth");
         return 0;
     }
 
-    KProcess p;
-    p << iceAuth << "source" << addTempFile.fileName();
-    p.execute();
+    QProcess::execute(iceAuth, QStringList() << "source" << addTempFile.fileName());
 
     return (1);
 }
@@ -484,7 +458,7 @@ void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
 
     free (authDataEntries);
 
-    QString iceAuth = KGlobal::dirs()->findExe("iceauth");
+    QString iceAuth = KStandardDirs::findExe("iceauth");
     if (iceAuth.isEmpty())
     {
         qWarning("KSMServer: could not find iceauth");
@@ -493,9 +467,7 @@ void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
 
     if (remTempFile)
     {
-        KProcess p;
-        p << iceAuth << "source" << remTempFile->fileName();
-        p.execute();
+        QProcess::execute(iceAuth, QStringList() << "source" << remTempFile->fileName());
     }
 
     delete remTempFile;
@@ -604,20 +576,14 @@ extern "C" int _IceTransNoListen(const char * protocol);
 #endif
 
 KSMServer::KSMServer( const QString& windowManager, bool _only_local, bool lockscreen )
-  : wmProcess( NULL )
+  : wmProcess( new QProcess( this ) )
   , sessionGroup( "" )
   , logoutEffectWidget( NULL )
 {
-#ifdef COMPILE_SCREEN_LOCKER
-    KGlobal::locale()->insertCatalog(QLatin1String( "libkworkspace" ));
-
-    ScreenLocker::KSldApp::self();
     if (lockscreen) {
-        ScreenLocker::KSldApp::self()->lock();
+        QDBusInterface screensaver("org.freedesktop.ScreenSaver", "/ScreenSaver", "org.freedesktop.ScreenSaver");
+        screensaver.asyncCall("Lock");
     }
-#else
-    Q_UNUSED(lockscreen)
-#endif
 
     new KSMServerInterfaceAdaptor( this );
     QDBusConnection::sessionBus().registerObject("/KSMServer", this);
@@ -670,7 +636,7 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local, bool locks
 
     {
         // publish available transports.
-        QByteArray fName = QFile::encodeName(KStandardDirs::locateLocal("socket", "KSMserver"));
+        QByteArray fName = QFile::encodeName(KStandardDirs::locateLocal("tmp", "KSMserver"));
         QString display = ::getenv("DISPLAY");
         // strip the screen number from the display
         display.replace(QRegExp("\\.[0-9]+$"), "");
@@ -719,10 +685,10 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local, bool locks
         connect( con, SIGNAL(activated(int)), this, SLOT(newConnection(int)) );
     }
 
-    signal(SIGHUP, sighandler);
-    signal(SIGTERM, sighandler);
-    signal(SIGINT, sighandler);
-    signal(SIGPIPE, SIG_IGN);
+    KDE_signal(SIGHUP, sighandler);
+    KDE_signal(SIGTERM, sighandler);
+    KDE_signal(SIGINT, sighandler);
+    KDE_signal(SIGPIPE, SIG_IGN);
 
     connect( &protectionTimer, SIGNAL(timeout()), this, SLOT(protectionTimeout()) );
     connect( &restoreTimer, SIGNAL(timeout()), this, SLOT(tryRestoreNext()) );
@@ -740,9 +706,15 @@ void KSMServer::cleanUp()
 {
     if (clean) return;
     clean = true;
+
+    if (wmProcess && wmProcess->state() != QProcess::NotRunning) {
+        wmProcess->kill();
+        wmProcess->waitForFinished();
+    }
+
     IceFreeListenObjs (numTransports, listenObjs);
 
-    QByteArray fName = QFile::encodeName(KStandardDirs::locateLocal("socket", "KSMserver"));
+    QByteArray fName = QFile::encodeName(KStandardDirs::locateLocal("tmp", "KSMserver"));
     QString display  = QString::fromLocal8Bit(::getenv("DISPLAY"));
     // strip the screen number from the display
     display.replace(QRegExp("\\.[0-9]+$"), "");
@@ -756,14 +728,14 @@ void KSMServer::cleanUp()
     ::unlink(fName.data());
 
     FreeAuthenticationData(numTransports, authDataEntries);
-    signal(SIGTERM, SIG_DFL);
-    signal(SIGINT, SIG_DFL);
 
-    KDisplayManager().shutdown( shutdownType, shutdownMode, bootOption );
+    KDE_signal(SIGTERM, SIG_DFL);
+    KDE_signal(SIGINT, SIG_DFL);
+
+    KDisplayManager().shutdown( shutdownType, shutdownMode );
 }
 
 
-
 void* KSMServer::watchConnection( IceConn iceConn )
 {
     KSMConnection* conn = new KSMConnection( iceConn );
@@ -869,7 +841,7 @@ void KSMServer::discardSession()
 {
     KConfigGroup config(KGlobal::config(), sessionGroup );
     int count =  config.readEntry( "count", 0 );
-	foreach ( KSMClient *c, clients ) {
+    foreach ( KSMClient *c, clients ) {
         QStringList discardCommand = c->discardCommand();
         if ( discardCommand.isEmpty())
             continue;
@@ -909,7 +881,7 @@ void KSMServer::storeSession()
         executeCommand( discardCommand );
     }
     config->deleteGroup( sessionGroup ); //### does not work with global config object...
-	KConfigGroup cg( config, sessionGroup);
+    KConfigGroup cg( config, sessionGroup);
     count =  0;
 
     if (state != ClosingSubSession) {
@@ -1036,29 +1008,27 @@ void KSMServer::wmChanged()
 
 void KSMServer::setupShortcuts()
 {
-    if (KAuthorized::authorize("logout")) {
-        KActionCollection* actionCollection = new KActionCollection(this);
-        KAction* a;
-        a = actionCollection->addAction("Log Out");
-        a->setText(i18n("Log Out"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_Delete));
-        connect(a, SIGNAL(triggered(bool)), SLOT(defaultLogout()));
+    KActionCollection* actionCollection = new KActionCollection(this);
+    KAction* a;
+    a = actionCollection->addAction("Log Out");
+    a->setText(i18n("Log Out"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_Delete));
+    connect(a, SIGNAL(triggered(bool)), SLOT(defaultLogout()));
 
-        a = actionCollection->addAction("Log Out Without Confirmation");
-        a->setText(i18n("Log Out Without Confirmation"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::SHIFT+Qt::Key_Delete));
-        connect(a, SIGNAL(triggered(bool)), SLOT(logoutWithoutConfirmation()));
+    a = actionCollection->addAction("Log Out Without Confirmation");
+    a->setText(i18n("Log Out Without Confirmation"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::SHIFT+Qt::Key_Delete));
+    connect(a, SIGNAL(triggered(bool)), SLOT(logoutWithoutConfirmation()));
 
-        a = actionCollection->addAction("Halt Without Confirmation");
-        a->setText(i18n("Halt Without Confirmation"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::SHIFT+Qt::Key_PageDown));
-        connect(a, SIGNAL(triggered(bool)), SLOT(haltWithoutConfirmation()));
+    a = actionCollection->addAction("Halt Without Confirmation");
+    a->setText(i18n("Halt Without Confirmation"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::SHIFT+Qt::Key_PageDown));
+    connect(a, SIGNAL(triggered(bool)), SLOT(haltWithoutConfirmation()));
 
-        a = actionCollection->addAction("Reboot Without Confirmation");
-        a->setText(i18n("Reboot Without Confirmation"));
-        a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::SHIFT+Qt::Key_PageUp));
-        connect(a, SIGNAL(triggered(bool)), SLOT(rebootWithoutConfirmation()));
-    }
+    a = actionCollection->addAction("Reboot Without Confirmation");
+    a->setText(i18n("Reboot Without Confirmation"));
+    a->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::SHIFT+Qt::Key_PageUp));
+    connect(a, SIGNAL(triggered(bool)), SLOT(rebootWithoutConfirmation()));
 }
 
 void KSMServer::defaultLogout()
@@ -1080,3 +1050,5 @@ void KSMServer::rebootWithoutConfirmation()
 {
     shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeReboot, KWorkSpace::ShutdownModeDefault);
 }
+
+#include "moc_server.cpp"
