@@ -25,17 +25,17 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef SERVER_H
 #define SERVER_H
 
-// needed to avoid clash with INT8 defined in X11/Xmd.h on solaris
-#define QT_CLEAN_NAMESPACE 1
 #include <QStringList>
 #include <QObject>
+#include <QProcess>
+#include <QTimer>
+#include <QDateTime>
+#include <QDBusInterface>
+#include <QMap>
 
 #include <kapplication.h>
 #include <kworkspace/kworkspace.h>
 #include <kmessagebox.h>
-#include <QTimer>
-#include <QTime>
-#include <QMap>
 
 #define INT32 QINT32
 #include <X11/Xlib.h>
@@ -54,14 +54,11 @@ extern "C" {
 #define SESSION_PREVIOUS_LOGOUT "saved at previous logout"
 #define SESSION_BY_USER  "saved by user"
 
-class KProcess;
-
 class KSMListener;
 class KSMConnection;
 class KSMClient;
 
 class OrgKdeKLauncherInterface;
-class QDBusInterface;
 
 enum SMType { SM_ERROR, SM_WMCOMMAND, SM_WMSAVEYOURSELF };
 struct SMData
@@ -161,18 +158,15 @@ private:
     void killingCompleted();
     void createLogoutEffectWidget();
 
-    void runUserAutostart();
-
     void discardSession();
     void storeSession();
 
     void startProtection();
     void endProtection();
 
-    KProcess* startApplication( const QStringList& command,
-        const QString& clientMachine = QString(),
-        const QString& userId = QString(),
-        bool wm = false );
+    bool startApplication( const QStringList& command,
+                           const QString& clientMachine = QString(),
+                           const QString& userId = QString());
     void executeCommand( const QStringList& command );
 
     bool isWM( const KSMClient* client ) const;
@@ -218,13 +212,12 @@ private:
     QList<KSMListener*> listener;
     QList<KSMClient*> clients;
 
-    enum State
-        {
+    enum State {
         Idle,
         LaunchingWM, AutoStart0, KcmInitPhase1, AutoStart1, Restoring, FinishingStartup, // startup
         Shutdown, Checkpoint, Killing, KillingWM, WaitingForKNotify, // shutdown
         ClosingSubSession, KillingSubSession, RestoringSubSession
-        };
+    };
     State state;
     bool dialogActive;
     bool saveSession;
@@ -234,13 +227,12 @@ private:
 
     KWorkSpace::ShutdownType shutdownType;
     KWorkSpace::ShutdownMode shutdownMode;
-    QString bootOption;
 
     bool clean;
     KSMClient* clientInteracting;
     QString wm;
     QStringList wmCommands;
-    KProcess* wmProcess;
+    QProcess* wmProcess;
     QString sessionGroup;
     QString sessionName;
     QTimer protectionTimer;
@@ -255,9 +247,6 @@ private:
     KWorkSpace::ShutdownType pendingShutdown_sdtype;
     KWorkSpace::ShutdownMode pendingShutdown_sdmode;
 
-    // ksplash interface
-    void upAndRunning( const QString& msg );
-
     // sequential startup
     int appsToStart;
     int lastAppStarted;
