@@ -28,20 +28,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 ******************************************************************/
 
+#include <config-unix.h>
 
-#include <config-workspace.h>
-#include <config-unix.h> // HAVE_LIMITS_H
-
-#include <pwd.h>
 #include <sys/types.h>
 #include <sys/param.h>
 #include <sys/stat.h>
-#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#endif
 #include <sys/socket.h>
 #include <sys/un.h>
-
 #include <unistd.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -49,10 +43,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <errno.h>
 #include <string.h>
 #include <assert.h>
-
-#ifdef HAVE_LIMITS_H
 #include <limits.h>
-#endif
 
 #include <QPushButton>
 #include <QTimer>
@@ -67,6 +58,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <KStandardDirs>
 #include <KTemporaryFile>
 #include <kworkspace/kdisplaymanager.h>
+
 #include "server.h"
 #include "global.h"
 #include "client.h"
@@ -77,7 +69,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kdebug.h>
 
 #include <QDesktopWidget>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 
@@ -125,7 +117,7 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
     KSharedConfig::Ptr config = KGlobal::config();
     config->reparseConfiguration(); // config may have changed in the KControl module
 
-	KConfigGroup cg( config, "General");
+    KConfigGroup cg( config, "General");
 
     bool logoutConfirmed =
         (confirm == KWorkSpace::ShutdownConfirmYes) ? false :
@@ -150,12 +142,10 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
         sdmode = KWorkSpace::ShutdownModeInteractive;
 
     dialogActive = true;
-    QString bopt;
     if ( !logoutConfirmed ) {
         KApplication::kApplication()->updateUserTimestamp();
-        KSMShutdownFeedback::start(); // make the screen gray
         QString theme = cg.readEntry( "theme", "default" );
-        logoutConfirmed = KSMShutdownDlg::confirmShutdown( maysd, choose, sdtype, bopt, theme);
+        logoutConfirmed = KSMShutdownDlg::confirmShutdown( maysd, choose, sdtype, theme);
         // ###### We can't make the screen remain gray while talking to the apps,
         // because this prevents interaction ("do you want to save", etc.)
         // TODO: turn the feedback widget into a list of apps to be closed,
@@ -171,7 +161,6 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
 
         shutdownType = sdtype;
         shutdownMode = sdmode;
-        bootOption = bopt;
 
         // shall we save the session on logout?
         saveSession = ( cg.readEntry( "loginMode", "restorePreviousLogout" ) == "restorePreviousLogout" );
@@ -223,8 +212,6 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
         }
         if ( clients.isEmpty() )
             completeShutdownOrCheckpoint();
-    } else {
-        KSMShutdownFeedback::logoutCanceled(); // make the screen become normal again
     }
     dialogActive = false;
 }
@@ -384,7 +371,7 @@ void KSMServer::cancelShutdown( KSMClient* c )
     } else {
         Solid::PowerManagement::stopSuppressingSleep(inhibitCookie);
         kDebug( 1218 ) << "Client " << c->program() << " (" << c->clientId() << ") canceled shutdown.";
-        KSMShutdownFeedback::logoutCanceled(); // make the screen become normal again
+        KSMShutdownFeedback::stop(); // make the screen become normal again
         KNotification::event( "cancellogout" , i18n( "Logout canceled by '%1'", c->program()),
                               QPixmap() , 0l , KNotification::DefaultEvent  );
         foreach( KSMClient* c, clients ) {
@@ -470,11 +457,11 @@ void KSMServer::completeShutdownOrCheckpoint()
         discardSession();
 
     if ( state == Shutdown ) {
-        KNotification *n = KNotification::event( "exitkde" , QString() , QPixmap() , 0l ,  KNotification::DefaultEvent  ); // KDE says good bye
+        // KDE says good bye
+        KNotification *n = KNotification::event( "exitkde" , QString() , QPixmap() , 0l ,  KNotification::DefaultEvent  );
         connect(n, SIGNAL(closed()) , this, SLOT(logoutSoundFinished()) );
         // https://bugs.kde.org/show_bug.cgi?id=228005
-        // if sound is not working for some reason (e.g. no phonon
-        // backends are installed) the closed() signal never happens
+        // if sound is not working for some reason the closed() signal never happens
         // and logoutSoundFinished() never gets called. Add this timer to make
         // sure the shutdown procedure continues even if sound system is broken.
         QTimer::singleShot(5000, this, SLOT(logoutSoundTimeout()));
@@ -514,16 +501,14 @@ void KSMServer::startKilling()
         SmsDie( c->connection() );
     }
 
-    kDebug( 1218 ) << " We killed all clients. We have now clients.count()=" <<
-    clients.count() << endl;
+    kDebug( 1218 ) << " We killed all clients. We have now clients.count()=" << clients.count();
     completeKilling();
     QTimer::singleShot( 10000, this, SLOT(timeoutQuit()) );
 }
 
 void KSMServer::completeKilling()
 {
-    kDebug( 1218 ) << "KSMServer::completeKilling clients.count()=" <<
-        clients.count() << endl;
+    kDebug( 1218 ) << "KSMServer::completeKilling clients.count()=" << clients.count();
     if( state == Killing ) {
         bool wait = false;
         foreach( KSMClient* c, clients ) {
@@ -542,10 +527,6 @@ void KSMServer::killWM()
     if( state != Killing )
         return;
     delete logoutEffectWidget;
-#ifdef COMPILE_SCREEN_LOCKER
-    // To prevent kwin from becoming "defunct".
-    ScreenLocker::KSldApp::self()->cleanUp();
-#endif
     kDebug( 1218 ) << "Starting killing WM";
     state = KillingWM;
     bool iswm = false;
@@ -566,8 +547,7 @@ void KSMServer::killWM()
 
 void KSMServer::completeKillingWM()
 {
-    kDebug( 1218 ) << "KSMServer::completeKillingWM clients.count()=" <<
-        clients.count() << endl;
+    kDebug( 1218 ) << "KSMServer::completeKillingWM clients.count()=" << clients.count();
     if( state == KillingWM ) {
         if( clients.isEmpty())
             killingCompleted();
@@ -612,18 +592,17 @@ void KSMServer::createLogoutEffectWidget()
     logoutEffectWidget = new QWidget( NULL, Qt::X11BypassWindowManagerHint );
     logoutEffectWidget->winId(); // workaround for Qt4.3 setWindowRole() assert
     logoutEffectWidget->setWindowRole( "logouteffect" );
-//#if !(QT_VERSION >= QT_VERSION_CHECK(4, 3, 3) || defined(QT_KDE_QT_COPY))
 // Qt doesn't set this on unmanaged windows
-    QByteArray appName = qAppName().toLatin1();
+    QByteArray appName = QApplication::applicationName().toLatin1();
+    QByteArray appClass = QX11Info::appClass();
     XClassHint class_hint;
     class_hint.res_name = appName.data(); // application name
-    class_hint.res_class = const_cast<char *>(QX11Info::appClass());   // application class
+    class_hint.res_class = appClass.data();   // application class
     XSetWMProperties( QX11Info::display(), logoutEffectWidget->winId(),
         NULL, NULL, NULL, 0, NULL, NULL, &class_hint );
     XChangeProperty( QX11Info::display(), logoutEffectWidget->winId(),
         XInternAtom( QX11Info::display(), "WM_WINDOW_ROLE", False ), XA_STRING, 8, PropModeReplace,
         (unsigned char *)"logouteffect", strlen( "logouteffect" ));
-//#endif
     logoutEffectWidget->setGeometry( -100, -100, 1, 1 );
     logoutEffectWidget->show();
 }
@@ -672,16 +651,14 @@ void KSMServer::startKillingSubSession()
         SmsDie( c->connection() );
     }
 
-    kDebug( 1218 ) << " We killed some clients. We have now clients.count()=" <<
-    clients.count() << endl;
+    kDebug( 1218 ) << " We killed some clients. We have now clients.count()=" << clients.count();
     completeKillingSubSession();
     QTimer::singleShot( 10000, this, SLOT(signalSubSessionClosed()) );
 }
 
 void KSMServer::completeKillingSubSession()
 {
-    kDebug( 1218 ) << "KSMServer::completeKillingSubSession clients.count()=" <<
-        clients.count() << endl;
+    kDebug( 1218 ) << "KSMServer::completeKillingSubSession clients.count()=" << clients.count();
     if( state == KillingSubSession ) {
         bool wait = false;
         foreach( KSMClient* c, clientsToKill ) {
