@@ -23,10 +23,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 ******************************************************************/
 
+#include "config-workspace.h"
 #include "shutdowndlg.h"
 #include "plasma/framesvg.h"
 #include "plasma/theme.h"
 
+#include <stdio.h>
+
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QTimer>
@@ -43,64 +46,17 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kuser.h>
+#include <kjob.h>
 #include <Solid/PowerManagement>
 #include <kwindowsystem.h>
 #include <netwm.h>
 #include <KStandardDirs>
 #include <kdeclarative.h>
-
-#include <stdio.h>
 #include <kxerrorhandler.h>
 
 #include <kworkspace/kdisplaymanager.h>
 
-#include <config-workspace.h>
-
-#include "logouteffect.h"
-#include "shutdowndlg.moc"
-
-#include <kjob.h>
-
-#define FONTCOLOR "#bfbfbf"
-
-KSMShutdownFeedback * KSMShutdownFeedback::s_pSelf = 0L;
-
-KSMShutdownFeedback::KSMShutdownFeedback()
- : QWidget( 0L, Qt::Popup ),
-    m_currentY( 0 ), initialized( false )
-{
-    setObjectName( "feedbackwidget" );
-    setAttribute( Qt::WA_NoSystemBackground );
-    setAttribute( Qt::WA_PaintOnScreen );
-    setGeometry( QApplication::desktop()->geometry() );
-    m_pixmap = QPixmap( size() );
-    QTimer::singleShot( 10, this, SLOT(slotPaintEffect()) );
-}
-
-
-void KSMShutdownFeedback::paintEvent( QPaintEvent* )
-{
-    if ( !initialized )
-        return;
-
-    QPainter painter( this );
-    painter.setCompositionMode( QPainter::CompositionMode_Source );
-    painter.drawPixmap( 0, 0, m_pixmap );
-}
-
-void KSMShutdownFeedback::slotPaintEffect()
-{
-    effect = LogoutEffect::create(this, &m_pixmap);
-    connect(effect, SIGNAL(initialized()),
-            this,   SLOT  (slotPaintEffectInitialized()));
-
-    effect->start();
-}
-
-void KSMShutdownFeedback::slotPaintEffectInitialized()
-{
-    initialized = true;
-}
+#include "moc_shutdowndlg.cpp"
 
 void KSMShutdownFeedback::start()
 {
@@ -133,17 +89,9 @@ void KSMShutdownFeedback::start()
             return;
         }
     }
-    s_pSelf = new KSMShutdownFeedback();
-    s_pSelf->show();
 }
 
 void KSMShutdownFeedback::stop()
-{
-    delete s_pSelf;
-    s_pSelf = NULL;
-}
-
-void KSMShutdownFeedback::logoutCanceled()
 {
     if( KWindowSystem::compositingActive()) {
         // We are no longer logging out, announce (Intended for the compositor)
@@ -164,20 +112,7 @@ KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
     // this is a WType_Popup on purpose. Do not change that! Not
     // having a popup here has severe side effects.
 {
-    winId(); // workaround for Qt4.3 setWindowRole() assert
-    setWindowRole( "logoutdialog" );
-//#if !(QT_VERSION >= QT_VERSION_CHECK(4, 3, 3) || defined(QT_KDE_QT_COPY))
-// Qt doesn't set this on unmanaged windows
-    QByteArray appName = qAppName().toLatin1();
-    XClassHint class_hint;
-    class_hint.res_name = appName.data(); // application name
-    class_hint.res_class = const_cast<char *>(QX11Info::appClass());   // application class
-    XSetWMProperties( QX11Info::display(), winId(), NULL, NULL, NULL, 0, NULL, NULL, &class_hint );
-    XChangeProperty( QX11Info::display(), winId(),
-        XInternAtom( QX11Info::display(), "WM_WINDOW_ROLE", False ), XA_STRING, 8, PropModeReplace,
-        (unsigned char *)"logoutdialog", strlen( "logoutdialog" ));
-
-//#endif
+    KSMShutdownFeedback::start(); // make the screen gray
 
     KDialog::centerOnScreen(this, -3);
 
@@ -203,21 +138,6 @@ KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
     mapSpdMethods->insert("HibernateState", QVariant::fromValue(spdMethods.contains(Solid::PowerManagement::HibernateState)));
     context->setContextProperty("spdMethods", mapSpdMethods);
 
-    QString bootManager = KConfig(KDE_CONFDIR "/kdm/kdmrc", KConfig::SimpleConfig).group("Shutdown").readEntry("BootManager", "None");
-    context->setContextProperty("bootManager", bootManager);
-
-    QStringList options;
-    int def, cur;
-    if ( KDisplayManager().bootOptions( rebootOptions, def, cur ) ) {
-        if ( cur > -1 ) {
-            def = cur;
-        }
-    }
-    QDeclarativePropertyMap *rebootOptionsMap = new QDeclarativePropertyMap(this);
-    rebootOptionsMap->insert("options", QVariant::fromValue(rebootOptions));
-    rebootOptionsMap->insert("default", QVariant::fromValue(def));
-    context->setContextProperty("rebootOptions", rebootOptionsMap);
-
     setModal( true );
 
     // window stuff
@@ -249,7 +169,7 @@ KSMShutdownDlg::KSMShutdownDlg( QWidget* parent,
     connect(rootObject, SIGNAL(suspendRequested(int)), SLOT(slotSuspend(int)) );
     connect(rootObject, SIGNAL(rebootRequested()), SLOT(slotReboot()));
     connect(rootObject, SIGNAL(rebootRequested2(int)), SLOT(slotReboot(int)) );
-    connect(rootObject, SIGNAL(cancelRequested()), SLOT(reject()));
+    connect(rootObject, SIGNAL(cancelRequested()), SLOT(slotCancel()));
     connect(rootObject, SIGNAL(lockScreenRequested()), SLOT(slotLockScreen()));
     m_view->show();
     m_view->setFocus();
@@ -285,25 +205,19 @@ void KSMShutdownDlg::slotLogout()
 
 void KSMShutdownDlg::slotReboot()
 {
-    // no boot option selected -> current
-    m_bootOption.clear();
     m_shutdownType = KWorkSpace::ShutdownTypeReboot;
     accept();
 }
 
 void KSMShutdownDlg::slotReboot(int opt)
 {
-    if (int(rebootOptions.size()) > opt)
-        m_bootOption = rebootOptions[opt];
     m_shutdownType = KWorkSpace::ShutdownTypeReboot;
     accept();
 }
 
-
 void KSMShutdownDlg::slotLockScreen()
 {
-    m_bootOption.clear();
-    QDBusMessage call = QDBusMessage::createMethodCall("org.kde.screensaver",
+    QDBusMessage call = QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver",
                                                        "/ScreenSaver",
                                                        "org.freedesktop.ScreenSaver",
                                                        "Lock");
@@ -313,50 +227,52 @@ void KSMShutdownDlg::slotLockScreen()
 
 void KSMShutdownDlg::slotHalt()
 {
-    m_bootOption.clear();
     m_shutdownType = KWorkSpace::ShutdownTypeHalt;
     accept();
 }
 
-
 void KSMShutdownDlg::slotSuspend(int spdMethod)
 {
-    m_bootOption.clear();
-    QDBusMessage call;
     switch (spdMethod) {
         case Solid::PowerManagement::StandbyState:
+            Solid::PowerManagement::requestSleep(Solid::PowerManagement::StandbyState, 0, 0);
+            break;
         case Solid::PowerManagement::SuspendState:
-            call = QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement",
-                                                  "/org/kde/Solid/PowerManagement",
-                                                  "org.kde.Solid.PowerManagement",
-                                                  "suspendToRam");
+            Solid::PowerManagement::requestSleep(Solid::PowerManagement::SuspendState, 0, 0);
             break;
         case Solid::PowerManagement::HibernateState:
-            call = QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement",
-                                                  "/org/kde/Solid/PowerManagement",
-                                                  "org.kde.Solid.PowerManagement",
-                                                  "suspendToDisk");
+            Solid::PowerManagement::requestSleep(Solid::PowerManagement::HibernateState, 0, 0);
+            break;
+        case Solid::PowerManagement::HybridSuspendState:
+            Solid::PowerManagement::requestSleep(Solid::PowerManagement::HybridSuspendState, 0, 0);
             break;
     }
-    QDBusConnection::sessionBus().asyncCall(call);
+    reject();
+}
+
+void KSMShutdownDlg::slotCancel()
+{
+    KSMShutdownFeedback::stop(); // make the screen become normal again
     reject();
 }
 
 bool KSMShutdownDlg::confirmShutdown(
-        bool maysd, bool choose, KWorkSpace::ShutdownType& sdtype, QString& bootOption,
+        bool maysd, bool choose, KWorkSpace::ShutdownType& sdtype,
         const QString& theme)
 {
-    KSMShutdownDlg* l = new KSMShutdownDlg( 0,
-                                            //KSMShutdownFeedback::self(),
-                                            maysd, choose, sdtype, theme );
+    KSMShutdownDlg* l = new KSMShutdownDlg(0,
+                                           //KSMShutdownFeedback::self(),
+                                           maysd, choose, sdtype, theme);
+    // NOTE: KWin logout effect expects class hint values to be ksmserver
     XClassHint classHint;
     classHint.res_name = const_cast<char*>("ksmserver");
     classHint.res_class = const_cast<char*>("ksmserver");
-
     XSetClassHint(QX11Info::display(), l->winId(), &classHint);
+
+    l->setWindowRole("logoutdialog");
+
     bool result = l->exec();
     sdtype = l->m_shutdownType;
-    bootOption = l->m_bootOption;
 
     delete l;
 
