@@ -3,7 +3,7 @@
 // oxygen configuration dialog
 // -------------------
 //
-// Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+// Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -24,17 +24,17 @@
 // IN THE SOFTWARE.
 //////////////////////////////////////////////////////////////////////////////
 #include "oxygenconfigdialog.h"
-#include "oxygenconfigdialog.moc"
+#include "moc_oxygenconfigdialog.cpp"
 
 #include <QtCore/QTextStream>
 #include <QtCore/QTimer>
+#include <QtCore/QLibrary>
 #include <QtGui/QLabel>
 #include <QtGui/QShortcut>
 
 #include <KConfigGroup>
 #include <KGlobalSettings>
 #include <KLocale>
-#include <KLibrary>
 #include <KPushButton>
 #include <KStandardShortcut>
 #include <KVBox>
@@ -82,7 +82,6 @@ namespace Oxygen
             connect( button( Reset ), SIGNAL(clicked()), _stylePluginObject, SLOT(reset()) );
             connect( button( Default ), SIGNAL(clicked()), _stylePluginObject, SLOT(defaults()) );
             connect( this, SIGNAL(pluginSave()), _stylePluginObject, SLOT(save()) );
-            connect( this, SIGNAL(pluginToggleExpertMode(bool)), _stylePluginObject, SLOT(toggleExpertMode(bool)) );
 
         }
 
@@ -102,13 +101,9 @@ namespace Oxygen
             connect( button( Default ), SIGNAL(clicked()), _decorationPluginObject, SLOT(defaults()) );
 
             connect( this, SIGNAL(pluginSave()), _decorationPluginObject, SLOT(save()) );
-            connect( this, SIGNAL(pluginToggleExpertMode(bool)), _decorationPluginObject, SLOT(toggleExpertMode(bool)) );
 
         }
 
-        // expert mode
-        emit pluginToggleExpertMode( true );
-
         // button connections
         connect( button( Apply ), SIGNAL(clicked()), SLOT(save()) );
         connect( button( Ok ), SIGNAL(clicked()), SLOT(save()) );
@@ -164,11 +159,11 @@ namespace Oxygen
     {
 
         // load decoration from plugin
-        KLibrary* library = new KLibrary( "kstyle_oxygen_config" );
+        QLibrary* library = new QLibrary( "kstyle_oxygen_config", this );
 
         if (library->load())
         {
-            KLibrary::void_function_ptr alloc_ptr = library->resolveFunction("allocate_kstyle_config");
+            void *alloc_ptr = library->resolve("allocate_kstyle_config");
             if (alloc_ptr != NULL)
             {
 
@@ -210,11 +205,11 @@ namespace Oxygen
     {
 
         // load decoration from plugin
-        KLibrary* library = new KLibrary( "kwin_oxygen_config" );
+        QLibrary* library = new QLibrary( "kwin_oxygen_config", this );
 
         if (library->load())
         {
-            KLibrary::void_function_ptr alloc_ptr = library->resolveFunction("allocate_config");
+            void *alloc_ptr = library->resolve("allocate_config");
             if (alloc_ptr != NULL)
             {
 
