@@ -3,7 +3,7 @@
 // oxygen configuration dialog
 // -------------------
 //
-// Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+// Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -24,7 +24,7 @@
 // IN THE SOFTWARE.
 //////////////////////////////////////////////////////////////////////////////
 #include "oxygendemodialog.h"
-#include "oxygendemodialog.moc"
+#include "moc_oxygendemodialog.cpp"
 
 #include "oxygenbenchmarkwidget.h"
 #include "oxygenbuttondemowidget.h"
