@@ -27,7 +27,7 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygensimulator.h"
-#include "oxygensimulator.moc"
+#include "moc_oxygensimulator.cpp"
 
 
 #include <QtGui/QAbstractItemView>
@@ -35,24 +35,20 @@
 #include <QtGui/QCheckBox>
 #include <QtGui/QComboBox>
 #include <QtGui/QCursor>
-#include <QtGui/QFocusEvent>
-#include <QtGui/QHoverEvent>
+#include <QtGui/qevent.h>
+#include <QtGui/qevent.h>
 #include <QtGui/QMdiSubWindow>
 #include <QtGui/QMenu>
-#include <QtGui/QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QPushButton>
 #include <QtGui/QRadioButton>
 #include <QtGui/QScrollBar>
 #include <QtGui/QSlider>
 #include <QtGui/QStyle>
-#include <QtGui/QStyleOptionComboBox>
-#include <QtGui/QStyleOptionSlider>
+#include <QtGui/qstyleoption.h>
+#include <QtGui/qstyleoption.h>
 #include <QtGui/QToolButton>
 
-#ifdef Q_OS_WIN
-/* need windows.h include for Sleep function*/
-#include <windows.h>
-#endif
 
 #ifdef Q_OS_UNIX
 #include <ctime>
@@ -796,12 +792,8 @@ namespace Oxygen
             int ms( 10 );
 
             // sleep
-            #ifdef Q_OS_WIN
-            Sleep(uint(ms));
-            #else
             struct timespec ts = { ms / 1000, (ms % 1000) * 1000 * 1000 };
             nanosleep(&ts, NULL);
-            #endif
 
         }
 
