@@ -1,5 +1,5 @@
-#ifndef oxygenframeshadow_h
-#define oxygenframeshadow_h
+#ifndef OXYGENFRAMESHADOW_H
+#define OXYGENFRAMESHADOW_H
 
 //////////////////////////////////////////////////////////////////////////////
 // oxygenframeshadow.h
@@ -38,7 +38,7 @@
 #include <QtCore/QSet>
 
 #include <QtGui/QWidget>
-#include <QtGui/QPaintEvent>
+#include <QtGui/qevent.h>
 #include <KColorScheme>
 
 namespace Oxygen
@@ -87,7 +87,7 @@ namespace Oxygen
         void setHasContrast( const QWidget* widget, bool ) const;
 
         //! update state
-        void updateState( const QWidget*, bool focus, bool hover, qreal opacity, AnimationMode ) const;
+        void updateState( const QWidget*, bool focus, bool hover ) const;
 
         protected:
 
@@ -167,7 +167,7 @@ namespace Oxygen
         virtual void updateGeometry( void ) = 0;
 
         //! update state
-        virtual void updateState( bool, bool, qreal, AnimationMode )
+        virtual void updateState( bool, bool )
         {}
 
         protected:
@@ -206,9 +206,7 @@ namespace Oxygen
             _viewFocusBrush( helper.viewFocusBrush() ),
             _viewHoverBrush( helper.viewHoverBrush() ),
             _focus( false ),
-            _hover( false ),
-            _opacity( -1 ),
-            _mode( AnimationNone )
+            _hover( false )
         { init(); }
 
 
@@ -220,7 +218,7 @@ namespace Oxygen
         virtual void updateGeometry( void );
 
         //! update state
-        void updateState( bool focus, bool hover, qreal opacity, AnimationMode mode );
+        void updateState( bool focus, bool hover );
 
         protected:
 
@@ -248,8 +246,6 @@ namespace Oxygen
         //@{
         bool _focus;
         bool _hover;
-        qreal _opacity;
-        AnimationMode _mode;
 
     };
 
