@@ -1,5 +1,5 @@
-#ifndef oxygenmdiwindowshadow_h
-#define oxygenmdiwindowshadow_h
+#ifndef OXYGENMDIWINDOWSHADOW_H
+#define OXYGENMDIWINDOWSHADOW_H
 
 //////////////////////////////////////////////////////////////////////////////
 // oxygenmdiwindowshadow.h
@@ -35,7 +35,7 @@
 #include <QtCore/QSet>
 
 #include <QtGui/QWidget>
-#include <QtGui/QPaintEvent>
+#include <QtGui/qevent.h>
 #include <KColorScheme>
 
 #include "oxygenstylehelper.h"
