@@ -1,12 +1,12 @@
-#ifndef oxygenpropertynames_h
-#define oxygenpropertynames_h
+#ifndef OXYGENPROPERTYNAMES_H
+#define OXYGENPROPERTYNAMES_H
 
 /*
 * oxygenpropertynames.h
 * hard-coded property names to disable some of oxygen features
 * -------------------
 *
-* Copyright (c) 2012 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2012 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * Largely inspired from Qtcurve style
 * Copyright (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
@@ -33,8 +33,10 @@ namespace Oxygen
     struct PropertyNames
     {
 
-        static const char* const noAnimations;
         static const char* const noWindowGrab;
+        static const char* const progressTimer;
+        static const char* const progressDirection;
+        static const char* const progressValue;
 
     };
 
