@@ -25,7 +25,7 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenshadowhelper.h"
-#include "oxygenshadowhelper.moc"
+#include "moc_oxygenshadowhelper.cpp"
 #include "oxygenshadowcache.h"
 #include "oxygenstylehelper.h"
 
@@ -35,9 +35,10 @@
 #include <QtGui/QToolBar>
 #include <QtCore/QTextStream>
 #include <QtCore/QEvent>
+#include <KPixmap>
 
 #ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #endif
@@ -55,19 +56,27 @@ namespace Oxygen
         _helper( helper ),
         _shadowCache( new ShadowCache( helper ) ),
         _size( 0 )
-        #ifdef Q_WS_X11
+#ifdef Q_WS_X11
         ,_atom( None )
-        #endif
+#endif
     {}
 
     //_______________________________________________________
     ShadowHelper::~ShadowHelper( void )
     {
 
-        #ifdef Q_WS_X11
-        foreach( const Qt::HANDLE& value, _pixmaps  ) XFreePixmap( QX11Info::display(), value );
-        foreach( const Qt::HANDLE& value, _dockPixmaps  ) XFreePixmap( QX11Info::display(), value );
-        #endif
+#ifdef Q_WS_X11
+        foreach( const Qt::HANDLE& value, _pixmaps ) {
+            if (value != 0) {
+                XFreePixmap( QX11Info::display(), value );
+            }
+        }
+        foreach( const Qt::HANDLE& value, _dockPixmaps ) {
+            if (value != 0) {
+                XFreePixmap( QX11Info::display(), value );
+            }
+        }
+#endif // Q_WS_X11
 
         delete _shadowCache;
 
@@ -76,11 +85,19 @@ namespace Oxygen
     //______________________________________________
     void ShadowHelper::reset( void )
     {
-        #ifdef Q_WS_X11
+#ifdef Q_WS_X11
         // round pixmaps
-        foreach( const Qt::HANDLE& value, _pixmaps  ) XFreePixmap( QX11Info::display(), value );
-        foreach( const Qt::HANDLE& value, _dockPixmaps  ) XFreePixmap( QX11Info::display(), value );
-        #endif
+        foreach( const Qt::HANDLE& value, _pixmaps ) {
+            if (value != 0) {
+                XFreePixmap( QX11Info::display(), value );
+            }
+        }
+        foreach( const Qt::HANDLE& value, _dockPixmaps ) {
+            if (value != 0) {
+                XFreePixmap( QX11Info::display(), value );
+            }
+        }
+#endif // Q_WS_X11
 
         _pixmaps.clear();
         _dockPixmaps.clear();
@@ -209,7 +226,7 @@ namespace Oxygen
 
     //_______________________________________________________
     bool ShadowHelper::isToolBar( QWidget* widget ) const
-    { return qobject_cast<QToolBar*>( widget ) || widget->inherits( "Q3ToolBar" ); }
+    { return qobject_cast<QToolBar*>( widget ); }
 
     //_______________________________________________________
     bool ShadowHelper::acceptWidget( QWidget* widget ) const
@@ -247,9 +264,9 @@ namespace Oxygen
         */
 
         // create atom
-        #ifdef Q_WS_X11
+#ifdef Q_WS_X11
         if( !_atom ) _atom = XInternAtom( QX11Info::display(), netWMShadowAtomName, False);
-        #endif
+#endif
 
         // make sure size is valid
         if( _size <= 0 ) return _pixmaps;
@@ -303,28 +320,17 @@ namespace Oxygen
         explicitly and draw the source pixmap on it.
         */
 
-        #ifdef Q_WS_X11
+#ifdef Q_WS_X11
         const int width( source.width() );
         const int height( source.height() );
 
         // create X11 pixmap
-        Pixmap pixmap = XCreatePixmap( QX11Info::display(), QX11Info::appRootWindow(), width, height, 32 );
-
-        // create explicitly shared QPixmap from it
-        QPixmap dest( QPixmap::fromX11Pixmap( pixmap, QPixmap::ExplicitlyShared ) );
-
-        // create surface for pixmap
-        {
-            QPainter painter( &dest );
-            painter.setCompositionMode( QPainter::CompositionMode_Source );
-            painter.drawPixmap( 0, 0, source );
-        }
-
-
-        return pixmap;
-        #else
+        KPixmap pixmap(source);
+        // handle not released, safe to return
+        return pixmap.handle();
+#else
         return 0;
-        #endif
+#endif // Q_WS_X11
 
     }
 
@@ -335,9 +341,7 @@ namespace Oxygen
         // check widget and shadow
         if( !widget ) return false;
 
-        #ifdef Q_WS_X11
-        #ifndef QT_NO_XRENDER
-
+#ifdef Q_WS_X11
         // TODO: also check for NET_WM_SUPPORTED atom, before installing shadow
 
         /*
@@ -402,9 +406,7 @@ namespace Oxygen
             reinterpret_cast<const unsigned char *>(data.constData()), data.size() );
 
         return true;
-
-        #endif
-        #endif
+#endif // Q_WS_X11
 
         return false;
 
@@ -414,10 +416,10 @@ namespace Oxygen
     void ShadowHelper::uninstallX11Shadows( QWidget* widget ) const
     {
 
-        #ifdef Q_WS_X11
+#ifdef Q_WS_X11
         if( !( widget && widget->testAttribute(Qt::WA_WState_Created) ) ) return;
         XDeleteProperty(QX11Info::display(), widget->winId(), _atom);
-        #endif
+#endif
 
     }
 
