@@ -1,5 +1,5 @@
-#ifndef oxygenstyle_h
-#define oxygenstyle_h
+#ifndef OXYGENSTYLE_H
+#define OXYGENSTYLE_H
 
 //////////////////////////////////////////////////////////////////////////////
 // oxygenstyle.h
@@ -47,7 +47,6 @@
 // Boston, MA 02110-1301, USA.
 //////////////////////////////////////////////////////////////////////////////
 
-#include "oxygenanimationmodes.h"
 #include "oxygenmetrics.h"
 #include "oxygentileset.h"
 
@@ -57,10 +56,11 @@
 #include <QtGui/QDockWidget>
 #include <QtGui/QMdiSubWindow>
 #include <QtGui/QStyleOption>
-#include <QtGui/QStyleOptionSlider>
+#include <QtGui/qstyleoption.h>
 #include <QtGui/QToolBar>
 #include <QtGui/QToolBox>
 #include <QtGui/QWidget>
+#include <QtGui/QProgressBar>
 
 #include <KIcon>
 
@@ -72,12 +72,10 @@ namespace Oxygen
     class MdiWindowShadowFactory;
     class Mnemonics;
     class ShadowHelper;
-    class SplitterFactory;
     class StyleHelper;
     class Transitions;
     class WindowManager;
     class WidgetExplorer;
-    class BlurHelper;
 
     //! toplevel manager
     class TopLevelManager: public QObject
@@ -174,11 +172,11 @@ namespace Oxygen
         bool eventFilterComboBoxContainer( QWidget*, QEvent* );
         bool eventFilterDockWidget( QDockWidget*, QEvent* );
         bool eventFilterMdiSubWindow( QMdiSubWindow*, QEvent* );
-        bool eventFilterQ3ListView( QWidget*, QEvent* );
         bool eventFilterScrollBar( QWidget*, QEvent* );
         bool eventFilterTabBar( QWidget*, QEvent* );
         bool eventFilterToolBar( QToolBar*, QEvent* );
         bool eventFilterToolBox( QToolBox*, QEvent* );
+        bool eventFilterProgressBar( QProgressBar*, QEvent* );
 
         //! install event filter to object, in a unique way
         void addEventFilter( QObject* object )
@@ -198,13 +196,21 @@ namespace Oxygen
         void globalPaletteChanged( void );
 
         //! copied from kstyle
+#ifndef QT_KATIE
         int layoutSpacingImplementation(
+#else
+        virtual int layoutSpacing(
+#endif
             QSizePolicy::ControlType, QSizePolicy::ControlType, Qt::Orientation,
             const QStyleOption* option, const QWidget* widget ) const
         { return pixelMetric(PM_DefaultLayoutSpacing, option, widget); }
 
         //! standard icons
+#ifndef QT_KATIE
         virtual QIcon standardIconImplementation(
+#else
+        virtual QIcon standardIcon(
+#endif
             StandardPixmap standardIcon,
             const QStyleOption *option,
             const QWidget *widget) const;
@@ -336,13 +342,6 @@ namespace Oxygen
 
         //@}
 
-        //! animations
-        Animations& animations( void ) const
-        { return *_animations; }
-
-        Transitions& transitions( void ) const
-        { return *_transitions; }
-
         //! window manager
         WindowManager& windowManager( void ) const
         { return *_windowManager; }
@@ -355,10 +354,6 @@ namespace Oxygen
         MdiWindowShadowFactory& mdiWindowShadowFactory( void ) const
         { return *_mdiWindowShadowFactory; }
 
-        //! blur helper
-        BlurHelper& blurHelper( void ) const
-        { return *_blurHelper; }
-
         //! mdi window shadows
         Mnemonics& mnemonics( void ) const
         { return *_mnemonics; }
@@ -371,10 +366,6 @@ namespace Oxygen
         WidgetExplorer& widgetExplorer( void ) const
         { return *_widgetExplorer; }
 
-        //! splitter factory
-        SplitterFactory& splitterFactory( void ) const
-        { return *_splitterFactory; }
-
         //! tabBar data
         TabBarData& tabBarData( void ) const
         { return *_tabBarData; }
@@ -515,8 +506,6 @@ namespace Oxygen
         bool drawPanelItemViewItemPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawPanelLineEditPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorMenuCheckMarkPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
-        bool drawQ3CheckListIndicatorPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
-        bool drawQ3CheckListExclusiveIndicatorPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorBranchPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorButtonDropDownPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorCheckBoxPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
@@ -579,7 +568,6 @@ namespace Oxygen
         /*! there are two methods (_Single and _Plain) implemented, to deal with tabbar appearance selected from options */
         virtual bool drawTabBarTabShapeControl_Single( const QStyleOption*, QPainter*, const QWidget* ) const;
         virtual bool drawTabBarTabShapeControl_Plain( const QStyleOption*, QPainter*, const QWidget* ) const;
-        virtual bool drawToolBarControl( const QStyleOption*, QPainter*, const QWidget* ) const;
         virtual bool drawToolBoxTabLabelControl( const QStyleOption*, QPainter*, const QWidget* ) const;
         virtual bool drawToolBoxTabShapeControl( const QStyleOption*, QPainter*, const QWidget* ) const;
         virtual bool drawToolButtonLabelControl( const QStyleOption*, QPainter*, const QWidget* ) const;
@@ -591,7 +579,6 @@ namespace Oxygen
         bool drawComboBoxComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
         bool drawDialComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
         bool drawGroupBoxComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
-        bool drawQ3ListViewComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
         bool drawSliderComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
         bool drawSpinBoxComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
         bool drawTitleBarComplexControl( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
@@ -677,33 +664,17 @@ namespace Oxygen
         //@{
 
         //! qdial slab
-        void renderDialSlab( QPainter* p, const QRect& r, const QColor& c, const QStyleOption* option, StyleOptions opts = 0 ) const
-        { renderDialSlab( p, r, c, option, opts, -1,  AnimationNone ); }
-
-        //! qdial slab
-        void renderDialSlab( QPainter*, const QRect&, const QColor&, const QStyleOption*, StyleOptions, qreal, AnimationMode ) const;
+        void renderDialSlab( QPainter* p, const QRect& r, const QColor& c, const QStyleOption* option, StyleOptions opts = 0 ) const;
 
         //! generic button slab
-        void renderButtonSlab( QPainter* p, QRect r, const QColor& c, StyleOptions opts = 0, TileSet::Tiles tiles = TileSet::Ring) const
-        { renderButtonSlab( p, r, c, opts, -1,  AnimationNone, tiles ); }
-
-        //! generic button slab
-        void renderButtonSlab( QPainter*, QRect, const QColor&, StyleOptions, qreal, AnimationMode, TileSet::Tiles ) const;
+        void renderButtonSlab( QPainter* p, QRect r, const QColor& c, StyleOptions opts = 0, TileSet::Tiles tiles = TileSet::Ring) const;
 
         //! generic slab
         void renderSlab( QPainter* painter, const SlabRect& slab, const QColor& color, StyleOptions options = 0 ) const
         { renderSlab( painter, slab._r, color, options, slab._tiles ); }
 
         //! generic slab
-        void renderSlab( QPainter* painter, QRect rect, const QColor& color, StyleOptions options = 0, TileSet::Tiles tiles = TileSet::Ring) const
-        { renderSlab( painter, rect, color, options, -1, AnimationNone, tiles ); }
-
-        //! generic slab
-        void renderSlab( QPainter* painter, const SlabRect& slab, const QColor& color, StyleOptions options, qreal opacity, AnimationMode mode ) const
-        { renderSlab( painter, slab._r, color, options, opacity, mode, slab._tiles ); }
-
-        //! generic slab
-        void renderSlab( QPainter*, QRect, const QColor&, StyleOptions, qreal, AnimationMode, TileSet::Tiles ) const;
+        void renderSlab( QPainter* painter, QRect rect, const QColor& color, StyleOptions options = 0, TileSet::Tiles tiles = TileSet::Ring) const;
 
         // render tab background
         void renderTabBackground( QPainter*, const QRect&, const QPalette&, const QTabBar::Shape, const QWidget* ) const;
@@ -730,13 +701,7 @@ namespace Oxygen
         void renderHeaderBackground( const QRect&, const QPalette&, QPainter*, const QWidget*, bool horizontal, bool reverse ) const;
         void renderHeaderLines( const QRect&, const QPalette&, QPainter*, TileSet::Tiles ) const;
 
-        //! menu item background
-        void renderMenuItemBackground( const QStyleOption*, QPainter*, const QWidget* ) const;
-
-        void renderMenuItemRect( const QStyleOption* opt, const QRect& rect, const QPalette& pal, QPainter* p, qreal opacity = -1 ) const
-        { renderMenuItemRect( opt, rect, pal.color(QPalette::Window), p, opacity ); }
-
-        void renderMenuItemRect( const QStyleOption*, const QRect&, const QColor&, const QPalette&, QPainter* p, qreal opacity = -1 ) const;
+        void renderMenuItemRect( const QStyleOption*, const QRect&, const QColor&, const QPalette&, QPainter* p ) const;
 
         //! checkbox state (used for checkboxes _and_ radio buttons)
         enum CheckBoxState
@@ -748,10 +713,10 @@ namespace Oxygen
         };
 
         //! checkbox
-        void renderCheckBox( QPainter*, const QRect&, const QPalette&, StyleOptions, CheckBoxState, qreal opacity = -1, AnimationMode mode = AnimationNone ) const;
+        void renderCheckBox( QPainter*, const QRect&, const QPalette&, StyleOptions, CheckBoxState) const;
 
         //! radio button
-        void renderRadioButton( QPainter*, const QRect&, const QPalette&, StyleOptions, CheckBoxState, qreal opacity = -1, AnimationMode mode = AnimationNone ) const;
+        void renderRadioButton( QPainter*, const QRect&, const QPalette&, StyleOptions, CheckBoxState ) const;
 
         //! scrollbar hole
         void renderScrollBarHole( QPainter*, const QRect&, const QColor&, const Qt::Orientation&, const TileSet::Tiles& = TileSet::Full ) const;
@@ -759,11 +724,7 @@ namespace Oxygen
         //! scrollbar handle (non animated)
         void renderScrollBarHandle(
             QPainter* painter, const QRect& r, const QPalette& palette,
-            const Qt::Orientation& orientation, const bool& hover) const
-        { renderScrollBarHandle( painter, r, palette, orientation, hover, -1 ); }
-
-        //! scrollbar handle (animated)
-        void renderScrollBarHandle( QPainter*, const QRect&, const QPalette&, const Qt::Orientation&, const bool&, const qreal& ) const;
+            const Qt::Orientation& orientation, const bool& hover) const;
 
         //! scrollbar arrow
         void renderScrollBarArrow( QPainter*, const QRect&, const QColor&, const QColor&, ArrowOrientation ) const;
@@ -777,7 +738,7 @@ namespace Oxygen
         //@}
 
         //! slab glowing color
-        QColor slabShadowColor( QColor, StyleOptions, qreal, AnimationMode ) const;
+        QColor slabShadowColor( QColor, StyleOptions ) const;
 
         //! returns point position for generic arrows
         QPolygonF genericArrow( ArrowOrientation, ArrowSize = ArrowNormal ) const;
@@ -858,12 +819,6 @@ namespace Oxygen
         //! shadow helper
         ShadowHelper* _shadowHelper;
 
-        //! animations
-        Animations* _animations;
-
-        //! transitions
-        Transitions* _transitions;
-
         //! window manager
         WindowManager* _windowManager;
 
@@ -879,18 +834,12 @@ namespace Oxygen
         //! keyboard accelerators
         Mnemonics* _mnemonics;
 
-        //! blur helper
-        BlurHelper* _blurHelper;
-
         //! widget explorer
         WidgetExplorer* _widgetExplorer;
 
         //! tabBar data
         TabBarData* _tabBarData;
 
-        //! splitter Factory, to extend splitters hit area
-        SplitterFactory* _splitterFactory;
-
         //! pointer to primitive specialized function
         typedef bool (Style::*StylePrimitive)( const QStyleOption*, QPainter*, const QWidget* ) const;
         StylePrimitive _frameFocusPrimitive;
