@@ -1,4 +1,5 @@
 /*
+ * Copyright 2013 Hugo Pereira Da Costa <hugo.pereira@free.fr>
  * Copyright 2008 Long Huynh Huu <long.upcase@googlemail.com>
  * Copyright 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
  * Copyright 2007 Casper Boemann <cbr@boemann.dk>
@@ -23,8 +24,10 @@
 #include <KColorUtils>
 #include <KColorScheme>
 
+#include <QtCore/QTextStream>
 #include <QtGui/QPainter>
-#include <QtGui/QLinearGradient>
+#include <QtGui/QBrush>
+#include <QtGui/QPen>
 
 #include <math.h>
 
@@ -39,7 +42,8 @@ namespace Oxygen
     //______________________________________________________________________________
     StyleHelper::StyleHelper( const QByteArray &componentName ):
         Helper( componentName ),
-        _debugArea( KDebug::registerArea( "Oxygen ( style )" ) )
+        _debugArea( 90230 ), // see kdebug.areas
+        _useBackgroundGradient( true )
     {
 
         #ifdef Q_WS_X11
@@ -108,6 +112,37 @@ namespace Oxygen
 
     }
 
+    //____________________________________________________________________
+    void StyleHelper::renderWindowBackground( QPainter* p, const QRect& clipRect, const QWidget* widget, const QColor& color, int y_shift, int gradientHeight)
+    {
+
+        if( _useBackgroundGradient )
+        {
+
+            // normal background gradient
+            Helper::renderWindowBackground( p, clipRect, widget, widget->window(), color, y_shift, gradientHeight );
+
+        } else {
+
+            // if background gradient is disabled, simply render flat background
+            if ( clipRect.isValid() )
+            { p->setClipRegion( clipRect,Qt::IntersectClip ); }
+
+            p->fillRect( widget->rect(), color );
+        }
+
+        // background pixmap
+        Helper::renderBackgroundPixmap( p, clipRect, widget, widget->window(), y_shift, gradientHeight );
+
+    }
+
+    //____________________________________________________________________
+    void StyleHelper::setHasBackgroundGradient( WId id, bool value ) const
+    {
+        if( _useBackgroundGradient )
+        { Helper::setHasBackgroundGradient( id, value ); }
+    }
+
     //____________________________________________________________________
     void StyleHelper::renderMenuBackground( QPainter* p, const QRect& clipRect, const QWidget* widget, const QColor& color )
     {
@@ -414,7 +449,6 @@ namespace Oxygen
             // colors
             const QColor base( KColorUtils::shade( color, shade ) );
             const QColor light( KColorUtils::shade( calcLightColor( color ), shade ) );
-            const QColor dark( KColorUtils::shade( calcDarkColor( color ), shade ) );
             const QColor mid( KColorUtils::shade( calcMidColor( color ), shade ) );
             const QColor shadow( calcShadowColor( color ) );
 
@@ -623,13 +657,15 @@ namespace Oxygen
         QPainter& p, const QColor& color,
         int pad, int size, int rsize ) const
     {
-
         const QRectF r( pad, pad, size, size );
         const qreal m( qreal( size )*0.5 );
 
         const qreal width( 3.5 );
         const qreal bias( _glowBias*7.0/rsize );
-        const qreal k0( ( m-width )/( m-bias ) );
+        qreal k0( ( m-width )/( m-bias ) );
+        if (k0 < 0.0) {
+            k0 = -k0;
+        }
         QRadialGradient glowGradient( pad+m, pad+m, m-bias );
         for ( int i = 0; i < 8; i++ )
         {
@@ -674,31 +710,15 @@ namespace Oxygen
     }
 
     //____________________________________________________________________________________
-    void StyleHelper::renderHole( QPainter* p, const QColor& base, const QRect& r, HoleOptions options, qreal opacity, Oxygen::AnimationMode animationMode,  TileSet::Tiles tiles )
+    void StyleHelper::renderHole( QPainter* p, const QColor& base, const QRect& r, HoleOptions options,  TileSet::Tiles tiles )
     {
         if( !r.isValid() ) return;
-        if( opacity >= 0 && ( animationMode & Oxygen::AnimationFocus ) )
-        {
-
-            // calculate proper glow color based on current settings and opacity
-            const QColor glow( (options&HoleHover) ?
-                KColorUtils::mix( viewHoverBrush().brush( QPalette::Active ).color(), viewFocusBrush().brush( QPalette::Active ).color(), opacity ):
-                alphaColor(  viewFocusBrush().brush( QPalette::Active ).color(), opacity ) );
-
-            hole( base, glow, 7, options )->render( r, p, tiles );
-
-        } else if( options & HoleFocus ) {
+        if( options & HoleFocus ) {
 
             const QColor glow( viewFocusBrush().brush( QPalette::Active ).color() );
             hole( base, glow, 7, options )->render( r, p, tiles );
 
-        } else if( opacity >= 0 && ( animationMode & Oxygen::AnimationHover ) ) {
-
-            // calculate proper glow color based on current settings and opacity
-            const QColor glow( alphaColor(  viewHoverBrush().brush( QPalette::Active ).color(), opacity ) );
-            hole( base, glow, 7, options )->render( r, p, tiles );
-
-        } else if( options & HoleHover ) {
+       } else if( options & HoleHover ) {
 
             const QColor glow( viewHoverBrush().brush( QPalette::Active ).color() );
             hole( base, glow, 7, options )->render( r, p, tiles );
