@@ -30,7 +30,7 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenwindowmanager.h"
-#include "oxygenwindowmanager.moc"
+#include "moc_oxygenwindowmanager.cpp"
 #include "oxygenpropertynames.h"
 #include "oxygenstyleconfigdata.h"
 
@@ -45,12 +45,12 @@
 #include <QtGui/QMainWindow>
 #include <QtGui/QMdiSubWindow>
 #include <QtGui/QMenuBar>
-#include <QtGui/QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QProgressBar>
 #include <QtGui/QScrollBar>
 #include <QtGui/QStatusBar>
 #include <QtGui/QStyle>
-#include <QtGui/QStyleOptionGroupBox>
+#include <QtGui/qstyleoption.h>
 #include <QtGui/QTabBar>
 #include <QtGui/QTabWidget>
 #include <QtGui/QToolBar>
@@ -62,7 +62,7 @@
 #include <KGlobalSettings>
 
 #ifdef Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <NETRootInfo>
 #endif
 
@@ -181,18 +181,17 @@ namespace Oxygen
         {
             case QEvent::MouseButtonPress:
                 return mousePressEvent( object, event );
-            break;
 
             case QEvent::MouseMove:
                 if ( object == _target.data() ) return mouseMoveEvent( object, event );
-            break;
+                break;
 
             case QEvent::MouseButtonRelease:
                 if ( _target ) return mouseReleaseEvent( object, event );
-            break;
+                break;
 
             default:
-            break;
+                break;
 
         }
 
@@ -333,9 +332,6 @@ namespace Oxygen
             !isDockWidgetTitle( widget ) )
         { return true; }
 
-        if( widget->inherits( "KScreenSaver" ) && widget->inherits( "KCModule" ) )
-        { return true; }
-
         if( isWhiteListed( widget ) )
         { return true; }
 
@@ -381,7 +377,7 @@ namespace Oxygen
     bool WindowManager::isBlackListed( QWidget* widget )
     {
 
-        // check against noAnimations propery
+        // check against noWindowGrab propery
         QVariant propertyValue( widget->property( PropertyNames::noWindowGrab ) );
         if( propertyValue.isValid() && propertyValue.toBool() ) return true;
 
