@@ -25,8 +25,7 @@
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QLabel>
-#include <QtGui/QFontInfo>
-#include <QtGui/QResizeEvent>
+#include <QtGui/qevent.h>
 
 
 #include <kdebug.h>
@@ -444,7 +443,7 @@ bool FancyPlotter::removeBeam( uint beamId )
 {
     if ( beamId >= mBeams ) {
         kDebug(1215) << "FancyPlotter::removeBeam: beamId out of range ("
-            << beamId << ")" << endl;
+            << beamId << ")";
         return false;
     }
 
@@ -935,4 +934,4 @@ QColor FPSensorProperties::color() const
 }
 
 
-#include "FancyPlotter.moc"
+#include "moc_FancyPlotter.cpp"
