@@ -19,11 +19,11 @@
 
 */
 
-#include <QDomElement>
+#include <QtXml/qdom.h>
 
 #include <QVBoxLayout>
 #include <QSortFilterProxyModel>
-#include <QTime>
+#include <QtCore/qdatetime.h>
 #include <QMenu>
 #include <QAction>
 
@@ -37,7 +37,7 @@
 #include <QTreeView>
 #include <QHeaderView>
 #include "ListView.h"
-#include "ListView.moc"
+#include "moc_ListView.cpp"
 #include "ListViewSettings.h"
 
 static QString formatByteSize(qlonglong amountInKB, int units) {
@@ -308,7 +308,7 @@ ListView::answerReceived(int id, const QList<QByteArray>& answer)
         case 19: {
             for (int i = 0; i < answer.count(); i++) {
                 KSGRD::SensorTokenizer records(answer[i], '\t');
-                for (uint j = 0; j < records.count() && j < mColumnTypes.count(); j++) {
+                for (int j = 0; j < records.count() && j < mColumnTypes.count(); j++) {
                     QStandardItem *item = new QStandardItem();
                     item->setEditable(false);
                     switch( mColumnTypes[j] ) {
@@ -318,7 +318,7 @@ ListView::answerReceived(int id, const QList<QByteArray>& answer)
                         break;
                       case Percentage:
                         item->setData(records[j].toInt(), Qt::UserRole);
-                        item->setText(records[j] + "%");
+                        item->setText(QLatin1String(records[j]) + "%");
                         break;
                       case Float:
                         item->setData(records[j].toFloat(), Qt::DisplayRole);
