@@ -19,18 +19,18 @@
 
 */
 
-#include <QtCore/QAbstractTableModel>
-#include <QtCore/QDate>
+#include <QtCore/qabstractitemmodel.h>
+#include <QtCore/qdatetime.h>
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
-#include <QtGui/QContextMenuEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QHeaderView>
 #include <QtGui/QMenu>
 #include <QtGui/QTreeView>
 #include <QtGui/QHBoxLayout>
-#include <QtXml/QDomNodeList>
-#include <QtXml/QDomDocument>
-#include <QtXml/QDomElement>
+#include <QtXml/qdom.h>
+#include <QtXml/qdom.h>
+#include <QtXml/qdom.h>
 
 #include <kapplication.h>
 #include <kiconloader.h>
@@ -570,9 +570,9 @@ bool SensorLogger::saveSettings( QDomDocument& doc, QDomElement& element )
     log.setAttribute("fileName", sensor->fileName());
     log.setAttribute("timerInterval", sensor->timerInterval());
     log.setAttribute("lowerLimitActive", QString("%1").arg(sensor->lowerLimitActive()));
-    log.setAttribute("lowerLimit", QString("%1").arg(sensor->lowerLimit()));
+    log.setAttribute("lowerLimit", QString::number(sensor->lowerLimit()));
     log.setAttribute("upperLimitActive", QString("%1").arg(sensor->upperLimitActive()));
-    log.setAttribute("upperLimit", QString("%1").arg(sensor->upperLimit()));
+    log.setAttribute("upperLimit", QString::number(sensor->upperLimit()));
 
     element.appendChild( log );
   }
@@ -659,4 +659,4 @@ void SensorLogger::contextMenuRequest( const QModelIndex &index, const QPoint &p
   }
 }
 
-#include "SensorLogger.moc"
+#include "moc_SensorLogger.cpp"
