@@ -25,8 +25,8 @@
 #include <QTextStream>
 #include <QGridLayout>
 #include <QEvent>
-#include <QDropEvent>
-#include <QDragEnterEvent>
+#include <QtGui/qevent.h>
+#include <QtGui/qevent.h>
 #include <QFile>
 #include <QByteArray>
 #include <QApplication>
@@ -113,9 +113,9 @@ bool WorkSheet::load( const QString &fileName )
     }
 
     // Check for proper size.
-    float interval = element.attribute( "interval", "0.5" ).toFloat();
+    float interval = element.attribute( "interval", "1" ).toFloat();
     if( interval  < 0 || interval > 100000 )  //make sure the interval is fairly sane
-        interval = 0.5;
+        interval = 1;
 
     setUpdateInterval( interval );
 
@@ -157,7 +157,7 @@ bool WorkSheet::load( const QString &fileName )
         int columnSpan = element.attribute( "columnSpan", "1" ).toInt();
         if ( row < 0 || rowSpan < 0 || (row + rowSpan - 1) >= mRows || column < 0 || columnSpan < 0 || (column + columnSpan - 1) >= mColumns) {
             kDebug(1215) << "Row or Column out of range (" << row << ", "
-                << column << ")-(" << (row + rowSpan - 1) << ", " << (column + columnSpan - 1) << ")" << endl;
+                << column << ")-(" << (row + rowSpan - 1) << ", " << (column + columnSpan - 1) << ")";
             return false;
         }
         replaceDisplay( row, column, element, rowSpan, columnSpan );
@@ -801,4 +801,4 @@ float WorkSheet::updateInterval() const
         return 0;
 }
 
-#include "WorkSheet.moc"
+#include "moc_WorkSheet.cpp"
