@@ -31,7 +31,6 @@
 #include <kacceleratormanager.h>
 #include <kactioncollection.h>
 #include <kmenu.h>
-#include <knewstuff3/downloaddialog.h>
 
 #include "WorkSheet.h"
 #include "WorkSheetSettings.h"
@@ -292,28 +291,6 @@ WorkSheet *Workspace::currentWorkSheet()
 {
     return (WorkSheet*)currentWidget();
 }
-void Workspace::uploadHotNewWorksheet()
-{
-    WorkSheet *currentWorksheet = currentWorkSheet();
-    if(!currentWorksheet)
-        return;
-
-    KMessageBox::information(this, i18n("<qt>To propose the current custom tab as a new System Monitor tab, email <br><a href=\"file:%1\">%2</a><br> to <a href=\"mailto:john.tapsell@kde.org?subject='System Monitor Tab'&attach='file://%2'\">john.tapsell@kde.org</a></qt>", currentWorksheet->fullFileName().section('/',0,-2), currentWorksheet->fullFileName()), i18n("Upload custom System Monitor tab"), QString::null, KMessageBox::AllowLink);
-}
-void Workspace::getHotNewWorksheet()
-{
-    KNS3::DownloadDialog dialog("ksysguard.knsrc");
-    if( dialog.exec() == QDialog::Rejected )
-        return;
-
-    KNS3::Entry::List entries = dialog.installedEntries();
-    foreach(KNS3::Entry entry, entries) {
-        if(!entry.installedFiles().isEmpty()) {
-            QString filename = entry.installedFiles().first();
-            restoreWorkSheet(filename, true);
-        }
-    }
-}
 
 bool Workspace::restoreWorkSheet( const QString &fileName, bool switchToTab)
 {
@@ -385,4 +362,4 @@ void Workspace::applyStyle()
     current->applyStyle();
 }
 
-#include "Workspace.moc"
+#include "moc_Workspace.cpp"
