@@ -51,6 +51,7 @@
 #include <ktoggleaction.h>
 #include <kurl.h>
 #include <kwindowsystem.h>
+#include <kdeversion.h>
 #include <QSplitter>
 
 #include <config-workspace.h>
@@ -71,7 +72,7 @@ static const char Description[] = I18N_NOOP( "KDE System Monitor" );
 TopLevel* Toplevel;
 
 TopLevel::TopLevel()
-  : KXmlGuiWindow( NULL, Qt::WindowFlags(KDE_DEFAULT_WINDOWFLAGS) | Qt::WindowContextHelpButtonHint)
+  : KXmlGuiWindow( NULL, Qt::WindowContextHelpButtonHint)
 {
   QDBusConnection::sessionBus().registerObject("/", this, QDBusConnection::ExportScriptableSlots);
   mTimerId = -1;
@@ -126,13 +127,6 @@ TopLevel::TopLevel()
   mMonitorRemoteAction = actionCollection()->addAction( "connect_host" );
   mMonitorRemoteAction->setIcon( KIcon("network-connect") );
   connect(mMonitorRemoteAction, SIGNAL(triggered(bool)), SLOT(connectHost()));
-  //knewstuff2 action
-  mHotNewWorksheetAction = actionCollection()->addAction( "get_new_worksheet" );
-  mHotNewWorksheetAction->setIcon( KIcon("network-server") );
-  connect(mHotNewWorksheetAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(getHotNewWorksheet()));
-  mHotNewWorksheetUploadAction = actionCollection()->addAction( "upload_worksheet" );
-  mHotNewWorksheetUploadAction->setIcon( KIcon("network-server") );
-  connect(mHotNewWorksheetUploadAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(uploadHotNewWorksheet()));
 
   mQuitAction = NULL;
 
@@ -155,15 +149,13 @@ void TopLevel::setLocalProcessController(ProcessController * localProcessControl
 
 void TopLevel::retranslateUi()
 {
-  setPlainCaption( i18n( "System Monitor" ) );
+  setWindowTitle( i18n( "System Monitor" ) );
   mRefreshTabAction->setText(i18n("&Refresh Tab"));
   mNewWorksheetAction->setText(i18n( "&New Tab..." ));
   mInsertWorksheetAction->setText(i18n( "Import Tab Fr&om File..." ));
   mTabExportAction->setText( i18n( "Save Tab &As..." ) );
   mTabRemoveAction->setText( i18n( "&Close Tab" ) );
   mMonitorRemoteAction->setText( i18n( "Monitor &Remote Machine..." ) );
-  mHotNewWorksheetAction->setText( i18n( "&Download New Tabs..." ) );
-  mHotNewWorksheetUploadAction->setText( i18n( "&Upload Current Tab..." ) );
 
   mConfigureSheetAction->setText( i18n( "Tab &Properties" ) );
   if(mQuitAction) {
@@ -188,7 +180,6 @@ void TopLevel::currentTabChanged(int index)
   bool locked = !sheet || sheet->isLocked();
   mTabRemoveAction->setVisible(!locked);
   mTabExportAction->setVisible(!locked);
-  mHotNewWorksheetUploadAction->setVisible(!locked);
   mMonitorRemoteAction->setVisible(!locked);
 
   //only show refresh option is update interval is 0 (manual)
@@ -233,11 +224,6 @@ void TopLevel::removeWorkSheet( const QString &fileName )
   mWorkSpace->removeWorkSheet( fileName );
 }
 
-void TopLevel::getHotNewWorksheet()
-{
-  mWorkSpace->getHotNewWorksheet( );
-}
-
 QStringList TopLevel::listSensors( const QString &hostName )
 {
   if(!mSensorBrowser) {
@@ -269,7 +255,7 @@ void TopLevel::initStatusBar()
   KSGRD::SensorMgr->sendRequest( "localhost", "mem/swap/used?",
                                  (KSGRD::SensorClient*)this, 7 );
 
-  KToggleAction *sb = dynamic_cast<KToggleAction*>(action("options_show_statusbar"));
+  KToggleAction *sb = qobject_cast<KToggleAction*>(action("options_show_statusbar"));
   if (sb)
      connect(sb, SIGNAL(toggled(bool)), this, SLOT(updateStatusBar()));
   setupGUI(QSize(800,600), ToolBar | Keys | StatusBar | Save | Create);
@@ -494,7 +480,7 @@ void TopLevel::setSwapInfo( qlonglong used, qlonglong free, const QString & )
 /*
  * Once upon a time...
  */
-extern "C" KDE_EXPORT int kdemain( int argc, char** argv )
+int main( int argc, char** argv )
 {
   // initpipe is used to keep the parent process around till the child
   // has registered with dbus
@@ -527,7 +513,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char** argv )
 #endif
 
   KAboutData aboutData( "ksysguard", 0, ki18n( "System Monitor" ),
-                        WORKSPACE_VERSION_STRING, ki18n(Description), KAboutData::License_GPL,
+                        KDE_VERSION_STRING, ki18n(Description), KAboutData::License_GPL,
                         ki18n( "(c) 1996-2008 The KDE System Monitor Developers" ) );
   aboutData.addAuthor( ki18n("John Tapsell"), ki18n("Current Maintainer"), "john.tapsell@kde.org" );
   aboutData.addAuthor( ki18n("Chris Schlaeger"), ki18n("Previous Maintainer"), "cs@kde.org" );
@@ -587,4 +573,4 @@ extern "C" KDE_EXPORT int kdemain( int argc, char** argv )
   return result;
 }
 
-#include "ksysguard.moc"
+#include "moc_ksysguard.cpp"
