@@ -31,22 +31,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "focuschain.h"
 #include "netinfo.h"
 #include "workspace.h"
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
 
 #include <fixx11h.h>
-#include <kxerrorhandler.h>
 #include <kstartupinfo.h>
 #include <kstringhandler.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 
 #include "atoms.h"
 #include "group.h"
 #include "rules.h"
 #include "screens.h"
 #include "useractions.h"
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 namespace KWin
 {
@@ -163,26 +159,6 @@ namespace KWin
          (SELI TODO - but what if they do?)
 
  Special cases I can think of:
-    - konqueror reusing, i.e. kfmclient tells running Konqueror instance
-        to open new window
-        - without focus stealing prevention - no problem
-        - with ASN (application startup notification) - ASN is forwarded,
-            and because it's newer than the instance's user timestamp,
-            it takes precedence
-        - without ASN - user timestamp needs to be reset, otherwise it would
-            be used, and it's old; moreover this new window mustn't be detected
-            as window belonging to already running application, or it wouldn't
-            be activated - see Client::sameAppWindowRoleMatch() for the (rather ugly)
-            hack
-    - konqueror preloading, i.e. window is created in advance, and kfmclient
-        tells this Konqueror instance to show it later
-        - without focus stealing prevention - no problem
-        - with ASN - ASN is forwarded, and because it's newer than the instance's
-            user timestamp, it takes precedence
-        - without ASN - user timestamp needs to be reset, otherwise it would
-            be used, and it's old; also, creation timestamp is changed to
-            the time the instance starts (re-)initializing the window,
-            this ensures creation timestamp will still work somewhat even in this case
     - KUniqueApplication - when the window is already visible, and the new instance
         wants it to activate
         - without focus stealing prevention - _NET_ACTIVE_WINDOW - no problem
@@ -302,14 +278,6 @@ void Workspace::activateClient(Client* c, bool force)
         VirtualDesktopManager::self()->setCurrent(c->desktop());
         --block_focus;
     }
-#ifdef KWIN_BUILD_ACTIVITIES
-    if (!c->isOnCurrentActivity()) {
-        ++block_focus;
-        //DBUS!
-        Activities::self()->setCurrent(c->activities().first()); //first isn't necessarily best, but it's easiest
-        --block_focus;
-    }
-#endif
     if (c->isMinimized())
         c->unminimize();
 
@@ -411,7 +379,7 @@ void Workspace::handleTakeActivity(KWin::Client *c, xcb_timestamp_t /*timestamp*
  */
 void Workspace::clientHidden(Client* c)
 {
-    assert(!c->isShown(true) || !c->isOnCurrentDesktop() || !c->isOnCurrentActivity());
+    assert(!c->isShown(true) || !c->isOnCurrentDesktop());
     activateNextClient(c);
 }
 
@@ -427,7 +395,7 @@ Client *Workspace::clientUnderMouse(int screen) const
         // rule out clients which are not really visible.
         // the screen test is rather superfluous for xrandr & twinview since the geometry would differ -> TODO: might be dropped
         if (!(client->isShown(false) && client->isOnCurrentDesktop() &&
-                client->isOnCurrentActivity() && client->isOnScreen(screen)))
+                client->isOnScreen(screen)))
             continue;
 
         if (client->geometry().contains(Cursor::pos())) {
@@ -596,7 +564,7 @@ bool Workspace::allowClientActivation(const KWin::Client *c, xcb_timestamp_t tim
     // level == 2 // normal
     Time user_time = ac->userTime();
     kDebug(1212) << "Activation, compared:" << c << ":" << time << ":" << user_time
-                 << ":" << (timestampCompare(time, user_time) >= 0) << endl;
+                 << ":" << (timestampCompare(time, user_time) >= 0);
     return timestampCompare(time, user_time) >= 0;   // time >= user_time
 }
 
@@ -628,7 +596,7 @@ bool Workspace::allowFullClientRaising(const KWin::Client *c, xcb_timestamp_t ti
         return false;
     xcb_timestamp_t user_time = ac->userTime();
     kDebug(1212) << "Raising, compared:" << time << ":" << user_time
-                 << ":" << (timestampCompare(time, user_time) >= 0) << endl;
+                 << ":" << (timestampCompare(time, user_time) >= 0);
     return timestampCompare(time, user_time) >= 0;   // time >= user_time
 }
 
