@@ -21,12 +21,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // own
 #include "client.h"
 // kwin
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
-#ifdef KWIN_BUILD_KAPPMENU
-#include "appmenu.h"
-#endif
 #include "atoms.h"
 #include "bridge.h"
 #include "client_machine.h"
@@ -43,16 +37,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #endif
 #include "workspace.h"
 // KDE
-#include <KDE/KIconLoader>
-#include <KDE/KStandardDirs>
-#include <KDE/KWindowSystem>
+#include <KIconLoader>
+#include <KStandardDirs>
+#include <KWindowSystem>
 // Qt
 #include <QApplication>
 #include <QProcess>
-#ifdef KWIN_BUILD_SCRIPTING
-#include <QScriptEngine>
-#include <QScriptProgram>
-#endif
 #include <QWhatsThis>
 // X
 #ifdef HAVE_XSYNC
@@ -93,8 +83,6 @@ Client::Client()
     , m_wrapper()
     , decoration(NULL)
     , bridge(new Bridge(this))
-    , m_activityUpdatesBlocked(false)
-    , m_blockedActivityUpdatesRequireTransients(false)
     , m_moveResizeGrabWindow()
     , move_resize_has_keyboard_grab(false)
     , m_managed(false)
@@ -133,12 +121,8 @@ Client::Client()
     , paintRedirector(0)
     , m_firstInTabBox(false)
     , electricMaximizing(false)
-    , activitiesDefined(false)
     , needsSessionInteract(false)
     , needsXWindowMove(false)
-#ifdef KWIN_BUILD_KAPPMENU
-    , m_menuAvailable(false)
-#endif
     , m_decoInputExtent()
 {
     // TODO: Do all as initialization
@@ -222,7 +206,7 @@ Client::Client()
  */
 Client::~Client()
 {
-    if (m_killHelperPID && !::kill(m_killHelperPID, 0)) { // means the process is alive
+    if (m_killHelperPID && ::kill(m_killHelperPID, 0) == -1) { // means the process is alive
         ::kill(m_killHelperPID, SIGTERM);
         m_killHelperPID = 0;
     }
@@ -357,7 +341,6 @@ void Client::destroyClient()
 
 // DnD handling for input shaping is broken in the clients for all Qt versions before 4.8.3
 // NOTICE do not query the Qt version macro, this is a runtime problem!
-// TODO KDE5 remove this 
 static inline bool qtBefore483()
 {
     QStringList l = QString(qVersion()).split(".");
@@ -459,12 +442,6 @@ void Client::createDecoration(const QRect& oldgeom)
             decoration, SLOT(maximizeChange()));
     connect(this, SIGNAL(keepAboveChanged(bool)), decoration, SIGNAL(keepAboveChanged(bool)));
     connect(this, SIGNAL(keepBelowChanged(bool)), decoration, SIGNAL(keepBelowChanged(bool)));
-#ifdef KWIN_BUILD_KAPPMENU
-    connect(this, SIGNAL(showRequest()), decoration, SIGNAL(showRequest()));
-    connect(this, SIGNAL(appMenuAvailable()), decoration, SIGNAL(appMenuAvailable()));
-    connect(this, SIGNAL(appMenuUnavailable()), decoration, SIGNAL(appMenuUnavailable()));
-    connect(this, SIGNAL(menuHidden()), decoration, SIGNAL(menuHidden()));
-#endif
     // TODO: Check decoration's minimum size?
     decoration->init();
     decoration->widget()->installEventFilter(this);
@@ -472,8 +449,7 @@ void Client::createDecoration(const QRect& oldgeom)
     decoration->widget()->lower();
     decoration->borders(border_left, border_right, border_top, border_bottom);
     padding_left = padding_right = padding_top = padding_bottom = 0;
-    if (KDecorationUnstable *deco2 = dynamic_cast<KDecorationUnstable*>(decoration))
-        deco2->padding(padding_left, padding_right, padding_top, padding_bottom);
+    decoration->padding(padding_left, padding_right, padding_top, padding_bottom);
     Xcb::moveWindow(decoration->widget()->winId(), -padding_left, -padding_top);
     move(calculateGravitation(false));
     plainResize(sizeForClientSize(clientSize()), ForceGeometrySet);
@@ -511,8 +487,7 @@ bool Client::checkBorderSizes(bool also_resize)
         return false;
 
     int new_left = 0, new_right = 0, new_top = 0, new_bottom = 0;
-    if (KDecorationUnstable *deco2 = dynamic_cast<KDecorationUnstable*>(decoration))
-        deco2->padding(new_left, new_right, new_top, new_bottom);
+    decoration->padding(new_left, new_right, new_top, new_bottom);
     if (padding_left != new_left || padding_top != new_top)
         Xcb::moveWindow(decoration->widget()->winId(), -new_left, -new_top);
     padding_left = new_left;
@@ -614,7 +589,6 @@ void Client::detectNoBorder()
     switch(windowType()) {
     case NET::Desktop :
     case NET::Dock :
-    case NET::TopMenu :
     case NET::Splash :
         noborder = true;
         app_noborder = true;
@@ -630,13 +604,6 @@ void Client::detectNoBorder()
     default:
         abort();
     }
-    // NET::Override is some strange beast without clear definition, usually
-    // just meaning "noborder", so let's treat it only as such flag, and ignore it as
-    // a window type otherwise (SUPPORTED_WINDOW_TYPES_MASK doesn't include it)
-    if (info->windowType(SUPPORTED_MANAGED_WINDOW_TYPES_MASK | NET::OverrideMask) == NET::Override) {
-        noborder = true;
-        app_noborder = true;
-    }
 }
 
 void Client::updateFrameExtents()
@@ -927,7 +894,7 @@ QRect Client::iconGeometry() const
         return geom;
     else {
         // Check all mainwindows of this window (recursively)
-        foreach (Client * mainwin, mainClients()) {
+        foreach (const Client * mainwin, mainClients()) {
             geom = mainwin->iconGeometry();
             if (geom.isValid())
                 return geom;
@@ -1096,13 +1063,6 @@ void Client::updateVisibility()
             internalHide();
         return;
     }
-    if (!isOnCurrentActivity()) {
-        if (compositing() && options->hiddenPreviews() != HiddenPreviewsNever)
-            internalKeep();
-        else
-            internalHide();
-        return;
-    }
     if (isManaged())
         resetShowingDesktop(true);
     internalShow();
@@ -1356,7 +1316,7 @@ void Client::gotPing(xcb_timestamp_t timestamp)
         return;
     delete ping_timer;
     ping_timer = NULL;
-    if (m_killHelperPID && !::kill(m_killHelperPID, 0)) { // means the process is alive
+    if (m_killHelperPID && ::kill(m_killHelperPID, 0) == -1) { // means the process is alive
         ::kill(m_killHelperPID, SIGTERM);
         m_killHelperPID = 0;
     }
@@ -1372,7 +1332,7 @@ void Client::pingTimeout()
 
 void Client::killProcess(bool ask, xcb_timestamp_t timestamp)
 {
-    if (m_killHelperPID && !::kill(m_killHelperPID, 0)) // means the process is alive
+    if (m_killHelperPID && ::kill(m_killHelperPID, 0) == -1) // means the process is alive
         return;
     Q_ASSERT(!ask || timestamp != XCB_TIME_CURRENT_TIME);
     pid_t pid = info->pid();
@@ -1384,8 +1344,9 @@ void Client::killProcess(bool ask, xcb_timestamp_t timestamp)
             QStringList lst;
             lst << clientMachine()->hostName() << "kill" << QString::number(pid);
             QProcess::startDetached("xon", lst);
-        } else
+        } else {
             ::kill(pid, SIGTERM);
+        }
     } else {
         QString hostname = clientMachine()->isLocal() ? "localhost" : clientMachine()->hostName();
         QProcess::startDetached(KStandardDirs::findExe("kwin_killer_helper"),
@@ -1477,7 +1438,7 @@ void Client::setDesktop(int desktop)
         // the next desktop change
     {
         foreach (Client * c2, mainClients())
-        c2->setDesktop(desktop);
+            c2->setDesktop(desktop);
     }
 
     FocusChain::self()->update(this, FocusChain::MakeFirst);
@@ -1492,99 +1453,6 @@ void Client::setDesktop(int desktop)
         emit desktopPresenceChanged(this, was_desk);
 }
 
-/**
- * Sets whether the client is on @p activity.
- * If you remove it from its last activity, then it's on all activities.
- *
- * Note: If it was on all activities and you try to remove it from one, nothing will happen;
- * I don't think that's an important enough use case to handle here.
- */
-void Client::setOnActivity(const QString &activity, bool enable)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    QStringList newActivitiesList = activities();
-    if (newActivitiesList.contains(activity) == enable)   //nothing to do
-        return;
-    if (enable) {
-        QStringList allActivities = Activities::self()->all();
-        if (!allActivities.contains(activity))   //bogus ID
-            return;
-        newActivitiesList.append(activity);
-    } else
-        newActivitiesList.removeOne(activity);
-    setOnActivities(newActivitiesList);
-#else
-    Q_UNUSED(activity)
-    Q_UNUSED(enable)
-#endif
-}
-
-/**
- * set exactly which activities this client is on
- */
-void Client::setOnActivities(QStringList newActivitiesList)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    QString joinedActivitiesList = newActivitiesList.join(",");
-    joinedActivitiesList = rules()->checkActivity(joinedActivitiesList, false);
-    newActivitiesList = joinedActivitiesList.split(',', QString::SkipEmptyParts);
-
-    QStringList allActivities = Activities::self()->all();
-    if ( newActivitiesList.isEmpty() ||
-        (newActivitiesList.count() > 1 && newActivitiesList.count() == allActivities.count()) ||
-        (newActivitiesList.count() == 1 && newActivitiesList.at(0) == Activities::nullUuid())) {
-        activityList.clear();
-        const QByteArray nullUuid = Activities::nullUuid().toUtf8();
-        XChangeProperty(display(), window(), atoms->activities, XA_STRING, 8,
-                        PropModeReplace, (const unsigned char *)nullUuid.constData(), nullUuid.length());
-
-    } else {
-        QByteArray joined = joinedActivitiesList.toAscii();
-        char *data = joined.data();
-        activityList = newActivitiesList;
-        XChangeProperty(display(), window(), atoms->activities, XA_STRING, 8,
-                    PropModeReplace, (unsigned char *)data, joined.size());
-
-    }
-
-    updateActivities(false);
-#else
-    Q_UNUSED(newActivitiesList)
-#endif
-}
-
-void Client::blockActivityUpdates(bool b)
-{
-    if (b) {
-        ++m_activityUpdatesBlocked;
-    } else {
-        Q_ASSERT(m_activityUpdatesBlocked);
-        --m_activityUpdatesBlocked;
-        if (!m_activityUpdatesBlocked)
-            updateActivities(m_blockedActivityUpdatesRequireTransients);
-    }
-}
-
-/**
- * update after activities changed
- */
-void Client::updateActivities(bool includeTransients)
-{
-    if (m_activityUpdatesBlocked) {
-        m_blockedActivityUpdatesRequireTransients |= includeTransients;
-        return;
-    }
-    emit activitiesChanged(this);
-    m_blockedActivityUpdatesRequireTransients = false; // reset
-    FocusChain::self()->update(this, FocusChain::MakeFirst);
-    updateVisibility();
-    updateWindowRules(Rules::Activity);
-
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Activity);
-}
-
 /**
  * Returns the virtual desktop within the workspace() the client window
  * is located in, 0 if it isn't located on any special desktop (not mapped yet),
@@ -1599,19 +1467,6 @@ int Client::desktop() const
     return desk;
 }
 
-/**
- * Returns the list of activities the client window is on.
- * if it's on all activities, the list will be empty.
- * Don't use this, use isOnActivity() and friends (from class Toplevel)
- */
-QStringList Client::activities() const
-{
-    if (needsSessionInteract) {
-        return QStringList();
-    }
-    return activityList;
-}
-
 void Client::setOnAllDesktops(bool b)
 {
     if ((b && isOnAllDesktops()) ||
@@ -1627,24 +1482,6 @@ void Client::setOnAllDesktops(bool b)
         tabGroup()->updateStates(this, TabGroup::Desktop);
 }
 
-/**
- * if @p on is true, sets on all activities.
- * if it's false, sets it to only be on the current activity
- */
-void Client::setOnAllActivities(bool on)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    if (on == isOnAllActivities())
-        return;
-    if (on) {
-        setOnActivities(QStringList());
-
-    } else {
-        setOnActivity(Activities::self()->current(), true);
-    }
-#endif
-}
-
 /**
  * Performs activation and/or raising of the window
  */
@@ -1765,30 +1602,6 @@ void Client::setCaption(const QString& _s, bool force)
         if (!s[i].isPrint())
             s[i] = QChar(' ');
     cap_normal = s;
-#ifdef KWIN_BUILD_SCRIPTING
-    if (options->condensedTitle()) {
-        static QScriptEngine engine;
-        static QScriptProgram stripTitle;
-        static QScriptValue script;
-        if (stripTitle.isNull()) {
-            const QString scriptFile = KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + "/stripTitle.js");
-            if (!scriptFile.isEmpty()) {
-                QFile f(scriptFile);
-                if (f.open(QIODevice::ReadOnly|QIODevice::Text)) {
-                    f.reset();
-                    stripTitle = QScriptProgram(QString::fromLocal8Bit(f.readAll()), "stripTitle.js");
-                    f.close();
-                }
-            }
-            if (stripTitle.isNull())
-                stripTitle = QScriptProgram("(function(title, wm_name, wm_class){ return title ; })", "stripTitle.js");
-            script = engine.evaluate(stripTitle);
-        }
-        QScriptValueList args;
-        args << _s << QString(resourceName()) << QString(resourceClass());
-        s = script.call(QScriptValue(), args).toString();
-    }
-#endif
     if (!force && s == cap_deco)
         return;
     cap_deco = s;
@@ -2117,10 +1930,10 @@ void Client::getWindowProtocols()
                 Pdeletewindow = 1;
             else if (p[i] == atoms->wm_take_focus)
                 Ptakefocus = 1;
-            else if (p[i] == atoms->net_wm_take_activity)
-                Ptakeactivity = 1;
             else if (p[i] == atoms->net_wm_context_help)
                 Pcontexthelp = 1;
+            else if (p[i] == atoms->net_wm_take_activity)
+                Ptakeactivity = 1;
             else if (p[i] == atoms->net_wm_ping)
                 Pping = 1;
         }
@@ -2294,7 +2107,7 @@ void Client::updateCompositeBlocking(bool readProperty)
 {
     if (readProperty) {
         const unsigned long properties[2] = {0, NET::WM2BlockCompositing};
-        NETWinInfo2 i(display(), window(), rootWindow(), properties, 2);
+        NETWinInfo i(display(), window(), rootWindow(), properties, 2);
         setBlockingCompositing(i.isBlockingCompositing());
     }
     else
@@ -2375,51 +2188,6 @@ QPixmap* kwin_get_menu_pix_hack()
     return &p;
 }
 
-void Client::checkActivities()
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    QStringList newActivitiesList;
-    QByteArray prop = getStringProperty(window(), atoms->activities);
-    activitiesDefined = !prop.isEmpty();
-    if (prop == Activities::nullUuid()) {
-        //copied from setOnAllActivities to avoid a redundant XChangeProperty.
-        if (!activityList.isEmpty()) {
-            activityList.clear();
-            updateActivities(true);
-        }
-        return;
-    }
-    if (prop.isEmpty()) {
-        //note: this makes it *act* like it's on all activities but doesn't set the property to 'ALL'
-        if (!activityList.isEmpty()) {
-            activityList.clear();
-            updateActivities(true);
-        }
-        return;
-    }
-
-    newActivitiesList = QString(prop).split(',');
-
-    if (newActivitiesList == activityList)
-        return; //expected change, it's ok.
-
-    //otherwise, somebody else changed it. we need to validate before reacting
-    QStringList allActivities = Activities::self()->all();
-    if (allActivities.isEmpty()) {
-        kDebug() << "no activities!?!?";
-        //don't touch anything, there's probably something bad going on and we don't wanna make it worse
-        return;
-    }
-    for (int i = 0; i < newActivitiesList.size(); ++i) {
-        if (! allActivities.contains(newActivitiesList.at(i))) {
-            kDebug() << "invalid:" << newActivitiesList.at(i);
-            newActivitiesList.removeAt(i--);
-        }
-    }
-    setOnActivities(newActivitiesList);
-#endif
-}
-
 void Client::setSessionInteract(bool needed)
 {
     needsSessionInteract = needed;
@@ -2467,25 +2235,6 @@ bool Client::isClient() const
     return true;
 }
 
-#ifdef KWIN_BUILD_KAPPMENU
-void Client::setAppMenuAvailable()
-{
-    m_menuAvailable = true;
-    emit appMenuAvailable();
-}
-
-void Client::setAppMenuUnavailable()
-{
-    m_menuAvailable = false;
-    emit appMenuUnavailable();
-}
-
-void Client::showApplicationMenu(const QPoint &p)
-{
-    ApplicationMenu::self()->showApplicationMenu(p, window());
-}
-#endif
-
 NET::WindowType Client::windowType(bool direct, int supportedTypes) const
 {
     // TODO: does it make sense to cache the returned window type for SUPPORTED_MANAGED_WINDOW_TYPES_MASK?
@@ -2523,4 +2272,4 @@ bool Client::decorationHasAlpha() const
 
 } // namespace
 
-#include "client.moc"
+#include "moc_client.cpp"
