@@ -29,8 +29,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "toplevel.h"
 #include "xcbutils.h"
 // KDE
-#include <KDE/KShortcut>
-#include <KDE/NETWinInfo>
+#include <KShortcut>
+#include <NETWinInfo>
 // Qt
 #include <QPixmap>
 // X
@@ -42,7 +42,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 // TODO: Cleanup the order of things in this .h file
 
-class QTimer;
+#include <QTimer>
 class KStartupInfoData;
 class KStartupInfoId;
 
@@ -346,12 +346,7 @@ public:
     void setDesktop(int);
     void setOnAllDesktops(bool set);
 
-    virtual QStringList activities() const;
-    void setOnActivity(const QString &activity, bool enable);
-    void setOnAllActivities(bool set);
-    void setOnActivities(QStringList newActivitiesList);
-    void updateActivities(bool includeTransients);
-    void blockActivityUpdates(bool b = true);
+    void sendToScreen(int screen);
 
     /// Is not minimized and not hidden. I.e. normally visible on some virtual desktop.
     bool isShown(bool shaded_is_shown) const;
@@ -405,6 +400,7 @@ public:
     virtual Layer layer() const;
     Layer belongsToLayer() const;
     void invalidateLayer();
+    void updateLayer();
     int sessionStackingOrder() const;
 
     void setModal(bool modal);
@@ -628,22 +624,6 @@ public:
     // a helper for the workspace window packing. tests for screen validity and updates since in maximization case as with normal moving
     void packTo(int left, int top);
 
-#ifdef KWIN_BUILD_KAPPMENU
-    // Used by workspace
-    void emitShowRequest() {
-        emit showRequest();
-    }
-    void emitMenuHidden() {
-        emit menuHidden();
-    }
-    void setAppMenuAvailable();
-    void setAppMenuUnavailable();
-    void showApplicationMenu(const QPoint&);
-    bool menuAvailable() {
-        return m_menuAvailable;
-    }
-#endif
-
     template <typename T>
     void print(T &stream) const;
 
@@ -719,6 +699,7 @@ signals:
     void activeChanged();
     void captionChanged();
     void desktopChanged();
+    void desktopPresenceChanged(KWin::Client*, int); // to be forwarded by Workspace
     void fullScreenChanged();
     void transientChanged();
     void modalChanged();
@@ -737,23 +718,6 @@ signals:
      **/
     void tabGroupChanged();
 
-    /**
-     * Emitted whenever the Client want to show it menu
-     */
-    void showRequest();
-    /**
-     * Emitted whenever the Client's menu is closed
-     */
-    void menuHidden();
-    /**
-     * Emitted whenever the Client's menu is available
-     **/
-    void appMenuAvailable();
-    /**
-     * Emitted whenever the Client's menu is unavailable
-     */
-    void appMenuUnavailable();
-
     /**
      * Emitted whenever the demands attention state changes.
      **/
@@ -837,9 +801,6 @@ private:
     KDecoration* decoration;
     Bridge* bridge;
     int desk;
-    QStringList activityList;
-    int m_activityUpdatesBlocked;
-    bool m_blockedActivityUpdatesRequireTransients;
     bool buttonDown;
     bool moveResizeMode;
     Xcb::Window m_moveResizeGrabWindow;
@@ -980,15 +941,9 @@ private:
 
     friend bool performTransiencyCheck();
 
-    void checkActivities();
-    bool activitiesDefined; //whether the x property was actually set
-
     bool needsSessionInteract;
     bool needsXWindowMove;
 
-#ifdef KWIN_BUILD_KAPPMENU
-    bool m_menuAvailable;
-#endif
     Xcb::Window m_decoInputExtent;
     QPoint input_offset;
 };
