@@ -20,10 +20,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "config-kwin.h"
 
 #include <QApplication>
-#include <QtDeclarative/QDeclarativeComponent>
-#include <QtDeclarative/QDeclarativeContext>
-#include <QtDeclarative/QDeclarativeEngine>
-#include <QtDeclarative/QDeclarativeItem>
+#include <QDeclarativeComponent>
+#include <QDeclarativeContext>
+#include <QDeclarativeEngine>
+#include <QDeclarativeItem>
 #include <QGraphicsView>
 #include <QPaintEngine>
 
@@ -33,14 +33,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KPluginInfo>
 #include <KServiceTypeTrader>
 #include <KStandardDirs>
-#include <Plasma/FrameSvg>
 
 namespace Aurorae
 {
 
 AuroraeFactory::AuroraeFactory()
         : QObject()
-        , KDecorationFactoryUnstable()
+        , KDecorationFactory()
         , m_theme(new AuroraeTheme(this))
         , m_engine(new QDeclarativeEngine(this))
         , m_component(new QDeclarativeComponent(m_engine, this))
@@ -111,7 +110,7 @@ void AuroraeFactory::initQML(const KConfigGroup &group)
     QString constraint = QString("[X-KDE-PluginInfo-Name] == '%1'").arg(internalname);
     KService::List offers = KServiceTypeTrader::self()->query("KWin/Decoration", constraint);
     if (offers.isEmpty()) {
-        kError(1212) << "Couldn't find QML Decoration " << themeName << endl;
+        kError(1212) << "Couldn't find QML Decoration " << themeName;
         // TODO: what to do in error case?
         return;
     }
@@ -119,7 +118,7 @@ void AuroraeFactory::initQML(const KConfigGroup &group)
     KPluginInfo plugininfo(service);
     const QString pluginName = service->property("X-KDE-PluginInfo-Name").toString();
     const QString scriptName = service->property("X-Plasma-MainScript").toString();
-    const QString file = KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + "/decorations/" + pluginName + "/contents/" + scriptName);
+    const QString file = KStandardDirs::locate("data", "kwin/decorations/" + pluginName + "/contents/" + scriptName);
     if (file.isNull()) {
         kDebug(1212) << "Could not find script file for " << pluginName;
         // TODO: what to do in error case?
@@ -186,7 +185,6 @@ bool AuroraeFactory::reset(unsigned long changed)
 bool AuroraeFactory::supports(Ability ability) const
 {
     switch (ability) {
-    case AbilityAnnounceButtons:
     case AbilityUsesAlphaChannel:
     case AbilityAnnounceAlphaChannel:
     case AbilityButtonMenu:
@@ -200,13 +198,10 @@ bool AuroraeFactory::supports(Ability ability) const
     case AbilityButtonShade:
     case AbilityButtonOnAllDesktops:
     case AbilityButtonHelp:
-    case AbilityButtonApplicationMenu:
     case AbilityProvidesShadow:
         return true; // TODO: correct value from theme
     case AbilityTabbing:
         return false;
-    case AbilityUsesBlurBehind:
-        return true;
     default:
         return false;
     }
@@ -238,7 +233,7 @@ AuroraeFactory *AuroraeFactory::s_instance = NULL;
 * Client
 *******************************************************/
 AuroraeClient::AuroraeClient(KDecorationBridge *bridge, KDecorationFactory *factory)
-    : KDecorationUnstable(bridge, factory)
+    : KDecoration(bridge, factory)
     , m_view(NULL)
     , m_scene(new QGraphicsScene(this))
     , m_item(AuroraeFactory::instance()->createQmlDecoration(this))
@@ -249,8 +244,6 @@ AuroraeClient::AuroraeClient(KDecorationBridge *bridge, KDecorationFactory *fact
     connect(AuroraeFactory::instance(), SIGNAL(configChanged()), SIGNAL(configChanged()));
     connect(AuroraeFactory::instance(), SIGNAL(titleFontChanged()), SIGNAL(fontChanged()));
     connect(m_item, SIGNAL(alphaChanged()), SLOT(slotAlphaChanged()));
-    connect(this, SIGNAL(appMenuAvailable()), SIGNAL(appMenuAvailableChanged()));
-    connect(this, SIGNAL(appMenuUnavailable()), SIGNAL(appMenuAvailableChanged()));
 }
 
 AuroraeClient::~AuroraeClient()
@@ -305,7 +298,7 @@ bool AuroraeClient::eventFilter(QObject *object, QEvent *event)
     // TODO: remove in KDE5
     // see BUG: 304248
     if (object != widget() || event->type() != QEvent::Wheel) {
-        return KDecorationUnstable::eventFilter(object, event);
+        return KDecoration::eventFilter(object, event);
     }
     QWheelEvent *wheel = static_cast<QWheelEvent*>(event);
     if (mousePosition(wheel->pos()) == PositionCenter) {
@@ -337,9 +330,7 @@ void AuroraeClient::desktopChange()
 
 void AuroraeClient::maximizeChange()
 {
-    if (!options()->moveResizeMaximizedWindows()) {
-        emit maximizeChanged();
-    }
+    emit maximizeChanged();
 }
 
 void AuroraeClient::resize(const QSize &s)
@@ -364,7 +355,7 @@ void AuroraeClient::borders(int &left, int &right, int &top, int &bottom) const
         left = right = top = bottom = 0;
         return;
     }
-    const bool maximized = maximizeMode() == MaximizeFull && !options()->moveResizeMaximizedWindows();
+    const bool maximized = maximizeMode() == MaximizeFull;
     QObject *borders = NULL;
     if (maximized) {
         borders = m_item->findChild<QObject*>("maximizedBorders");
@@ -376,11 +367,7 @@ void AuroraeClient::borders(int &left, int &right, int &top, int &bottom) const
 
 void AuroraeClient::padding(int &left, int &right, int &top, int &bottom) const
 {
-    if (!m_item) {
-        left = right = top = bottom = 0;
-        return;
-    }
-    if (maximizeMode() == MaximizeFull && !options()->moveResizeMaximizedWindows()) {
+    if (!m_item || maximizeMode() == MaximizeFull) {
         left = right = top = bottom = 0;
         return;
     }
@@ -458,11 +445,6 @@ void AuroraeClient::menuClicked()
     showWindowMenu(QCursor::pos());
 }
 
-void AuroraeClient::appMenuClicked()
-{
-    showApplicationMenu(QCursor::pos());
-}
-
 void AuroraeClient::toggleShade()
 {
     setShade(!isShade());
@@ -480,7 +462,7 @@ void AuroraeClient::toggleKeepBelow()
 
 bool AuroraeClient::isMaximized() const
 {
-    return maximizeMode()==KDecorationDefines::MaximizeFull && !options()->moveResizeMaximizedWindows();
+    return maximizeMode()==KDecorationDefines::MaximizeFull;
 }
 
 void AuroraeClient::titlePressed(int button, int buttons)
@@ -550,12 +532,12 @@ int AuroraeClient::doubleClickInterval() const
 
 void AuroraeClient::closeWindow()
 {
-    QMetaObject::invokeMethod(qobject_cast< KDecorationUnstable* >(this), "doCloseWindow", Qt::QueuedConnection);
+    QMetaObject::invokeMethod(qobject_cast< KDecoration* >(this), "doCloseWindow", Qt::QueuedConnection);
 }
 
 void AuroraeClient::doCloseWindow()
 {
-    KDecorationUnstable::closeWindow();
+    KDecoration::closeWindow();
 }
 
 void AuroraeClient::maximize(int button)
@@ -563,7 +545,7 @@ void AuroraeClient::maximize(int button)
     // a maximized window does not need to have a window decoration
     // in that case we need to delay handling by one cycle
     // BUG: 304870
-    QMetaObject::invokeMethod(qobject_cast< KDecorationUnstable* >(this),
+    QMetaObject::invokeMethod(qobject_cast< KDecoration* >(this),
                               "doMaximzie",
                               Qt::QueuedConnection,
                               Q_ARG(int, button));
@@ -571,19 +553,19 @@ void AuroraeClient::maximize(int button)
 
 void AuroraeClient::doMaximzie(int button)
 {
-    KDecorationUnstable::maximize(static_cast<Qt::MouseButton>(button));
+    KDecoration::maximize(static_cast<Qt::MouseButton>(button));
 }
 
 void AuroraeClient::titlebarDblClickOperation()
 {
     // the double click operation can result in a window being maximized
     // see maximize
-    QMetaObject::invokeMethod(qobject_cast< KDecorationUnstable* >(this), "doTitlebarDblClickOperation", Qt::QueuedConnection);
+    QMetaObject::invokeMethod(qobject_cast< KDecoration* >(this), "doTitlebarDblClickOperation", Qt::QueuedConnection);
 }
 
 void AuroraeClient::doTitlebarDblClickOperation()
 {
-    KDecorationUnstable::titlebarDblClickOperation();
+    KDecoration::titlebarDblClickOperation();
 }
 
 QVariant AuroraeClient::readConfig(const QString &key, const QVariant &defaultValue)
@@ -661,4 +643,4 @@ extern "C"
 }
 
 
-#include "aurorae.moc"
+#include "moc_aurorae.cpp"
