@@ -23,12 +23,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kdecoration.h>
 #include <kdecorationfactory.h>
 
-class QDeclarativeComponent;
-class QDeclarativeEngine;
-class QDeclarativeItem;
-class QGraphicsSceneMouseEvent;
-class QGraphicsScene;
-class QGraphicsView;
+#include <QDeclarativeComponent>
+#include <QDeclarativeEngine>
+#include <QDeclarativeItem>
+#include <QGraphicsSceneMouseEvent>
+#include <QGraphicsScene>
+#include <QGraphicsView>
 class KConfig;
 class KConfigGroup;
 
@@ -37,7 +37,7 @@ namespace Aurorae
 class AuroraeTheme;
 class AuroraeClient;
 
-class AuroraeFactory :  public QObject, public KDecorationFactoryUnstable
+class AuroraeFactory :  public QObject, public KDecorationFactory
 {
     Q_OBJECT
 public:
@@ -82,7 +82,7 @@ private:
     QString m_themeName;
 };
 
-class AuroraeClient : public KDecorationUnstable
+class AuroraeClient : public KDecoration
 {
     Q_OBJECT
     Q_PROPERTY(bool active READ isActive NOTIFY activeChanged)
@@ -106,7 +106,6 @@ class AuroraeClient : public KDecorationUnstable
     Q_PROPERTY(bool keepBelow READ keepBelow WRITE setKeepBelow NOTIFY keepBelowChangedWrapper)
     Q_PROPERTY(bool maximized READ isMaximized NOTIFY maximizeChanged)
     Q_PROPERTY(bool providesContextHelp READ providesContextHelp)
-    Q_PROPERTY(bool appMenu READ menuAvailable NOTIFY appMenuAvailableChanged)
     Q_PROPERTY(QRect transparentRect READ transparentRect)
     Q_PROPERTY(int width READ width)
     Q_PROPERTY(qulonglong windowId READ windowId CONSTANT)
@@ -154,11 +153,9 @@ Q_SIGNALS:
      **/
     void configChanged();
     void fontChanged();
-    void appMenuAvailableChanged();
 
 public slots:
     void menuClicked();
-    void appMenuClicked();
     void toggleShade();
     void toggleKeepAbove();
     void toggleKeepBelow();
