@@ -18,7 +18,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "colorhelper.h"
 #include "decorationoptions.h"
 #include <qdeclarative.h>
-Q_EXPORT_PLUGIN2(decorationplugin, DecorationPlugin)
+
+Q_EXPORT_PLUGIN(DecorationPlugin)
 
 void DecorationPlugin::registerTypes(const char *uri)
 {
@@ -28,4 +29,4 @@ void DecorationPlugin::registerTypes(const char *uri)
     qmlRegisterType<KWin::Borders>(uri, 0, 1, "Borders");
 }
 
-#include "decorationplugin.moc"
+#include "moc_decorationplugin.cpp"
