@@ -145,9 +145,6 @@ public:
     int buttonWidthMenu() const {
         return m_buttonWidthMenu;
     }
-    int buttonWidthAppMenu() const {
-        return m_buttonWidthAppMenu;
-    }
     int buttonHeight() const {
         return m_buttonHeight;
     }
@@ -311,9 +308,6 @@ public:
     static int defaultButtonWidthMenu() {
         return defaultButtonWidth();
     }
-    static int defaultButtonWidthAppMenu() {
-        return defaultButtonWidthMenu();
-    }
     static int defaultButtonHeight() {
         return 20;
     }
@@ -395,7 +389,6 @@ private:
     int m_buttonWidthShade;
     int m_buttonWidthHelp;
     int m_buttonWidthMenu;
-    int m_buttonWidthAppMenu;
     int m_buttonHeight;
     int m_buttonSpacing;
     int m_buttonMarginTop;
