@@ -20,7 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "plastikbutton.h"
 #include <kdecoration.h>
-#include <KDE/KColorScheme>
+#include <KColorScheme>
 #include <QPainter>
 
 namespace KWin
@@ -91,8 +91,6 @@ QPixmap PlastikButtonProvider::requestPixmap(const QString &id, QSize *size, con
         } else {
             button = ShadeIcon;
         }
-    } else if (idParts[0] == "N") {
-        button = AppMenuIcon;
     } else {
         // not recognized icon
         return QDeclarativeImageProvider::requestPixmap(id, size, requestedSize);
@@ -362,13 +360,6 @@ QPixmap PlastikButtonProvider::icon(ButtonIcon icon, int size, bool active, bool
 
             break;
         }
-        case AppMenuIcon:
-        {
-            drawObject(p, HorizontalLine, r.x(), r.top()+(lwTitleBar-1), r.width(), lwTitleBar);
-            drawObject(p, HorizontalLine, r.x(), r.center().y(), r.width(), lwTitleBar);
-            drawObject(p, HorizontalLine, r.x(), r.bottom()-(lwTitleBar-1), r.width(), lwTitleBar);
-            break;
-        }
 
         default:
             break;
