@@ -17,6 +17,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KWIN_PLASTIK_BUTTON_H
 #define KWIN_PLASTIK_BUTTON_H
 
+#include <QPainter>
 #include <QDeclarativeImageProvider>
 
 namespace KWin
@@ -43,7 +44,6 @@ private:
         NoKeepBelowIcon,
         ShadeIcon,
         UnShadeIcon,
-        AppMenuIcon,
         NumButtonIcons
     };
     enum Object {
