@@ -17,7 +17,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "plastikplugin.h"
 #include "plastikbutton.h"
 #include <QDeclarativeEngine>
-Q_EXPORT_PLUGIN2(plastikplugin, PlastikPlugin)
+
+Q_EXPORT_PLUGIN(PlastikPlugin)
 
 void PlastikPlugin::registerTypes(const char *uri)
 {
@@ -31,4 +32,4 @@ void PlastikPlugin::initializeEngine(QDeclarativeEngine *engine, const char *uri
     QDeclarativeExtensionPlugin::initializeEngine(engine, uri);
 }
 
-#include "plastikplugin.moc"
+#include "moc_plastikplugin.cpp"
