@@ -1,12 +1,12 @@
-#ifndef oxygenshadowdemodialog_h
-#define oxygenshadowdemodialog_h
+#ifndef OXYGENSHADOWDEMODIALOG_H
+#define OXYGENSHADOWDEMODIALOG_H
 
 //////////////////////////////////////////////////////////////////////////////
 // oxygenshadowdemodialog.h
 // oxygen shadow demo dialog
 // -------------------
 //
-// Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+// Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
