@@ -27,8 +27,6 @@
 #include "oxygenexceptionlist.h"
 #include "oxygenutil.h"
 
-#include <QTextStream>
-
 namespace Oxygen
 {
 
@@ -60,7 +58,6 @@ namespace Oxygen
 
             // propagate all features found in mask to the output configuration
             if( exception.mask() & FrameBorder ) configuration->setFrameBorder( exception.frameBorder() );
-            if( exception.mask() & BlendColor ) configuration->setBlendStyle( exception.blendStyle() );
             if( exception.mask() & DrawSeparator ) configuration->setSeparatorMode( exception.separatorMode() );
             if( exception.mask() & TitleOutline ) configuration->setDrawTitleOutline( exception.drawTitleOutline() );
             if( exception.mask() & SizeGripMode ) configuration->setDrawSizeGrip( exception.drawSizeGrip() );
@@ -84,8 +81,7 @@ namespace Oxygen
 
         // rewrite current exceptions
         int index = 0;
-        foreach( const ConfigurationPtr& exception, _exceptions )
-        {
+        foreach( const ConfigurationPtr& exception, _exceptions ) {
 
             Util::writeConfig( exception.data(), config.data(), exceptionGroupName( index ) );
             ++index;
@@ -97,9 +93,7 @@ namespace Oxygen
     //_______________________________________________________________________
     QString ExceptionList::exceptionGroupName( int index )
     {
-      QString out;
-      QTextStream( &out ) << "Windeco Exception " << index;
-      return out;
+        return (QString::fromLatin1("Windeco Exception ") + QString::number(index));
     }
 
 }
