@@ -25,7 +25,7 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenfactory.h"
-#include "oxygenfactory.moc"
+#include "moc_oxygenfactory.cpp"
 #include "oxygenclient.h"
 #include "oxygenexceptionlist.h"
 
@@ -101,7 +101,6 @@ namespace Oxygen
 
         // read shadowCache configuration
         _shadowCache.readConfig();
-        _shadowCache.setAnimationsDuration( _defaultConfiguration->shadowAnimationsDuration() );
 
         // background pixmap
         {
@@ -116,14 +115,8 @@ namespace Oxygen
     {
         switch( ability )
         {
-
-            // announce
-            case AbilityAnnounceButtons:
-            case AbilityAnnounceColors:
-
             // buttons
             case AbilityButtonMenu:
-            case AbilityButtonApplicationMenu:
             case AbilityButtonHelp:
             case AbilityButtonMinimize:
             case AbilityButtonMaximize:
@@ -160,8 +153,7 @@ namespace Oxygen
 
         QString windowTitle;
         QString className;
-        foreach( const ConfigurationPtr& configuration, _exceptions )
-        {
+        foreach( const ConfigurationPtr& configuration, _exceptions ) {
 
             // discard disabled exceptions
             if( !configuration->enabled() ) continue;
