@@ -17,13 +17,14 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
+
+#include <config-X11.h>
+#include <config-kwin.h>
+
 #include "composite.h"
 #include "compositingadaptor.h"
 
-#include <config-X11.h>
-
 #include "utils.h"
-#include <QTextStream>
 #include "workspace.h"
 #include "client.h"
 #include "unmanaged.h"
@@ -32,7 +33,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "overlaywindow.h"
 #include "scene.h"
 #include "scene_xrender.h"
-#include "scene_opengl.h"
 #include "shadow.h"
 #include "useractions.h"
 #include "compositingprefs.h"
@@ -40,18 +40,17 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <stdio.h>
 
-#include <QtConcurrentRun>
-#include <QFutureWatcher>
+#include <QTextStream>
+#include <QFile>
 #include <QMenu>
-#include <QTimerEvent>
+#include <QtCore/qcoreevent.h>
 #include <QDateTime>
 #include <QDBusConnection>
 #include <kaction.h>
 #include <kactioncollection.h>
-#include <KDE/KGlobal>
-#include <KDE/KLocalizedString>
-#include <KDE/KNotification>
-#include <KDE/KSelectionWatcher>
+#include <KGlobal>
+#include <KLocalizedString>
+#include <KNotification>
 
 #include <xcb/composite.h>
 #include <xcb/damage.h>
@@ -63,16 +62,6 @@ namespace KWin
 
 extern int currentRefreshRate();
 
-CompositorSelectionOwner::CompositorSelectionOwner(const char *selection) : KSelectionOwner(selection), owning(false)
-{
-    connect (this, SIGNAL(lostOwnership()), SLOT(looseOwnership()));
-}
-
-void CompositorSelectionOwner::looseOwnership()
-{
-    owning = false;
-}
-
 KWIN_SINGLETON_FACTORY_VARIABLE(Compositor, s_compositor)
 
 static inline qint64 milliToNano(int milli) { return milli * 1000 * 1000; }
@@ -82,7 +71,6 @@ Compositor::Compositor(QObject* workspace)
     : QObject(workspace)
     , m_suspended(options->isUseCompositing() ? NoReasonSuspend : UserSuspend)
     , cm_selection(NULL)
-    , vBlankInterval(0)
     , fpsInterval(0)
     , m_xrrRefreshRate(0)
     , forceUnredirectCheck(false)
@@ -106,10 +94,6 @@ Compositor::Compositor(QObject* workspace)
     // 2 sec which should be enough to restart the compositor
     static const int compositorLostMessageDelay = 2000;
 
-    m_releaseSelectionTimer.setSingleShot(true);
-    m_releaseSelectionTimer.setInterval(compositorLostMessageDelay);
-    connect(&m_releaseSelectionTimer, SIGNAL(timeout()), SLOT(releaseCompositorSelection()));
-
     m_unusedSupportPropertyTimer.setInterval(compositorLostMessageDelay);
     m_unusedSupportPropertyTimer.setSingleShot(true);
     connect(&m_unusedSupportPropertyTimer, SIGNAL(timeout()), SLOT(deleteUnusedSupportProperties()));
@@ -125,7 +109,10 @@ Compositor::~Compositor()
 {
     finish();
     deleteUnusedSupportProperties();
-    delete cm_selection;
+    if (cm_selection) {
+        disconnect(cm_selection, 0, this, 0);
+        delete cm_selection;
+    }
     s_compositor = NULL;
 }
 
@@ -144,38 +131,20 @@ void Compositor::setup()
     m_starting = true;
 
     if (!options->isCompositingInitialized()) {
-#ifndef KWIN_HAVE_OPENGLES
-        // options->reloadCompositingSettings(true) initializes the CompositingPrefs which calls an
-        // external program in turn
-        // run this in an external thread to make startup faster.
-        QFutureWatcher<void> *compositingPrefsFuture = new QFutureWatcher<void>();
-        connect(compositingPrefsFuture, SIGNAL(finished()), this, SLOT(slotCompositingOptionsInitialized()));
-        connect(compositingPrefsFuture, SIGNAL(finished()), compositingPrefsFuture, SLOT(deleteLater()));
-        compositingPrefsFuture->setFuture(QtConcurrent::run(options, &Options::reloadCompositingSettings, true));
-#else
-        // OpenGL ES does not call the external program, so no need to create a thread
+        // options->reloadCompositingSettings(true) initializes the CompositingPrefs
         options->reloadCompositingSettings(true);
-        slotCompositingOptionsInitialized();
-#endif
-    } else {
-        slotCompositingOptionsInitialized();
     }
-}
 
-extern int screen_number; // main.cpp
-extern bool is_multihead;
-
-void Compositor::slotCompositingOptionsInitialized()
-{
-    char selection_name[ 100 ];
-    sprintf(selection_name, "_NET_WM_CM_S%d", DefaultScreen(display()));
     if (!cm_selection) {
-        cm_selection = new CompositorSelectionOwner(selection_name);
-        connect(cm_selection, SIGNAL(lostOwnership()), SLOT(finish()));
+        const int selection_sreen = DefaultScreen(display());
+        char selection_name[ 100 ];
+        ::memset(selection_name, '\0', sizeof(selection_name) * sizeof(char));
+        ::sprintf(selection_name, "_NET_WM_CM_S%d", selection_sreen);
+        cm_selection = new KSelectionOwner(selection_name, selection_sreen, this);
     }
-    if (!cm_selection->owning) {
+    if (cm_selection->ownerWindow() == XNone) {
         cm_selection->claim(true);   // force claiming
-        cm_selection->owning = true;
+        connect(cm_selection, SIGNAL(lostOwnership()), SLOT(finish()));
     }
 
     // There might still be a deleted around, needs to be cleared before creating the scene (BUG 333275)
@@ -184,44 +153,7 @@ void Compositor::slotCompositingOptionsInitialized()
     }
 
     switch(options->compositingMode()) {
-    case OpenGLCompositing: {
-        kDebug(1212) << "Initializing OpenGL compositing";
-
-        // Some broken drivers crash on glXQuery() so to prevent constant KWin crashes:
-        KSharedConfigPtr unsafeConfigPtr = KGlobal::config();
-        KConfigGroup unsafeConfig(unsafeConfigPtr, "Compositing");
-        const QString openGLIsUnsafe = "OpenGLIsUnsafe" + (is_multihead ? QString::number(screen_number) : "");
-        if (unsafeConfig.readEntry(openGLIsUnsafe, false))
-            kWarning(1212) << "KWin has detected that your OpenGL library is unsafe to use";
-        else {
-            unsafeConfig.writeEntry(openGLIsUnsafe, true);
-            unsafeConfig.sync();
-#ifndef KWIN_HAVE_OPENGLES
-            if (!CompositingPrefs::hasGlx()) {
-                unsafeConfig.writeEntry(openGLIsUnsafe, false);
-                unsafeConfig.sync();
-                kDebug(1212) << "No glx extensions available";
-                break;
-            }
-#endif
-
-            m_scene = SceneOpenGL::createScene();
-            connect(m_scene, SIGNAL(resetCompositing()), SLOT(restart()));
-
-            // TODO: Add 30 second delay to protect against screen freezes as well
-            unsafeConfig.writeEntry(openGLIsUnsafe, false);
-            unsafeConfig.sync();
-
-            if (m_scene && !m_scene->initFailed())
-                break; // -->
-            delete m_scene;
-            m_scene = NULL;
-        }
-
-        // Do not Fall back to XRender - it causes problems when selfcheck fails during startup, but works later on
-        break;
-    }
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     case XRenderCompositing:
         kDebug(1212) << "Initializing XRender compositing";
         m_scene = new SceneXrender(Workspace::self());
@@ -230,7 +162,6 @@ void Compositor::slotCompositingOptionsInitialized()
     default:
         kDebug(1212) << "No compositing enabled";
         m_starting = false;
-        cm_selection->owning = false;
         cm_selection->release();
         return;
     }
@@ -240,17 +171,11 @@ void Compositor::slotCompositingOptionsInitialized()
         delete m_scene;
         m_scene = NULL;
         m_starting = false;
-        cm_selection->owning = false;
         cm_selection->release();
         return;
     }
     m_xrrRefreshRate = KWin::currentRefreshRate();
     fpsInterval = options->maxFpsInterval();
-    if (m_scene->syncsToVBlank()) {  // if we do vsync, set the fps to the next multiple of the vblank rate
-        vBlankInterval = milliToNano(1000) / m_xrrRefreshRate;
-        fpsInterval = qMax((fpsInterval / vBlankInterval) * vBlankInterval, vBlankInterval);
-    } else
-        vBlankInterval = milliToNano(1); // no sync - DO NOT set "0", would cause div-by-zero segfaults.
     m_timeSinceLastVBlank = fpsInterval - (options->vBlankTime() + 1); // means "start now" - we don't have even a slight idea when the first vsync will occur
     scheduleRepaint();
     xcb_composite_redirect_subwindows(connection(), rootWindow(), XCB_COMPOSITE_REDIRECT_MANUAL);
@@ -271,9 +196,6 @@ void Compositor::slotCompositingOptionsInitialized()
     emit compositingToggled(true);
 
     m_starting = false;
-    if (m_releaseSelectionTimer.isActive()) {
-        m_releaseSelectionTimer.stop();
-    }
 
     // render at least once
     performCompositing();
@@ -290,7 +212,6 @@ void Compositor::finish()
     if (!hasScene())
         return;
     m_finishing = true;
-    m_releaseSelectionTimer.start();
     foreach (Client * c, Workspace::self()->clientList())
         m_scene->windowClosed(c, NULL);
     foreach (Client * c, Workspace::self()->desktopList())
@@ -300,13 +221,13 @@ void Compositor::finish()
     foreach (Deleted * c, Workspace::self()->deletedList())
         m_scene->windowDeleted(c);
     foreach (Client * c, Workspace::self()->clientList())
-    c->finishCompositing();
+        c->finishCompositing();
     foreach (Client * c, Workspace::self()->desktopList())
-    c->finishCompositing();
+        c->finishCompositing();
     foreach (Unmanaged * c, Workspace::self()->unmanagedList())
-    c->finishCompositing();
+        c->finishCompositing();
     foreach (Deleted * c, Workspace::self()->deletedList())
-    c->finishCompositing();
+        c->finishCompositing();
     xcb_composite_unredirect_subwindows(connection(), rootWindow(), XCB_COMPOSITE_REDIRECT_MANUAL);
     delete effects;
     effects = NULL;
@@ -319,7 +240,7 @@ void Compositor::finish()
             ++it) {
         // forward all opacity values to the frame in case there'll be other CM running
         if ((*it)->opacity() != 1.0) {
-            NETWinInfo2 i(display(), (*it)->frameId(), rootWindow(), 0);
+            NETWinInfo i(display(), (*it)->frameId(), rootWindow(), 0);
             i.setOpacity(static_cast< unsigned long >((*it)->opacity() * 0xffffffff));
         }
     }
@@ -328,28 +249,13 @@ void Compositor::finish()
         Workspace::self()->deletedList().first()->discard();
     m_finishing = false;
     emit compositingToggled(false);
-}
-
-void Compositor::releaseCompositorSelection()
-{
-    if (hasScene() && !m_finishing) {
-        // compositor is up and running again, no need to release the selection
-        return;
+    if (cm_selection) {
+        kDebug(1212) << "Releasing compositor selection";
+        disconnect(cm_selection, 0, this, 0);
+        cm_selection->release();
+        delete cm_selection;
+        cm_selection = 0;
     }
-    if (m_starting) {
-        // currently still starting the compositor, it might fail, so restart the timer to test again
-        m_releaseSelectionTimer.start();
-        return;
-    }
-
-    if (m_finishing) {
-        // still shutting down, a restart might follow, so restart the timer to test again
-        m_releaseSelectionTimer.start();
-        return;
-    }
-    kDebug(1212) << "Releasing compositor selection";
-    cm_selection->owning = false;
-    cm_selection->release();
 }
 
 void Compositor::keepSupportProperty(xcb_atom_t atom)
@@ -381,23 +287,6 @@ void Compositor::deleteUnusedSupportProperties()
     }
 }
 
-// OpenGL self-check failed, fallback to XRender
-void Compositor::fallbackToXRenderCompositing()
-{
-    finish();
-    KConfigGroup config(KGlobal::config(), "Compositing");
-    config.writeEntry("Backend", "XRender");
-    config.writeEntry("GraphicsSystem", "native");
-    config.sync();
-    if (Extensions::nonNativePixmaps()) { // must restart to change the graphicssystem
-        restartKWin("automatic graphicssystem change for XRender backend");
-        return;
-    } else {
-        options->setCompositingMode(XRenderCompositing);
-        setup();
-    }
-}
-
 void Compositor::slotConfigChanged()
 {
     if (!m_suspended) {
@@ -405,20 +294,15 @@ void Compositor::slotConfigChanged()
         if (effects)   // setupCompositing() may fail
             effects->reconfigure();
         addRepaintFull();
-    } else
+    } else {
         finish();
+    }
 }
 
 void Compositor::slotReinitialize()
 {
     // Reparse config. Config options will be reloaded by setup()
     KGlobal::config()->reparseConfiguration();
-    const QString graphicsSystem = KConfigGroup(KGlobal::config(), "Compositing").readEntry("GraphicsSystem", "");
-    if ((Extensions::nonNativePixmaps() && graphicsSystem == "native") ||
-        (!Extensions::nonNativePixmaps() && (graphicsSystem == "raster" || graphicsSystem == "opengl")) ) {
-        restartKWin("explicitly reconfigured graphicsSystem change");
-        return;
-    }
 
     // Restart compositing
     finish();
@@ -586,15 +470,6 @@ void Compositor::performCompositing()
 
     // Get the replies
     foreach (Toplevel *win, damaged) {
-        // Discard the cached lanczos texture
-        if (win->effectWindow()) {
-            const QVariant texture = win->effectWindow()->data(LanczosCacheRole);
-            if (texture.isValid()) {
-                delete static_cast<GLTexture *>(texture.value<void*>());
-                win->effectWindow()->setData(LanczosCacheRole, QVariant());
-            }
-        }
-
         win->getDamageRegionReply();
     }
 
@@ -613,9 +488,12 @@ void Compositor::performCompositing()
     // TODO ?
     // this cannot be used so carelessly - needs protections against broken clients, the window
     // should not get focus before it's displayed, handle unredirected windows properly and so on.
-    foreach (Toplevel *t, windows)
+    QMutableListIterator<Toplevel*> windows_it(windows);
+    while (windows_it.hasNext()) {
+        const Toplevel *t = windows_it.next();
         if (!t->readyForPainting())
-            windows.removeAll(t);
+            windows_it.remove();
+    }
 
     QRegion repaints = repaints_region;
     // clear all repaints, so that post-pass can add repaints for the next repaint
@@ -634,18 +512,22 @@ void Compositor::performCompositing()
 
 bool Compositor::windowRepaintsPending() const
 {
-    foreach (Toplevel * c, Workspace::self()->clientList())
-    if (!c->repaints().isEmpty())
-        return true;
-    foreach (Toplevel * c, Workspace::self()->desktopList())
-    if (!c->repaints().isEmpty())
-        return true;
-    foreach (Toplevel * c, Workspace::self()->unmanagedList())
-    if (!c->repaints().isEmpty())
-        return true;
-    foreach (Toplevel * c, Workspace::self()->deletedList())
-    if (!c->repaints().isEmpty())
-        return true;
+    foreach (const Toplevel * c, Workspace::self()->clientList()) {
+        if (!c->repaints().isEmpty())
+            return true;
+    }
+    foreach (const Toplevel * c, Workspace::self()->desktopList()) {
+        if (!c->repaints().isEmpty())
+            return true;
+    }
+    foreach (const Toplevel * c, Workspace::self()->unmanagedList()) {
+        if (!c->repaints().isEmpty())
+            return true;
+    }
+    foreach (const Toplevel * c, Workspace::self()->deletedList()) {
+        if (!c->repaints().isEmpty())
+            return true;
+    }
     return false;
 }
 
@@ -660,52 +542,14 @@ void Compositor::setCompositeTimer()
         return;
 
     uint waitTime = 1;
-
-    if (m_scene->blocksForRetrace()) {
-
-        // TODO: make vBlankTime dynamic?!
-        // It's required because glXWaitVideoSync will *likely* block a full frame if one enters
-        // a retrace pass which can last a variable amount of time, depending on the actual screen
-        // Now, my ooold 19" CRT can do such retrace so that 2ms are entirely sufficient,
-        // while another ooold 15" TFT requires about 6ms
-
-        qint64 padding = m_timeSinceLastVBlank;
-        if (padding > fpsInterval) {
-            // we're at low repaints or spent more time in painting than the user wanted to wait for that frame
-            padding = vBlankInterval - (padding%vBlankInterval); // -> align to next vblank
-        } else {  // -> align to the next maxFps tick
-            padding = ((vBlankInterval - padding%vBlankInterval) + (fpsInterval/vBlankInterval-1)*vBlankInterval);
-            //               "remaining time of the first vsync" + "time for the other vsyncs of the frame"
-        }
-
-        if (padding < options->vBlankTime()) { // we'll likely miss this frame
-            waitTime = nanoToMilli(padding + vBlankInterval - options->vBlankTime()); // so we add one
-        } else {
-            waitTime = nanoToMilli(padding - options->vBlankTime());
-        }
-    }
-    else { // w/o blocking vsync we just jump to the next demanded tick
-        if (fpsInterval > m_timeSinceLastVBlank) {
-            waitTime = nanoToMilli(fpsInterval - m_timeSinceLastVBlank);
-            if (!waitTime) {
-                waitTime = 1; // will ensure we don't block out the eventloop - the system's just not faster ...
-            }
-        }/* else if (m_scene->syncsToVBlank() && m_timeSinceLastVBlank - fpsInterval < (vBlankInterval<<1)) {
-            // NOTICE - "for later" ------------------------------------------------------------------
-            // It can happen that we push two frames within one refresh cycle.
-            // Swapping will then block even with triple buffering when the GPU does not discard but
-            // queues frames
-            // now here's the mean part: if we take that as "OMG, we're late - next frame ASAP",
-            // there'll immediately be 2 frames in the pipe, swapping will block, we think we're
-            // late ... ewww
-            // so instead we pad to the clock again and add 2ms safety to ensure the pipe is really
-            // free
-            // NOTICE: obviously m_timeSinceLastVBlank can be too big because we're too slow as well
-            // So if this code was enabled, we'd needlessly half the framerate once more (15 instead of 30)
-            waitTime = nanoToMilli(vBlankInterval - (m_timeSinceLastVBlank - fpsInterval)%vBlankInterval) + 2;
-        }*/ else {
-            waitTime = 1; // ... "0" would be sufficient, but the compositor isn't the WMs only task
+    // w/o blocking vsync we just jump to the next demanded tick
+    if (fpsInterval > m_timeSinceLastVBlank) {
+        waitTime = nanoToMilli(fpsInterval - m_timeSinceLastVBlank);
+        if (!waitTime) {
+            waitTime = 1; // will ensure we don't block out the eventloop - the system's just not faster ...
         }
+    } else {
+        waitTime = 1; // ... "0" would be sufficient, but the compositor isn't the WMs only task
     }
     compositeTimer.start(qMin(waitTime, 250u), this); // force 4fps minimum
 }
@@ -738,9 +582,9 @@ void Compositor::delayedCheckUnredirect()
     ToplevelList list;
     bool changed = forceUnredirectCheck;
     foreach (Client * c, Workspace::self()->clientList())
-    list.append(c);
+        list.append(c);
     foreach (Unmanaged * c, Workspace::self()->unmanagedList())
-    list.append(c);
+        list.append(c);
     foreach (Toplevel * c, list) {
         if (c->updateUnredirectedState())
             changed = true;
@@ -802,14 +646,6 @@ void Compositor::setOverlayWindowVisibility(bool visible)
     }
 }
 
-void Compositor::restartKWin(const QString &reason)
-{
-    kDebug(1212) << "restarting kwin for:" << reason;
-    char cmd[1024]; // copied from crashhandler - maybe not the best way to do?
-    sprintf(cmd, "%s --replace &", QFile::encodeName(QCoreApplication::applicationFilePath()).constData());
-    system(cmd);
-}
-
 bool Compositor::isCompositingPossible() const
 {
     return CompositingPrefs::compositingPossible();
@@ -820,11 +656,6 @@ QString Compositor::compositingNotPossibleReason() const
     return CompositingPrefs::compositingNotPossibleReason();
 }
 
-bool Compositor::isOpenGLBroken() const
-{
-    return CompositingPrefs::openGlIsBroken();
-}
-
 QString Compositor::compositingType() const
 {
     if (!hasScene()) {
@@ -833,14 +664,6 @@ QString Compositor::compositingType() const
     switch (m_scene->compositingType()) {
     case XRenderCompositing:
         return "xrender";
-    case OpenGL1Compositing:
-            return "gl1";
-    case OpenGL2Compositing:
-#ifdef KWIN_HAVE_OPENGLES
-        return "gles";
-#else
-        return "gl2";
-#endif
     case NoCompositing:
     default:
         return "none";
@@ -882,7 +705,7 @@ bool Toplevel::setupCompositing()
     // and us setting up damage tracking.  If the client wins we won't get a damage event even
     // though the window has been painted.  To avoid this we mark the whole window as damaged
     // and schedule a repaint immediately after creating the damage object.
-    if (dynamic_cast<Unmanaged*>(this))
+    if (qobject_cast<Unmanaged*>(this))
         addDamageFull();
 
     return true;
@@ -1186,14 +1009,7 @@ bool Client::shouldUnredirect() const
 
 bool Unmanaged::shouldUnredirect() const
 {
-    // the pixmap is needed for the login effect, a nicer solution would be the login effect increasing
-    // refcount for the window pixmap (which would prevent unredirect), avoiding this hack
-    if (resourceClass() == "ksplashx"
-            || resourceClass() == "ksplashsimple"
-            || resourceClass() == "ksplashqml"
-            )
-        return false;
-// it must cover whole display or one xinerama screen, and be the topmost there
+    // it must cover whole display or one xinerama screen, and be the topmost there
     const int desktop = VirtualDesktopManager::self()->current();
     if (geometry() == workspace()->clientArea(FullArea, geometry().center(), desktop)
             || geometry() == workspace()->clientArea(ScreenArea, geometry().center(), desktop)) {
