@@ -30,9 +30,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kwinadaptor.h"
 #include "workspace.h"
 #include "virtualdesktops.h"
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
 
 // Qt
 #include <QDBusServiceWatcher>
@@ -48,8 +45,7 @@ DBusInterface::DBusInterface(QObject *parent)
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.registerObject("/KWin", this);
     if (!dbus.registerService("org.kde.KWin")) {
-        QDBusServiceWatcher *dog = new QDBusServiceWatcher("org.kde.KWin", dbus, QDBusServiceWatcher::WatchForUnregistration, this);
-        connect (dog, SIGNAL(serviceUnregistered(QString)), SLOT(becomeKWinService(QString)));
+        kDebug(1212) << "failed to register service org.kde.KWin. Perhaps something has already taken it?";
     }
     connect(Compositor::self(), SIGNAL(compositingToggled(bool)), SIGNAL(compositingToggled(bool)));
     dbus.connect(QString(), "/KWin", "org.kde.KWin", "reloadConfig",
@@ -58,15 +54,6 @@ DBusInterface::DBusInterface(QObject *parent)
                  Compositor::self(), SLOT(slotReinitialize()));
 }
 
-void DBusInterface::becomeKWinService(const QString &service)
-{
-    // TODO: this watchdog exists to make really safe that we at some point get the service
-    // but it's probably no longer needed since we explicitly unregister the service with the deconstructor
-    if (service == "org.kde.KWin" && QDBusConnection::sessionBus().registerService("org.kde.KWin") && sender()) {
-        sender()->deleteLater(); // bye doggy :'(
-    }
-}
-
 DBusInterface::~DBusInterface()
 {
     QDBusConnection::sessionBus().unregisterService("org.kde.KWin"); // this is the long standing legal service
@@ -129,24 +116,6 @@ WRAP(bool, waitForCompositingSetup)
 
 #undef WRAP
 
-bool DBusInterface::startActivity(const QString &in0)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    return Activities::self()->start(in0);
-#else
-    return false;
-#endif
-}
-
-bool DBusInterface::stopActivity(const QString &in0)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    return Activities::self()->stop(in0);
-#else
-    return false;
-#endif
-}
-
 void DBusInterface::doNotManage(const QString &name)
 {
     Q_UNUSED(name)
@@ -177,11 +146,6 @@ bool DBusInterface::compositingPossible()
     return Compositor::self()->isCompositingPossible();
 }
 
-bool DBusInterface::openGLIsBroken()
-{
-    return Compositor::self()->isOpenGLBroken();
-}
-
 bool DBusInterface::compositingActive()
 {
     return Compositor::self()->isActive();
@@ -252,9 +216,4 @@ void DBusInterface::previousDesktop()
     VirtualDesktopManager::self()->moveTo<DesktopPrevious>();
 }
 
-QList< int > DBusInterface::decorationSupportedColors()
-{
-    return decorationPlugin()->supportedColors();
-}
-
 } // namespace
