@@ -23,12 +23,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QObject>
 #include <QtDBus/QtDBus>
-class QByteArray;
-template<class T> class QList;
-template<class Key, class Value> class QMap;
-class QString;
-class QStringList;
-class QVariant;
+#include <QByteArray>
+#include <QList>
+#include <QMap>
+#include <QString>
+#include <QStringList>
+#include <QVariant>
 
 namespace KWin
 {
@@ -58,30 +58,27 @@ public:
 
 public: // PROPERTIES
 public Q_SLOTS: // METHODS
-    Q_NOREPLY void cascadeDesktop();
+    void cascadeDesktop();
     /**
      * @deprecated
      **/
     void circulateDesktopApplications();
     int currentDesktop();
-    QList<int> decorationSupportedColors();
     /**
      * @deprecated
      **/
     void doNotManage(const QString &name);
-    Q_NOREPLY void killWindow();
+    void killWindow();
     void nextDesktop();
     void previousDesktop();
-    Q_NOREPLY void reconfigure();
+    void reconfigure();
     bool setCurrentDesktop(int desktop);
     /**
      * @deprecated
      **/
     void showWindowMenuAt(qlonglong winId, int x, int y);
-    bool startActivity(const QString &in0);
-    bool stopActivity(const QString &in0);
     QString supportInformation();
-    Q_NOREPLY void unclutterDesktop();
+    void unclutterDesktop();
     // from compositor
     /**
      * @deprecated
@@ -102,11 +99,7 @@ public Q_SLOTS: // METHODS
     /**
      * @deprecated
      **/
-    bool openGLIsBroken();
-    /**
-     * @deprecated
-     **/
-    Q_NOREPLY void toggleCompositing();
+    void toggleCompositing();
     /**
      * @deprecated
      **/
@@ -150,8 +143,6 @@ Q_SIGNALS: // SIGNALS
      * @deprecated
      **/
     void compositingToggled(bool active);
-private Q_SLOTS:
-    void becomeKWinService(const QString &service);
 };
 
 } // namespace
