@@ -71,16 +71,15 @@ void Deleted::discard()
 
 void Deleted::copyToDeleted(Toplevel* c)
 {
-    assert(dynamic_cast< Deleted* >(c) == NULL);
+    assert(qobject_cast< Deleted* >(c) == NULL);
     Toplevel::copyToDeleted(c);
     desk = c->desktop();
-    activityList = c->activities();
     contentsRect = QRect(c->clientPos(), c->clientSize());
     transparent_rect = c->transparentRect();
     m_layer = c->layer();
     if (WinInfo* cinfo = dynamic_cast< WinInfo* >(info))
         cinfo->disable();
-    Client* client = dynamic_cast<Client*>(c);
+    Client* client = qobject_cast<Client*>(c);
     if (client) {
         m_wasClient = true;
         no_border = client->noBorder();
@@ -103,7 +102,7 @@ void Deleted::copyToDeleted(Toplevel* c)
         m_minimized = client->isMinimized();
         m_modal = client->isModal();
         m_mainClients = client->mainClients();
-        foreach (Client *c, m_mainClients) {
+        foreach (const Client *c, m_mainClients) {
             connect(c, SIGNAL(windowClosed(KWin::Toplevel*,KWin::Deleted*)), SLOT(mainClientClosed(KWin::Toplevel*)));
         }
     }
@@ -125,11 +124,6 @@ int Deleted::desktop() const
     return desk;
 }
 
-QStringList Deleted::activities() const
-{
-    return activityList;
-}
-
 QPoint Deleted::clientPos() const
 {
     return contentsRect.topLeft();
@@ -185,4 +179,4 @@ void Deleted::mainClientClosed(Toplevel *client)
 
 } // namespace
 
-#include "deleted.moc"
+#include "moc_deleted.cpp"
