@@ -19,19 +19,17 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
+#include "config-kwin.h"
+
 #include "effects.h"
 
 #include "effectsadaptor.h"
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
 #include "decorations.h"
 #include "deleted.h"
 #include "client.h"
 #include "cursor.h"
 #include "group.h"
 #include "scene_xrender.h"
-#include "scene_opengl.h"
 #include "unmanaged.h"
 #ifdef KWIN_BUILD_TABBOX
 #include "tabbox.h"
@@ -39,31 +37,24 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifdef KWIN_BUILD_SCREENEDGES
 #include "screenedge.h"
 #endif
-#ifdef KWIN_BUILD_SCRIPTING
-#include "scripting/scriptedeffect.h"
-#endif
 #include "screens.h"
 #include "thumbnailitem.h"
 #include "virtualdesktops.h"
 #include "workspace.h"
-#include "kwinglutils.h"
 
 #include <QFile>
-#include <QFutureWatcher>
-#include <QtConcurrentRun>
 #include <QDBusServiceWatcher>
-#include <QDBusPendingCallWatcher>
+#include <QtDBus/qdbuspendingcall.h>
+#include <QLibrary>
 
-#include <KDE/KDebug>
-#include <KDE/KLibrary>
-#include <KDE/KDesktopFile>
-#include <KDE/KConfigGroup>
-#include <KDE/KGlobal>
-#include <KDE/KStandardDirs>
-#include <KDE/KService>
-#include <KDE/KServiceTypeTrader>
-#include <KDE/KPluginInfo>
-#include <Plasma/Theme>
+#include <KDebug>
+#include <KDesktopFile>
+#include <KConfigGroup>
+#include <KGlobal>
+#include <KStandardDirs>
+#include <KService>
+#include <KServiceTypeTrader>
+#include <KPluginInfo>
 
 #include <assert.h>
 #include "composite.h"
@@ -72,6 +63,27 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // dbus generated
 #include "screenlocker_interface.h"
 
+#include "effects/diminactive/diminactive.h"
+#include "effects/dimscreen/dimscreen.h"
+#include "effects/highlightwindow/highlightwindow.h"
+#include "effects/logout/logout.h"
+#include "effects/magnifier/magnifier.h"
+#include "effects/minimizeanimation/minimizeanimation.h"
+#include "effects/mousemark/mousemark.h"
+#include "effects/presentwindows/presentwindows.h"
+#include "effects/resize/resize.h"
+#include "effects/showfps/showfps.h"
+#include "effects/showpaint/showpaint.h"
+#include "effects/slide/slide.h"
+#include "effects/slideback/slideback.h"
+#include "effects/slidingpopups/slidingpopups.h"
+#include "effects/snaphelper/snaphelper.h"
+#include "effects/taskbarthumbnail/taskbarthumbnail.h"
+#include "effects/thumbnailaside/thumbnailaside.h"
+#include "effects/trackmouse/trackmouse.h"
+#include "effects/windowgeometry/windowgeometry.h"
+#include "effects/zoom/zoom.h"
+#include "effects/startupfeedback/startupfeedback.h"
 
 namespace KWin
 {
@@ -88,12 +100,14 @@ ScreenLockerWatcher::ScreenLockerWatcher(QObject *parent)
     m_serviceWatcher->setWatchMode(QDBusServiceWatcher::WatchForOwnerChange);
     m_serviceWatcher->addWatchedService(SCREEN_LOCKER_SERVICE_NAME);
     // check whether service is registered
-    QFutureWatcher<QDBusReply<bool> > *watcher = new QFutureWatcher<QDBusReply<bool> >(this);
-    connect(watcher, SIGNAL(finished()), SLOT(serviceRegisteredQueried()));
-    connect(watcher, SIGNAL(canceled()), watcher, SLOT(deleteLater()));
-    watcher->setFuture(QtConcurrent::run(QDBusConnection::sessionBus().interface(),
-                                         &QDBusConnectionInterface::isServiceRegistered,
-                                         SCREEN_LOCKER_SERVICE_NAME));
+    QDBusConnectionInterface* dbusConnection = QDBusConnection::sessionBus().interface();
+    QDBusReply<bool> reply = dbusConnection->isServiceRegistered(SCREEN_LOCKER_SERVICE_NAME);
+    if (reply.isValid() && reply.value()) {
+        QDBusReply<QString> reply2 = dbusConnection->serviceOwner(SCREEN_LOCKER_SERVICE_NAME);
+        if (reply2.isValid()) {
+            serviceOwnerChanged(SCREEN_LOCKER_SERVICE_NAME, QString(), reply2.value());
+        }
+    }
 }
 
 ScreenLockerWatcher::~ScreenLockerWatcher()
@@ -117,38 +131,6 @@ void ScreenLockerWatcher::serviceOwnerChanged(const QString &serviceName, const
     }
 }
 
-void ScreenLockerWatcher::serviceRegisteredQueried()
-{
-    QFutureWatcher<QDBusReply<bool> > *watcher = dynamic_cast<QFutureWatcher<QDBusReply<bool> > *>(sender());
-    if (!watcher) {
-        return;
-    }
-    const QDBusReply<bool> &reply = watcher->result();
-    if (reply.isValid() && reply.value()) {
-        QFutureWatcher<QDBusReply<QString> > *ownerWatcher = new QFutureWatcher<QDBusReply<QString> >(this);
-        connect(ownerWatcher, SIGNAL(finished()), SLOT(serviceOwnerQueried()));
-        connect(ownerWatcher, SIGNAL(canceled()), ownerWatcher, SLOT(deleteLater()));
-        ownerWatcher->setFuture(QtConcurrent::run(QDBusConnection::sessionBus().interface(),
-                                                  &QDBusConnectionInterface::serviceOwner,
-                                                  SCREEN_LOCKER_SERVICE_NAME));
-    }
-    watcher->deleteLater();
-}
-
-void ScreenLockerWatcher::serviceOwnerQueried()
-{
-    QFutureWatcher<QDBusReply<QString> > *watcher = dynamic_cast<QFutureWatcher<QDBusReply<QString> > *>(sender());
-    if (!watcher) {
-        return;
-    }
-    const QDBusReply<QString> reply = watcher->result();
-    if (reply.isValid()) {
-        serviceOwnerChanged(SCREEN_LOCKER_SERVICE_NAME, QString(), reply.value());
-    }
-
-    watcher->deleteLater();
-}
-
 void ScreenLockerWatcher::activeQueried(QDBusPendingCallWatcher *watcher)
 {
     QDBusPendingReply<bool> reply = *watcher;
@@ -237,12 +219,6 @@ EffectsHandlerImpl::EffectsHandlerImpl(Compositor *compositor, Scene *scene)
     connect(Cursor::self(), SIGNAL(mouseChanged(QPoint,QPoint,Qt::MouseButtons,Qt::MouseButtons,Qt::KeyboardModifiers,Qt::KeyboardModifiers)),
             SIGNAL(mouseChanged(QPoint,QPoint,Qt::MouseButtons,Qt::MouseButtons,Qt::KeyboardModifiers,Qt::KeyboardModifiers)));
     connect(ws, SIGNAL(propertyNotify(long)), this, SLOT(slotPropertyNotify(long)));
-#ifdef KWIN_BUILD_ACTIVITIES
-    Activities *activities = Activities::self();
-    connect(activities, SIGNAL(added(QString)), SIGNAL(activityAdded(QString)));
-    connect(activities, SIGNAL(removed(QString)), SIGNAL(activityRemoved(QString)));
-    connect(activities, SIGNAL(currentChanged(QString)), SIGNAL(currentActivityChanged(QString)));
-#endif
     connect(ws, SIGNAL(stackingOrderChanged()), SIGNAL(stackingOrderChanged()));
 #ifdef KWIN_BUILD_TABBOX
     TabBox::TabBox *tabBox = TabBox::TabBox::self();
@@ -256,10 +232,10 @@ EffectsHandlerImpl::EffectsHandlerImpl(Compositor *compositor, Scene *scene)
 #endif
     connect(m_screenLockerWatcher, SIGNAL(locked(bool)), SIGNAL(screenLockingChanged(bool)));
     // connect all clients
-    foreach (Client *c, ws->clientList()) {
+    foreach (const Client *c, ws->clientList()) {
         setupClientConnections(c);
     }
-    foreach (Unmanaged *u, ws->unmanagedList()) {
+    foreach (const Unmanaged *u, ws->unmanagedList()) {
         setupUnmanagedConnections(u);
     }
     reconfigure();
@@ -267,13 +243,15 @@ EffectsHandlerImpl::EffectsHandlerImpl(Compositor *compositor, Scene *scene)
 
 EffectsHandlerImpl::~EffectsHandlerImpl()
 {
-    if (keyboard_grab_effect != NULL)
+    if (keyboard_grab_effect != NULL) {
         ungrabKeyboard();
-    foreach (const EffectPair & ep, loaded_effects)
-    unloadEffect(ep.first);
+    }
+    foreach (const EffectPair & ep, loaded_effects) {
+        unloadEffect(ep.first);
+    }
 }
 
-void EffectsHandlerImpl::setupClientConnections(Client* c)
+void EffectsHandlerImpl::setupClientConnections(const Client* c)
 {
     connect(c, SIGNAL(windowClosed(KWin::Toplevel*,KWin::Deleted*)), this, SLOT(slotWindowClosed(KWin::Toplevel*)));
     connect(c, SIGNAL(clientMaximizedStateChanged(KWin::Client*,KDecorationDefines::MaximizeMode)), this, SLOT(slotClientMaximized(KWin::Client*,KDecorationDefines::MaximizeMode)));
@@ -290,7 +268,7 @@ void EffectsHandlerImpl::setupClientConnections(Client* c)
     connect(c, SIGNAL(propertyNotify(KWin::Toplevel*,long)), this, SLOT(slotPropertyNotify(KWin::Toplevel*,long)));
 }
 
-void EffectsHandlerImpl::setupUnmanagedConnections(Unmanaged* u)
+void EffectsHandlerImpl::setupUnmanagedConnections(const Unmanaged* u)
 {
     connect(u, SIGNAL(windowClosed(KWin::Toplevel*,KWin::Deleted*)), this, SLOT(slotWindowClosed(KWin::Toplevel*)));
     connect(u, SIGNAL(opacityChanged(KWin::Toplevel*,qreal)), this, SLOT(slotOpacityChanged(KWin::Toplevel*,qreal)));
@@ -302,22 +280,7 @@ void EffectsHandlerImpl::setupUnmanagedConnections(Unmanaged* u)
 
 void EffectsHandlerImpl::reconfigure()
 {
-    // perform querying for the services in a thread
-    QFutureWatcher<KService::List> *watcher = new QFutureWatcher<KService::List>(this);
-    connect(watcher, SIGNAL(finished()), this, SLOT(slotEffectsQueried()));
-    watcher->setFuture(QtConcurrent::run(KServiceTypeTrader::self(), &KServiceTypeTrader::query, QString("KWin/Effect"), QString()));
-    watcher->waitForFinished(); // TODO: remove once KConfigGroup is thread safe, bug #321576
-}
-
-void EffectsHandlerImpl::slotEffectsQueried()
-{
-    QFutureWatcher<KService::List> *watcher = dynamic_cast< QFutureWatcher<KService::List>* >(sender());
-    if (!watcher) {
-        // slot invoked not from a FutureWatcher
-        return;
-    }
-
-    KService::List offers = watcher->result();
+    const KService::List offers = KServiceTypeTrader::self()->query(QString("KWin/Effect"), QString());
     QStringList effectsToBeLoaded;
     QStringList checkDefault;
     KSharedConfig::Ptr _config = KGlobal::config();
@@ -353,7 +316,6 @@ void EffectsHandlerImpl::slotEffectsQueried()
         if (!newLoaded.contains(ep.first))    // don't reconfigure newly loaded effects
             ep.second->reconfigure(Effect::ReconfigureAll);
     }
-    watcher->deleteLater();
 }
 
 // the idea is that effects call this function again which calls the next one
@@ -475,24 +437,14 @@ bool EffectsHandlerImpl::hasDecorationShadows() const
     return decorationPlugin()->hasShadows();
 }
 
-bool EffectsHandlerImpl::decorationsHaveAlpha() const
-{
-    return decorationPlugin()->hasAlpha();
-}
-
-bool EffectsHandlerImpl::decorationSupportsBlurBehind() const
-{
-    return decorationPlugin()->supportsBlurBehind();
-}
-
 // start another painting pass
 void EffectsHandlerImpl::startPaint()
 {
     m_activeEffects.clear();
     m_activeEffects.reserve(loaded_effects.count());
-    for(QVector< KWin::EffectPair >::const_iterator it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
-        if (it->second->isActive()) {
-            m_activeEffects << it->second;
+    foreach (const KWin::EffectPair it, loaded_effects) {
+        if (it.second->isActive()) {
+            m_activeEffects << it.second;
         }
     }
     m_currentDrawWindowIterator = m_activeEffects.constBegin();
@@ -565,8 +517,8 @@ void EffectsHandlerImpl::slotUnmanagedAdded(Unmanaged *u)
 
 void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
 {
-    Q_ASSERT(dynamic_cast<Client*>(t));
-    Client *c = static_cast<Client*>(t);
+    Q_ASSERT(qobject_cast<Client*>(t));
+    Client *c = qobject_cast<Client*>(t);
     setupClientConnections(c);
     if (!c->tabGroup()) // the "window" has already been there
         emit windowAdded(c->effectWindow());
@@ -574,8 +526,8 @@ void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
 
 void EffectsHandlerImpl::slotUnmanagedShown(KWin::Toplevel *t)
 {   // regardless, unmanaged windows are -yet?- not synced anyway
-    Q_ASSERT(dynamic_cast<Unmanaged*>(t));
-    Unmanaged *u = static_cast<Unmanaged*>(t);
+    Q_ASSERT(qobject_cast<Unmanaged*>(t));
+    Unmanaged *u = qobject_cast<Unmanaged*>(t);
     setupUnmanagedConnections(u);
     emit windowAdded(u->effectWindow());
 }
@@ -762,9 +714,11 @@ void* EffectsHandlerImpl::getProxy(QString name)
     // All effects start with "kwin4_effect_", prepend it to the name
     name.prepend("kwin4_effect_");
 
-    for (QVector< EffectPair >::const_iterator it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it)
-        if ((*it).first == name)
-            return (*it).second->proxy();
+    foreach (const EffectPair it, loaded_effects) {
+        if (it.first == name) {
+            return it.second->proxy();
+        }
+    }
 
     return NULL;
 }
@@ -880,7 +834,7 @@ void EffectsHandlerImpl::deleteRootProperty(long atom) const
 
 void EffectsHandlerImpl::activateWindow(EffectWindow* c)
 {
-    if (Client* cl = dynamic_cast< Client* >(static_cast<EffectWindowImpl*>(c)->window()))
+    if (Client* cl = qobject_cast< Client* >(static_cast<EffectWindowImpl*>(c)->window()))
         Workspace::self()->activateClient(cl, true);
 }
 
@@ -891,7 +845,7 @@ EffectWindow* EffectsHandlerImpl::activeWindow() const
 
 void EffectsHandlerImpl::moveWindow(EffectWindow* w, const QPoint& pos, bool snap, double snapAdjust)
 {
-    Client* cl = dynamic_cast< Client* >(static_cast<EffectWindowImpl*>(w)->window());
+    Client* cl = qobject_cast< Client* >(static_cast<EffectWindowImpl*>(w)->window());
     if (!cl || !cl->isMovable())
         return;
 
@@ -903,14 +857,14 @@ void EffectsHandlerImpl::moveWindow(EffectWindow* w, const QPoint& pos, bool sna
 
 void EffectsHandlerImpl::windowToDesktop(EffectWindow* w, int desktop)
 {
-    Client* cl = dynamic_cast< Client* >(static_cast<EffectWindowImpl*>(w)->window());
+    Client* cl = qobject_cast< Client* >(static_cast<EffectWindowImpl*>(w)->window());
     if (cl && !cl->isDesktop() && !cl->isDock())
         Workspace::self()->sendClientToDesktop(cl, desktop, true);
 }
 
 void EffectsHandlerImpl::windowToScreen(EffectWindow* w, int screen)
 {
-    Client* cl = dynamic_cast< Client* >(static_cast<EffectWindowImpl*>(w)->window());
+    Client* cl = qobject_cast< Client* >(static_cast<EffectWindowImpl*>(w)->window());
     if (cl && !cl->isDesktop() && !cl->isDock())
         Workspace::self()->sendClientToScreen(cl, screen);
 }
@@ -920,15 +874,6 @@ void EffectsHandlerImpl::setShowingDesktop(bool showing)
     Workspace::self()->setShowingDesktop(showing);
 }
 
-QString EffectsHandlerImpl::currentActivity() const
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    return Activities::self()->current();
-#else
-    return QString();
-#endif
-}
-
 int EffectsHandlerImpl::currentDesktop() const
 {
     return VirtualDesktopManager::self()->current();
@@ -1055,9 +1000,9 @@ EffectWindowList EffectsHandlerImpl::stackingOrder() const
 {
     ToplevelList list = Workspace::self()->xStackingOrder();
     EffectWindowList ret;
-    foreach (Toplevel *t, list) {
-        if (EffectWindow *w = effectWindow(t))
-            ret.append(w);
+    foreach (Toplevel *it, list) {
+        if (EffectWindow *ew = effectWindow(it))
+            ret.append(ew);
     }
     return ret;
 }
@@ -1072,7 +1017,7 @@ void EffectsHandlerImpl::setElevatedWindow(EffectWindow* w, bool set)
 void EffectsHandlerImpl::setTabBoxWindow(EffectWindow* w)
 {
 #ifdef KWIN_BUILD_TABBOX
-    if (Client* c = dynamic_cast< Client* >(static_cast< EffectWindowImpl* >(w)->window())) {
+    if (Client* c = qobject_cast< Client* >(static_cast< EffectWindowImpl* >(w)->window())) {
         TabBox::TabBox::self()->setCurrentClient(c);
     }
 #else
@@ -1095,8 +1040,9 @@ EffectWindowList EffectsHandlerImpl::currentTabBoxWindowList() const
     EffectWindowList ret;
     ClientList clients;
     clients = TabBox::TabBox::self()->currentClientList();
-    foreach (Client * c, clients)
-    ret.append(c->effectWindow());
+    foreach (Client *client, clients) {
+        ret.append(client->effectWindow());
+    }
     return ret;
 #else
     return EffectWindowList();
@@ -1192,7 +1138,7 @@ QRect EffectsHandlerImpl::clientArea(clientAreaOption opt, int screen, int deskt
 QRect EffectsHandlerImpl::clientArea(clientAreaOption opt, const EffectWindow* c) const
 {
     const Toplevel* t = static_cast< const EffectWindowImpl* >(c)->window();
-    if (const Client* cl = dynamic_cast< const Client* >(t))
+    if (const Client* cl = qobject_cast< const Client* >(t))
         return Workspace::self()->clientArea(opt, cl);
     else
         return Workspace::self()->clientArea(opt, t->geometry().center(), VirtualDesktopManager::self()->current());
@@ -1292,26 +1238,19 @@ void EffectsHandlerImpl::unreserveElectricBorder(ElectricBorder border, Effect *
 
 unsigned long EffectsHandlerImpl::xrenderBufferPicture()
 {
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
-    if (SceneXrender* s = dynamic_cast< SceneXrender* >(m_scene))
+#ifdef KWIN_BUILD_COMPOSITE
+    if (SceneXrender* s = qobject_cast< SceneXrender* >(m_scene))
         return s->bufferPicture();
 #endif
     return None;
 }
 
-KLibrary* EffectsHandlerImpl::findEffectLibrary(KService* service)
+QLibrary* EffectsHandlerImpl::findEffectLibrary(KService* service)
 {
-    QString libname = service->library();
-#ifdef KWIN_HAVE_OPENGLES
-    if (libname.startsWith(QLatin1String("kwin4_effect_"))) {
-        libname.replace("kwin4_effect_", "kwin4_effect_gles_");
-    }
-#endif
-    libname.replace("kwin", KWIN_NAME);
-    KLibrary* library = new KLibrary(libname);
+    QLibrary* library = new QLibrary(service->library());
     if (!library) {
         kError(1212) << "couldn't open library for effect '" <<
-                     service->name() << "'" << endl;
+                     service->name() << "'";
         return 0;
     }
 
@@ -1329,15 +1268,15 @@ void EffectsHandlerImpl::toggleEffect(const QString& name)
 QStringList EffectsHandlerImpl::loadedEffects() const
 {
     QStringList listModules;
-    for (QVector< EffectPair >::const_iterator it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
-        listModules << (*it).first;
+    foreach (const EffectPair it, loaded_effects) {
+        listModules << it.first;
     }
     return listModules;
 }
 
 QStringList EffectsHandlerImpl::listOfEffects() const
 {
-    KService::List offers = KServiceTypeTrader::self()->query("KWin/Effect");
+    const KService::List offers = KServiceTypeTrader::self()->query("KWin/Effect");
     QStringList listOfModules;
     // First unload necessary effects
     foreach (const KService::Ptr & service, offers) {
@@ -1355,8 +1294,8 @@ bool EffectsHandlerImpl::loadEffect(const QString& name, bool checkDefault)
         kWarning(1212) << "Effect names usually have kwin4_effect_ prefix" ;
 
     // Make sure a single effect won't be loaded multiple times
-    for (QVector< EffectPair >::const_iterator it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
-        if ((*it).first == name) {
+    foreach (const EffectPair it, loaded_effects) {
+        if (it.first == name) {
             kDebug(1212) << "EffectsHandler::loadEffect : Effect already loaded : " << name;
             return true;
         }
@@ -1369,126 +1308,155 @@ bool EffectsHandlerImpl::loadEffect(const QString& name, bool checkDefault)
     QString constraint = QString("[X-KDE-PluginInfo-Name] == '%1'").arg(internalname);
     KService::List offers = KServiceTypeTrader::self()->query("KWin/Effect", constraint);
     if (offers.isEmpty()) {
-        kError(1212) << "Couldn't find effect " << name << endl;
+        kError(1212) << "Couldn't find effect " << name;
         return false;
     }
     KService::Ptr service = offers.first();
 
-    if (service->property("X-Plasma-API").toString() == "javascript") {
-        // this is a scripted effect - use different loader
-        return loadScriptedEffect(name, service.data());
+    Effect* effect = 0;
+    QLibrary* library = 0;
+    // builtins first
+    if (internalname == "kwin4_effect_presentwindows") {
+        effect = new PresentWindowsEffect();
+    } else if (internalname == "kwin4_effect_slidingpopups") {
+        effect = new SlidingPopupsEffect();
+    } else if (internalname == "kwin4_effect_taskbarthumbnail") {
+        effect = new TaskbarThumbnailEffect();
+    } else if (internalname == "kwin4_effect_diminactive") {
+        effect = new DimInactiveEffect();
+    } else if (internalname == "kwin4_effect_dimscreen") {
+        effect = new DimScreenEffect();
+    } else if (internalname == "kwin4_effect_highlightwindow") {
+        effect = new HighlightWindowEffect();
+    } else if (internalname == "kwin4_effect_minimizeanimation") {
+        effect = new MinimizeAnimationEffect();
+    } else if (internalname == "kwin4_effect_resize") {
+        effect = new ResizeEffect();
+    } else if (internalname == "kwin4_effect_showfps") {
+        effect = new ShowFpsEffect();
+    } else if (internalname == "kwin4_effect_showpaint") {
+        effect = new ShowPaintEffect();
+    } else if (internalname == "kwin4_effect_slide") {
+        effect = new SlideEffect();
+    } else if (internalname == "kwin4_effect_slideback") {
+        effect = new SlideBackEffect();
+    } else if (internalname == "kwin4_effect_thumbnailaside") {
+        effect = new ThumbnailAsideEffect();
+    } else if (internalname == "kwin4_effect_windowgeometry") {
+        effect = new WindowGeometryEffect();
+    } else if (internalname == "kwin4_effect_zoom") {
+        effect = new ZoomEffect();
+    } else if (internalname == "kwin4_effect_logout") {
+        effect = new LogoutEffect();
+    } else if (internalname == "kwin4_effect_magnifier") {
+        effect = new MagnifierEffect();
+    } else if (internalname == "kwin4_effect_mousemark") {
+        effect = new MouseMarkEffect();
+    } else if (internalname == "kwin4_effect_snaphelper") {
+        effect = new SnapHelperEffect();
+    } else if (internalname == "kwin4_effect_trackmouse") {
+        effect = new TrackMouseEffect();
+    } else if (internalname == "kwin4_effect_startupfeedback") {
+        effect = new StartupFeedbackEffect();
     }
 
-    KLibrary* library = findEffectLibrary(service.data());
-    if (!library) {
-        return false;
-    }
+    if (effect) {
+        kDebug(1212) << "Effect is internal" << name;
+        bool enabledByDefault = service->property("X-KDE-PluginInfo-EnabledByDefault").toBool();
+        if (checkDefault && !enabledByDefault) {
+            delete effect;
+            return false;
+        }
+    // external second
+    } else {
+        kDebug(1212) << "Effect is external" << name;
+        library = findEffectLibrary(service.data());
+        if (!library) {
+            return false;
+        }
 
-    QString version_symbol = "effect_version_" + name;
-    KLibrary::void_function_ptr version_func = library->resolveFunction(version_symbol.toAscii());
-    if (version_func == NULL) {
-        kWarning(1212) << "Effect " << name << " does not provide required API version, ignoring.";
-	delete library;
-        return false;
-    }
-    typedef int (*t_versionfunc)();
-    int version = reinterpret_cast< t_versionfunc >(version_func)();   // call it
-    // Version must be the same or less, but major must be the same.
-    // With major 0 minor must match exactly.
-    if (version > KWIN_EFFECT_API_VERSION
-            || (version >> 8) != KWIN_EFFECT_API_VERSION_MAJOR
-            || (KWIN_EFFECT_API_VERSION_MAJOR == 0 && version != KWIN_EFFECT_API_VERSION)) {
-        kWarning(1212) << "Effect " << name << " requires unsupported API version " << version;
-        delete library;
-        return false;
-    }
+        QString version_symbol = "effect_version_" + name;
+        void *version_func = library->resolve(version_symbol.toAscii());
+        if (version_func == NULL) {
+            kWarning(1212) << "Effect " << name << " does not provide required API version, ignoring.";
+            delete library;
+            return false;
+        }
+        typedef int (*t_versionfunc)();
+        int version = reinterpret_cast< t_versionfunc >(version_func)();   // call it
+        // Version must be the same or less, but major must be the same.
+        // With major 0 minor must match exactly.
+        if (version > KWIN_EFFECT_API_VERSION
+                || (version >> 8) != KWIN_EFFECT_API_VERSION_MAJOR
+                || (KWIN_EFFECT_API_VERSION_MAJOR == 0 && version != KWIN_EFFECT_API_VERSION)) {
+            kWarning(1212) << "Effect " << name << " requires unsupported API version " << version;
+            delete library;
+            return false;
+        }
 
-    const QString enabledByDefault_symbol = "effect_enabledbydefault_" + name;
-    KLibrary::void_function_ptr enabledByDefault_func = library->resolveFunction(enabledByDefault_symbol.toAscii().data());
+        const QString enabledByDefault_symbol = "effect_enabledbydefault_" + name;
+        void *enabledByDefault_func = library->resolve(enabledByDefault_symbol.toAscii().data());
 
-    const QString supported_symbol = "effect_supported_" + name;
-    KLibrary::void_function_ptr supported_func = library->resolveFunction(supported_symbol.toAscii().data());
+        const QString supported_symbol = "effect_supported_" + name;
+        void *supported_func = library->resolve(supported_symbol.toAscii().data());
 
-    const QString create_symbol = "effect_create_" + name;
-    KLibrary::void_function_ptr create_func = library->resolveFunction(create_symbol.toAscii().data());
+        const QString create_symbol = "effect_create_" + name;
+        void *create_func = library->resolve(create_symbol.toAscii().data());
 
-    if (supported_func) {
-        typedef bool (*t_supportedfunc)();
-        t_supportedfunc supported = reinterpret_cast<t_supportedfunc>(supported_func);
-        if (!supported()) {
-            kWarning(1212) << "EffectsHandler::loadEffect : Effect " << name << " is not supported" ;
+        if (supported_func) {
+            typedef bool (*t_supportedfunc)();
+            t_supportedfunc supported = reinterpret_cast<t_supportedfunc>(supported_func);
+            if (!supported()) {
+                kWarning(1212) << "EffectsHandler::loadEffect : Effect " << name << " is not supported" ;
+                library->unload();
+                return false;
+            }
+        }
+
+        if (checkDefault && enabledByDefault_func) {
+            typedef bool (*t_enabledByDefaultfunc)();
+            t_enabledByDefaultfunc enabledByDefault = reinterpret_cast<t_enabledByDefaultfunc>(enabledByDefault_func);
+
+            if (!enabledByDefault()) {
+                library->unload();
+                return false;
+            }
+        }
+
+        if (!create_func) {
+            kError(1212) << "EffectsHandler::loadEffect : effect_create function not found";
             library->unload();
             return false;
         }
-    }
 
-    if (checkDefault && enabledByDefault_func) {
-        typedef bool (*t_enabledByDefaultfunc)();
-        t_enabledByDefaultfunc enabledByDefault = reinterpret_cast<t_enabledByDefaultfunc>(enabledByDefault_func);
+        typedef Effect*(*t_createfunc)();
+        t_createfunc create = reinterpret_cast<t_createfunc>(create_func);
 
-        if (!enabledByDefault()) {
-            library->unload();
-            return false;
+        // Make sure all depenedencies have been loaded
+        // TODO: detect circular deps
+        KPluginInfo plugininfo(service);
+        foreach (const QString & depName, plugininfo.dependencies()) {
+            if (!loadEffect(depName)) {
+                kError(1212) << "EffectsHandler::loadEffect : Couldn't load dependencies for effect " << name;
+                library->unload();
+                return false;
+            }
         }
+
+        effect = create();
     }
 
-    if (!create_func) {
-        kError(1212) << "EffectsHandler::loadEffect : effect_create function not found" << endl;
-        library->unload();
-        return false;
-    }
-
-    typedef Effect*(*t_createfunc)();
-    t_createfunc create = reinterpret_cast<t_createfunc>(create_func);
-
-    // Make sure all depenedencies have been loaded
-    // TODO: detect circular deps
-    KPluginInfo plugininfo(service);
-    QStringList dependencies = plugininfo.dependencies();
-    foreach (const QString & depName, dependencies) {
-        if (!loadEffect(depName)) {
-            kError(1212) << "EffectsHandler::loadEffect : Couldn't load dependencies for effect " << name << endl;
-            library->unload();
-            return false;
-        }
-    }
-
-    Effect* e = create();
-
-    effect_order.insert(service->property("X-KDE-Ordering").toInt(), EffectPair(name, e));
-    effectsChanged();
-    effect_libraries[ name ] = library;
-
-    return true;
-}
-
-bool EffectsHandlerImpl::loadScriptedEffect(const QString& name, KService *service)
-{
-#ifdef KWIN_BUILD_SCRIPTING
-    const KDesktopFile df("services", service->entryPath());
-    const QString scriptName = df.desktopGroup().readEntry<QString>("X-Plasma-MainScript", "");
-    if (scriptName.isEmpty()) {
-        kDebug(1212) << "X-Plasma-MainScript not set";
-        return false;
-    }
-    const QString scriptFile = KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + "/effects/" + name + "/contents/" + scriptName);
-    if (scriptFile.isNull()) {
-        kDebug(1212) << "Could not locate the effect script";
-        return false;
-    }
-    ScriptedEffect *effect = ScriptedEffect::create(name, scriptFile);
-    if (!effect) {
-        kDebug(1212) << "Could not initialize scripted effect: " << name;
-        return false;
-    }
     effect_order.insert(service->property("X-KDE-Ordering").toInt(), EffectPair(name, effect));
     effectsChanged();
+    if (effect) {
+        kDebug(1212) << "Internal effect has been loaded" << name;
+        effect_factories[ name ] = effect;
+    } else if (library) {
+        kDebug(1212) << "External effect has been loaded" << name;
+        effect_libraries[ name ] = library;
+    }
+
     return true;
-#else
-    Q_UNUSED(name)
-    Q_UNUSED(service)
-    return false;
-#endif
 }
 
 void EffectsHandlerImpl::unloadEffect(const QString& name)
@@ -1508,9 +1476,11 @@ void EffectsHandlerImpl::unloadEffect(const QString& name)
                 removeSupportProperty(property, it.value().second);
             }
             delete it.value().second;
-            effect_order.erase(it);
+            effect_order.remove(it.key());
             effectsChanged();
-            if (effect_libraries.contains(name)) {
+            if (effect_factories.contains(name)) {
+                delete effect_libraries[ name ];
+            } else if (effect_libraries.contains(name)) {
                 effect_libraries[ name ]->unload();
             }
             return;
@@ -1568,18 +1538,17 @@ void EffectsHandlerImpl::effectsChanged()
 QStringList EffectsHandlerImpl::activeEffects() const
 {
     QStringList ret;
-    for(QVector< KWin::EffectPair >::const_iterator it = loaded_effects.constBegin(),
-                                                    end = loaded_effects.constEnd(); it != end; ++it) {
-            if (it->second->isActive()) {
-                ret << it->first;
-            }
+    foreach(const KWin::EffectPair it, loaded_effects) {
+        if (it.second->isActive()) {
+            ret << it.first;
         }
+    }
     return ret;
 }
 
-EffectFrame* EffectsHandlerImpl::effectFrame(EffectFrameStyle style, bool staticSize, const QPoint& position, Qt::Alignment alignment) const
+EffectFrame* EffectsHandlerImpl::effectFrame(bool staticSize, const QPoint& position, Qt::Alignment alignment) const
 {
-    return new EffectFrameImpl(style, staticSize, position, alignment);
+    return new EffectFrameImpl(staticSize, position, alignment);
 }
 
 
@@ -1613,7 +1582,7 @@ QString EffectsHandlerImpl::supportInformation(const QString &name) const
                 if (QLatin1String(property.name()) == "objectName") {
                     continue;
                 }
-                support.append(QLatin1String(property.name()) % ": " % (*it).second->property(property.name()).toString() % '\n');
+                support.append(QLatin1String(property.name()) + ": " + (*it).second->property(property.name()).toString() + '\n');
             }
             return support;
         }
@@ -1651,11 +1620,6 @@ EffectWindowImpl::EffectWindowImpl(Toplevel *toplevel)
 
 EffectWindowImpl::~EffectWindowImpl()
 {
-    QVariant cachedTextureVariant = data(LanczosCacheRole);
-    if (cachedTextureVariant.isValid()) {
-        GLTexture *cachedTexture = static_cast< GLTexture*>(cachedTextureVariant.value<void*>());
-        delete cachedTexture;
-    }
 }
 
 bool EffectWindowImpl::isPaintingEnabled()
@@ -1675,21 +1639,21 @@ void EffectWindowImpl::disablePainting(int reason)
 
 const EffectWindowGroup* EffectWindowImpl::group() const
 {
-    if (Client* c = dynamic_cast< Client* >(toplevel))
+    if (Client* c = qobject_cast< Client* >(toplevel))
         return c->group()->effectGroup();
     return NULL; // TODO
 }
 
 void EffectWindowImpl::refWindow()
 {
-    if (Deleted* d = dynamic_cast< Deleted* >(toplevel))
+    if (Deleted* d = qobject_cast< Deleted* >(toplevel))
         return d->refWindow();
     abort(); // TODO
 }
 
 void EffectWindowImpl::unrefWindow()
 {
-    if (Deleted* d = dynamic_cast< Deleted* >(toplevel))
+    if (Deleted* d = qobject_cast< Deleted* >(toplevel))
         return d->unrefWindow();   // delays deletion in case
     abort(); // TODO
 }
@@ -1712,7 +1676,7 @@ QRegion EffectWindowImpl::shape() const
 
 QRect EffectWindowImpl::decorationInnerRect() const
 {
-    Client *client = dynamic_cast<Client*>(toplevel);
+    Client *client = qobject_cast<Client*>(toplevel);
     return client ? client->transparentRect() : contentsRect();
 }
 
@@ -1728,7 +1692,7 @@ void EffectWindowImpl::deleteProperty(long int atom) const
 
 EffectWindow* EffectWindowImpl::findModal()
 {
-    if (Client* c = dynamic_cast< Client* >(toplevel)) {
+    if (Client* c = qobject_cast< Client* >(toplevel)) {
         if (Client* c2 = c->findModal())
             return c2->effectWindow();
     }
@@ -1741,8 +1705,9 @@ EffectWindowList getMainWindows(Toplevel *toplevel)
     T *c = static_cast<T*>(toplevel);
     EffectWindowList ret;
     ClientList mainclients = c->mainClients();
-    foreach (Client * tmp, mainclients)
+    foreach (Client *tmp, mainclients) {
         ret.append(tmp->effectWindow());
+    }
     return ret;
 }
 
@@ -1857,8 +1822,9 @@ void EffectWindowImpl::unreferencePreviousWindowPixmap()
 EffectWindowList EffectWindowGroupImpl::members() const
 {
     EffectWindowList ret;
-    foreach (Toplevel * c, group->members())
-    ret.append(c->effectWindow());
+    foreach (Toplevel *client, group->members()) {
+        ret.append(client->effectWindow());
+    }
     return ret;
 }
 
@@ -1866,29 +1832,15 @@ EffectWindowList EffectWindowGroupImpl::members() const
 // EffectFrameImpl
 //****************************************
 
-EffectFrameImpl::EffectFrameImpl(EffectFrameStyle style, bool staticSize, QPoint position, Qt::Alignment alignment)
+EffectFrameImpl::EffectFrameImpl(bool staticSize, QPoint position, Qt::Alignment alignment)
     : QObject(0)
     , EffectFrame()
-    , m_style(style)
     , m_static(staticSize)
     , m_point(position)
     , m_alignment(alignment)
-    , m_shader(NULL)
 {
-    if (m_style == EffectFrameStyled) {
-        m_frame.setImagePath("widgets/background");
-        m_frame.setCacheAllRenderedFrames(true);
-        connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(plasmaThemeChanged()));
-    }
-    m_selection.setImagePath("widgets/viewitem");
-    m_selection.setElementPrefix("hover");
-    m_selection.setCacheAllRenderedFrames(true);
-    m_selection.setEnabledBorders(Plasma::FrameSvg::AllBorders);
-
-    if (effects->isOpenGLCompositing()) {
-        m_sceneFrame = new SceneOpenGL::EffectFrame(this, static_cast<SceneOpenGL*>(Compositor::self()->scene()));
-    } else if (effects->compositingType() == XRenderCompositing) {
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+    if (effects->compositingType() == XRenderCompositing) {
+#ifdef KWIN_BUILD_COMPOSITE
         m_sceneFrame = new SceneXrender::EffectFrame(this);
 #endif
     } else {
@@ -1946,12 +1898,6 @@ void EffectFrameImpl::setGeometry(const QRect& geometry, bool force)
         return;
     }
 
-    if (m_style == EffectFrameStyled) {
-        qreal left, top, right, bottom;
-        m_frame.getMargins(left, top, right, bottom);   // m_geometry is the inner geometry
-        m_frame.resizeFrame(m_geometry.adjusted(-left, -top, right, bottom).size());
-    }
-
     free();
 }
 
@@ -1987,23 +1933,17 @@ void EffectFrameImpl::setIconSize(const QSize& size)
     m_sceneFrame->freeIconFrame();
 }
 
-void EffectFrameImpl::plasmaThemeChanged()
-{
-    free();
-}
-
 void EffectFrameImpl::render(QRegion region, double opacity, double frameOpacity)
 {
     if (m_geometry.isEmpty()) {
         return; // Nothing to display
     }
-    m_shader = NULL;
     effects->paintEffectFrame(this, region, opacity, frameOpacity);
 }
 
 void EffectFrameImpl::finalRender(QRegion region, double opacity, double frameOpacity) const
 {
-    region = infiniteRegion(); // TODO: Old region doesn't seem to work with OpenGL
+    region = infiniteRegion();
 
     m_sceneFrame->render(region, opacity, frameOpacity);
 }
@@ -2069,19 +2009,6 @@ void EffectFrameImpl::setText(const QString& text)
     }
 }
 
-void EffectFrameImpl::setSelection(const QRect& selection)
-{
-    if (selection == m_selectionGeometry) {
-        return;
-    }
-    m_selectionGeometry = selection;
-    if (m_selectionGeometry.size() != m_selection.frameSize().toSize()) {
-        m_selection.resizeFrame(m_selectionGeometry.size());
-    }
-    // TODO; optimize to only recreate when resizing
-    m_sceneFrame->freeSelection();
-}
-
 void EffectFrameImpl::autoResize()
 {
     if (m_static)
@@ -2103,9 +2030,4 @@ void EffectFrameImpl::autoResize()
     setGeometry(geometry);
 }
 
-QColor EffectFrameImpl::styledTextColor()
-{
-    return Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
-}
-
 } // namespace
