@@ -29,10 +29,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QStack>
 #include <QHash>
-#include <Plasma/FrameSvg>
 
-class QDBusPendingCallWatcher;
-class QDBusServiceWatcher;
+#include <QDBusPendingCallWatcher>
+#include <QDBusServiceWatcher>
 class KService;
 class OrgFreedesktopScreenSaverInterface;
 
@@ -85,7 +84,6 @@ public:
     virtual void windowToScreen(EffectWindow* w, int screen);
     virtual void setShowingDesktop(bool showing);
 
-    virtual QString currentActivity() const;
     virtual int currentDesktop() const;
     virtual int numberOfDesktops() const;
     virtual void setCurrentDesktop(int desktop);
@@ -163,11 +161,7 @@ public:
 
     virtual bool hasDecorationShadows() const;
 
-    virtual bool decorationsHaveAlpha() const;
-
-    virtual bool decorationSupportsBlurBehind() const;
-
-    virtual EffectFrame* effectFrame(EffectFrameStyle style, bool staticSize, const QPoint& position, Qt::Alignment alignment) const;
+    virtual EffectFrame* effectFrame(bool staticSize, const QPoint& position, Qt::Alignment alignment) const;
 
     virtual QVariant kwinOption(KWinOption kwopt);
     virtual bool isScreenLocked() const;
@@ -237,11 +231,10 @@ protected Q_SLOTS:
     void slotPropertyNotify(long atom);
 
 protected:
-    bool loadScriptedEffect(const QString &name, KService *service);
-    KLibrary* findEffectLibrary(KService* service);
+    QLibrary* findEffectLibrary(KService* service);
     void effectsChanged();
-    void setupClientConnections(KWin::Client *c);
-    void setupUnmanagedConnections(KWin::Unmanaged *u);
+    void setupClientConnections(const KWin::Client *c);
+    void setupUnmanagedConnections(const KWin::Unmanaged *u);
 
     Effect* keyboard_grab_effect;
     Effect* fullscreen_effect;
@@ -250,9 +243,6 @@ protected:
     QHash< long, int > registered_atoms;
     int next_window_quad_type;
 
-private Q_SLOTS:
-    void slotEffectsQueried();
-
 private:
     typedef QVector< Effect*> EffectsList;
     typedef EffectsList::const_iterator EffectsIterator;
@@ -351,7 +341,7 @@ class EffectFrameImpl
 {
     Q_OBJECT
 public:
-    explicit EffectFrameImpl(EffectFrameStyle style, bool staticSize = true, QPoint position = QPoint(-1, -1),
+    explicit EffectFrameImpl(bool staticSize = true, QPoint position = QPoint(-1, -1),
                              Qt::Alignment alignment = Qt::AlignCenter);
     virtual ~EffectFrameImpl();
 
@@ -370,46 +360,15 @@ public:
     virtual void setPosition(const QPoint& point);
     virtual const QString& text() const;
     virtual void setText(const QString& text);
-    virtual EffectFrameStyle style() const {
-        return m_style;
-    };
-    Plasma::FrameSvg& frame() {
-        return m_frame;
-    }
     bool isStatic() const {
         return m_static;
     };
     void finalRender(QRegion region, double opacity, double frameOpacity) const;
-    virtual void setShader(GLShader* shader) {
-        m_shader = shader;
-    }
-    virtual GLShader* shader() const {
-        return m_shader;
-    }
-    virtual void setSelection(const QRect& selection);
-    const QRect& selection() const {
-        return m_selectionGeometry;
-    }
-    Plasma::FrameSvg& selectionFrame() {
-        return m_selection;
-    }
-    /**
-     * The foreground text color as specified by the default Plasma theme.
-     */
-    static QColor styledTextColor();
-
-private Q_SLOTS:
-    void plasmaThemeChanged();
-
 private:
     Q_DISABLE_COPY(EffectFrameImpl)   // As we need to use Qt slots we cannot copy this class
     void align(QRect &geometry);   // positions geometry around m_point respecting m_alignment
     void autoResize(); // Auto-resize if not a static size
 
-    EffectFrameStyle m_style;
-    Plasma::FrameSvg m_frame; // TODO: share between all EffectFrames
-    Plasma::FrameSvg m_selection;
-
     // Position
     bool m_static;
     QPoint m_point;
@@ -421,10 +380,8 @@ private:
     QFont m_font;
     QPixmap m_icon;
     QSize m_iconSize;
-    QRect m_selectionGeometry;
 
     Scene::EffectFrame* m_sceneFrame;
-    GLShader* m_shader;
 };
 
 class ScreenLockerWatcher : public QObject
@@ -442,8 +399,6 @@ private Q_SLOTS:
     void setLocked(bool activated);
     void activeQueried(QDBusPendingCallWatcher *watcher);
     void serviceOwnerChanged(const QString &serviceName, const QString &oldOwner, const QString &newOwner);
-    void serviceRegisteredQueried();
-    void serviceOwnerQueried();
 private:
     OrgFreedesktopScreenSaverInterface *m_interface;
     QDBusServiceWatcher *m_serviceWatcher;
