@@ -19,13 +19,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "dimscreen.h"
 
-#include <kwinglutils.h>
-
 namespace KWin
 {
 
-KWIN_EFFECT(dimscreen, DimScreenEffect)
-
 DimScreenEffect::DimScreenEffect()
     : mActivated(false)
     , activateAnimation(false)
