@@ -29,14 +29,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace KWin
 {
 
-class GLRenderTarget;
-class GLTexture;
-
 class LogoutEffect
     : public Effect
 {
     Q_OBJECT
-    Q_PROPERTY(bool useBlur READ isUseBlur)
 public:
     LogoutEffect();
     ~LogoutEffect();
@@ -47,10 +43,6 @@ public:
     virtual void paintWindow(EffectWindow* w, int mask, QRegion region, WindowPaintData& data);
     virtual bool isActive() const;
 
-    // for properties
-    bool isUseBlur() const {
-        return useBlur;
-    }
 public Q_SLOTS:
     void slotWindowAdded(KWin::EffectWindow* w);
     void slotWindowClosed(KWin::EffectWindow *w);
@@ -69,20 +61,10 @@ private:
     bool canDoPersistent;
     EffectWindowList ignoredWindows;
 
-    void renderVignetting();
-    void renderVignettingLegacy();
-    void renderBlurTexture();
-    void renderBlurTextureLegacy();
     int frameDelay;
-    bool blurSupported, useBlur;
-    GLTexture* blurTexture;
-    GLRenderTarget* blurTarget;
     double windowOpacity;
     EffectWindowList windows;
     QHash< EffectWindow*, double > windowsOpacities;
-    GLShader *m_vignettingShader;
-    GLShader *m_blurShader;
-    QString m_shadersDir;
 };
 
 } // namespace
