@@ -25,8 +25,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace KWin
 {
 
-KWIN_EFFECT(minimizeanimation, MinimizeAnimationEffect)
-
 MinimizeAnimationEffect::MinimizeAnimationEffect()
 {
     mActiveAnimations = 0;
@@ -130,7 +128,7 @@ void MinimizeAnimationEffect::slotWindowMinimized(EffectWindow* w)
         timeline = new QTimeLine(animationTime(250), this);
         mTimeLineWindows.insert(w, timeline);
     }
-    timeline->setCurveShape(QTimeLine::EaseInCurve);
+    timeline->setEasingCurve(QEasingCurve(QEasingCurve::InCurve));
     timeline->setCurrentTime(0.0);
 }
 
@@ -145,7 +143,7 @@ void MinimizeAnimationEffect::slotWindowUnminimized(EffectWindow* w)
         timeline = new QTimeLine(animationTime(250), this);
         mTimeLineWindows.insert(w, timeline);
     }
-    timeline->setCurveShape(QTimeLine::EaseInOutCurve);
+    timeline->setEasingCurve(QEasingCurve(QEasingCurve::InOutSine));
     timeline->setCurrentTime(timeline->duration());
 }
 
