@@ -24,17 +24,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "presentwindowsconfig.h"
 #include <kactioncollection.h>
 #include <kaction.h>
-#include <KDE/KGlobal>
-#include <KDE/KIcon>
-#include <KDE/KLocalizedString>
-#include <KDE/KStandardDirs>
+#include <KGlobal>
+#include <KIcon>
+#include <KLocalizedString>
+#include <KStandardDirs>
 #include <kdebug.h>
 #include <kglobalsettings.h>
 #include <kdeclarative.h>
 
-#include <kwinglutils.h>
-
-#include <QMouseEvent>
+#include <QtGui/qevent.h>
 #include <netwm_def.h>
 
 #include <math.h>
@@ -44,16 +42,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QDeclarativeContext>
 #include <QDeclarativeEngine>
 #include <QDesktopWidget>
-#include <QGraphicsObject>
+#include <QtGui/qgraphicsitem.h>
 #include <QTimer>
 #include <QVector2D>
-#include <QVector4D>
 
 namespace KWin
 {
 
-KWIN_EFFECT(presentwindows, PresentWindowsEffect)
-
 PresentWindowsEffect::PresentWindowsEffect()
     : m_proxy(this)
     , m_activated(false)
@@ -323,7 +318,6 @@ void PresentWindowsEffect::paintWindow(EffectWindow *w, int mask, QRegion region
             return;
         }
 
-        mask |= PAINT_WINDOW_LANCZOS;
         // Apply opacity and brightness
         data.multiplyOpacity(winData->opacity);
         data.multiplyBrightness(interpolate(0.40, 1.0, winData->highlight));
@@ -357,9 +351,6 @@ void PresentWindowsEffect::paintWindow(EffectWindow *w, int mask, QRegion region
                     tScale = area.height() / effSize.height();
                 const qreal scale = interpolate(1.0, tScale, winData->highlight);
                 if (scale > 1.0) {
-                    if (scale < tScale) // don't use lanczos during transition
-                        mask &= ~PAINT_WINDOW_LANCZOS;
-
                     const float df = (tScale-1.0f)*0.5f;
                     int tx = qRound(rect.width()*df);
                     int ty = qRound(rect.height()*df);
@@ -378,9 +369,6 @@ void PresentWindowsEffect::paintWindow(EffectWindow *w, int mask, QRegion region
                 }
             }
 
-            if (m_motionManager.areWindowsMoving()) {
-                mask &= ~PAINT_WINDOW_LANCZOS;
-            }
             if (m_dragInProgress && m_dragWindow == w) {
                 data += (cursorPos() - m_dragStart);
             }
@@ -391,20 +379,12 @@ void PresentWindowsEffect::paintWindow(EffectWindow *w, int mask, QRegion region
                 QPoint point(rect.x() + rect.width() * 0.95,
                              rect.y() + rect.height() * 0.95);
                 winData->iconFrame->setPosition(point);
-                if (effects->compositingType() == KWin::OpenGL2Compositing && data.shader) {
-                    const float a = 0.9 * data.opacity() * m_decalOpacity * 0.75;
-                    data.shader->setUniform(GLShader::ModulationConstant, QVector4D(a, a, a, a));
-                }
                 winData->iconFrame->render(region, 0.9 * data.opacity() * m_decalOpacity, 0.75);
             }
             if (m_showCaptions) {
                 QPoint point(rect.x() + rect.width() / 2,
                              rect.y() + rect.height() / 2);
                 winData->textFrame->setPosition(point);
-                if (effects->compositingType() == KWin::OpenGL2Compositing && data.shader) {
-                    const float a = 0.9 * data.opacity() * m_decalOpacity * 0.75;
-                    data.shader->setUniform(GLShader::ModulationConstant, QVector4D(a, a, a, a));
-                }
                 winData->textFrame->render(region, 0.9 * data.opacity() * m_decalOpacity, 0.75);
             }
         } else
@@ -424,12 +404,12 @@ void PresentWindowsEffect::slotWindowAdded(EffectWindow *w)
     winData->visible = isVisibleWindow(w);
     winData->opacity = 0.0;
     winData->highlight = 0.0;
-    winData->textFrame = effects->effectFrame(EffectFrameUnstyled, false);
+    winData->textFrame = effects->effectFrame(false);
     QFont font;
     font.setBold(true);
     font.setPointSize(12);
     winData->textFrame->setFont(font);
-    winData->iconFrame = effects->effectFrame(EffectFrameUnstyled, false);
+    winData->iconFrame = effects->effectFrame(false);
     winData->iconFrame->setAlignment(Qt::AlignRight | Qt::AlignBottom);
     winData->iconFrame->setIcon(w->icon());
     if (isSelectableWindow(w)) {
@@ -597,7 +577,7 @@ void PresentWindowsEffect::windowInputMouseEvent(QEvent *e)
                 mouseActionDesktop(m_leftButtonDesktop);
             }
         }
-        if (me->button() == Qt::MidButton) {
+        if (me->button() == Qt::MiddleButton) {
             if (hovering) {
                 // mouse is hovering above a window - use MouseActionsWindow
                 mouseActionWindow(m_middleButtonWindow);
@@ -1031,7 +1011,7 @@ void PresentWindowsEffect::calculateWindowTransformationsClosest(EffectWindowLis
         }
 
     // Assign each window to the closest available slot
-    EffectWindowList tmpList = windowlist; // use a QLinkedList copy instead?
+    EffectWindowList tmpList = windowlist; // use a QList copy instead?
     QPoint otherPos;
     while (!tmpList.isEmpty()) {
         EffectWindow *w = tmpList.first();
@@ -1221,7 +1201,7 @@ void PresentWindowsEffect::calculateWindowTransformationsKompose(EffectWindowLis
 
             //kDebug(1212) << "Window '" << window->caption() << "' gets moved to (" <<
             //        mWindowData[window].area.left() << "; " << mWindowData[window].area.right() <<
-            //        "), scale: " << mWindowData[window].scale << endl;
+            //        "), scale: " << mWindowData[window].scale;
         }
         if (maxRowHeights[i] - h > 0)
             topOffset += maxRowHeights[i] - h;
@@ -1515,12 +1495,12 @@ void PresentWindowsEffect::setActive(bool active)
             if (w->isOnCurrentDesktop() && !w->isMinimized())
                 winData->opacity = 1.0;
             winData->highlight = 1.0;
-            winData->textFrame = effects->effectFrame(EffectFrameUnstyled, false);
+            winData->textFrame = effects->effectFrame(false);
             QFont font;
             font.setBold(true);
             font.setPointSize(12);
             winData->textFrame->setFont(font);
-            winData->iconFrame = effects->effectFrame(EffectFrameUnstyled, false);
+            winData->iconFrame = effects->effectFrame(false);
             winData->iconFrame->setAlignment(Qt::AlignRight | Qt::AlignBottom);
             winData->iconFrame->setIcon(w->icon());
         }
@@ -1617,7 +1597,7 @@ void PresentWindowsEffect::updateFilterFrame()
 {
     QRect area = effects->clientArea(ScreenArea, effects->activeScreen(), effects->currentDesktop());
     if (!m_filterFrame) {
-        m_filterFrame = effects->effectFrame(EffectFrameStyled, false);
+        m_filterFrame = effects->effectFrame(false);
         QFont font;
         font.setPointSize(font.pointSize() * 2);
         font.setBold(true);
@@ -1632,8 +1612,6 @@ void PresentWindowsEffect::updateFilterFrame()
 
 bool PresentWindowsEffect::isSelectableWindow(EffectWindow *w)
 {
-    if (!w->isOnCurrentActivity())
-        return false;
     if (w->isSpecialWindow() || w->isUtility())
         return false;
     if (w->isDeleted())
@@ -1944,7 +1922,7 @@ void PresentWindowsEffect::screenCountChanged()
         m_gridSizes.append(GridSize());
         if (m_dragToClose) {
             const QRect screenRect = effects->clientArea(FullScreenArea, i, 1);
-            EffectFrame *frame = effects->effectFrame(EffectFrameNone, false);
+            EffectFrame *frame = effects->effectFrame(false);
             KIcon icon("user-trash");
             frame->setIcon(icon.pixmap(QSize(128, 128)));
             frame->setPosition(QPoint(screenRect.x() + screenRect.width(), screenRect.y()));
@@ -2015,4 +1993,4 @@ void CloseWindowView::hideEvent(QHideEvent *event)
 
 } // namespace
 
-#include "presentwindows.moc"
+#include "moc_presentwindows.cpp"
