@@ -28,7 +28,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kshortcut.h>
 #include <QDeclarativeView>
 
-class QTimer;
+#include <QTimer>
 
 namespace KWin
 {
