@@ -21,14 +21,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KWIN_SHOWFPS_H
 #define KWIN_SHOWFPS_H
 
-#include <QTime>
+#include <QtCore/qscopedpointer.h>
+#include <QtCore/qdatetime.h>
 
 #include <kwineffects.h>
 
 
 namespace KWin
 {
-class GLTexture;
 
 class ShowFpsEffect
     : public Effect
@@ -73,8 +73,7 @@ public:
         return textColor;
     }
 private:
-    void paintGL(int fps);
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     void paintXrender(int fps);
 #endif
     void paintFPSGraph(int x, int y);
@@ -93,7 +92,6 @@ private:
     int x;
     int y;
     QRect fps_rect;
-    GLTexture *fpsText;
     int textPosition;
     QFont textFont;
     QColor textColor;
