@@ -35,8 +35,6 @@ public:
     virtual void paintScreen(int mask, QRegion region, ScreenPaintData& data);
     virtual void paintWindow(EffectWindow* w, int mask, QRegion region, WindowPaintData& data);
 private:
-    void paintGL();
-    void paintXrender();
     QRegion painted; // what's painted in one pass
     int color_index;
 };
