@@ -26,13 +26,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace KWin
 {
 
-KWIN_EFFECT(slide, SlideEffect)
-
 SlideEffect::SlideEffect()
     : slide(false)
 {
     connect(effects, SIGNAL(desktopChanged(int,int)), this, SLOT(slotDesktopChanged(int,int)));
-    mTimeLine.setCurveShape(QTimeLine::EaseInOutCurve);
+    mTimeLine.setEasingCurve(QEasingCurve(QEasingCurve::InOutSine));
     reconfigure(ReconfigureAll);
 }
 
@@ -258,4 +256,4 @@ bool SlideEffect::isActive() const
 
 } // namespace
 
-#include "slide.moc"
+#include "moc_slide.cpp"
