@@ -20,14 +20,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef KWIN_STARTUPFEEDBACK_H
 #define KWIN_STARTUPFEEDBACK_H
+
 #include <QObject>
 #include <kwineffects.h>
-#include <KDE/KStartupInfo>
+#include <KStartupInfo>
 
-class KSelectionOwner;
 namespace KWin
 {
-class GLTexture;
 
 class StartupFeedbackEffect
     : public Effect
@@ -38,45 +37,26 @@ public:
     virtual ~StartupFeedbackEffect();
 
     virtual void reconfigure(ReconfigureFlags flags);
-    virtual void prePaintScreen(ScreenPrePaintData& data, int time);
-    virtual void paintScreen(int mask, QRegion region, ScreenPaintData& data);
-    virtual void postPaintScreen();
     virtual bool isActive() const;
 
-    static bool supported();
-
 private Q_SLOTS:
     void gotNewStartup(const KStartupInfoId& id, const KStartupInfoData& data);
     void gotRemoveStartup(const KStartupInfoId& id, const KStartupInfoData& data);
     void gotStartupChange(const KStartupInfoId& id, const KStartupInfoData& data);
-    void slotMouseChanged(const QPoint& pos, const QPoint& oldpos, Qt::MouseButtons buttons, Qt::MouseButtons oldbuttons, Qt::KeyboardModifiers modifiers, Qt::KeyboardModifiers oldmodifiers);
 
 private:
     enum FeedbackType {
-        NoFeedback,
-        BouncingFeedback,
-        BlinkingFeedback,
-        PassiveFeedback
+        NoFeedback = 0,
+        PassiveFeedback = 1
     };
     void start(const QString& icon);
     void stop();
-    QImage scalePixmap(const QPixmap& pm, const QSize& size) const;
-    void prepareTextures(const QPixmap& pix);
-    QRect feedbackRect() const;
 
-    qreal m_bounceSizesRatio;
     KStartupInfo* m_startupInfo;
-    KSelectionOwner* m_selection;
     KStartupInfoId m_currentStartup;
     QMap< KStartupInfoId, QString > m_startups; // QString == pixmap
     bool m_active;
-    int m_frame;
-    int m_progress;
-    GLTexture* m_bouncingTextures[5];
-    GLTexture* m_texture; // for passive and blinking
     FeedbackType m_type;
-    QRect m_currentGeometry, m_dirtyRect;
-    GLShader *m_blinkingShader;
 };
 } // namespace
 
