@@ -25,13 +25,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <kactioncollection.h>
 #include <kaction.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 
 namespace KWin
 {
 
-KWIN_EFFECT(thumbnailaside, ThumbnailAsideEffect)
-
 ThumbnailAsideEffect::ThumbnailAsideEffect()
 {
     KActionCollection* actionCollection = new KActionCollection(this);
@@ -66,7 +64,7 @@ void ThumbnailAsideEffect::paintScreen(int mask, QRegion region, ScreenPaintData
             data.multiplyOpacity(opacity);
             QRect region;
             setPositionTransformations(data, region, d.window, d.rect, Qt::KeepAspectRatio);
-            effects->drawWindow(d.window, PAINT_WINDOW_OPAQUE | PAINT_WINDOW_TRANSLUCENT | PAINT_WINDOW_TRANSFORMED | PAINT_WINDOW_LANCZOS,
+            effects->drawWindow(d.window, PAINT_WINDOW_OPAQUE | PAINT_WINDOW_TRANSLUCENT | PAINT_WINDOW_TRANSFORMED,
                                 region, data);
         }
     }
@@ -178,7 +176,7 @@ void ThumbnailAsideEffect::arrange()
 void ThumbnailAsideEffect::repaintAll()
 {
     foreach (const Data & d, windows)
-    effects->addRepaint(d.rect);
+        effects->addRepaint(d.rect);
 }
 
 bool ThumbnailAsideEffect::isActive() const
@@ -188,4 +186,4 @@ bool ThumbnailAsideEffect::isActive() const
 
 } // namespace
 
-#include "thumbnailaside.moc"
+#include "moc_thumbnailaside.cpp"
