@@ -19,46 +19,39 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
+#include <config-kwin.h>
+
 #include "trackmouse.h"
 
 // KConfigSkeleton
 #include "trackmouseconfig.h"
 
-#include <QTime>
-#include <QMatrix4x4>
-
-#include <kwinconfig.h>
-#include <kwinglutils.h>
 #include <kwinxrenderutils.h>
-
 #include <kglobal.h>
 #include <kstandarddirs.h>
-
 #include <kaction.h>
 #include <kactioncollection.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
+#include <kdebug.h>
+
+#ifdef KWIN_BUILD_COMPOSITE
+#include <xcbutils.h>
+#endif
 
 #include <math.h>
 
-#include <kdebug.h>
-
 namespace KWin
 {
 
-KWIN_EFFECT(trackmouse, TrackMouseEffect)
-
 TrackMouseEffect::TrackMouseEffect()
     : m_active(false)
     , m_angle(0)
 {
-    m_texture[0] = m_texture[1] = 0;
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     m_picture[0] = m_picture[1] = 0;
     if ( effects->compositingType() == XRenderCompositing)
-        m_angleBase = 1.57079632679489661923; // Pi/2
+        m_angleBase = M_PI_2;
 #endif
-    if ( effects->isOpenGLCompositing())
-        m_angleBase = 90.0;
     m_mousePolling = false;
     KActionCollection *actionCollection = new KActionCollection(this);
     m_action = static_cast< KAction* >(actionCollection->addAction("TrackMouse"));
@@ -76,8 +69,7 @@ TrackMouseEffect::~TrackMouseEffect()
     if (m_mousePolling)
         effects->stopMousePolling();
     for (int i = 0; i < 2; ++i) {
-        delete m_texture[i]; m_texture[i] = 0;
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
         delete m_picture[i]; m_picture[i] = 0;
 #endif
     }
@@ -124,41 +116,7 @@ void TrackMouseEffect::paintScreen(int mask, QRegion region, ScreenPaintData& da
     if (!m_active)
         return;
 
-    if ( effects->isOpenGLCompositing() && m_texture[0] && m_texture[1]) {
-        ShaderBinder binder(ShaderManager::GenericShader);
-        GLShader *shader(binder.shader());
-        QMatrix4x4 modelview;
-        if (shader) {
-            modelview = shader->getUniformMatrix4x4("modelview");
-        }
-        glEnable(GL_BLEND);
-        glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-        QMatrix4x4 matrix(modelview);
-        const QPointF p = m_lastRect[0].topLeft() + QPoint(m_lastRect[0].width()/2.0, m_lastRect[0].height()/2.0);
-        const float x = p.x()*data.xScale() + data.xTranslation();
-        const float y = p.y()*data.yScale() + data.yTranslation();
-        for (int i = 0; i < 2; ++i) {
-            matrix.translate(x, y, 0.0);
-            matrix.rotate(i ? -2*m_angle : m_angle, 0, 0, 1.0);
-            matrix.translate(-x, -y, 0.0);
-            if (shader) {
-                shader->setUniform(GLShader::ModelViewMatrix, matrix);
-                shader->setUniform(GLShader::Saturation, 1.0);
-                shader->setUniform(GLShader::ModulationConstant, QVector4D(1.0, 1.0, 1.0, 1.0));
-            } else
-                pushMatrix(matrix);
-            m_texture[i]->bind();
-            m_texture[i]->render(region, m_lastRect[i]);
-            m_texture[i]->unbind();
-            if (!shader)
-                popMatrix();
-        }
-        glDisable(GL_BLEND);
-        if (shader) {
-            shader->setUniform(GLShader::ModelViewMatrix, modelview);
-        }
-    }
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     if ( effects->compositingType() == XRenderCompositing && m_picture[0] && m_picture[1]) {
         float sine = sin(m_angle);
         const float cosine = cos(m_angle);
@@ -167,13 +125,11 @@ void TrackMouseEffect::paintScreen(int mask, QRegion region, ScreenPaintData& da
             const float dx = m_size[i].width()/2.0;
             const float dy = m_size[i].height()/2.0;
             const xcb_render_picture_t picture = *m_picture[i];
-#define DOUBLE_TO_FIXED(d) ((xcb_render_fixed_t) ((d) * 65536))
             xcb_render_transform_t xform = {
-                DOUBLE_TO_FIXED( cosine ), DOUBLE_TO_FIXED( -sine ), DOUBLE_TO_FIXED( dx - cosine*dx + sine*dy ),
-                DOUBLE_TO_FIXED( sine ), DOUBLE_TO_FIXED( cosine ), DOUBLE_TO_FIXED( dy - sine*dx - cosine*dy ),
-                DOUBLE_TO_FIXED( 0.0 ), DOUBLE_TO_FIXED( 0.0 ), DOUBLE_TO_FIXED( 1.0 )
+                KWIN_DOUBLE_TO_FIXED( cosine ), KWIN_DOUBLE_TO_FIXED( -sine ), KWIN_DOUBLE_TO_FIXED( dx - cosine*dx + sine*dy ),
+                KWIN_DOUBLE_TO_FIXED( sine ), KWIN_DOUBLE_TO_FIXED( cosine ), KWIN_DOUBLE_TO_FIXED( dy - sine*dx - cosine*dy ),
+                KWIN_DOUBLE_TO_FIXED( 0.0 ), KWIN_DOUBLE_TO_FIXED( 0.0 ), KWIN_DOUBLE_TO_FIXED( 1.0 )
             };
-#undef DOUBLE_TO_FIXED
             xcb_render_set_picture_transform(connection(), picture, xform);
             xcb_render_set_picture_filter(connection(), picture, 8, "bilinear", 0, NULL);
             const QRect &rect = m_lastRect[i];
@@ -197,18 +153,15 @@ void TrackMouseEffect::postPaintScreen()
 
 bool TrackMouseEffect::init()
 {
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
-    if (!(m_texture[0] || m_picture[0])) {
+#ifdef KWIN_BUILD_COMPOSITE
+    if (!m_picture[0]) {
         loadTexture();
-        if (!(m_texture[0] || m_picture[0]))
+        if (!m_picture[0])
             return false;
     }
 #else
-    if (!m_texture[0]) {
-        loadTexture();
-        if (!m_texture[0])
-            return false;
-    }
+    loadTexture();
+    return false;
 #endif
     m_lastRect[0].moveCenter(cursorPos());
     m_lastRect[1].moveCenter(cursorPos());
@@ -255,17 +208,12 @@ void TrackMouseEffect::loadTexture()
         return;
 
     for (int i = 0; i < 2; ++i) {
-        if ( effects->isOpenGLCompositing()) {
-            QImage img(f[i]);
-            m_texture[i] = new GLTexture(img);
-            m_lastRect[i].setSize(img.size());
-        }
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
         if ( effects->compositingType() == XRenderCompositing) {
-            QPixmap pixmap(f[i]);
-            m_picture[i] = new XRenderPicture(pixmap);
-            m_size[i] = pixmap.size();
-            m_lastRect[i].setSize(pixmap.size());
+            QImage image(f[i]);
+            m_picture[i] = new XRenderPicture(image);
+            m_size[i] = image.size();
+            m_lastRect[i].setSize(image.size());
         }
 #endif
     }
