@@ -19,24 +19,25 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
+#include "config-kwin.h"
+
 #include "zoom.h"
 // KConfigSkeleton
 #include "zoomconfig.h"
 
 #include <QApplication>
 #include <QStyle>
-#include <QtGui/QVector2D>
-#include <QtDBus/QDBusConnection>
+#include <QVector2D>
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kstandardaction.h>
-#include <KDE/KConfigGroup>
-#include <KDE/KLocalizedString>
-#include <KDE/KDebug>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KDebug>
 
-#include <kwinglutils.h>
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
 #include <kwinxrenderutils.h>
+#include <xcbutils.h>
 #include <xcb/render.h>
 #endif
 #include <xcb/xfixes.h>
@@ -46,8 +47,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace KWin
 {
 
-KWIN_EFFECT(zoom, ZoomEffect)
-
 ZoomEffect::ZoomEffect()
     : Effect()
     , zoom(1)
@@ -55,10 +54,7 @@ ZoomEffect::ZoomEffect()
     , polling(false)
     , zoomFactor(1.25)
     , mouseTracking(MouseTrackingProportional)
-    , enableFocusTracking(false)
-    , followFocus(true)
     , mousePointer(MousePointerScale)
-    , focusDelay(350)   // in milliseconds
     , imageWidth(0)
     , imageHeight(0)
     , isMouseHidden(false)
@@ -95,12 +91,6 @@ ZoomEffect::ZoomEffect()
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_Down));
     connect(a, SIGNAL(triggered(bool)), this, SLOT(moveZoomDown()));
 
-    // TODO: these two actions don't belong into the effect. They need to be moved into KWin core
-    a = static_cast< KAction* >(actionCollection->addAction("MoveMouseToFocus"));
-    a->setText(i18n("Move Mouse to Focus"));
-    a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_F5));
-    connect(a, SIGNAL(triggered(bool)), this, SLOT(moveMouseToFocus()));
-
     a = static_cast< KAction* >(actionCollection->addAction("MoveMouseToCenter"));
     a->setText(i18n("Move Mouse to Center"));
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_F6));
@@ -129,10 +119,9 @@ ZoomEffect::~ZoomEffect()
 void ZoomEffect::showCursor()
 {
     if (isMouseHidden) {
-        // show the previously hidden mouse-pointer again and free the loaded texture/picture.
+        // show the previously hidden mouse-pointer again and free the loaded picture.
         xcb_xfixes_show_cursor(connection(), rootWindow());
-        texture.reset();
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
         xrenderPicture.reset();
 #endif
         isMouseHidden = false;
@@ -144,13 +133,11 @@ void ZoomEffect::hideCursor()
     if (mouseTracking == MouseTrackingProportional && mousePointer == MousePointerKeep)
         return; // don't replace the actual cursor by a static image for no reason.
     if (!isMouseHidden) {
-        // try to load the cursor-theme into a OpenGL texture and if successful then hide the mouse-pointer
+        // try to load the cursor-theme and if successful then hide the mouse-pointer
         recreateTexture();
         bool shouldHide = false;
-        if (effects->isOpenGLCompositing()) {
-            shouldHide = !texture.isNull();
-        } else if (effects->compositingType() == XRenderCompositing) {
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+        if (effects->compositingType() == XRenderCompositing) {
+#ifdef KWIN_BUILD_COMPOSITE
             shouldHide = !xrenderPicture.isNull();
 #endif
         }
@@ -179,16 +166,14 @@ void ZoomEffect::recreateTexture()
     if (!ximg) // default is better then nothing, so keep it as backup
         ximg = XcursorLibraryLoadImage("left_ptr", "default", iconSize);
     if (ximg) {
-        // turn the XcursorImage into a QImage that will be used to create the GLTexture/XRenderPicture.
+        // turn the XcursorImage into a QImage that will be used to create the XRenderPicture.
         imageWidth = ximg->width;
         imageHeight = ximg->height;
         cursorHotSpot = QPoint(ximg->xhot, ximg->yhot);
         QImage img((uchar*)ximg->pixels, imageWidth, imageHeight, QImage::Format_ARGB32_Premultiplied);
-        if (effects->isOpenGLCompositing())
-            texture.reset(new GLTexture(img));
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
         if (effects->compositingType() == XRenderCompositing)
-            xrenderPicture.reset(new XRenderPicture(QPixmap::fromImage(img)));
+            xrenderPicture.reset(new XRenderPicture(img));
 #endif
         XcursorImageDestroy(ximg);
     }
@@ -207,21 +192,6 @@ void ZoomEffect::reconfigure(ReconfigureFlags)
     mousePointer = MousePointerType(ZoomConfig::mousePointer());
     // Track moving of the mouse.
     mouseTracking = MouseTrackingType(ZoomConfig::mouseTracking());
-    // Enable tracking of the focused location.
-    bool _enableFocusTracking = ZoomConfig::enableFocusTracking();
-    if (enableFocusTracking != _enableFocusTracking) {
-        enableFocusTracking = _enableFocusTracking;
-        if (QDBusConnection::sessionBus().isConnected()) {
-            if (enableFocusTracking)
-                QDBusConnection::sessionBus().connect("org.kde.kaccessibleapp", "/Adaptor", "org.kde.kaccessibleapp.Adaptor", "focusChanged", this, SLOT(focusChanged(int,int,int,int,int,int)));
-            else
-                QDBusConnection::sessionBus().disconnect("org.kde.kaccessibleapp", "/Adaptor", "org.kde.kaccessibleapp.Adaptor", "focusChanged", this, SLOT(focusChanged(int,int,int,int,int,int)));
-        }
-    }
-    // When the focus changes, move the zoom area to the focused location.
-    followFocus = ZoomConfig::enableFollowFocus();
-    // The time in milliseconds to wait before a focus-event takes away a mouse-move.
-    focusDelay = qMax(uint(0), ZoomConfig::focusDelay());
     // The factor the zoom-area will be moved on touching an edge on push-mode or using the navigation KAction's.
     moveFactor = qMax(0.1, ZoomConfig::moveFactor());
     if (source_zoom < 0) {
@@ -237,9 +207,7 @@ void ZoomEffect::reconfigure(ReconfigureFlags)
 
 void ZoomEffect::prePaintScreen(ScreenPrePaintData& data, int time)
 {
-    bool altered = false;
     if (zoom != target_zoom) {
-        altered = true;
         const float zoomDist = qAbs(target_zoom - source_zoom);
         if (target_zoom > zoom)
             zoom = qMin(zoom + ((zoomDist * time) / animationTime(150*zoomFactor)), target_zoom);
@@ -249,9 +217,6 @@ void ZoomEffect::prePaintScreen(ScreenPrePaintData& data, int time)
 
     if (zoom == 1.0) {
         showCursor();
-        // reset the generic shader to avoid artifacts in plenty other effects
-        if (altered && effects->isOpenGLCompositing())
-            ShaderBinder binder(ShaderManager::GenericShader, true);
     } else {
         hideCursor();
         data.mask |= PAINT_SCREEN_TRANSFORMED;
@@ -302,22 +267,6 @@ void ZoomEffect::paintScreen(int mask, QRegion region, ScreenPaintData& data)
                 break;
             }
         }
-
-        // use the focusPoint if focus tracking is enabled
-        if (enableFocusTracking && followFocus) {
-            bool acceptFocus = true;
-            if (mouseTracking != MouseTrackingDisabled && focusDelay > 0) {
-                // Wait some time for the mouse before doing the switch. This serves as threshold
-                // to prevent the focus from jumping around to much while working with the mouse.
-                const int msecs = lastMouseEvent.msecsTo(lastFocusEvent);
-                acceptFocus = msecs > focusDelay;
-            }
-            if (acceptFocus) {
-                data.setXTranslation(- int(focusPoint.x() * (zoom - 1.0)));
-                data.setYTranslation(- int(focusPoint.y() * (zoom - 1.0)));
-                prevPoint = focusPoint;
-            }
-        }
     }
 
     effects->paintScreen(mask, region, data);
@@ -335,28 +284,19 @@ void ZoomEffect::paintScreen(int mask, QRegion region, ScreenPaintData& data)
         const QPoint p = effects->cursorPos() - cursorHotSpot;
         QRect rect(p.x() * zoom + data.xTranslation(), p.y() * zoom + data.yTranslation(), w, h);
 
-        if (texture) {
-            texture->bind();
-            glEnable(GL_BLEND);
-            glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-            texture->render(region, rect);
-            texture->unbind();
-            glDisable(GL_BLEND);
-        }
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
         if (xrenderPicture) {
-#define DOUBLE_TO_FIXED(d) ((xcb_render_fixed_t) ((d) * 65536))
             static xcb_render_transform_t xrenderIdentity = {
-                DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
-                DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0),
-                DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1)
+                KWIN_DOUBLE_TO_FIXED(1), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0),
+                KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1), KWIN_DOUBLE_TO_FIXED(0),
+                KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1)
             };
             if (mousePointer == MousePointerScale) {
                 xcb_render_set_picture_filter(connection(), *xrenderPicture, 4, const_cast<char*>("good"), 0, NULL);
                 const xcb_render_transform_t xform = {
-                    DOUBLE_TO_FIXED(1.0 / zoom), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
-                    DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1.0 / zoom), DOUBLE_TO_FIXED(0),
-                    DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1)
+                    KWIN_DOUBLE_TO_FIXED(1.0 / zoom), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0),
+                    KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1.0 / zoom), KWIN_DOUBLE_TO_FIXED(0),
+                    KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1)
                 };
                 xcb_render_set_picture_transform(connection(), *xrenderPicture, xform);
             }
@@ -364,7 +304,6 @@ void ZoomEffect::paintScreen(int mask, QRegion region, ScreenPaintData& data)
                                  effects->xrenderBufferPicture(), 0, 0, 0, 0, rect.x(), rect.y(), rect.width(), rect.height());
             if (mousePointer == MousePointerScale)
                 xcb_render_set_picture_transform(connection(), *xrenderPicture, xrenderIdentity);
-#undef DOUBLE_TO_FIXED
         }
 #endif
     }
@@ -471,11 +410,6 @@ void ZoomEffect::moveZoomDown()
     moveZoom(0, 1);
 }
 
-void ZoomEffect::moveMouseToFocus()
-{
-    QCursor::setPos(focusPoint.x(), focusPoint.y());
-}
-
 void ZoomEffect::moveMouseToCenter()
 {
     QRect r(0, 0, displayWidth(), displayHeight());
@@ -494,17 +428,6 @@ void ZoomEffect::slotMouseChanged(const QPoint& pos, const QPoint& old, Qt::Mous
     }
 }
 
-void ZoomEffect::focusChanged(int px, int py, int rx, int ry, int rwidth, int rheight)
-{
-    if (zoom == 1.0)
-        return;
-    focusPoint = (px >= 0 && py >= 0) ? QPoint(px, py) : QPoint(rx + qMax(0, (qMin(displayWidth(), rwidth) / 2) - 60), ry + qMax(0, (qMin(displayHeight(), rheight) / 2) - 60));
-    if (enableFocusTracking) {
-        lastFocusEvent = QTime::currentTime();
-        effects->addRepaintFull();
-    }
-}
-
 bool ZoomEffect::isActive() const
 {
     return zoom != 1.0 || zoom != target_zoom;
@@ -512,4 +435,4 @@ bool ZoomEffect::isActive() const
 
 } // namespace
 
-#include "zoom.moc"
+#include "moc_zoom.cpp"
