@@ -25,11 +25,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <kwineffects.h>
 
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <kdebug.h>
 #include <KActionCollection>
-#include <kaction.h>
+#include <KAction>
 #include <KShortcutsEditor>
+#include <KIcon>
 
 #include <QVBoxLayout>
 
@@ -97,12 +98,6 @@ ZoomEffectConfig::ZoomEffectConfig(QWidget* parent, const QVariantList& args) :
     a->setProperty("isConfigurationAction", true);
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_Down));
 
-    a = static_cast< KAction* >(actionCollection->addAction("MoveMouseToFocus"));
-    a->setIcon(KIcon("view-restore"));
-    a->setText(i18n("Move Mouse to Focus"));
-    a->setProperty("isConfigurationAction", true);
-    a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_F5));
-
     a = static_cast< KAction* >(actionCollection->addAction("MoveMouseToCenter"));
     a->setIcon(KIcon("view-restore"));
     a->setText(i18n("Move Mouse to Center"));
@@ -128,4 +123,4 @@ void ZoomEffectConfig::save()
 
 } // namespace
 
-#include "zoom_config.moc"
+#include "moc_zoom_config.cpp"
