@@ -57,7 +57,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <X11/extensions/Xfixes.h>
 #include <X11/extensions/Xrandr.h>
 #include <X11/Xatom.h>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 #include "composite.h"
 #include "killwindow.h"
@@ -123,7 +123,7 @@ bool Workspace::workspaceEvent(XEvent * e)
         was_user_interaction = true;
         int keyQt;
         KKeyServer::xEventToQt(e, &keyQt);
-//            kDebug(125) << "Workspace::keyPress( " << keyQt << " )";
+        // kDebug(1212) << "Workspace::keyPress( " << keyQt << " )";
         if (movingClient) {
             movingClient->keyPressEvent(keyQt);
             return true;
@@ -437,7 +437,7 @@ bool Client::windowEvent(XEvent* e)
                 emit opacityChanged(this, old_opacity);
             } else {
                 // forward to the frame if there's possibly another compositing manager running
-                NETWinInfo2 i(display(), frameId(), rootWindow(), 0);
+                NETWinInfo i(display(), frameId(), rootWindow(), 0);
                 i.setOpacity(info->opacity());
             }
         }
@@ -719,8 +719,6 @@ void Client::propertyNotifyEvent(XPropertyEvent* e)
             getMotifHints();
         else if (e->atom == atoms->net_wm_sync_request_counter)
             getSyncCounter();
-        else if (e->atom == atoms->activities)
-            checkActivities();
         else if (e->atom == atoms->kde_net_wm_block_compositing)
             updateCompositeBlocking(true);
         else if (e->atom == atoms->kde_first_in_window_list)
@@ -1055,10 +1053,8 @@ bool Client::buttonPressEvent(xcb_window_t w, int button, int state, int x, int
         return processDecorationButtonPress(button, state, x, y, x_root, y_root, true);
     }
     if (w == decorationId()) {
-        if (dynamic_cast<KDecorationUnstable*>(decoration))
-            // New API processes core events FIRST and only passes unused ones to the decoration
-            return processDecorationButtonPress(button, state, x, y, x_root, y_root, true);
-        return false;
+        // New API processes core events FIRST and only passes unused ones to the decoration
+        return processDecorationButtonPress(button, state, x, y, x_root, y_root, true);
     }
     if (w == frameId())
         processDecorationButtonPress(button, state, x, y, x_root, y_root);
@@ -1121,7 +1117,7 @@ void Client::processMousePressEvent(QMouseEvent* e)
     case Qt::LeftButton:
         button = Button1;
         break;
-    case Qt::MidButton:
+    case Qt::MiddleButton:
         button = Button2;
         break;
     case Qt::RightButton:
