@@ -25,18 +25,16 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
-//#define QT_CLEAN_NAMESPACE
-
 #include "group.h"
-#include <QTextStream>
 #include "workspace.h"
 #include "client.h"
 #include "effects.h"
 
-#include <assert.h>
 #include <kstartupinfo.h>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
+#include <QTextStream>
 
+#include <assert.h>
 
 /*
  TODO
@@ -71,15 +69,15 @@ bool performTransiencyCheck()
         if ((*it1)->deleting)
             continue;
         if ((*it1)->in_group == NULL) {
-            kDebug(1212) << "TC: " << *it1 << " in not in a group" << endl;
+            kDebug(1212) << "TC: " << *it1 << " in not in a group";
             ret = false;
         } else if (!(*it1)->in_group->members().contains(*it1)) {
-            kDebug(1212) << "TC: " << *it1 << " has a group " << (*it1)->in_group << " but group does not contain it" << endl;
+            kDebug(1212) << "TC: " << *it1 << " has a group " << (*it1)->in_group << " but group does not contain it";
             ret = false;
         }
         if (!(*it1)->isTransient()) {
             if (!(*it1)->mainClients().isEmpty()) {
-                kDebug(1212) << "TC: " << *it1 << " is not transient, has main clients:" << (*it1)->mainClients() << endl;
+                kDebug(1212) << "TC: " << *it1 << " is not transient, has main clients:" << (*it1)->mainClients();
                 ret = false;
             }
         } else {
@@ -96,7 +94,7 @@ bool performTransiencyCheck()
                     continue;
                 }
                 if (!(*it2)->transients_list.contains(*it1)) {
-                    kdDebug(1212) << "TC:" << *it1 << " has main client " << *it2 << " but main client does not have it as a transient" << endl;
+                    kDebug(1212) << "TC:" << *it1 << " has main client " << *it2 << " but main client does not have it as a transient";
                     ret = false;
                 }
             }
@@ -114,7 +112,7 @@ bool performTransiencyCheck()
                 continue;
             }
             if (!(*it2)->mainClients().contains(*it1)) {
-                kdDebug(1212) << "TC:" << *it1 << " has transient " << *it2 << " but transient does not have it as a main client" << endl;
+                kDebug(1212) << "TC:" << *it1 << " has transient " << *it2 << " but transient does not have it as a main client";
                 ret = false;
             }
         }
@@ -128,7 +126,7 @@ bool performTransiencyCheck()
                 it2 != members.constEnd();
                 ++it2) {
             if ((*it2)->in_group != *it1) {
-                kDebug(1212) << "TC: Group " << *it1 << " contains client " << *it2 << " but client is not in that group" << endl;
+                kDebug(1212) << "TC: Group " << *it1 << " contains client " << *it2 << " but client is not in that group";
                 ret = false;
             }
         }
@@ -153,8 +151,8 @@ static void checkTransiency()
 {
     if (--transiencyCheck == 0) {
         if (!performTransiencyCheck()) {
-            kDebug(1212) << "BT:" << transiencyCheckStartBt << endl;
-            kDebug(1212) << "CLIENT:" << transiencyCheckClient << endl;
+            kDebug(1212) << "BT:" << transiencyCheckStartBt;
+            kDebug(1212) << "CLIENT:" << transiencyCheckClient;
             abort();
         }
         transiencyCheckNonExistent = false;
@@ -203,7 +201,7 @@ Group::Group(Window leader_P)
     if (leader_P != None) {
         leader_client = workspace()->findClient(WindowMatchPredicate(leader_P));
         unsigned long properties[ 2 ] = { 0, NET::WM2StartupId };
-        leader_info = new NETWinInfo2(display(), leader_P, rootWindow(),
+        leader_info = new NETWinInfo(display(), leader_P, rootWindow(),
                                       properties, 2);
     }
     effect_group = new EffectWindowGroupImpl(this);
@@ -384,7 +382,7 @@ void Workspace::updateMinimizedOfTransients(Client* c)
         }
         if (c->isModal()) { // if a modal dialog is minimized, minimize its mainwindow too
             foreach (Client * c2, c->mainClients())
-            c2->minimize();
+                c2->minimize();
         }
     } else {
         // else unmiminize the transients
@@ -398,7 +396,7 @@ void Workspace::updateMinimizedOfTransients(Client* c)
         }
         if (c->isModal()) {
             foreach (Client * c2, c->mainClients())
-            c2->unminimize();
+                c2->unminimize();
         }
     }
 }
@@ -790,7 +788,7 @@ xcb_window_t Client::verifyTransientFor(xcb_window_t new_transient_for, bool set
     if (Client* new_transient_for_client = workspace()->findClient(WindowMatchPredicate(new_transient_for))) {
         if (new_transient_for != before_search) {
             kDebug(1212) << "Client " << this << " has WM_TRANSIENT_FOR poiting to non-toplevel window "
-                         << before_search << ", child of " << new_transient_for_client << ", adjusting." << endl;
+                         << before_search << ", child of " << new_transient_for_client << ", adjusting.";
             new_property_value = new_transient_for; // also fix the property
         }
     } else
@@ -923,7 +921,7 @@ ClientList Client::allMainClients() const
 {
     ClientList result = mainClients();
     foreach (const Client * cl, result)
-    result += cl->allMainClients();
+        result += cl->allMainClients();
     return result;
 }
 
