@@ -31,11 +31,11 @@
 #include <kwindowsystem.h>
 #include <kiconloader.h>
 
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <kdebug.h>
 #include <kvbox.h>
 
-#include "ktimerdialog.moc"
+#include "moc_ktimerdialog.cpp"
 
 KTimerDialog::KTimerDialog(int msec, TimerStyle style, QWidget *parent,
                            const QString &caption,
