@@ -22,10 +22,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define __MAIN_H__
 
 #include <kcmodule.h>
-
 #include <ksharedconfig.h>
 #include <ktemporaryfile.h>
 
+#include <QLabel>
+
 #include "kwin_interface.h"
 
 #include "ui_main.h"
@@ -33,7 +34,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 class KPluginSelector;
 class KActionCollection;
-class QLabel;
 
 namespace KWin
 {
@@ -78,15 +78,11 @@ public slots:
 
 private slots:
     void confirmReInit() { showConfirmDialog(true); }
-    void glSwapStrategyChanged(int idx);
-    void rearmGlSupport();
-    void suggestGraphicsSystem();
     void alignGuiToCompositingType(int compositingType);
     void toggleEffectShortcutChanged(const QKeySequence &seq);
     void updateStatusUI(bool compositingIsPossible);
     void showDetailedEffectLoadingInformation();
     void blockFutureWarnings();
-    void slotGHNS();
 
 private:
     bool effectEnabled(const QString& effect, const KConfigGroup& cfg) const;
@@ -99,7 +95,6 @@ private:
     KSharedConfigPtr mTmpConfig;
     bool m_showConfirmDialog;
     KActionCollection* m_actionCollection;
-    QString originalGraphicsSystem;
     QAction *m_showDetailedErrors;
     QAction *m_dontShowAgain;
     QString m_externErrorDetails;
