@@ -30,7 +30,6 @@
 */
 
 #include "buttons.h"
-#include "pixmaps.h"
 #include "config-kwin.h"
 
 #include <QApplication>
@@ -40,22 +39,49 @@
 #include <QMimeData>
 #include <QScrollBar>
 
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <kglobalsettings.h>
-
-#ifdef KWIN_BUILD_KAPPMENU
-#include <KConfigGroup>
-#include <KConfig>
-#endif
-
 #include <kdecorationfactory.h>
-
+#include <kglobal.h>
+#include <kstandarddirs.h>
+#include <kdebug.h>
 
 #define BUTTONDRAGMIMETYPE "application/x-kde_kwindecoration_buttons"
 
 namespace KWin
 {
 
+// helper functions to deal with the Button's bitmaps more easily...
+static QBitmap buttonBitmap(const char* const bitmapname)
+{
+    QByteArray bitmapnamebytes("kwin/kcm_kwindecoration/buttons/");
+    bitmapnamebytes.append(bitmapname);
+    bitmapnamebytes.append(".png");
+    const QString bitmapfilepath = KGlobal::dirs()->findResource("data", bitmapnamebytes.constData());
+    if (bitmapfilepath.isEmpty()) {
+        kWarning() << "No button image for" << bitmapname;
+        return QBitmap();
+    }
+
+    const QImage image(bitmapfilepath);
+    QBitmap bmp = QBitmap::fromImage(image);
+    bmp.createMaskFromColor(Qt::white);
+    return bmp;
+}
+
+static QPixmap bitmapPixmap(const QBitmap& bm, const QColor& color)
+{
+    QPixmap pm(bm.size());
+    pm.fill(Qt::white);
+    QPainter p(&pm);
+    p.setPen(color);
+    p.drawPixmap(0, 0, bm);
+    p.end();
+    pm.setMask(pm.createMaskFromColor(Qt::white));
+    return pm;
+}
+
+
 ButtonDrag::ButtonDrag(Button btn)
     : QMimeData()
 {
@@ -115,20 +141,6 @@ Button::~Button()
 {
 }
 
-// helper function to deal with the Button's bitmaps more easily...
-QPixmap bitmapPixmap(const QBitmap& bm, const QColor& color)
-{
-    QPixmap pm(bm.size());
-    pm.fill(Qt::white);
-    QPainter p(&pm);
-    p.setPen(color);
-    p.drawPixmap(0, 0, bm);
-    p.end();
-    pm.setMask(pm.createMaskFromColor(Qt::white));
-    return pm;
-}
-
-
 ButtonSource::ButtonSource(QWidget *parent)
     : QListWidget(parent)
 {
@@ -688,16 +700,6 @@ ButtonPositionWidget::ButtonPositionWidget(QWidget *parent)
     bool dummy;
 
     m_supportedButtons = "MSHIAX_FBLR";
-#ifdef KWIN_BUILD_KAPPMENU
-    KConfig config("kdeglobals", KConfig::FullConfig);
-    KConfigGroup configGroup = config.group("Appmenu Style");
-    QString style = configGroup.readEntry("Style", "InApplication");
-
-    if (style == "ButtonVertical") {
-        m_supportedButtons = "MNSHIAX_FBLR"; // support all buttons
-        new ButtonSourceItem(m_buttonSource, getButton('N', dummy));
-    }
-#endif
 
     new ButtonSourceItem(m_buttonSource, getButton('R', dummy));
     new ButtonSourceItem(m_buttonSource, getButton('L', dummy));
@@ -721,55 +723,27 @@ Button ButtonPositionWidget::getButton(QChar type, bool& success)
     success = true;
 
     if (type == 'R') {
-        QBitmap bmp = QBitmap::fromData(QSize(resize_width, resize_height), resize_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Resize"), bmp, 'R', false, m_supportedButtons.contains('R'));
+        return Button(i18n("Resize"), buttonBitmap("resize"), 'R', false, m_supportedButtons.contains('R'));
     } else if (type == 'L') {
-        QBitmap bmp = QBitmap::fromData(QSize(shade_width, shade_height), shade_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Shade"), bmp, 'L', false, m_supportedButtons.contains('L'));
+        return Button(i18n("Shade"), buttonBitmap("shade"), 'L', false, m_supportedButtons.contains('L'));
     } else if (type == 'B') {
-        QBitmap bmp = QBitmap::fromData(QSize(keepbelowothers_width, keepbelowothers_height), keepbelowothers_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Keep Below Others"), bmp, 'B', false, m_supportedButtons.contains('B'));
+        return Button(i18n("Keep Below Others"), buttonBitmap("keepbelowothers"), 'B', false, m_supportedButtons.contains('B'));
     } else if (type == 'F') {
-        QBitmap bmp = QBitmap::fromData(QSize(keepaboveothers_width, keepaboveothers_height), keepaboveothers_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Keep Above Others"), bmp, 'F', false, m_supportedButtons.contains('F'));
+        return Button(i18n("Keep Above Others"), buttonBitmap("keepaboveothers"), 'F', false, m_supportedButtons.contains('F'));
     } else if (type == 'X') {
-        QBitmap bmp = QBitmap::fromData(QSize(close_width, close_height), close_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Close"), bmp, 'X', false, m_supportedButtons.contains('X'));
+        return Button(i18n("Close"), buttonBitmap("close"), 'X', false, m_supportedButtons.contains('X'));
     } else if (type == 'A') {
-        QBitmap bmp = QBitmap::fromData(QSize(maximize_width, maximize_height), maximize_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Maximize"), bmp, 'A', false, m_supportedButtons.contains('A'));
+        return Button(i18n("Maximize"), buttonBitmap("maximize"), 'A', false, m_supportedButtons.contains('A'));
     } else if (type == 'I') {
-        QBitmap bmp = QBitmap::fromData(QSize(minimize_width, minimize_height), minimize_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Minimize"), bmp, 'I', false, m_supportedButtons.contains('I'));
+        return Button(i18n("Minimize"), buttonBitmap("minimize"), 'I', false, m_supportedButtons.contains('I'));
     } else if (type == 'H') {
-        QBitmap bmp = QBitmap::fromData(QSize(help_width, help_height), help_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("Help"), bmp, 'H', false, m_supportedButtons.contains('H'));
+        return Button(i18n("Help"), buttonBitmap("help"), 'H', false, m_supportedButtons.contains('H'));
     } else if (type == 'S') {
-        QBitmap bmp = QBitmap::fromData(QSize(onalldesktops_width, onalldesktops_height), onalldesktops_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("On All Desktops"), bmp, 'S', false, m_supportedButtons.contains('S'));
+        return Button(i18n("On All Desktops"), buttonBitmap("onalldesktops"), 'S', false, m_supportedButtons.contains('S'));
     } else if (type == 'M') {
-        QBitmap bmp = QBitmap::fromData(QSize(menu_width, menu_height), menu_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18nc("Button showing window actions menu", "Window Menu"), bmp, 'M', false, m_supportedButtons.contains('M'));
-#ifdef KWIN_BUILD_KAPPMENU
-    } else if (type == 'N') {
-        QBitmap bmp = QBitmap::fromData(QSize(menu_width, menu_height), menu_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18nc("Button showing application menu imported from dbusmenu", "Application Menu"), bmp, 'N', false, m_supportedButtons.contains('N'));
-#endif
+        return Button(i18nc("Button showing window actions menu", "Window Menu"), buttonBitmap("menu"), 'M', false, m_supportedButtons.contains('M'));
     } else if (type == '_') {
-        QBitmap bmp = QBitmap::fromData(QSize(spacer_width, spacer_height), spacer_bits);
-        bmp.createMaskFromColor(Qt::white);
-        return Button(i18n("--- spacer ---"), bmp, '_', true, m_supportedButtons.contains('_'));
+        return Button(i18n("--- spacer ---"), buttonBitmap("spacer"), '_', true, m_supportedButtons.contains('_'));
     } else {
         success = false;
         return Button();
@@ -832,6 +806,4 @@ void ButtonPositionWidget::setButtonsRight(const QString &buttons)
 
 } // namespace KWin
 
-#include "buttons.moc"
-// vim: ts=4
-// kate: space-indent off; tab-width 4;
+#include "moc_buttons.cpp"
