@@ -34,6 +34,7 @@
 #include "decorationmodel.h"
 #include "auroraetheme.h"
 // Qt
+#include <QFile>
 #include <QTimer>
 #include <QtDBus/QtDBus>
 #include <QtDeclarative/QDeclarativeContext>
@@ -41,17 +42,16 @@
 #include <QtDeclarative/QDeclarativeItem>
 #include <QtDeclarative/QDeclarativeView>
 #include <QSortFilterProxyModel>
-#include <QGraphicsObject>
+#include <QtGui/qgraphicsitem.h>
 #include <QScrollBar>
 #include <QUiLoader>
 // KDE
 #include <KAboutData>
 #include <KDialog>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KNS3/DownloadDialog>
-#include <KDE/KStandardDirs>
-#include <KDE/KConfigDialogManager>
+#include <KStandardDirs>
+#include <KConfigDialogManager>
 #include <KPluginFactory>
 #include <Plasma/ConfigLoader>
 #include <qdeclarative.h>
@@ -88,7 +88,6 @@ KWinDecorationModule::KWinDecorationModule(QWidget* parent, const QVariantList &
     m_ui = new KWinDecorationForm(this);
     m_ui->configureDecorationButton->setIcon(KIcon("configure"));
     m_ui->configureButtonsButton->setIcon(KIcon("configure"));
-    m_ui->ghnsButton->setIcon(KIcon("get-hot-new-stuff"));
     QVBoxLayout* layout = new QVBoxLayout(this);
     layout->addWidget(m_ui);
 
@@ -160,7 +159,6 @@ void KWinDecorationModule::init()
     connect(m_ui->decorationList->rootObject(), SIGNAL(currentIndexChanged()), SLOT(slotSelectionChanged()));
     connect(m_ui->decorationList->rootObject(), SIGNAL(widthChanged()), SLOT(updatePreviewWidth()));
     connect(m_ui->configureButtonsButton, SIGNAL(clicked(bool)), this, SLOT(slotConfigureButtons()));
-    connect(m_ui->ghnsButton, SIGNAL(clicked(bool)), SLOT(slotGHNSClicked()));
     connect(m_ui->searchEdit, SIGNAL(textChanged(QString)), m_proxyModel, SLOT(setFilterFixedString(QString)));
     connect(m_ui->searchEdit, SIGNAL(textChanged(QString)), m_ui->decorationList->rootObject(), SLOT(returnToBounds()), Qt::QueuedConnection);
     connect(m_ui->searchEdit, SIGNAL(textChanged(QString)), SLOT(updateScrollbarRange()), Qt::QueuedConnection);
@@ -347,37 +345,6 @@ void KWinDecorationModule::slotConfigureButtons()
     delete configDialog;
 }
 
-void KWinDecorationModule::slotGHNSClicked()
-{
-    QPointer<KNS3::DownloadDialog> downloadDialog = new KNS3::DownloadDialog("aurorae.knsrc", this);
-    if (downloadDialog->exec() == KDialog::Accepted) {
-        if (!downloadDialog->changedEntries().isEmpty()) {
-            const QModelIndex index = m_proxyModel->mapToSource(m_proxyModel->index(m_ui->decorationList->rootObject()->property("currentIndex").toInt(), 0));
-            const QString libraryName = m_model->data(index, DecorationModel::LibraryNameRole).toString();
-            bool aurorae = m_model->data(index, DecorationModel::TypeRole).toInt() == DecorationModelData::AuroraeDecoration;
-            bool qml = m_model->data(index, DecorationModel::TypeRole).toInt() == DecorationModelData::QmlDecoration;
-            const QString auroraeName = m_model->data(index, DecorationModel::AuroraeNameRole).toString();
-            m_model->reload();
-            if (aurorae) {
-                const QModelIndex proxyIndex = m_proxyModel->mapFromSource(m_model->indexOfAuroraeName(auroraeName, "aurorae"));
-                if (proxyIndex.isValid())
-                    m_ui->decorationList->rootObject()->setProperty("currentIndex", proxyIndex.row());
-            } else if (qml) {
-                const QModelIndex proxyIndex = m_proxyModel->mapFromSource(m_model->indexOfAuroraeName(auroraeName, "qml"));
-                if (proxyIndex.isValid())
-                    m_ui->decorationList->rootObject()->setProperty("currentIndex", proxyIndex.row());
-            } else {
-                const QModelIndex proxyIndex = m_proxyModel->mapFromSource(m_model->indexOfLibrary(libraryName));
-                if (proxyIndex.isValid())
-                    m_ui->decorationList->rootObject()->setProperty("currentIndex", proxyIndex.row());
-            }
-            m_lastPreviewWidth = 0;
-            updatePreviews();
-        }
-    }
-    delete downloadDialog;
-}
-
 void KWinDecorationModule::slotConfigureDecoration()
 {
     const QModelIndex index = m_proxyModel->mapToSource(m_proxyModel->index(m_ui->decorationList->rootObject()->property("currentIndex").toInt(), 0));
@@ -618,4 +585,4 @@ void DecorationButtons::resetToDefaults()
 
 } // namespace KWin
 
-#include "kwindecoration.moc"
+#include "moc_kwindecoration.cpp"
