@@ -20,13 +20,13 @@
 #include "preview.h"
 
 #include <kapplication.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <QLabel>
 #include <QStyle>
 #include <QPainter>
-#include <QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QVector>
 #include <kicon.h>
 
@@ -118,13 +118,11 @@ void KDecorationPreview::render(QPainter *painter, KDecoration *decoration, cons
     int padLeft, padRight, padTop, padBottom;
     padLeft = padRight = padTop = padBottom = 0;
     bool useMask = true;
-    if (KDecorationUnstable *unstable = qobject_cast<KDecorationUnstable *>(decoration)) {
-        unstable->padding(padLeft, padRight, padTop, padBottom);
-        size.setWidth(size.width() + padLeft + padRight);
-        size.setHeight(size.height() + padTop + padBottom);
-        if (padLeft || padRight || padTop || padBottom) {
-            useMask = false;
-        }
+    decoration->padding(padLeft, padRight, padTop, padBottom);
+    size.setWidth(size.width() + padLeft + padRight);
+    size.setHeight(size.height() + padTop + padBottom);
+    if (padLeft || padRight || padTop || padBottom) {
+        useMask = false;
     }
     decoration->resize(size);
 
@@ -301,15 +299,6 @@ void KDecorationPreviewBridge::showWindowMenu(const QPoint &)
 {
 }
 
-void KDecorationPreviewBridge::showApplicationMenu(const QPoint &)
-{
-}
-
-bool KDecorationPreviewBridge::menuAvailable() const
-{
-    return false;
-}
-
 void KDecorationPreviewBridge::performWindowOperation(WindowOperation)
 {
 }
@@ -526,9 +515,4 @@ void KDecorationPreviewOptions::setCustomTitleButtons(const QString &left, const
     updateSettings();
 }
 
-bool KDecorationPreviewPlugins::provides(Requirement)
-{
-    return false;
-}
-
-#include "preview.moc"
+#include "moc_preview.cpp"
