@@ -27,7 +27,7 @@
 
 class KDecorationPreviewBridge;
 class KDecorationPreviewOptions;
-class QMouseEvent;
+#include <QMouseEvent>
 
 class KDecorationPreview
     : public QWidget
@@ -60,7 +60,7 @@ private:
 };
 
 class KDecorationPreviewBridge
-    : public KDecorationBridgeUnstable
+    : public KDecorationBridge
 {
 public:
     KDecorationPreviewBridge(KDecorationPreview* preview, bool active);
@@ -86,8 +86,6 @@ public:
     virtual void processMousePressEvent(QMouseEvent*);
     virtual void showWindowMenu(const QRect &);
     virtual void showWindowMenu(const QPoint &);
-    virtual void showApplicationMenu(const QPoint &);
-    virtual bool menuAvailable() const;
     virtual void performWindowOperation(WindowOperation);
     virtual void setMask(const QRegion&, int);
     virtual bool isPreview() const;
@@ -158,7 +156,6 @@ class KDecorationPreviewPlugins
 {
 public:
     explicit KDecorationPreviewPlugins(const KSharedConfigPtr &cfg);
-    virtual bool provides(Requirement);
 };
 
 inline KDecorationPreviewPlugins::KDecorationPreviewPlugins(const KSharedConfigPtr &cfg)
