@@ -24,7 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QLabel>
 #include <QGridLayout>
 
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <KLineEdit>
 
 namespace KWin
@@ -122,4 +122,4 @@ void DesktopNamesWidget::setDesktopConfig(KWinDesktopConfig* desktopConfig)
 
 } // namespace
 
-#include "desktopnameswidget.moc"
+#include "moc_desktopnameswidget.cpp"
