@@ -25,8 +25,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QList>
 
 class KLineEdit;
-class QLabel;
-class QGridLayout;
+#include <QLabel>
+#include <QGridLayout>
 
 namespace KWin
 {
