@@ -22,7 +22,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QDBusMessage>
 #include <QDBusConnection>
-#include <QDBusInterface>
 
 #include <KAboutApplicationDialog>
 #include <KActionCollection>
@@ -36,7 +35,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KServiceTypeTrader>
 #include <KShortcutsEditor>
 
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 #include <netwm.h>
 
@@ -124,23 +123,10 @@ void KWinDesktopConfig::init()
     // TODO: way to recognize if a effect is not found
     KServiceTypeTrader* trader = KServiceTypeTrader::self();
     KService::List services;
-    QString slide;
-    QString cube;
-    QString fadedesktop;
+    m_ui->effectComboBox->addItem(i18n("No Animation"));
     services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_slide'");
     if (!services.isEmpty())
-        slide = services.first()->name();
-    services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_cubeslide'");
-    if (!services.isEmpty())
-        cube = services.first()->name();
-    services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_fadedesktop'");
-    if (!services.isEmpty())
-        fadedesktop = services.first()->name();
-
-    m_ui->effectComboBox->addItem(i18n("No Animation"));
-    m_ui->effectComboBox->addItem(slide);
-    m_ui->effectComboBox->addItem(cube);
-    m_ui->effectComboBox->addItem(fadedesktop);
+        m_ui->effectComboBox->addItem(services.first()->name());
 
     // effect config and info button
     m_ui->effectInfoButton->setIcon(KIcon("dialog-information"));
@@ -149,7 +135,6 @@ void KWinDesktopConfig::init()
     connect(m_ui->rowsSpinBox, SIGNAL(valueChanged(int)), SLOT(changed()));
     connect(m_ui->numberSpinBox, SIGNAL(valueChanged(int)), SLOT(changed()));
     connect(m_ui->numberSpinBox, SIGNAL(valueChanged(int)), SLOT(slotChangeShortcuts(int)));
-    connect(m_ui->activityCheckBox, SIGNAL(stateChanged(int)), SLOT(changed()));
     connect(m_ui->desktopNames, SIGNAL(changed()), SLOT(changed()));
     connect(m_ui->popupInfoCheckBox, SIGNAL(toggled(bool)), SLOT(changed()));
     connect(m_ui->popupHideSpinBox, SIGNAL(valueChanged(int)), SLOT(changed()));
@@ -264,21 +249,9 @@ void KWinDesktopConfig::load()
     m_ui->effectComboBox->setCurrentIndex(0);
     if (effectEnabled("slide", effectconfig))
         m_ui->effectComboBox->setCurrentIndex(1);
-    if (effectEnabled("cubeslide", effectconfig))
-        m_ui->effectComboBox->setCurrentIndex(2);
-    if (effectEnabled("fadedesktop", effectconfig))
-        m_ui->effectComboBox->setCurrentIndex(3);
     slotEffectSelectionChanged(m_ui->effectComboBox->currentIndex());
     // TODO: plasma stuff
 
-    QDBusInterface interface("org.kde.plasma-desktop", "/App");
-    if (interface.isValid()) {
-        bool perVirtualDesktopViews = interface.call("perVirtualDesktopViews").arguments().first().toBool();
-        m_ui->activityCheckBox->setEnabled(true);
-        m_ui->activityCheckBox->setChecked(perVirtualDesktopViews);
-    } else
-        m_ui->activityCheckBox->setEnabled(false);
-
     emit changed(false);
 }
 
@@ -338,26 +311,10 @@ void KWinDesktopConfig::save()
     case 0:
         // no effect
         effectconfig.writeEntry("kwin4_effect_slideEnabled", false);
-        effectconfig.writeEntry("kwin4_effect_cubeslideEnabled", false);
-        effectconfig.writeEntry("kwin4_effect_fadedesktopEnabled", false);
         break;
     case 1:
         // slide
         effectconfig.writeEntry("kwin4_effect_slideEnabled", true);
-        effectconfig.writeEntry("kwin4_effect_cubeslideEnabled", false);
-        effectconfig.writeEntry("kwin4_effect_fadedesktopEnabled", false);
-        break;
-    case 2:
-        // cube
-        effectconfig.writeEntry("kwin4_effect_slideEnabled", false);
-        effectconfig.writeEntry("kwin4_effect_cubeslideEnabled", true);
-        effectconfig.writeEntry("kwin4_effect_fadedesktopEnabled", false);
-        break;
-    case 3:
-        // fadedesktop
-        effectconfig.writeEntry("kwin4_effect_slideEnabled", false);
-        effectconfig.writeEntry("kwin4_effect_cubeslideEnabled", false);
-        effectconfig.writeEntry("kwin4_effect_fadedesktopEnabled", true);
         break;
     }
 
@@ -368,9 +325,6 @@ void KWinDesktopConfig::save()
     QDBusMessage message = QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig");
     QDBusConnection::sessionBus().send(message);
 
-    QDBusInterface interface("org.kde.plasma-desktop", "/App");
-    interface.call("setPerVirtualDesktopViews", (m_ui->activityCheckBox->isChecked()));
-
     emit changed(false);
 }
 
@@ -519,12 +473,6 @@ void KWinDesktopConfig::slotAboutEffectClicked()
     case 1:
         effect = "slide";
         break;
-    case 2:
-        effect = "cubeslide";
-        break;
-    case 3:
-        effect = "fadedesktop";
-        break;
     default:
         return;
     }
@@ -562,35 +510,8 @@ void KWinDesktopConfig::slotAboutEffectClicked()
 
 void KWinDesktopConfig::slotConfigureEffectClicked()
 {
-    QString effect;
-    switch(m_ui->effectComboBox->currentIndex()) {
-    case 2:
-        effect = "cubeslide_config";
-        break;
-    default:
-        return;
-    }
-    KCModuleProxy* proxy = new KCModuleProxy(effect);
-    QPointer< KDialog > configDialog = new KDialog(this);
-    configDialog->setWindowTitle(m_ui->effectComboBox->currentText());
-    configDialog->setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Default);
-    connect(configDialog, SIGNAL(defaultClicked()), proxy, SLOT(defaults()));
-
-    QWidget *showWidget = new QWidget(configDialog);
-    QVBoxLayout *layout = new QVBoxLayout;
-    showWidget->setLayout(layout);
-    layout->addWidget(proxy);
-    layout->insertSpacing(-1, KDialog::marginHint());
-    configDialog->setMainWidget(showWidget);
-
-    if (configDialog->exec() == QDialog::Accepted) {
-        proxy->save();
-    } else {
-        proxy->load();
-    }
-    delete configDialog;
 }
 
 } // namespace
 
-#include "main.moc"
+#include "moc_main.cpp"
