@@ -34,7 +34,7 @@
 #include <QtDBus/QtDBus>
 
 #include <KButtonGroup>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <knuminput.h>
 #include <kdialog.h>
 
@@ -642,4 +642,4 @@ void KMovingConfig::setCenterSnapZone(int pxls)
     m_ui->centerSnap->setValue(pxls);
 }
 
-#include "windows.moc"
+#include "moc_windows.cpp"
