@@ -19,7 +19,7 @@
 #include <kcmdlineargs.h>
 #include <kapplication.h>
 #include <kconfig.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <kwindowsystem.h>
 #include <QtDBus/QtDBus>
 #include <X11/Xlib.h>
@@ -79,7 +79,7 @@ static Rules* findRule(const QList< Rules* >& rules, Window wid, bool whole_app)
     QByteArray wmclass_name = info.windowClassName().toLower();
     QByteArray role = info.windowRole().toLower();
     NET::WindowType type = info.windowType(NET::NormalMask | NET::DesktopMask | NET::DockMask
-                                           | NET::ToolbarMask | NET::MenuMask | NET::DialogMask | NET::OverrideMask | NET::TopMenuMask
+                                           | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
                                            | NET::UtilityMask | NET::SplashMask);
     QString title = info.name();
     QByteArray machine = clientMachine.hostName();
@@ -238,8 +238,7 @@ static int edit(Window wid, bool whole_app)
 
 } // namespace
 
-extern "C"
-KDE_EXPORT int kdemain(int argc, char* argv[])
+int main(int argc, char* argv[])
 {
     KCmdLineArgs::init(argc, argv, "kwin_rules_dialog", "kcmkwinrules", ki18n("KWin"), "1.0" ,
                        ki18n("KWin helper utility"));
