@@ -25,12 +25,9 @@
 #include <kpushbutton.h>
 #include <QLabel>
 #include <kwindowsystem.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <QRegExp>
 
-#ifdef KWIN_BUILD_ACTIVITIES
-#include <KActivities/Consumer>
-#endif
 
 #include <assert.h>
 #include <kmessagebox.h>
@@ -89,9 +86,6 @@ RulesWidget::RulesWidget(QWidget* parent)
     SETUP(size, set);
     SETUP(desktop, set);
     SETUP(screen, set);
-#ifdef KWIN_BUILD_ACTIVITIES
-    SETUP(activity, set);
-#endif
     SETUP(maximizehoriz, set);
     SETUP(maximizevert, set);
     SETUP(minimize, set);
@@ -130,11 +124,6 @@ RulesWidget::RulesWidget(QWidget* parent)
     edit_reg_title->hide();
     edit_reg_machine->hide();
 
-#ifndef KWIN_BUILD_ACTIVITIES
-    rule_activity->hide();
-    enable_activity->hide();
-    activity->hide();
-#endif
     int i;
     for (i = 1;
             i <= KWindowSystem::numberOfDesktops();
@@ -142,16 +131,6 @@ RulesWidget::RulesWidget(QWidget* parent)
         desktop->addItem(QString::number(i).rightJustified(2) + ':' + KWindowSystem::desktopName(i));
     desktop->addItem(i18n("All Desktops"));
 
-#ifdef KWIN_BUILD_ACTIVITIES
-    static KActivities::Consumer activities;
-    foreach (const QString & activityId, activities.listActivities()) {
-        activity->addItem(KActivities::Info::name(activityId), activityId);
-    }
-    // cloned from kactivities/src/lib/core/consumer.cpp
-    #define NULL_UUID "00000000-0000-0000-0000-000000000000"
-    activity->addItem(i18n("All Activities"), QString::fromLatin1(NULL_UUID));
-    #undef NULL_UUID
-#endif
 }
 
 #undef SETUP
@@ -168,9 +147,6 @@ UPDATE_ENABLE_SLOT(position)
 UPDATE_ENABLE_SLOT(size)
 UPDATE_ENABLE_SLOT(desktop)
 UPDATE_ENABLE_SLOT(screen)
-#ifdef KWIN_BUILD_ACTIVITIES
-UPDATE_ENABLE_SLOT(activity)
-#endif
 UPDATE_ENABLE_SLOT(maximizehoriz)
 UPDATE_ENABLE_SLOT(maximizevert)
 UPDATE_ENABLE_SLOT(minimize)
@@ -288,28 +264,6 @@ int RulesWidget::comboToDesktop(int val) const
         return NET::OnAllDesktops;
     return val + 1;
 }
-#ifdef KWIN_BUILD_ACTIVITIES
-int RulesWidget::activityToCombo(QString d) const
-{
-    // TODO: ivan - do a multiselection list
-    for (int i = 0; i < activity->count(); i++) {
-        if (activity->itemData(i).toString() == d) {
-            return i;
-        }
-    }
-
-    return activity->count() - 1; // on all activities
-}
-
-QString RulesWidget::comboToActivity(int val) const
-{
-    // TODO: ivan - do a multiselection list
-    if (val < 0 || val >= activity->count())
-        return QString();
-
-    return activity->itemData(val).toString();
-}
-#endif
 static int placementToCombo(Placement::Policy placement)
 {
     static const int conv[] = {
@@ -348,24 +302,17 @@ static Placement::Policy comboToPlacement(int val)
 
 static int typeToCombo(NET::WindowType type)
 {
-    if (type < NET::Normal || type > NET::Splash ||
-        type == NET::Override) // The user must NOT set a window to be unmanaged.
-                               // This case is not handled in KWin and will lead to segfaults.
-                               // Even iff it was supported, it would mean to allow the user to shoot himself
-                               // since an unmanaged window has to manage itself, what is probably not the case when the hint is not set.
-                               // Rule opportunity might be a relict from the Motif Hint window times of KDE1
+    if (type < NET::Normal || type > NET::Splash)
         return 0; // Normal
     static const int conv[] = {
         0, // Normal
-        7, // Desktop
+        1, // Dialog
+        2, // Utility
         3, // Dock
         4, // Toolbar
         5, // Menu
-        1, // Dialog
-        8, // Override - ignored.
-        9, // TopMenu
-        2, // Utility
-        6  // Splash
+        6,  // Splash
+        7 // Desktop
     };
     return conv[ type ];
 }
@@ -380,8 +327,7 @@ static NET::WindowType comboToType(int val)
         NET::Toolbar,
         NET::Menu,
         NET::Splash,
-        NET::Desktop,
-        NET::TopMenu
+        NET::Desktop
     };
     return conv[ val ];
 }
@@ -432,8 +378,6 @@ void RulesWidget::setRules(Rules* rules)
     types->item(5)->setSelected(rules->types & NET::MenuMask);
     types->item(6)->setSelected(rules->types & NET::SplashMask);
     types->item(7)->setSelected(rules->types & NET::DesktopMask);
-    types->item(8)->setSelected(rules->types & NET::OverrideMask);
-    types->item(9)->setSelected(rules->types & NET::TopMenuMask);
     title->setText(rules->title);
     title_match->setCurrentIndex(rules->titlematch);
     titleMatchChanged();
@@ -444,9 +388,6 @@ void RulesWidget::setRules(Rules* rules)
     LINEEDIT_SET_RULE(size, sizeToStr);
     COMBOBOX_SET_RULE(desktop, desktopToCombo);
     SPINBOX_SET_RULE(screen, inc);
-#ifdef KWIN_BUILD_ACTIVITIES
-    COMBOBOX_SET_RULE(activity, activityToCombo);
-#endif
     CHECKBOX_SET_RULE(maximizehoriz,);
     CHECKBOX_SET_RULE(maximizevert,);
     CHECKBOX_SET_RULE(minimize,);
@@ -532,8 +473,6 @@ Rules* RulesWidget::rules() const
         rules->types |= types->item(5)->isSelected() ? NET::MenuMask : 0U;
         rules->types |= types->item(6)->isSelected() ? NET::SplashMask : 0U;
         rules->types |= types->item(7)->isSelected() ? NET::DesktopMask : 0U;
-        rules->types |= types->item(8)->isSelected() ? NET::OverrideMask : 0U;
-        rules->types |= types->item(9)->isSelected() ? NET::TopMenuMask : 0U;
     }
     rules->title = title->text();
     rules->titlematch = static_cast< Rules::StringMatch >(title_match->currentIndex());
@@ -543,9 +482,6 @@ Rules* RulesWidget::rules() const
     LINEEDIT_SET_RULE(size, strToSize);
     COMBOBOX_SET_RULE(desktop, comboToDesktop);
     SPINBOX_SET_RULE(screen, dec);
-#ifdef KWIN_BUILD_ACTIVITIES
-    COMBOBOX_SET_RULE(activity, comboToActivity);
-#endif
     CHECKBOX_SET_RULE(maximizehoriz,);
     CHECKBOX_SET_RULE(maximizevert,);
     CHECKBOX_SET_RULE(minimize,);
@@ -868,4 +804,4 @@ QKeySequence ShortcutDialog::shortcut() const
 
 } // namespace
 
-#include "ruleswidget.moc"
+#include "moc_ruleswidget.cpp"
