@@ -23,6 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtDBus/QtDBus>
 #include <QDesktopWidget>
 #include <QVBoxLayout>
+#include <QtCore/qdebug.h>
 
 // KDE
 #include <KAction>
@@ -37,7 +38,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KServiceTypeTrader>
 #include <KShortcutsEditor>
 #include <KStandardDirs>
-#include <KNS3/DownloadDialog>
 
 // own
 #include "tabboxconfig.h"
@@ -108,7 +108,6 @@ KWinTabBoxConfig::KWinTabBoxConfig(QWidget* parent, const QVariantList& args)
     KWinTabBoxConfigForm *ui[2] = { m_primaryTabBoxUi, m_alternativeTabBoxUi };
     for (int i = 0; i < 2; ++i) {
         ui[i]->effectConfigButton->setIcon(KIcon("view-preview"));
-        ui[i]->ghns->setIcon(KIcon("get-hot-new-stuff"));
 
         connect(ui[i]->highlightWindowCheck, SIGNAL(clicked(bool)), SLOT(changed()));
         connect(ui[i]->showTabBox, SIGNAL(clicked(bool)), SLOT(tabBoxToggled(bool)));
@@ -123,10 +122,6 @@ KWinTabBoxConfig::KWinTabBoxConfig(QWidget* parent, const QVariantList& args)
         connect(ui[i]->currentDesktop, SIGNAL(clicked(bool)), SLOT(changed()));
         connect(ui[i]->otherDesktops, SIGNAL(clicked(bool)), SLOT(changed()));
 
-        connect(ui[i]->filterActivities, SIGNAL(clicked(bool)), SLOT(changed()));
-        connect(ui[i]->currentActivity, SIGNAL(clicked(bool)), SLOT(changed()));
-        connect(ui[i]->otherActivities, SIGNAL(clicked(bool)), SLOT(changed()));
-
         connect(ui[i]->filterScreens, SIGNAL(clicked(bool)), SLOT(changed()));
         if (QApplication::desktop()->screenCount() < 2) {
             ui[i]->filterScreens->hide();
@@ -140,7 +135,6 @@ KWinTabBoxConfig::KWinTabBoxConfig(QWidget* parent, const QVariantList& args)
         connect(ui[i]->filterMinimization, SIGNAL(clicked(bool)), SLOT(changed()));
         connect(ui[i]->visibleWindows, SIGNAL(clicked(bool)), SLOT(changed()));
         connect(ui[i]->hiddenWindows, SIGNAL(clicked(bool)), SLOT(changed()));
-        connect(ui[i]->ghns, SIGNAL(clicked(bool)), SLOT(slotGHNS()));
     }
 
     // check focus policy - we don't offer configs for unreasonable focus policies
@@ -162,19 +156,10 @@ void KWinTabBoxConfig::initLayoutLists()
     // search the effect names
     // TODO: way to recognize if a effect is not found
     KServiceTypeTrader* trader = KServiceTypeTrader::self();
-    KService::List services;
-    QString coverswitch;
-    QString flipswitch;
-    services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_coverswitch'");
-    if (!services.isEmpty())
-        coverswitch = services.first()->name();
-    services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_flipswitch'");
-    if (!services.isEmpty())
-        flipswitch = services.first()->name();
 
     KService::List offers = trader->query("KWin/WindowSwitcher");
     QStringList layoutNames, layoutPlugins, layoutPaths;
-    foreach (KService::Ptr service, offers) {
+    foreach (const KService::Ptr service, offers) {
         const QString pluginName = service->property("X-KDE-PluginInfo-Name").toString();
         if (service->property("X-Plasma-API").toString() != "declarativeappletscript") {
             continue;
@@ -198,8 +183,6 @@ void KWinTabBoxConfig::initLayoutLists()
         int index = ui[i]->effectCombo->currentIndex();
         QVariant data = ui[i]->effectCombo->itemData(index);
         ui[i]->effectCombo->clear();
-        ui[i]->effectCombo->addItem(coverswitch);
-        ui[i]->effectCombo->addItem(flipswitch);
         for (int j = 0; j < layoutNames.count(); ++j) {
             ui[i]->effectCombo->addItem(layoutNames[j], layoutPlugins[j]);
             ui[i]->effectCombo->setItemData(ui[i]->effectCombo->count() - 1, layoutPaths[j], Qt::UserRole+1);
@@ -226,12 +209,6 @@ void KWinTabBoxConfig::load()
 
         updateUiFromConfig(ui[i], *(tabBoxConfig[i]));
 
-        KConfigGroup effectconfig(m_config, "Plugins");
-        if (effectEnabled("coverswitch", effectconfig) && KConfigGroup(m_config, "Effect-CoverSwitch").readEntry(group[i], false))
-            ui[i]->effectCombo->setCurrentIndex(CoverSwitch);
-        else if (effectEnabled("flipswitch", effectconfig) && KConfigGroup(m_config, "Effect-FlipSwitch").readEntry(group[i], false))
-            ui[i]->effectCombo->setCurrentIndex(FlipSwitch);
-
         QString action;
 #define LOAD_SHORTCUT(_BTN_)\
         action = ui[i]->_BTN_->property("shortcutAction").toString();\
@@ -251,8 +228,6 @@ void KWinTabBoxConfig::loadConfig(const KConfigGroup& config, KWin::TabBox::TabB
 {
     tabBoxConfig.setClientDesktopMode(TabBoxConfig::ClientDesktopMode(
                                        config.readEntry<int>("DesktopMode", TabBoxConfig::defaultDesktopMode())));
-    tabBoxConfig.setClientActivitiesMode(TabBoxConfig::ClientActivitiesMode(
-                                       config.readEntry<int>("ActivitiesMode", TabBoxConfig::defaultActivitiesMode())));
     tabBoxConfig.setClientApplicationsMode(TabBoxConfig::ClientApplicationsMode(
                                        config.readEntry<int>("ApplicationsMode", TabBoxConfig::defaultApplicationsMode())));
     tabBoxConfig.setClientMinimizedMode(TabBoxConfig::ClientMinimizedMode(
@@ -274,7 +249,6 @@ void KWinTabBoxConfig::saveConfig(KConfigGroup& config, const KWin::TabBox::TabB
 {
     // combo boxes
     config.writeEntry("DesktopMode",        int(tabBoxConfig.clientDesktopMode()));
-    config.writeEntry("ActivitiesMode",     int(tabBoxConfig.clientActivitiesMode()));
     config.writeEntry("ApplicationsMode",   int(tabBoxConfig.clientApplicationsMode()));
     config.writeEntry("MinimizedMode",      int(tabBoxConfig.clientMinimizedMode()));
     config.writeEntry("ShowDesktopMode",    int(tabBoxConfig.showDesktopMode()));
@@ -304,32 +278,12 @@ void KWinTabBoxConfig::save()
     // effects
     bool highlightWindows = m_primaryTabBoxUi->highlightWindowCheck->isChecked() ||
                             m_alternativeTabBoxUi->highlightWindowCheck->isChecked();
-    const bool coverSwitch = m_primaryTabBoxUi->showTabBox->isChecked() &&
-                             m_primaryTabBoxUi->effectCombo->currentIndex() == CoverSwitch;
-    const bool flipSwitch = m_primaryTabBoxUi->showTabBox->isChecked() &&
-                            m_primaryTabBoxUi->effectCombo->currentIndex() == FlipSwitch;
-    const bool coverSwitchAlternative = m_alternativeTabBoxUi->showTabBox->isChecked() &&
-                                        m_alternativeTabBoxUi->effectCombo->currentIndex() == CoverSwitch;
-    const bool flipSwitchAlternative = m_alternativeTabBoxUi->showTabBox->isChecked() &&
-                                       m_alternativeTabBoxUi->effectCombo->currentIndex() == FlipSwitch;
 
     // activate effects if not active
     KConfigGroup effectconfig(m_config, "Plugins");
-    if (coverSwitch || coverSwitchAlternative)
-        effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", true);
-    if (flipSwitch || flipSwitchAlternative)
-        effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", true);
     if (highlightWindows)
         effectconfig.writeEntry("kwin4_effect_highlightwindowEnabled", true);
     effectconfig.sync();
-    KConfigGroup coverswitchconfig(m_config, "Effect-CoverSwitch");
-    coverswitchconfig.writeEntry("TabBox", coverSwitch);
-    coverswitchconfig.writeEntry("TabBoxAlternative", coverSwitchAlternative);
-    coverswitchconfig.sync();
-    KConfigGroup flipswitchconfig(m_config, "Effect-FlipSwitch");
-    flipswitchconfig.writeEntry("TabBox", flipSwitch);
-    flipswitchconfig.writeEntry("TabBoxAlternative", flipSwitchAlternative);
-    flipswitchconfig.sync();
 
     // Reload KWin.
     QDBusMessage message = QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig");
@@ -348,9 +302,6 @@ void KWinTabBoxConfig::defaults()
         CONFIGURE(filterDesktops, Desktop, !=, AllDesktopsClients);
         CONFIGURE(currentDesktop, Desktop, ==, OnlyCurrentDesktopClients);
         CONFIGURE(otherDesktops, Desktop, ==, ExcludeCurrentDesktopClients);
-        CONFIGURE(filterActivities, Activities, !=, AllActivitiesClients);
-        CONFIGURE(currentActivity, Activities, ==, OnlyCurrentActivityClients);
-        CONFIGURE(otherActivities, Activities, ==, ExcludeCurrentActivityClients);
         CONFIGURE(filterScreens, MultiScreen, !=, IgnoreMultiScreen);
         CONFIGURE(currentScreen, MultiScreen, ==, OnlyCurrentScreenClients);
         CONFIGURE(otherScreens, MultiScreen, ==, ExcludeCurrentScreenClients);
@@ -404,9 +355,6 @@ void KWinTabBoxConfig::updateUiFromConfig(KWinTabBoxConfigForm* ui, const KWin::
     CONFIGURE(filterDesktops, clientDesktop, !=, AllDesktopsClients);
     CONFIGURE(currentDesktop, clientDesktop, ==, OnlyCurrentDesktopClients);
     CONFIGURE(otherDesktops, clientDesktop, ==, ExcludeCurrentDesktopClients);
-    CONFIGURE(filterActivities, clientActivities, !=, AllActivitiesClients);
-    CONFIGURE(currentActivity, clientActivities, ==, OnlyCurrentActivityClients);
-    CONFIGURE(otherActivities, clientActivities, ==, ExcludeCurrentActivityClients);
     CONFIGURE(filterScreens, clientMultiScreen, !=, IgnoreMultiScreen);
     CONFIGURE(currentScreen, clientMultiScreen, ==, OnlyCurrentScreenClients);
     CONFIGURE(otherScreens, clientMultiScreen, ==, ExcludeCurrentScreenClients);
@@ -431,10 +379,6 @@ void KWinTabBoxConfig::updateConfigFromUi(const KWin::KWinTabBoxConfigForm* ui,
         config.setClientDesktopMode(ui->currentDesktop->isChecked() ? TabBoxConfig::OnlyCurrentDesktopClients : TabBoxConfig::ExcludeCurrentDesktopClients);
     else
         config.setClientDesktopMode(TabBoxConfig::AllDesktopsClients);
-    if (ui->filterActivities->isChecked())
-        config.setClientActivitiesMode(ui->currentActivity->isChecked() ? TabBoxConfig::OnlyCurrentActivityClients : TabBoxConfig::ExcludeCurrentActivityClients);
-    else
-        config.setClientActivitiesMode(TabBoxConfig::AllActivitiesClients);
     if (ui->filterScreens->isChecked())
         config.setClientMultiScreenMode(ui->currentScreen->isChecked() ? TabBoxConfig::OnlyCurrentScreenClients : TabBoxConfig::ExcludeCurrentScreenClients);
     else
@@ -449,9 +393,7 @@ void KWinTabBoxConfig::updateConfigFromUi(const KWin::KWinTabBoxConfigForm* ui,
 
     config.setShowTabBox(ui->showTabBox->isChecked());
     config.setHighlightWindows(ui->highlightWindowCheck->isChecked());
-    if (ui->effectCombo->currentIndex() >= Layout) {
-        config.setLayoutName(ui->effectCombo->itemData(ui->effectCombo->currentIndex()).toString());
-    }
+    config.setLayoutName(ui->effectCombo->itemData(ui->effectCombo->currentIndex()).toString());
     config.setShowDesktopMode(ui->showDesktop->isChecked() ? TabBoxConfig::ShowDesktopClient : TabBoxConfig::DoNotShowDesktopClient);
 }
 
@@ -466,21 +408,18 @@ void KWinTabBoxConfig::updateConfigFromUi(const KWin::KWinTabBoxConfigForm* ui,
 void KWinTabBoxConfig::effectSelectionChanged(int index)
 {
     CHECK_CURRENT_TABBOX_UI
-    ui->effectConfigButton->setIcon(KIcon(index < Layout ? "configure" : "view-preview"));
+    ui->effectConfigButton->setIcon(KIcon("view-preview"));
     if (!ui->showTabBox->isChecked())
         return;
-    ui->highlightWindowCheck->setEnabled(index >= Layout);
+    ui->highlightWindowCheck->setEnabled(index);
     if (m_layoutPreview && m_layoutPreview->isVisible()) {
-        if (index < Layout)
-            m_layoutPreview->hide();
-        else
-            m_layoutPreview->setLayout(ui->effectCombo->itemData(index, Qt::UserRole+1).toString(), ui->effectCombo->itemText(index));
+        m_layoutPreview->setLayout(ui->effectCombo->itemData(index, Qt::UserRole+1).toString(), ui->effectCombo->itemText(index));
     }
 }
 
 void KWinTabBoxConfig::tabBoxToggled(bool on) {
     CHECK_CURRENT_TABBOX_UI
-    on = !on || ui->effectCombo->currentIndex() >= Layout;
+    on = !on || ui->effectCombo->currentIndex() >= 0;
     ui->highlightWindowCheck->setEnabled(on);
     emit changed();
 }
@@ -490,35 +429,13 @@ void KWinTabBoxConfig::configureEffectClicked()
     CHECK_CURRENT_TABBOX_UI
 
     const int effect = ui->effectCombo->currentIndex();
-    if (effect >= Layout) {
-        if (!m_layoutPreview) {
-            m_layoutPreview = new LayoutPreview(this);
-            m_layoutPreview->setWindowTitle(i18n("Tabbox layout preview"));
-            m_layoutPreview->setWindowFlags(Qt::Dialog);
-        }
-        m_layoutPreview->setLayout(ui->effectCombo->itemData(effect, Qt::UserRole+1).toString(), ui->effectCombo->itemText(effect));
-        m_layoutPreview->show();
-    } else {
-        QPointer< KDialog > configDialog = new KDialog(this);
-        configDialog->setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Default);
-        configDialog->setWindowTitle(ui->effectCombo->currentText());
-        KCModuleProxy* proxy = new KCModuleProxy(effect == CoverSwitch ? "coverswitch_config" : "flipswitch_config");
-        connect(configDialog, SIGNAL(defaultClicked()), proxy, SLOT(defaults()));
-
-        QWidget *showWidget = new QWidget(configDialog);
-        QVBoxLayout *layout = new QVBoxLayout;
-        showWidget->setLayout(layout);
-        layout->addWidget(proxy);
-        layout->insertSpacing(-1, KDialog::marginHint());
-        configDialog->setMainWidget(showWidget);
-
-        if (configDialog->exec() == QDialog::Accepted) {
-            proxy->save();
-        } else {
-            proxy->load();
-        }
-        delete configDialog;
+    if (!m_layoutPreview) {
+        m_layoutPreview = new LayoutPreview(this);
+        m_layoutPreview->setWindowTitle(i18n("Tabbox layout preview"));
+        m_layoutPreview->setWindowFlags(Qt::Dialog);
     }
+    m_layoutPreview->setLayout(ui->effectCombo->itemData(effect, Qt::UserRole+1).toString(), ui->effectCombo->itemText(effect));
+    m_layoutPreview->show();
 }
 
 void KWinTabBoxConfig::shortcutChanged(const QKeySequence &seq)
@@ -533,15 +450,4 @@ void KWinTabBoxConfig::shortcutChanged(const QKeySequence &seq)
     m_actionCollection->writeSettings();
 }
 
-void KWinTabBoxConfig::slotGHNS()
-{
-    QPointer<KNS3::DownloadDialog> downloadDialog = new KNS3::DownloadDialog("kwinswitcher.knsrc", this);
-    if (downloadDialog->exec() == KDialog::Accepted) {
-        if (!downloadDialog->changedEntries().isEmpty()) {
-            initLayoutLists();
-        }
-    }
-    delete downloadDialog;
-}
-
 } // namespace
