@@ -24,8 +24,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtDeclarative/QDeclarativeEngine>
 #include <QtDeclarative/QDeclarativeView>
 // KDE
-#include <KDE/KDebug>
-#include <KDE/KStandardDirs>
+#include <KDebug>
+#include <KStandardDirs>
 
 namespace KWin
 {
@@ -52,8 +52,8 @@ void WindowThumbnailItem::findImage()
 {
     QString imagePath;
     switch (m_wId) {
-    case Konqueror:
-        imagePath = KStandardDirs::locate("data", "kwin/kcm_kwintabbox/konqueror.png");
+    case Konsole:
+        imagePath = KStandardDirs::locate("data", "kwin/kcm_kwintabbox/konsole.png");
         break;
     case Systemsettings:
         imagePath = KStandardDirs::locate("data", "kwin/kcm_kwintabbox/systemsettings.png");
