@@ -43,10 +43,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
  and ActiveLayer (see also NETWM sect.7.10.). The layer a window is in depends
  on the window type, and on other things like whether the window is active.
 
- NET::Splash clients belong to the Normal layer. NET::TopMenu clients
- belong to Dock layer. Clients that are both NET::Dock and NET::KeepBelow
- are in the Normal layer in order to keep the 'allow window to cover
- the panel' Kicker setting to work as intended (this may look like a slight
+ NET::Splash clients belong to the Normal layer. Clients that are both NET::Dock
+ and NET::KeepBelow are in the Normal layer in order to keep the 'allow window to
+ cover the panel' Kicker setting to work as intended (this may look like a slight
  spec violation, but a) I have no better idea, b) the spec allows adjusting
  the stacking order if the WM thinks it's a good idea . We put all
  NET::KeepAbove above all Docks too, even though the spec suggests putting
@@ -88,7 +87,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "unmanaged.h"
 #include "deleted.h"
 #include "effects.h"
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include "composite.h"
 #ifdef KWIN_BUILD_SCREENEDGES
 #include "screenedge.h"
@@ -251,7 +250,7 @@ Client* Workspace::topClientOnDesktop(int desktop, int screen, bool unconstraine
         if (!c) {
             continue;
         }
-        if (c->isOnDesktop(desktop) && c->isShown(false) && c->isOnCurrentActivity()) {
+        if (c->isOnDesktop(desktop) && c->isShown(false)) {
             if (screen != -1 && c->screen() != screen)
                 continue;
             if (!only_normal)
@@ -373,7 +372,7 @@ void Workspace::raiseClient(Client* c, bool nogroup)
         Client *transient_parent = c;
         while ((transient_parent = transient_parent->transientFor()))
             transients << transient_parent;
-        foreach (transient_parent, transients)
+        foreach (Client *transient_parent, transients)
             raiseClient(transient_parent, true);
     }
 
@@ -382,7 +381,6 @@ void Workspace::raiseClient(Client* c, bool nogroup)
 
     if (!c->isSpecialWindow()) {
         most_recently_raised = c;
-        pending_take_activity = NULL;
     }
 }
 
@@ -673,10 +671,8 @@ ToplevelList Workspace::xStackingOrder() const
     XQueryTree(display(), rootWindow(), &dummy, &dummy, &windows, &count);
     // use our own stacking order, not the X one, as they may differ
     foreach (Toplevel * c, stacking_order)
-    x_stacking.append(c);
-    for (unsigned int i = 0;
-            i < count;
-            ++i) {
+        x_stacking.append(c);
+    for (unsigned int i = 0; i < count; ++i) {
         if (Unmanaged* c = findUnmanaged(WindowMatchPredicate(windows[ i ])))
             x_stacking.append(c);
     }
@@ -743,7 +739,7 @@ void Client::restackWindow(xcb_window_t above, int detail, NET::RequestSource sr
             Client *c = qobject_cast<Client*>(*it);
 
             if (!c || !(  (*it)->isNormalWindow() && c->isShown(true) &&
-                    (*it)->isOnCurrentDesktop() && (*it)->isOnCurrentActivity() && (*it)->isOnScreen(screen()) ))
+                    (*it)->isOnCurrentDesktop() && (*it)->isOnScreen(screen()) ))
                 continue; // irrelevant clients
 
             if (*(it - 1) == other)
