@@ -37,9 +37,9 @@
 
 #include <kapplication.h>
 #include "kdecorationfactory.h"
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 
-#include "kcommondecoration.moc"
+#include "moc_kcommondecoration.cpp"
 
 /** @addtogroup kdecoration */
 /** @{ */
@@ -393,27 +393,6 @@ void KCommonDecoration::addButtons(ButtonContainer &btnContainer, const QString&
                     m_button[MenuButton] = btn;
                 }
                 break;
-             case 'N': // Application Menu button
-                if (!m_button[AppMenuButton]) {
-                    btn = createButton(AppMenuButton);
-                    if (!btn) break;
-                    btn->setTipText(i18nc("Button showing application menu", "Application Menu"));
-                    btn->setRealizeButtons(Qt::LeftButton);
-                    connect(btn, SIGNAL(clicked()), SLOT(appMenuButtonPressed()), Qt::QueuedConnection);
-                    // Application want to show it menu
-                    connect(decoration(), SIGNAL(showRequest()), this, SLOT(appMenuButtonPressed()), Qt::UniqueConnection);
-                    // Wait for menu to become available before displaying any button
-                    connect(decoration(), SIGNAL(appMenuAvailable()), this, SLOT(slotAppMenuAvailable()), Qt::UniqueConnection);
-                    // On Kded module shutdown, hide application menu button
-                    connect(decoration(), SIGNAL(appMenuUnavailable()), this, SLOT(slotAppMenuUnavailable()), Qt::UniqueConnection);
-                    // Application menu button may need to be modified on this signal
-                    connect(decoration(), SIGNAL(menuHidden()), btn, SLOT(slotAppMenuHidden()), Qt::UniqueConnection);
-
-                    // fix double deletion, see objDestroyed()
-                    connect(btn, SIGNAL(destroyed(QObject*)), this, SLOT(objDestroyed(QObject*)));
-                    m_button[AppMenuButton] = btn;
-                }
-                break;
             case 'S': // OnAllDesktops button
                 if (!m_button[OnAllDesktopsButton]) {
                     btn = createButton(OnAllDesktopsButton);
@@ -460,7 +439,7 @@ void KCommonDecoration::addButtons(ButtonContainer &btnContainer, const QString&
                 if ((!m_button[MaxButton]) && isMaximizable()) {
                     btn = createButton(MaxButton);
                     if (!btn) break;
-                    btn->setRealizeButtons(Qt::LeftButton | Qt::MidButton | Qt::RightButton);
+                    btn->setRealizeButtons(Qt::LeftButton | Qt::MiddleButton | Qt::RightButton);
                     const bool max = maximizeMode() == MaximizeFull;
                     btn->setTipText(max ? i18n("Restore") : i18n("Maximize"));
                     btn->setToggleButton(true);
@@ -542,12 +521,7 @@ void KCommonDecoration::addButtons(ButtonContainer &btnContainer, const QString&
             if (btn) {
                 btn->setLeft(isLeft);
                 btn->setSize(QSize(layoutMetric(LM_ButtonWidth, true, btn), layoutMetric(LM_ButtonHeight, true, btn)));
-                // will be shown later on window registration
-                if (btn->type() == AppMenuButton && !isPreview() && !wrapper->menuAvailable()) {
-                    btn->hide();
-                } else {
-                    btn->show();
-                }
+                btn->show();
 
                 btnContainer.append(btn);
             }
@@ -564,7 +538,7 @@ void KCommonDecoration::calcHiddenButtons()
     btnHideLastWidth = width();
 
     //Hide buttons in the following order:
-    KCommonDecorationButton* btnArray[] = { m_button[HelpButton], m_button[AppMenuButton], m_button[ShadeButton], m_button[BelowButton],
+    KCommonDecorationButton* btnArray[] = { m_button[HelpButton], m_button[ShadeButton], m_button[BelowButton],
                                             m_button[AboveButton], m_button[OnAllDesktopsButton], m_button[MaxButton],
                                             m_button[MinButton], m_button[MenuButton], m_button[CloseButton]
                                           };
@@ -589,8 +563,7 @@ void KCommonDecoration::calcHiddenButtons()
             if (! btnArray[i]->isHidden())
                 break; // all buttons shown...
 
-            if (btnArray[i]->type() != AppMenuButton || wrapper->menuAvailable())
-                btnArray[i]->show();
+            btnArray[i]->show();
         }
     }
 }
@@ -788,34 +761,6 @@ void KCommonDecoration::doShowWindowMenu()
     showWindowMenu(QRect(menutop, menubottom));
 }
 
-
-void KCommonDecoration::appMenuButtonPressed()
-{
-    QRect menuRect = m_button[AppMenuButton]->rect();
-    wrapper->showApplicationMenu(m_button[AppMenuButton]->mapToGlobal(menuRect.bottomLeft()));
-
-    KDecorationFactory* f = factory();
-    if (!f->exists(decoration()))   // 'this' was deleted
-        return;
-    m_button[AppMenuButton]->setDown(false);
-}
-
-void KCommonDecoration::slotAppMenuAvailable()
-{
-    if (m_button[AppMenuButton]) {
-        m_button[AppMenuButton]->show();
-        updateLayout();
-    }
-}
-
-void KCommonDecoration::slotAppMenuUnavailable()
-{
-    if (m_button[AppMenuButton]) {
-        m_button[AppMenuButton]->hide();
-        updateLayout();
-    }
-}
-
 void KCommonDecoration::resizeEvent(QResizeEvent */*e*/)
 {
     if (decorationBehaviour(DB_ButtonHide))
@@ -986,7 +931,7 @@ bool KCommonDecoration::eventFilter(QObject* o, QEvent* e)
 }
 
 const int SUPPORTED_WINDOW_TYPES_MASK = NET::NormalMask | NET::DesktopMask | NET::DockMask
-                                        | NET::ToolbarMask | NET::MenuMask | NET::DialogMask /*| NET::OverrideMask*/ | NET::TopMenuMask
+                                        | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
                                         | NET::UtilityMask | NET::SplashMask;
 
 bool KCommonDecoration::isToolWindow() const
@@ -1118,14 +1063,6 @@ void KCommonDecorationButton::mouseReleaseEvent(QMouseEvent* e)
 
 
 // *** wrap everything from KDecoration *** //
-bool KCommonDecoration::drawbound(const QRect&, bool)
-{
-    return false;
-}
-bool KCommonDecoration::windowDocked(Position)
-{
-    return false;
-}
 const KDecorationOptions* KCommonDecoration::options()
 {
     return KDecoration::options();
@@ -1357,94 +1294,5 @@ KDecoration* KCommonDecoration::decoration()
     return wrapper;
 }
 
-
-KCommonDecorationUnstable::KCommonDecorationUnstable(KDecorationBridge* bridge, KDecorationFactory* factory)
-    : KCommonDecoration(bridge, factory)
-{
-    Q_ASSERT(dynamic_cast<const KDecorationUnstable*>(decoration()));
-}
-
-KCommonDecorationUnstable::~KCommonDecorationUnstable()
-{
-}
-
-// All copied from kdecoration.cpp
-bool KCommonDecorationUnstable::compositingActive() const
-{
-    return static_cast<const KDecorationUnstable*>(decoration())->compositingActive();
-}
-
-// Window tabbing
-
-int KCommonDecorationUnstable::tabCount() const
-{
-    return static_cast<const KDecorationUnstable*>(decoration())->tabCount();
-}
-
-QString KCommonDecorationUnstable::caption(int idx) const
-{
-    return static_cast<const KDecorationUnstable*>(decoration())->caption(idx);
-}
-
-QIcon KCommonDecorationUnstable::icon(int idx) const
-{
-    return static_cast<const KDecorationUnstable*>(decoration())->icon(idx);
-}
-
-long KCommonDecorationUnstable::tabId(int idx) const
-{
-    return static_cast<const KDecorationUnstable*>(decoration())->tabId(idx);
-}
-
-long KCommonDecorationUnstable::currentTabId() const
-{
-    return static_cast<const KDecorationUnstable*>(decoration())->currentTabId();
-}
-
-void KCommonDecorationUnstable::setCurrentTab(long id)
-{
-    static_cast<KDecorationUnstable*>(decoration())->setCurrentTab(id);
-}
-
-void KCommonDecorationUnstable::tab_A_before_B(long A, long B)
-{
-    static_cast<KDecorationUnstable*>(decoration())->tab_A_before_B(A, B);
-}
-
-void KCommonDecorationUnstable::tab_A_behind_B(long A, long B)
-{
-    static_cast<KDecorationUnstable*>(decoration())->tab_A_behind_B(A, B);
-}
-
-void KCommonDecorationUnstable::untab(long id, const QRect& newGeom)
-{
-    static_cast<KDecorationUnstable*>(decoration())->untab(id, newGeom);
-}
-
-void KCommonDecorationUnstable::closeTab(long id)
-{
-    static_cast<KDecorationUnstable*>(decoration())->closeTab(id);
-}
-
-void KCommonDecorationUnstable::closeTabGroup()
-{
-    static_cast<KDecorationUnstable*>(decoration())->closeTabGroup();
-}
-
-void KCommonDecorationUnstable::showWindowMenu(const QPoint &pos, long id)
-{
-    static_cast<KDecorationUnstable*>(decoration())->showWindowMenu(pos, id);
-}
-
-KDecoration::WindowOperation KCommonDecorationUnstable::buttonToWindowOperation(Qt::MouseButtons button)
-{
-    return static_cast<KDecorationUnstable*>(decoration())->buttonToWindowOperation(button);
-}
-
-bool KCommonDecorationUnstable::eventFilter(QObject* o, QEvent* e)
-{
-    return KCommonDecoration::eventFilter(o, e);
-}
-
 // kate: space-indent on; indent-width 4; mixedindent off; indent-mode cstyle;
 
