@@ -32,7 +32,7 @@ DEALINGS IN THE SOFTWARE.
 #include <assert.h>
 #include <X11/Xlib.h>
 #include <fixx11h.h>
-#include <QX11Info>
+#include <qx11info_x11.h>
 
 #include "kdecorationfactory.h"
 #include "kdecorationbridge.h"
@@ -227,16 +227,6 @@ void KDecoration::showWindowMenu(QPoint pos)
     bridge_->showWindowMenu(pos);
 }
 
-void KDecoration::showApplicationMenu(const QPoint &p)
-{
-    bridge_->showApplicationMenu(p);
-}
-
-bool KDecoration::menuAvailable() const
-{
-    return bridge_->menuAvailable();
-}
-
 void KDecoration::performWindowOperation(WindowOperation op)
 {
     bridge_->performWindowOperation(op);
@@ -340,26 +330,6 @@ void KDecoration::setKeepBelow(bool set)
     bridge_->setKeepBelow(set);
 }
 
-void KDecoration::emitKeepAboveChanged(bool above)
-{
-    keepAboveChanged(above);
-}
-
-void KDecoration::emitKeepBelowChanged(bool below)
-{
-    keepBelowChanged(below);
-}
-
-bool KDecoration::drawbound(const QRect&, bool)
-{
-    return false;
-}
-
-bool KDecoration::windowDocked(Position)
-{
-    return false;
-}
-
 void KDecoration::reset(unsigned long)
 {
 }
@@ -411,10 +381,7 @@ KDecoration::Position KDecoration::mousePosition(const QPoint& p) const
 
 QRect KDecoration::transparentRect() const
 {
-    if (KDecorationBridgeUnstable *bridge2 = dynamic_cast<KDecorationBridgeUnstable*>(bridge_))
-        return bridge2->transparentRect();
-    else
-        return QRect();
+    return bridge_->transparentRect();
 }
 
 void KDecoration::setAlphaEnabled(bool enabled)
@@ -431,92 +398,83 @@ bool KDecoration::isAlphaEnabled() const
     return d->alphaEnabled;
 }
 
-KDecorationUnstable::KDecorationUnstable(KDecorationBridge* bridge, KDecorationFactory* factory)
-    : KDecoration(bridge, factory)
+bool KDecoration::compositingActive() const
 {
+    return bridge_->compositingActive();
 }
 
-KDecorationUnstable::~KDecorationUnstable()
-{
-}
-
-bool KDecorationUnstable::compositingActive() const
-{
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->compositingActive();
-}
-
-void KDecorationUnstable::padding(int &left, int &right, int &top, int &bottom) const
+void KDecoration::padding(int &left, int &right, int &top, int &bottom) const
 {
     left = right = top = bottom = 0;
 }
 
 //BEGIN Window tabbing
 
-int KDecorationUnstable::tabCount() const
+int KDecoration::tabCount() const
 {
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->tabCount();
+    return bridge_->tabCount();
 }
 
-long KDecorationUnstable::tabId(int idx) const
+long KDecoration::tabId(int idx) const
 {
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->tabId(idx);
+    return bridge_->tabId(idx);
 }
 
-QString KDecorationUnstable::caption(int idx) const
+QString KDecoration::caption(int idx) const
 {
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->caption(idx);
+    return bridge_->caption(idx);
 }
 
-QIcon KDecorationUnstable::icon(int idx) const
+QIcon KDecoration::icon(int idx) const
 {
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->icon(idx);
+    return bridge_->icon(idx);
 }
 
-long KDecorationUnstable::currentTabId() const
+long KDecoration::currentTabId() const
 {
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->currentTabId();
+    return bridge_->currentTabId();
 }
 
-void KDecorationUnstable::setCurrentTab(long id)
+void KDecoration::setCurrentTab(long id)
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->setCurrentTab(id);
+    bridge_->setCurrentTab(id);
 }
 
-void KDecorationUnstable::tab_A_before_B(long A, long B)
+void KDecoration::tab_A_before_B(long A, long B)
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->tab_A_before_B(A, B);
+    bridge_->tab_A_before_B(A, B);
 }
 
-void KDecorationUnstable::tab_A_behind_B(long A, long B)
+void KDecoration::tab_A_behind_B(long A, long B)
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->tab_A_behind_B(A, B);
+    bridge_->tab_A_behind_B(A, B);
 }
 
-void KDecorationUnstable::untab(long id, const QRect& newGeom)
+void KDecoration::untab(long id, const QRect& newGeom)
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->untab(id, newGeom);
+    bridge_->untab(id, newGeom);
 }
 
-void KDecorationUnstable::closeTab(long id)
+void KDecoration::closeTab(long id)
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->closeTab(id);
+    bridge_->closeTab(id);
 }
 
-void KDecorationUnstable::closeTabGroup()
+void KDecoration::closeTabGroup()
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->closeTabGroup();
+    bridge_->closeTabGroup();
 }
 
-void KDecorationUnstable::showWindowMenu(const QPoint &pos, long id)
+void KDecoration::showWindowMenu(const QPoint &pos, long id)
 {
-    static_cast< KDecorationBridgeUnstable* >(bridge_)->showWindowMenu(pos, id);
+    bridge_->showWindowMenu(pos, id);
 }
 
 //END tabbing
 
-KDecoration::WindowOperation KDecorationUnstable::buttonToWindowOperation(Qt::MouseButtons button)
+KDecoration::WindowOperation KDecoration::buttonToWindowOperation(Qt::MouseButtons button)
 {
-    return static_cast< KDecorationBridgeUnstable* >(bridge_)->buttonToWindowOperation(button);
+    return bridge_->buttonToWindowOperation(button);
 }
 
 QRegion KDecoration::region(KDecorationDefines::Region)
@@ -619,16 +577,10 @@ KDecorationOptions::BorderSize KDecorationOptions::preferredBorderSize(KDecorati
     return d->cached_border_size;
 }
 
-bool KDecorationOptions::moveResizeMaximizedWindows() const
-{
-    // TODO KF5: remove function with API break
-    return false;
-}
-
 KDecorationDefines::WindowOperation KDecorationOptions::operationMaxButtonClick(Qt::MouseButtons button) const
 {
     return button == Qt::RightButton ? d->opMaxButtonRightClick :
-           button == Qt::MidButton ?   d->opMaxButtonMiddleClick :
+           button == Qt::MiddleButton ?   d->opMaxButtonMiddleClick :
            d->opMaxButtonLeftClick;
 }
 
@@ -677,4 +629,4 @@ int decoration_bridge_version()
 
 }
 
-#include "kdecoration.moc"
+#include "moc_kdecoration.cpp"
