@@ -25,14 +25,14 @@ DEALINGS IN THE SOFTWARE.
 #ifndef KDECORATION_H
 #define KDECORATION_H
 
+#include <kwinglobals.h>
+
 #include <QtGui/QColor>
 #include <QtGui/QFont>
-#include <QtCore/QObject>
+#include <QObject>
 #include <QtGui/QIcon>
 #include <netwm_def.h>
-#include <QtGui/QMouseEvent>
-
-#define KWIN_EXPORT KDE_EXPORT
+#include <QtGui/qevent.h>
 
 #define KWIN_DECORATION_API_VERSION 1
 
@@ -47,6 +47,11 @@ DEALINGS IN THE SOFTWARE.
         KWIN_EXPORT int decoration_version() { return KWIN_DECORATION_API_VERSION; } \
     }
 
+#define KWIN_DECORATION_BRIDGE_API_VERSION 1
+extern "C" {
+    int decoration_bridge_version();
+}
+
 class KConfig;
 
 /** @defgroup kdecoration KWin decorations library */
@@ -93,6 +98,19 @@ public:
         MaximizeFull = MaximizeVertical | MaximizeHorizontal
     };
 
+    enum QuickTileFlag {
+        QuickTileNone = 0,
+        QuickTileLeft = 1,
+        QuickTileRight = 1<<1,
+        QuickTileTop = 1<<2,
+        QuickTileBottom = 1<<3,
+        QuickTileHorizontal = QuickTileLeft|QuickTileRight,
+        QuickTileVertical = QuickTileTop|QuickTileBottom,
+        QuickTileMaximize = QuickTileLeft|QuickTileRight|QuickTileTop|QuickTileBottom
+    };
+
+    Q_DECLARE_FLAGS(QuickTileMode, QuickTileFlag)
+
     enum WindowOperation {
         MaximizeOp = 5000,
         RestoreOp,
@@ -121,19 +139,7 @@ public:
         CloseTabGroupOp, // Close the group
         ActivateNextTabOp, // Move left in the group
         ActivatePreviousTabOp, // Move right in the group
-        ///< @deprecated, tiling got removed in 4.10
-        ToggleClientTiledStateOp, // put a floating client into tiling
         TabDragOp,
-
-        //BEGIN ABI stability stuff
-        // NOTICE for ABI stability
-        // TODO remove with mandatory version tagging fo 4.9.x or 4.10
-        /** @deprecated ABI compatibility only - don't use */
-        RemoveClientFromGroupOp = RemoveTabFromGroupOp, // Remove from group
-        CloseClientGroupOp = CloseTabGroupOp, // Close the group
-        MoveClientInGroupLeftOp = ActivateNextTabOp, // Move left in the group
-        MoveClientInGroupRightOp = ActivatePreviousTabOp // Move right in the group
-        //END ABI stability stuff
     };
     /**
      * Basic color types that should be recognized by all decoration styles.
@@ -176,6 +182,8 @@ public:
         BorderHuge,      ///< Huge borders
         BorderVeryHuge,  ///< Very huge borders
         BorderOversized, ///< Oversized borders
+        BorderNoSides,   ///< No borders on sides @since 4.11
+        BorderNone,      ///< No borders except title @since 4.11
         BordersCount     ///< @internal
     };
 
@@ -184,62 +192,35 @@ public:
      * @see KDecorationFactory::supports()
      */
     enum Ability {
-        // announce
-        AbilityAnnounceButtons = 0, ///< decoration supports AbilityButton* values (always use)
-        AbilityAnnounceColors = 1, ///< decoration supports AbilityColor* values (always use), @deprecated @todo remove KDE5
         // buttons
-        AbilityButtonMenu = 1000,   ///< decoration supports the window menu button
-        AbilityButtonOnAllDesktops = 1001, ///< decoration supports the on all desktops button
-        AbilityButtonSpacer = 1002, ///< decoration supports inserting spacers between buttons
-        AbilityButtonHelp = 1003,   ///< decoration supports what's this help button
-        AbilityButtonMinimize = 1004,  ///< decoration supports a minimize button
-        AbilityButtonMaximize = 1005, ///< decoration supports a maximize button
-        AbilityButtonClose = 1006, ///< decoration supports a close button
-        AbilityButtonAboveOthers = 1007, ///< decoration supports an above button
-        AbilityButtonBelowOthers = 1008, ///< decoration supports a below button
-        AbilityButtonShade = 1009, ///< decoration supports a shade button
-        AbilityButtonResize = 1010, ///< decoration supports a resize button
-        AbilityButtonApplicationMenu = 1011,   ///< decoration supports the application menu button
-        // colors
-        AbilityColorTitleBack = 2000, ///< decoration supports titlebar background color, @deprecated @todo remove KDE5
-        ABILITYCOLOR_FIRST = AbilityColorTitleBack, ///< @internal, @deprecated @todo remove KDE5
-        AbilityColorTitleFore = 2001, ///< decoration supports titlebar foreground color, @deprecated @todo remove KDE5
-        AbilityColorTitleBlend = 2002, ///< decoration supports second titlebar background color, @deprecated @todo remove KDE5
-        AbilityColorFrame = 2010, ///< decoration supports frame color, @deprecated @todo remove KDE5
-        AbilityColorHandle = 2011, ///< decoration supports resize handle color, @deprecated @todo remove KDE5
-        AbilityColorButtonBack = 2020, ///< decoration supports button background color, @deprecated @todo remove KDE5
-        AbilityColorButtonFore = 2021, ///< decoration supports button foreground color, @deprecated @todo remove KDE5
-        ABILITYCOLOR_END, ///< @internal, @deprecated @todo remove KDE5
+        AbilityButtonMenu = 0,             ///< decoration supports the window menu button
+        AbilityButtonOnAllDesktops = 1,    ///< decoration supports the on all desktops button
+        AbilityButtonSpacer = 2,           ///< decoration supports inserting spacers between buttons
+        AbilityButtonHelp = 3,             ///< decoration supports what's this help button
+        AbilityButtonMinimize = 4,         ///< decoration supports a minimize button
+        AbilityButtonMaximize = 5,         ///< decoration supports a maximize button
+        AbilityButtonClose = 6,            ///< decoration supports a close button
+        AbilityButtonAboveOthers = 7,      ///< decoration supports an above button
+        AbilityButtonBelowOthers = 8,      ///< decoration supports a below button
+        AbilityButtonShade = 9,            ///< decoration supports a shade button
+        AbilityButtonResize = 10,          ///< decoration supports a resize button
         // compositing
-        AbilityProvidesShadow = 3000, ///< The decoration draws its own shadows.
+        AbilityProvidesShadow = 11,        ///< The decoration draws its own shadows.
         ///  @since 4.3
-        AbilityUsesAlphaChannel = 3001, ///< The decoration isn't clipped to the mask when compositing is enabled.
+        AbilityUsesAlphaChannel = 12,      ///< The decoration isn't clipped to the mask when compositing is enabled.
         ///  The mask is still used to define the input region and the blurred
         ///  region, when the blur plugin is enabled.
         ///  @since 4.3
-        AbilityExtendIntoClientArea = 3002, ///< The decoration respects transparentRect()
-        ///  @since 4.4
-        AbilityUsesBlurBehind = 3003, ///< The decoration wants the background to be blurred, when the blur plugin is enabled.
+        AbilityExtendIntoClientArea = 13,  ///< The decoration respects transparentRect()
         /// @since 4.6
-        AbilityAnnounceAlphaChannel = 4004, ///< The decoration can tell whether it currently uses an alpha channel or not. Requires AbilityUsesAlphaChannel.
+        AbilityAnnounceAlphaChannel = 14,  ///< The decoration can tell whether it currently uses an alpha channel or not. Requires AbilityUsesAlphaChannel.
         /// @since 4.10
         // Tabbing
-        AbilityTabbing = 4000, ///< The decoration supports tabbing
-        // TODO colors for individual button types
-        ABILITY_DUMMY = 10000000,
-
-        //BEGIN ABI stability stuff
-        // NOTICE for ABI stability
-        // TODO remove with mandatory version tagging fo 4.9.x or 4.10
-        /** @deprecated ABI compatibility only - don't use */
-        AbilityClientGrouping = AbilityTabbing
-        //END ABI stability stuff
+        AbilityTabbing = 15,               ///< The decoration supports tabbing
     };
 
-    enum Requirement { REQUIREMENT_DUMMY = 1000000 };
-
     /**
-     * Regions that can be returned by KDecorationUnstable::region().
+     * Regions that can be returned by KDecoration::region().
      */
     enum Region {
         /**
@@ -262,45 +243,15 @@ public:
     /**
      * Returns the mimeType used to drag and drop clientGroupItems
      */
-    //BEGIN ABI stability stuff
-    // NOTICE for ABI stability
-    // TODO remove with mandatory version tagging fo 4.9.x or 4.10
-    /** @deprecated ABI compatibility only - don't use */
-    static QString clientGroupItemDragMimeType() { return tabDragMimeType(); }
-    //END ABI stability stuff
     static QString tabDragMimeType();
 
 };
 
-//BEGIN ABI stability stuff
-// NOTICE for ABI stability
-// TODO remove with mandatory version tagging fo 4.9.x or 4.10
-/** @deprecated ABI compatibility only - don't use */
-class KWIN_EXPORT ClientGroupItem
-{
-public:
-    ClientGroupItem(QString t, QIcon i) {
-        title_ = t;
-        icon_ = i;
-    }
-    inline QIcon icon() const {
-        return icon_;
-    }
-    inline QString title() const {
-        return title_;
-    }
-private:
-    QString title_;
-    QIcon icon_;
-};
-//END ABI stability stuff
-
 class KDecorationProvides
     : public KDecorationDefines
 {
 public:
     virtual ~KDecorationProvides() {}
-    virtual bool provides(Requirement req) = 0;
 };
 
 /**
@@ -355,7 +306,6 @@ public:
      * If customButtonPositions() returns true, titleButtonsLeft
      * returns which buttons should be on the left side of the titlebar from left
      * to right. Characters in the returned string have this meaning :
-     * @li 'N' application menu button
      * @li 'M' window menu button
      * @li 'S' on_all_desktops button
      * @li 'H' quickhelp button
@@ -385,7 +335,7 @@ public:
      * in titleButtonsLeft().
      *
      * The default ( which is also returned if customButtonPositions returns false )
-     * is "HIA__X".
+     * is "HIAX".
      * Unknown buttons in the returned string must be ignored.
      * The changed flags for this setting is SettingButtons.
      */
@@ -412,14 +362,6 @@ public:
      */
     BorderSize preferredBorderSize(KDecorationFactory* factory) const;
 
-    /*
-    * When this functions returns false, moving and resizing of maximized windows
-    * is not allowed, and therefore the decoration is allowed to turn off (some of)
-    * its borders.
-    * The changed flags for this setting is SettingButtons.
-    */
-    bool moveResizeMaximizedWindows() const;
-
     /**
      * @internal
      */
@@ -503,6 +445,13 @@ public:
     /**
      * Returns @a true if the decorated window can be minimized by the user.
      */
+
+    /**
+     * Returns the current quicktiling mode of the decorated window.
+     * (window is places into one of the corners or edges)
+     */
+    QuickTileMode quickTileMode() const;
+
     bool isMinimizable() const;
     /**
      * Return @a true if the decorated window can show context help
@@ -574,7 +523,7 @@ public:
      * @code
      * const unsigned long supported_types = NET::NormalMask | NET::DesktopMask
      *  | NET::DockMask | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
-     *  | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask;
+     *  | NET::UtilityMask | NET::SplashMask;
      *
      * NET::WindowType type = windowType( supported_types );
      *
@@ -625,14 +574,6 @@ public:
      * Overloaded version of the above.
      */
     void showWindowMenu(QPoint pos);
-    /**
-     * show application menu at p
-     */
-    void showApplicationMenu(const QPoint& p);
-    /**
-     * Returns @a true if menu available for client
-     */
-    bool menuAvailable() const;
     /**
      * This function performs the given window operation. This function may destroy
      * the current decoration object, just like showWindowMenu().
@@ -778,272 +719,8 @@ public:
      * used to keep the decorated window at least as large.
      */
     virtual QSize minimumSize() const = 0;
-    /**
-     * This function is called whenever the window either becomes or stops being active.
-     * Use isActive() to find out the current state.
-     */
-    virtual void activeChange() = 0;
-    /**
-     * This function is called whenever the caption changes. Use caption() to get it.
-     */
-    virtual void captionChange() = 0;
-    /**
-     * This function is called whenever the window icon changes. Use icon() to get it.
-     */
-    virtual void iconChange() = 0;
-    /**
-     * This function is called whenever the maximalization state of the window changes.
-     * Use maximizeMode() to get the current state.
-     */
-    virtual void maximizeChange() = 0;
-    /**
-     * This function is called whenever the desktop for the window changes. Use
-     * desktop() or isOnAllDesktops() to find out the current desktop
-     * on which the window is.
-     */
-    virtual void desktopChange() = 0;
-    /**
-     * This function is called whenever the window is shaded or unshaded. Use
-     * isShade() to get the current state.
-     */
-    virtual void shadeChange() = 0;
 
-Q_SIGNALS:
-    /**
-     * This signal is emitted whenever the window's keep-above state changes.
-     */
-    void keepAboveChanged(bool);
-    /**
-     * This signal is emitted whenever the window's keep-below state changes.
-     */
-    void keepBelowChanged(bool);
-
-    /**
-     * This signal is emitted whenever application menu is closed
-     * Application menu button may need to be modified on this signal
-     */
-    void menuHidden();
-    /**
-     * This signal is emitted whenever application want to show it menu
-     */
-    void showRequest();
-    /**
-     * This signal is emitted whenever application menu becomes available
-     */
-    void appMenuAvailable();
-    /**
-     * This signal is emitted whenever application menu becomes unavailable
-     */
-    void appMenuUnavailable();
-
-    /**
-     * This signal is emitted whenever the decoration changes it's alpha enabled
-     * change. Only relevant in case the decoration provides AbilityAnnounceAlphaChannel.
-     *
-     * @param enabled The new state of alpha channel usage
-     * @see setAlphaEnabled
-     * @see isAlphaEnabled
-     * @since 4.10
-     **/
-    void alphaEnabledChanged(bool enabled);
-
-public:
-    /**
-     * This method is not any more invoked from KWin core since version 4.8.
-     * There is no need to implement it.
-     *
-     * @param geom  The geometry at this the bound should be drawn
-     * @param clear @a true if the bound should be cleared (when doing the usual XOR
-     *              painting this argument can be simply ignored)
-     *
-     * @see geometry()
-     * @deprecated
-     */
-    virtual bool drawbound(const QRect& geom, bool clear);
-    /**
-     * @internal Reserved.
-     */
-    // TODO position will need also values for top+left+bottom etc. docking ?
-    virtual bool windowDocked(Position side);
-    /**
-     * This function is called to reset the decoration on settings changes.
-     * It is usually invoked by calling KDecorationFactory::resetDecorations().
-     *
-     * @param changed Specifies which settings were changed, given by the SettingXXX masks
-     */
-    virtual void reset(unsigned long changed);
-
-    // special
-
-    /**
-     * This should be the first function called in init() to specify
-     * the main widget of the decoration. The widget should be created
-     * with parent specified by initialParentWidget() and flags
-     * specified by initialWFlags().
-     */
-    void setMainWidget(QWidget*);
-    /**
-     * Convenience functions that creates and sets a main widget as necessary.
-     * In such case, it's usually needed to install an event filter
-     * on the main widget to receive important events on it.
-     *
-     * @param flags Additional widget flags for the main widget. Note that only
-     *              flags that affect widget drawing are allowed. Window type flags
-     *              like WX11BypassWM or WStyle_NoBorder are forbidden.
-     */
-    void createMainWidget(Qt::WFlags flags = 0);
-    /**
-     * The parent widget that should be used for the main widget.
-     */
-    QWidget* initialParentWidget() const;
-    /**
-     * The flags that should be used when creating the main widget.
-     * It is possible to add more flags when creating the main widget, but only flags
-     * that affect widget drawing are allowed. Window type flags like WX11BypassWM
-     * or WStyle_NoBorder are forbidden.
-     */
-    Qt::WFlags initialWFlags() const;
-    /**
-     * Returns the main widget for the decoration.
-     */
-    QWidget* widget();
-    /**
-     * Returns the main widget for the decoration.
-     */
-    const QWidget* widget() const;
-    /**
-     * Returns the factory that created this decoration.
-     */
-    KDecorationFactory* factory() const;
-    /**
-     * Performs X server grab. It is safe to call it several times in a row.
-     */
-    void grabXServer();
-    /**
-     * Ungrabs X server (if the number of ungrab attempts matches the number of grab attempts).
-     */
-    void ungrabXServer();
-public Q_SLOTS:
-    // requests from decoration
-
-    /**
-     * This function can be called by the decoration to request
-     * closing of the decorated window. Note that closing the window
-     * also involves destroying the decoration.
-     * IMPORTANT: This function may destroy the current decoration object,
-     * just like showWindowMenu().
-     */
-    void closeWindow();
-    /**
-     * Changes the maximize mode of the decorated window. This function should
-     * be preferred to the other maximize() overload for reacting on clicks
-     * on the maximize titlebar button.
-     */
-    void maximize(Qt::MouseButtons button);
-    /**
-     * Set the maximize mode of the decorated window.
-     * @param mode The maximization mode to be set.
-     */
-    void maximize(MaximizeMode mode);
-    /**
-     * Minimize the decorated window.
-     */
-    void minimize();
-    /**
-     * Start showing context help in the window (i.e. the mouse will enter
-     * the what's this mode).
-     */
-    void showContextHelp();
-    /**
-     * Moves the window to the given desktop. Use NET::OnAllDesktops for making
-     * the window appear on all desktops.
-     */
-    void setDesktop(int desktop);
-    /**
-     * This function toggles the on-all-desktops state of the decorated window.
-     */
-    void toggleOnAllDesktops(); // convenience
-    /**
-     * This function performs the operation configured as titlebar double click
-     * operation.
-     */
-    void titlebarDblClickOperation();
-    /**
-     * This function performs the operation configured as titlebar wheel mouse
-     * operation.
-     * @param delta the mouse wheel delta
-     */
-    void titlebarMouseWheelOperation(int delta);
-    /**
-     * Shades or unshades the decorated window.
-     * @param set Whether the window should be shaded
-     */
-    void setShade(bool set);
-    /**
-     * Sets or reset keeping this window above others.
-     * @param set Whether to keep the window above others
-     */
-    void setKeepAbove(bool set);
-    /**
-     * Sets or reset keeping this window below others.
-     * @param set Whether to keep the window below others
-     */
-    void setKeepBelow(bool set);
-    /**
-     * @internal
-     */
-    void emitKeepAboveChanged(bool above);
-    /**
-     * @internal
-     */
-    void emitKeepBelowChanged(bool below);
-
-protected Q_SLOTS:
-    /**
-     * A decoration providing AbilityAnnounceAlphaChannel can use this method to enable/disable the
-     * use of alpha channel. This is useful if for a normal window the decoration renders its own
-     * shadows or round corners and thus needs alpha channel. But in maximized state the decoration
-     * is fully opaque. By disabling the alpha channel the Compositor can optimize the rendering.
-     *
-     * @param enabled If @c true alpha channel is enabled, if @c false alpha channel is disabled
-     * @see isAlphaEnabled
-     * @see alphaEnabledChanged
-     * @since 4.10
-     **/
-    void setAlphaEnabled(bool enabled);
-    /**
-     * This slot can be reimplemented to return the regions defined
-     * by KDecorationDefines::Region.
-     *
-     * The default implementation always returns an empty region.
-     *
-     * @since 4.8
-     */
-    QRegion region(KDecorationDefines::Region r);
-
-private:
-    KDecorationBridge* bridge_;
-    QWidget* w_;
-    KDecorationFactory* factory_;
-    friend class KDecorationOptions; // for options_
-    friend class KDecorationUnstable; // for bridge_
-    static KDecorationOptions* options_;
-    KDecorationPrivate* d;
-
-};
-
-/**
- * @warning THIS CLASS IS UNSTABLE!
- */
-class KWIN_EXPORT KDecorationUnstable
-    : public KDecoration
-{
-    Q_OBJECT
-
-public:
-    KDecorationUnstable(KDecorationBridge* bridge, KDecorationFactory* factory);
-    virtual ~KDecorationUnstable();
-    /**
+        /**
      * This function can return additional padding values that are added outside the
      * borders of the window, and can be used by the decoration if it wants to paint
      * outside the frame.
@@ -1119,17 +796,228 @@ public:
      * global coordinates specified by \p pos.
      */
     void showWindowMenu(const QPoint& pos, long id);
-    /**
-     * unshadow virtuals
-     */
-    using KDecoration::caption;
-    using KDecoration::icon;
-    using KDecoration::showWindowMenu;
     /**
      * Determine which action the user has mapped \p button to. Useful for determining whether
      * a button press was for window tab dragging or for displaying the client menu.
      */
     WindowOperation buttonToWindowOperation(Qt::MouseButtons button);
+
+public Q_SLOTS:
+    /**
+     * This function is called whenever the window either becomes or stops being active.
+     * Use isActive() to find out the current state.
+     */
+    virtual void activeChange() = 0;
+    /**
+     * This function is called whenever the caption changes. Use caption() to get it.
+     */
+    virtual void captionChange() = 0;
+    /**
+     * This function is called whenever the window icon changes. Use icon() to get it.
+     */
+    virtual void iconChange() = 0;
+    /**
+     * This function is called whenever the maximalization state of the window changes.
+     * Use maximizeMode() to get the current state.
+     */
+    virtual void maximizeChange() = 0;
+    /**
+     * This function is called whenever the desktop for the window changes. Use
+     * desktop() or isOnAllDesktops() to find out the current desktop
+     * on which the window is.
+     */
+    virtual void desktopChange() = 0;
+    /**
+     * This function is called whenever the window is shaded or unshaded. Use
+     * isShade() to get the current state.
+     */
+    virtual void shadeChange() = 0;
+
+Q_SIGNALS:
+    /**
+     * This signal is emitted whenever the window's keep-above state changes.
+     */
+    void keepAboveChanged(bool);
+    /**
+     * This signal is emitted whenever the window's keep-below state changes.
+     */
+    void keepBelowChanged(bool);
+
+    /**
+     * This signal is emitted whenever the decoration changes it's alpha enabled
+     * change. Only relevant in case the decoration provides AbilityAnnounceAlphaChannel.
+     *
+     * @param enabled The new state of alpha channel usage
+     * @see setAlphaEnabled
+     * @see isAlphaEnabled
+     * @since 4.10
+     **/
+    void alphaEnabledChanged(bool enabled);
+
+public:
+    /**
+     * This function is called to reset the decoration on settings changes.
+     * It is usually invoked by calling KDecorationFactory::resetDecorations().
+     *
+     * @param changed Specifies which settings were changed, given by the SettingXXX masks
+     */
+    virtual void reset(unsigned long changed);
+
+    // special
+
+    /**
+     * This should be the first function called in init() to specify
+     * the main widget of the decoration. The widget should be created
+     * with parent specified by initialParentWidget() and flags
+     * specified by initialWFlags().
+     */
+    void setMainWidget(QWidget*);
+    /**
+     * Convenience functions that creates and sets a main widget as necessary.
+     * In such case, it's usually needed to install an event filter
+     * on the main widget to receive important events on it.
+     *
+     * @param flags Additional widget flags for the main widget. Note that only
+     *              flags that affect widget drawing are allowed. Window type flags
+     *              like WX11BypassWM or WStyle_NoBorder are forbidden.
+     */
+    void createMainWidget(Qt::WFlags flags = 0);
+    /**
+     * The parent widget that should be used for the main widget.
+     */
+    QWidget* initialParentWidget() const;
+    /**
+     * The flags that should be used when creating the main widget.
+     * It is possible to add more flags when creating the main widget, but only flags
+     * that affect widget drawing are allowed. Window type flags like WX11BypassWM
+     * or WStyle_NoBorder are forbidden.
+     */
+    Qt::WFlags initialWFlags() const;
+    /**
+     * Returns the main widget for the decoration.
+     */
+    QWidget* widget();
+    /**
+     * Returns the main widget for the decoration.
+     */
+    const QWidget* widget() const;
+    /**
+     * Returns the factory that created this decoration.
+     */
+    KDecorationFactory* factory() const;
+    /**
+     * Performs X server grab. It is safe to call it several times in a row.
+     */
+    void grabXServer();
+    /**
+     * Ungrabs X server (if the number of ungrab attempts matches the number of grab attempts).
+     */
+    void ungrabXServer();
+
+public: // invokables; runtime resolution
+    /**
+     * reimplement this invokable to signal the core where the titlebar is (usually PositionTop)
+     */
+    Q_INVOKABLE KDecorationDefines::Position titlebarPosition();
+
+public Q_SLOTS:
+    // requests from decoration
+
+    /**
+     * This function can be called by the decoration to request
+     * closing of the decorated window. Note that closing the window
+     * also involves destroying the decoration.
+     * IMPORTANT: This function may destroy the current decoration object,
+     * just like showWindowMenu().
+     */
+    void closeWindow();
+    /**
+     * Changes the maximize mode of the decorated window. This function should
+     * be preferred to the other maximize() overload for reacting on clicks
+     * on the maximize titlebar button.
+     */
+    void maximize(Qt::MouseButtons button);
+    /**
+     * Set the maximize mode of the decorated window.
+     * @param mode The maximization mode to be set.
+     */
+    void maximize(MaximizeMode mode);
+    /**
+     * Minimize the decorated window.
+     */
+    void minimize();
+    /**
+     * Start showing context help in the window (i.e. the mouse will enter
+     * the what's this mode).
+     */
+    void showContextHelp();
+    /**
+     * Moves the window to the given desktop. Use NET::OnAllDesktops for making
+     * the window appear on all desktops.
+     */
+    void setDesktop(int desktop);
+    /**
+     * This function toggles the on-all-desktops state of the decorated window.
+     */
+    void toggleOnAllDesktops(); // convenience
+    /**
+     * This function performs the operation configured as titlebar double click
+     * operation.
+     */
+    void titlebarDblClickOperation();
+    /**
+     * This function performs the operation configured as titlebar wheel mouse
+     * operation.
+     * @param delta the mouse wheel delta
+     */
+    void titlebarMouseWheelOperation(int delta);
+    /**
+     * Shades or unshades the decorated window.
+     * @param set Whether the window should be shaded
+     */
+    void setShade(bool set);
+    /**
+     * Sets or reset keeping this window above others.
+     * @param set Whether to keep the window above others
+     */
+    void setKeepAbove(bool set);
+    /**
+     * Sets or reset keeping this window below others.
+     * @param set Whether to keep the window below others
+     */
+    void setKeepBelow(bool set);
+
+protected Q_SLOTS:
+    /**
+     * A decoration providing AbilityAnnounceAlphaChannel can use this method to enable/disable the
+     * use of alpha channel. This is useful if for a normal window the decoration renders its own
+     * shadows or round corners and thus needs alpha channel. But in maximized state the decoration
+     * is fully opaque. By disabling the alpha channel the Compositor can optimize the rendering.
+     *
+     * @param enabled If @c true alpha channel is enabled, if @c false alpha channel is disabled
+     * @see isAlphaEnabled
+     * @see alphaEnabledChanged
+     * @since 4.10
+     **/
+    void setAlphaEnabled(bool enabled);
+    /**
+     * This slot can be reimplemented to return the regions defined
+     * by KDecorationDefines::Region.
+     *
+     * The default implementation always returns an empty region.
+     *
+     * @since 4.8
+     */
+    QRegion region(KDecorationDefines::Region r);
+
+private:
+    KDecorationBridge* bridge_;
+    QWidget* w_;
+    KDecorationFactory* factory_;
+    friend class KDecorationOptions; // for options_
+    static KDecorationOptions* options_;
+    KDecorationPrivate* d;
+
 };
 
 inline
@@ -1182,4 +1070,6 @@ inline int KDecoration::height() const
 
 /** @} */
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(KDecoration::QuickTileMode)
+
 #endif
