@@ -29,14 +29,14 @@ DEALINGS IN THE SOFTWARE.
 #include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <klibrary.h>
 #include <kconfiggroup.h>
-#include <KDE/KLocalizedString>
-#include <KDE/KGlobal>
+#include <KLocalizedString>
+#include <KGlobal>
 #include <assert.h>
 
 #include <QDir>
 #include <QFile>
+#include <QLibrary>
 
 #include "kdecorationfactory.h"
 
@@ -106,7 +106,7 @@ KDecoration* KDecorationPlugins::createDecoration(KDecorationBridge* bridge)
 }
 
 // tests whether the plugin can be loaded
-bool KDecorationPlugins::canLoad(QString nameStr, KLibrary **loadedLib)
+bool KDecorationPlugins::canLoad(QString nameStr, QLibrary **loadedLib)
 {
     if (nameStr.isEmpty())
         return false; // we can't load that
@@ -125,7 +125,7 @@ bool KDecorationPlugins::canLoad(QString nameStr, KLibrary **loadedLib)
         return false;
     }
 
-    KLibrary libToFind(nameStr);
+    QLibrary libToFind(nameStr);
     QString path = libToFind.fileName();
     kDebug(1212) << "kwin : path " << path << " for " << nameStr;
 
@@ -134,7 +134,7 @@ bool KDecorationPlugins::canLoad(QString nameStr, KLibrary **loadedLib)
     }
 
     // Try loading the requested plugin
-    KLibrary *lib = new KLibrary(path);
+    QLibrary *lib = new QLibrary(path);
 
     if (!lib)
         return false;
@@ -155,21 +155,11 @@ bool KDecorationPlugins::canLoad(QString nameStr, KLibrary **loadedLib)
     KDecorationFactory*(*cptr)() = NULL;
     int (*vptr)()  = NULL;
     int deco_version = 0;
-    KLibrary::void_function_ptr version_func = lib->resolveFunction("decoration_version");
+    void *version_func = lib->resolve("decoration_version");
     if (version_func) {
         vptr = (int(*)())version_func;
         deco_version = vptr();
     } else {
-        // block some decos known to link the unstable API but (for now) let through other legacy stuff
-        const bool isLegacyStableABI = !(nameStr.contains("qtcurve", Qt::CaseInsensitive) ||
-                                         nameStr.contains("crystal", Qt::CaseInsensitive) ||
-                                         nameStr.contains("oxygen", Qt::CaseInsensitive));
-        if (isLegacyStableABI) {
-            // it's an old build of a legacy decoration that very likely uses the stable API
-            // so we just set the API version to the current one
-            // TODO: remove for 4.9.x or 4.10 - this is just to cover recompiles
-            deco_version = KWIN_DECORATION_API_VERSION;
-        }
         kWarning(1212) << QString("****** The library %1 has no API version ******").arg(path);
         kWarning(1212) << "****** Please use the KWIN_DECORATION macro in extern \"C\" to get this decoration loaded in future versions of kwin";
     }
@@ -181,7 +171,7 @@ bool KDecorationPlugins::canLoad(QString nameStr, KLibrary **loadedLib)
         return false;
     }
 
-    KLibrary::void_function_ptr create_func = lib->resolveFunction("create_factory");
+    void *create_func = lib->resolve("create_factory");
     if (create_func)
         cptr = (KDecorationFactory * (*)())create_func;
 
@@ -214,7 +204,7 @@ bool KDecorationPlugins::loadPlugin(QString nameStr)
     if (pluginStr == nameStr)
         return true;
 
-    KLibrary *oldLibrary = library;
+    QLibrary *oldLibrary = library;
     KDecorationFactory* oldFactory = fact;
 
     if (!canLoad(nameStr, &library)) {
@@ -229,7 +219,7 @@ bool KDecorationPlugins::loadPlugin(QString nameStr)
     }
 
     // guarded by "canLoad"
-    KLibrary::void_function_ptr create_func = library->resolveFunction("create_factory");
+    void *create_func = library->resolve("create_factory");
     if (create_func)
         create_ptr = (KDecorationFactory * (*)())create_func;
     if (!create_ptr) {  // this means someone probably attempted to load "some" kwin plugin/lib as deco
@@ -246,7 +236,6 @@ bool KDecorationPlugins::loadPlugin(QString nameStr)
     }
 
     fact = create_ptr();
-    fact->checkRequirements(this);   // let it check what is supported
 
     pluginStr = nameStr;
 
