@@ -23,7 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QDateTime>
 #include <QTimer>
-#include <QtDebug>
+#include <QtCore/qdebug.h>
 #include <QVector3D>
 
 QDebug operator<<(QDebug dbg, const KWin::FPx2 &fpx2)
@@ -36,7 +36,7 @@ namespace KWin {
 
 QElapsedTimer AnimationEffect::s_clock;
 
-struct AnimationEffectPrivate {
+class AnimationEffectPrivate {
 public:
     AnimationEffectPrivate() { m_animated = m_damageDirty = m_animationsTouched = m_isInitialized = false; }
     AnimationEffect::AniMap m_animations;
@@ -284,6 +284,7 @@ void AnimationEffect::prePaintScreen( ScreenPrePaintData& data, int time )
                 AniData *aData = &(*anim);
                 if (aData->attribute == KWin::AnimationEffect::CrossFadePrevious) {
                     oldW->unreferencePreviousWindowPixmap();
+                    effects->addRepaint(oldW->expandedGeometry());
                 }
                 animationEnded(oldW, anim->attribute, anim->meta);
                 // NOTICE animationEnded is an external call and might have called "::animate"
