@@ -19,11 +19,11 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
-#include "kwineffects.h"
-
-#include "kwinxrenderutils.h"
 #include "config-kwin.h"
 
+#include "kwineffects.h"
+#include "kwinxrenderutils.h"
+
 #include <QtDBus/QtDBus>
 #include <QVariant>
 #include <QList>
@@ -32,8 +32,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtGui/QPainter>
 #include <QtGui/QPixmap>
 #include <QtGui/QVector2D>
-#include <QGraphicsRotation>
-#include <QGraphicsScale>
+#include <QtGui/qgraphicstransform.h>
+#include <QtCore/qmath.h>
 
 #include <kdebug.h>
 #include <ksharedconfig.h>
@@ -42,29 +42,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <assert.h>
 
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
 #include <X11/extensions/Xrender.h>
 #include <X11/extensions/Xfixes.h>
 #include <xcb/xfixes.h>
 #endif
 
-#if defined(__GNUC__)
-#  define KWIN_ALIGN(n) __attribute((aligned(n)))
-#  if defined(__SSE2__)
-#    define HAVE_SSE2
-#  endif
-#elif defined(__INTEL_COMPILER)
-#  define KWIN_ALIGN(n) __declspec(align(n))
-#  define HAVE_SSE2
-#else
-#  define KWIN_ALIGN(n)
-#endif
-
-#ifdef HAVE_SSE2
-#  include <emmintrin.h>
-#endif
-
-
 namespace KWin
 {
 
@@ -237,7 +220,6 @@ public:
 
 WindowPaintData::WindowPaintData(EffectWindow* w)
     : PaintData()
-    , shader(NULL)
     , d(new WindowPaintDataPrivate())
 {
     quads = w->buildQuads();
@@ -252,7 +234,6 @@ WindowPaintData::WindowPaintData(EffectWindow* w)
 WindowPaintData::WindowPaintData(const WindowPaintData &other)
     : PaintData()
     , quads(other.quads)
-    , shader(other.shader)
     , d(new WindowPaintDataPrivate())
 {
     setXScale(other.xScale());
@@ -638,11 +619,6 @@ CompositingType EffectsHandler::compositingType() const
     return compositing_type;
 }
 
-bool EffectsHandler::isOpenGLCompositing() const
-{
-    return compositing_type & OpenGLCompositing;
-}
-
 void EffectsHandler::sendReloadMessage(const QString& effectname)
 {
     QDBusMessage message = QDBusMessage::createMethodCall("org.kde.kwin", "/KWin", "org.kde.KWin", "reconfigureEffect");
@@ -652,7 +628,7 @@ void EffectsHandler::sendReloadMessage(const QString& effectname)
 
 KConfigGroup EffectsHandler::effectConfig(const QString& effectname)
 {
-    KSharedConfig::Ptr kwinconfig = KSharedConfig::openConfig(KWIN_CONFIG, KConfig::NoGlobals);
+    KSharedConfig::Ptr kwinconfig = KSharedConfig::openConfig("kwinrc", KConfig::NoGlobals);
     return kwinconfig->group("Effect-" + effectname);
 }
 
@@ -709,7 +685,6 @@ WINDOW_HELPER(bool, isManaged, "managed")
 WINDOW_HELPER(bool, isDeleted, "deleted")
 WINDOW_HELPER(bool, hasOwnShape, "shaped")
 WINDOW_HELPER(QString, windowRole, "windowRole")
-WINDOW_HELPER(QStringList, activities, "activities")
 WINDOW_HELPER(bool, skipsCloseAnimation, "skipsCloseAnimation")
 
 QString EffectWindow::windowClass() const
@@ -727,17 +702,6 @@ NET::WindowType EffectWindow::windowType() const
     return static_cast<NET::WindowType>(parent()->property("windowType").toInt());
 }
 
-bool EffectWindow::isOnActivity(QString activity) const
-{
-    const QStringList activities = parent()->property("activities").toStringList();
-    return activities.isEmpty() || activities.contains(activity);
-}
-
-bool EffectWindow::isOnAllActivities() const
-{
-    return parent()->property("activities").toStringList().isEmpty();
-}
-
 #undef WINDOW_HELPER
 
 #define WINDOW_HELPER_DEFAULT( rettype, prototype, propertyname, defaultValue ) \
@@ -822,10 +786,6 @@ void EffectWindow::addLayerRepaint(const QRect &r)
     QMetaObject::invokeMethod(parent(), "addLayerRepaint", Q_ARG(const QRect&, r));
 }
 
-bool EffectWindow::isOnCurrentActivity() const
-{
-    return isOnActivity(effects->currentActivity());
-}
 
 bool EffectWindow::isOnCurrentDesktop() const
 {
@@ -849,9 +809,7 @@ bool EffectWindow::hasDecoration() const
 
 bool EffectWindow::isVisible() const
 {
-    return !isMinimized()
-           && isOnCurrentDesktop()
-           && isOnCurrentActivity();
+    return !isMinimized() && isOnCurrentDesktop();
 }
 
 
@@ -1103,137 +1061,6 @@ WindowQuadList WindowQuadList::makeRegularGrid(int xSubdivisions, int ySubdivisi
     return ret;
 }
 
-#ifndef GL_TRIANGLES
-#  define GL_TRIANGLES      0x0004
-#endif
-
-#ifndef GL_QUADS
-#  define GL_QUADS          0x0007
-#endif
-
-void WindowQuadList::makeInterleavedArrays(unsigned int type, GLVertex2D *vertices, const QMatrix4x4 &textureMatrix) const
-{
-    // Since we know that the texture matrix just scales and translates
-    // we can use this information to optimize the transformation
-    const QVector2D coeff(textureMatrix(0, 0), textureMatrix(1, 1));
-    const QVector2D offset(textureMatrix(0, 3), textureMatrix(1, 3));
-
-    GLVertex2D *vertex = vertices;
-
-    assert(type == GL_QUADS || type == GL_TRIANGLES);
-
-    switch (type)
-    {
-    case GL_QUADS:
-#ifdef HAVE_SSE2
-        if (!(intptr_t(vertex) & 0xf)) {
-            for (int i = 0; i < count(); i++) {
-                const WindowQuad &quad = at(i);
-                KWIN_ALIGN(16) GLVertex2D v[4];
-
-                for (int j = 0; j < 4; j++) {
-                    const WindowVertex &wv = quad[j];
-
-                    v[j].position = QVector2D(wv.x(), wv.y());
-                    v[j].texcoord = QVector2D(wv.u(), wv.v()) * coeff + offset;
-                }
-
-                const __m128i *srcP = (const __m128i *) &v;
-                __m128i *dstP = (__m128i *) vertex;
-
-                _mm_stream_si128(&dstP[0], _mm_load_si128(&srcP[0])); // Top-left
-                _mm_stream_si128(&dstP[1], _mm_load_si128(&srcP[1])); // Top-right
-                _mm_stream_si128(&dstP[2], _mm_load_si128(&srcP[2])); // Bottom-right
-                _mm_stream_si128(&dstP[3], _mm_load_si128(&srcP[3])); // Bottom-left
-
-                vertex += 4;
-            }
-        } else
-#endif // HAVE_SSE2
-        {
-            for (int i = 0; i < count(); i++) {
-                const WindowQuad &quad = at(i);
-
-                for (int j = 0; j < 4; j++) {
-                    const WindowVertex &wv = quad[j];
-
-                    GLVertex2D v;
-                    v.position = QVector2D(wv.x(), wv.y());
-                    v.texcoord = QVector2D(wv.u(), wv.v()) * coeff + offset;
-
-                    *(vertex++) = v;
-                }
-            }
-        }
-        break;
-
-    case GL_TRIANGLES:
-#ifdef HAVE_SSE2
-        if (!(intptr_t(vertex) & 0xf)) {
-            for (int i = 0; i < count(); i++) {
-                const WindowQuad &quad = at(i);
-                KWIN_ALIGN(16) GLVertex2D v[4];
-
-                for (int j = 0; j < 4; j++) {
-                    const WindowVertex &wv = quad[j];
-
-                    v[j].position = QVector2D(wv.x(), wv.y());
-                    v[j].texcoord = QVector2D(wv.u(), wv.v()) * coeff + offset;
-                }
-
-                const __m128i *srcP = (const __m128i *) &v;
-                __m128i *dstP = (__m128i *) vertex;
-
-                __m128i src[4];
-                src[0] = _mm_load_si128(&srcP[0]); // Top-left
-                src[1] = _mm_load_si128(&srcP[1]); // Top-right
-                src[2] = _mm_load_si128(&srcP[2]); // Bottom-right
-                src[3] = _mm_load_si128(&srcP[3]); // Bottom-left
-
-                // First triangle
-                _mm_stream_si128(&dstP[0], src[1]); // Top-right
-                _mm_stream_si128(&dstP[1], src[0]); // Top-left
-                _mm_stream_si128(&dstP[2], src[3]); // Bottom-left
-
-                // Second triangle
-                _mm_stream_si128(&dstP[3], src[3]); // Bottom-left
-                _mm_stream_si128(&dstP[4], src[2]); // Bottom-right
-                _mm_stream_si128(&dstP[5], src[1]); // Top-right
-
-                vertex += 6;
-            }
-        } else
-#endif // HAVE_SSE2
-        {
-            for (int i = 0; i < count(); i++) {
-                const WindowQuad &quad = at(i);
-                GLVertex2D v[4]; // Four unique vertices / quad
-
-                for (int j = 0; j < 4; j++) {
-                    const WindowVertex &wv = quad[j];
-
-                    v[j].position = QVector2D(wv.x(), wv.y());
-                    v[j].texcoord = QVector2D(wv.u(), wv.v()) * coeff + offset;
-                }
-
-                // First triangle
-                *(vertex++) = v[1]; // Top-right
-                *(vertex++) = v[0]; // Top-left
-                *(vertex++) = v[3]; // Bottom-left
-
-                // Second triangle
-                *(vertex++) = v[3]; // Bottom-left
-                *(vertex++) = v[2]; // Bottom-right
-                *(vertex++) = v[1]; // Top-right
-            }
-        }
-        break;
-
-    default:
-        break;
-    }
-}
-
 void WindowQuadList::makeArrays(float **vertices, float **texcoords, const QSizeF &size, bool yInverted) const
 {
     *vertices = new float[count() * 6 * 2];
@@ -1368,12 +1195,7 @@ struct PaintClipper::Iterator::Data {
 PaintClipper::Iterator::Iterator()
     : data(new Data)
 {
-    if (clip() && effects->isOpenGLCompositing()) {
-        data->rects = paintArea().rects();
-        data->index = -1;
-        next(); // move to the first one
-    }
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     if (clip() && effects->compositingType() == XRenderCompositing) {
         XFixesRegion region(paintArea());
         xcb_xfixes_set_picture_clip_region(connection(), effects->xrenderBufferPicture(), region, 0, 0);
@@ -1383,7 +1205,7 @@ PaintClipper::Iterator::Iterator()
 
 PaintClipper::Iterator::~Iterator()
 {
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     if (clip() && effects->compositingType() == XRenderCompositing)
         xcb_xfixes_set_picture_clip_region(connection(), effects->xrenderBufferPicture(), XCB_XFIXES_REGION_NONE, 0, 0);
 #endif
@@ -1394,9 +1216,7 @@ bool PaintClipper::Iterator::isDone()
 {
     if (!clip())
         return data->index == 1; // run once
-    if (effects->isOpenGLCompositing())
-        return data->index >= data->rects.count(); // run once per each area
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     if (effects->compositingType() == XRenderCompositing)
         return data->index == 1; // run once
 #endif
@@ -1412,9 +1232,7 @@ QRect PaintClipper::Iterator::boundingRect() const
 {
     if (!clip())
         return infiniteRegion();
-    if (effects->isOpenGLCompositing())
-        return data->rects[ data->index ];
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
     if (effects->compositingType() == XRenderCompositing)
         return paintArea().boundingRect();
 #endif
@@ -1742,4 +1560,4 @@ void EffectFrame::enableCrossFade(bool enable)
 
 } // namespace
 
-#include "kwineffects.moc"
+#include "moc_kwineffects.cpp"
