@@ -19,46 +19,39 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
+#include "config-unix.h"
 #include "main.h"
 
-//#define QT_CLEAN_NAMESPACE
-#include <ksharedconfig.h>
-
-#include <kglobal.h>
-#include <klocale.h>
-#include <stdlib.h>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <kcrash.h>
-#include <signal.h>
 #include <fcntl.h>
-#include <QX11Info>
 #include <stdio.h>
-#include <fixx11h.h>
-#include <kxerrorhandler.h>
-#include <kdefakes.h>
-#include <QtDBus/QtDBus>
-#include <QMessageBox>
-#include <QEvent>
-
-#include <kdialog.h>
-#include <kstandarddirs.h>
-#include <kdebug.h>
-#include <kde_file.h>
-#include <QLabel>
-#include <KComboBox>
-#include <QVBoxLayout>
-
-#include "config-workspace.h"
-
-#ifdef HAVE_UNISTD_H
+#include <stdlib.h>
 #include <unistd.h>
-#endif // HAVE_UNISTD_H
 
 #ifdef HAVE_MALLOC_H
 #include <malloc.h>
 #endif // HAVE_MALLOC_H
 
+#include <QDBusConnection>
+#include <QMessageBox>
+#include <QEvent>
+#include <QVBoxLayout>
+#include <QLabel>
+#include <QFile>
+
+#include <ksharedconfig.h>
+#include <kglobal.h>
+#include <klocale.h>
+#include <kcmdlineargs.h>
+#include <kaboutdata.h>
+#include <kcrash.h>
+#include <kxerrorhandler.h>
+#include <kdialog.h>
+#include <kstandarddirs.h>
+#include <kdebug.h>
+#include <KComboBox>
+#include <QtGui/qx11info_x11.h>
+#include <fixx11h.h>
+
 #include <ksmserver_interface.h>
 
 #include "atoms.h"
@@ -67,22 +60,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "utils.h"
 #include "effects.h"
 #include "workspace.h"
+#include "composite.h"
 #include "xcbutils.h"
 
-#define INT8 _X11INT8
-#define INT32 _X11INT32
 #include <X11/Xproto.h>
-#undef INT8
-#undef INT32
-
-static bool isMultiHead()
-{
-    QByteArray multiHead = qgetenv("KDE_MULTIHEAD");
-    if (!multiHead.isEmpty()) {
-        return (multiHead.toLower() == "true");
-    }
-    return true;
-}
 
 namespace KWin
 {
@@ -103,58 +84,15 @@ bool initting = false;
  */
 static bool kwin_sync = false;
 
-//************************************
-// KWinSelectionOwner
-//************************************
-
-KWinSelectionOwner::KWinSelectionOwner(int screen_P)
-    : KSelectionOwner(make_selection_atom(screen_P), screen_P)
-{
-}
-
-Atom KWinSelectionOwner::make_selection_atom(int screen_P)
+static QByteArray make_selection_atom(int screen_P)
 {
     if (screen_P < 0)
         screen_P = DefaultScreen(display());
     char tmp[ 30 ];
     sprintf(tmp, "WM_S%d", screen_P);
-    return XInternAtom(display(), tmp, False);
+    return QByteArray(tmp);
 }
 
-void KWinSelectionOwner::getAtoms()
-{
-    KSelectionOwner::getAtoms();
-    if (xa_version == None) {
-        Atom atoms[ 1 ];
-        const char* const names[] =
-        { "VERSION" };
-        XInternAtoms(display(), const_cast< char** >(names), 1, False, atoms);
-        xa_version = atoms[ 0 ];
-    }
-}
-
-void KWinSelectionOwner::replyTargets(Atom property_P, Window requestor_P)
-{
-    KSelectionOwner::replyTargets(property_P, requestor_P);
-    Atom atoms[ 1 ] = { xa_version };
-    // PropModeAppend !
-    XChangeProperty(display(), requestor_P, property_P, XA_ATOM, 32, PropModeAppend,
-    reinterpret_cast< unsigned char* >(atoms), 1);
-}
-
-bool KWinSelectionOwner::genericReply(Atom target_P, Atom property_P, Window requestor_P)
-{
-    if (target_P == xa_version) {
-        long version[] = { 2, 0 };
-        XChangeProperty(display(), requestor_P, property_P, XA_INTEGER, 32,
-        PropModeReplace, reinterpret_cast< unsigned char* >(&version), 2);
-    } else
-        return KSelectionOwner::genericReply(target_P, property_P, requestor_P);
-    return true;
-}
-
-Atom KWinSelectionOwner::xa_version = None;
-
 // errorMessage is only used ifndef NDEBUG, and only in one place.
 // it might be worth reevaluating why this is used? I don't know.
 #ifndef NDEBUG
@@ -283,7 +221,7 @@ public:
         addWM("metacity");
         addWM("openbox");
         addWM("fvwm2");
-        addWM(KWIN_NAME);
+        addWM("kwin");
 
         setMainWidget(mainWidget);
 
@@ -308,7 +246,7 @@ int Application::crashes = 0;
 
 Application::Application()
     : KApplication()
-    , owner(screen_number)
+    , owner(new KSelectionOwner(make_selection_atom(screen_number), screen_number, this))
 {
     if (KCmdLineArgs::parsedArgs("qt")->isSet("sync")) {
         kwin_sync = true;
@@ -316,6 +254,29 @@ Application::Application()
         kDebug(1212) << "Running KWin in sync mode";
     }
     setQuitOnLastWindowClosed(false);
+
+    if (screen_number == -1)
+        screen_number = DefaultScreen(display());
+}
+
+Application::~Application()
+{
+    disconnect(owner, 0, this, 0);
+    delete Workspace::self();
+    if (owner->ownerWindow() != None) { // If there was no --replace (no new WM)
+        XSetInputFocus(display(), PointerRoot, RevertToPointerRoot, xTime());
+        // Remove windowmanager privileges
+        XSelectInput(display(), rootWindow(), PropertyChangeMask);
+    }
+    delete options;
+    delete effects;
+    delete atoms;
+    owner->release();
+    delete owner;
+}
+
+bool Application::setup()
+{
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
     KSharedConfig::Ptr config = KGlobal::config();
     if (!config->isImmutable() && args->isSet("lock")) {
@@ -324,25 +285,24 @@ Application::Application()
         config->reparseConfiguration();
     }
 
-    if (screen_number == -1)
-        screen_number = DefaultScreen(display());
-
-    if (!owner.claim(args->isSet("replace"), true)) {
+    if (!owner->claim(args->isSet("replace"))) {
         fputs(i18n("kwin: unable to claim manager selection, another wm running? (try using --replace)\n").toLocal8Bit(), stderr);
-        ::exit(1);
+        return false;
     }
-    connect(&owner, SIGNAL(lostOwnership()), SLOT(lostSelection()));
+    connect(owner, SIGNAL(lostOwnership()), this, SLOT(lostSelection()), Qt::DirectConnection);
 
+    KApplication::quitOnSignal();
     KCrash::setEmergencySaveFunction(Application::crashHandler);
     crashes = args->getOption("crashes").toInt();
     if (crashes >= 4) {
         // Something has gone seriously wrong
         AlternativeWMDialog dialog;
-        QString cmd = KWIN_NAME;
-        if (dialog.exec() == QDialog::Accepted)
+        QString cmd = "kwin";
+        if (dialog.exec() == QDialog::Accepted) {
             cmd = dialog.selectedWM();
-        else
-            ::exit(1);
+        } else {
+            return false;
+        }
         if (cmd.length() > 500) {
             kDebug(1212) << "Command is too long, truncating";
             cmd = cmd.left(500);
@@ -351,7 +311,7 @@ Application::Application()
         char buf[1024];
         sprintf(buf, "%s &", cmd.toAscii().data());
         system(buf);
-        ::exit(1);
+        return false;
     }
     if (crashes >= 2) {
         // Disable compositing if we have had too many crashes
@@ -387,33 +347,11 @@ Application::Application()
     syncX(); // Trigger possible errors, there's still a chance to abort
 
     initting = false; // Startup done, we are up and running now.
-
-    XEvent e;
-    e.xclient.type = ClientMessage;
-    e.xclient.message_type = XInternAtom(display(), "_KDE_SPLASH_PROGRESS", False);
-    e.xclient.display = display();
-    e.xclient.window = rootWindow();
-    e.xclient.format = 8;
-    strcpy(e.xclient.data.b, "wm");
-    XSendEvent(display(), rootWindow(), False, SubstructureNotifyMask, &e);
-}
-
-Application::~Application()
-{
-    delete Workspace::self();
-    if (owner.ownerWindow() != None)   // If there was no --replace (no new WM)
-        XSetInputFocus(display(), PointerRoot, RevertToPointerRoot, xTime());
-    delete options;
-    delete effects;
-    delete atoms;
+    return true;
 }
 
 void Application::lostSelection()
 {
-    sendPostedEvents();
-    delete Workspace::self();
-    // Remove windowmanager privileges
-    XSelectInput(display(), rootWindow(), PropertyChangeMask);
     quit();
 }
 
@@ -426,16 +364,11 @@ bool Application::x11EventFilter(XEvent* e)
 
 bool Application::notify(QObject* o, QEvent* e)
 {
-    if (Workspace::self()->workspaceEvent(e))
+    if (Workspace::self() && Workspace::self()->workspaceEvent(e))
         return true;
     return KApplication::notify(o, e);
 }
 
-static void sighandler(int)
-{
-    QApplication::exit();
-}
-
 void Application::crashHandler(int signal)
 {
     crashes++;
@@ -459,8 +392,7 @@ void Application::resetCrashesCount()
 static const char version[] = KWIN_VERSION_STRING;
 static const char description[] = I18N_NOOP("KDE window manager");
 
-extern "C"
-KDE_EXPORT int kdemain(int argc, char * argv[])
+int main(int argc, char * argv[])
 {
 #ifdef M_TRIM_THRESHOLD
     // Prevent fragmentation of the heap by malloc (glibc).
@@ -469,30 +401,10 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     // due to fragmentation especially if we use the raster graphicssystem. On the
     // otherside if the threshold is too low, free() starts to permanently ask the kernel
     // about shrinking the heap.
-#ifdef HAVE_UNISTD_H
     const int pagesize = sysconf(_SC_PAGESIZE);
-#else
-    const int pagesize = 4*1024;
-#endif // HAVE_UNISTD_H
     mallopt(M_TRIM_THRESHOLD, 5*pagesize);
 #endif // M_TRIM_THRESHOLD
 
-    // the raster graphicssystem has a quite terrible performance on the XRender backend or when not
-    // compositing at all while some to many decorations suffer from bad performance of the native
-    // graphicssystem (lack of implementation, QGradient internally uses the raster system and
-    // XPutImage's the result because some graphics drivers have insufficient or bad performing
-    // implementations of XRenderCreate*Gradient)
-    //
-    // Therefore we allow configurationa and do some automagic selection to discourage
-    // ""known to be stupid" ideas ;-P
-    // The invalid system parameter "" will use the systems default graphicssystem
-    // "!= XRender" is intended since eg. pot. SW backends likely would profit from raster as well
-    KConfigGroup config(KSharedConfig::openConfig(KWIN_CONFIG), "Compositing");
-    QString preferredSystem("native");
-    if (config.readEntry("Enabled", true) && config.readEntry("Backend", "OpenGL") != "XRender")
-        preferredSystem = "";
-    QApplication::setGraphicsSystem(config.readEntry("GraphicsSystem", preferredSystem));
-
     Display* dpy = XOpenDisplay(NULL);
     if (!dpy) {
         fprintf(stderr, "%s: FATAL ERROR while trying to open display %s\n",
@@ -503,7 +415,7 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     int number_of_screens = ScreenCount(dpy);
 
     // multi head
-    if (number_of_screens != 1 && isMultiHead()) {
+    if (number_of_screens != 1 && KGlobalSettings::isMultiHead()) {
         KWin::is_multihead = true;
         KWin::screen_number = DefaultScreen(dpy);
         int pos; // Temporarily needed to reconstruct DISPLAY var if multi-head
@@ -536,7 +448,7 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     }
 
     KAboutData aboutData(
-        KWIN_NAME,                     // The program name used internally
+        "kwin",                     // The program name used internally
         0,                          // The message catalog name. If null, program name is used instead
         ki18n("KWin"),              // A displayable program name string
         version,                    // The program version string
@@ -557,31 +469,30 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     args.add("crashes <n>", ki18n("Indicate that KWin has recently crashed n times"));
     KCmdLineArgs::addCmdLineOptions(args);
 
-    if (KDE_signal(SIGTERM, KWin::sighandler) == SIG_IGN)
-        KDE_signal(SIGTERM, SIG_IGN);
-    if (KDE_signal(SIGINT, KWin::sighandler) == SIG_IGN)
-        KDE_signal(SIGINT, SIG_IGN);
-    if (KDE_signal(SIGHUP, KWin::sighandler) == SIG_IGN)
-        KDE_signal(SIGHUP, SIG_IGN);
-
-    // Disable the glib event loop integration, since it seems to be responsible
-    // for several bug reports about high CPU usage (bug #239963)
-    setenv("QT_NO_GLIB", "1", true);
-
-    org::kde::KSMServerInterface ksmserver("org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
-    ksmserver.suspendStartup(KWIN_NAME);
     KWin::Application a;
+    org::kde::KSMServerInterface ksmserver("org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
+    ksmserver.suspendStartup("kwin");
+    if (!a.setup()) {
+        ksmserver.resumeStartup("kwin");
+        a.exit(1);
+        return 1;
+    }
 
-    ksmserver.resumeStartup(KWIN_NAME);
+    // wait for the workspace initialization to complete before resuming
+    while (KWin::Workspace::self() && KWin::Workspace::self()->initializing()) {
+        a.processEvents();
+    }
+    // and the compositor
+    while (KWin::Compositor::starting()) {
+        a.processEvents();
+    }
+    // and one more iteration just in case
+    a.processEvents();
+
+    ksmserver.resumeStartup("kwin");
     KWin::SessionManager weAreIndeed;
     KWin::SessionSaveDoneHelper helper;
     KGlobal::locale()->insertCatalog("kwin_effects");
-    KGlobal::locale()->insertCatalog("kwin_scripts");
-    KGlobal::locale()->insertCatalog("kwin_scripting");
-
-    // Announce when KWIN_DIRECT_GL is set for above HACK
-    if (qstrcmp(qgetenv("KWIN_DIRECT_GL"), "1") == 0)
-        kDebug(1212) << "KWIN_DIRECT_GL set, not forcing LIBGL_ALWAYS_INDIRECT=1";
 
     fcntl(XConnectionNumber(KWin::display()), F_SETFD, 1);
 
@@ -597,4 +508,4 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     return a.exec();
 }
 
-#include "main.moc"
+#include "moc_main.cpp"
