@@ -23,26 +23,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define MAIN_H
 
 #include <kapplication.h>
-#include <KDE/KSelectionWatcher>
+#include <KSelectionOwner>
 
 namespace KWin
 {
 
-class KWinSelectionOwner
-    : public KSelectionOwner
-{
-    Q_OBJECT
-public:
-    explicit KWinSelectionOwner(int screen);
-protected:
-    virtual bool genericReply(Atom target, Atom property, Window requestor);
-    virtual void replyTargets(Atom property, Window requestor);
-    virtual void getAtoms();
-private:
-    Atom make_selection_atom(int screen);
-    static Atom xa_version;
-};
-
 class Application : public  KApplication
 {
     Q_OBJECT
@@ -50,6 +35,9 @@ public:
     Application();
     ~Application();
 
+public:
+    bool setup();
+
 protected:
     bool x11EventFilter(XEvent*);
     bool notify(QObject* o, QEvent* e);
@@ -60,7 +48,7 @@ private slots:
     void resetCrashesCount();
 
 private:
-    KWinSelectionOwner owner;
+    KSelectionOwner* owner;
     static int crashes;
 };
 
