@@ -27,12 +27,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kglobal.h>
 #include <X11/extensions/shape.h>
 
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
 #include "cursor.h"
 #include "decorations.h"
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include "rules.h"
 #include "group.h"
 #include "netinfo.h"
@@ -160,14 +157,11 @@ bool Client::manage(xcb_window_t w, bool isMapped)
     init_minimize = rules()->checkMinimize(init_minimize, !isMapped);
     noborder = rules()->checkNoBorder(noborder, !isMapped);
 
-    checkActivities();
-
     // Initial desktop placement
     if (session) {
         desk = session->desktop;
         if (session->onAllDesktops)
             desk = NET::OnAllDesktops;
-        setOnActivities(session->activities);
     } else {
         // If this window is transient, ensure that it is opened on the
         // same window as its parent.  this is necessary when an application
@@ -195,26 +189,11 @@ bool Client::manage(xcb_window_t w, bool isMapped)
                 desk = VirtualDesktopManager::self()->current();
             else if (maincl != NULL)
                 desk = maincl->desktop();
-
-            if (maincl)
-                setOnActivities(maincl->activities());
         }
         if (info->desktop())
             desk = info->desktop(); // Window had the initial desktop property, force it
         if (desktop() == 0 && asn_valid && asn_data.desktop() != 0)
             desk = asn_data.desktop();
-#ifdef KWIN_BUILD_ACTIVITIES
-        if (!isMapped && !noborder && isNormalWindow() && !activitiesDefined) {
-            //a new, regular window, when we're not recovering from a crash,
-            //and it hasn't got an activity. let's try giving it the current one.
-            //TODO: decide whether to keep this before the 4.6 release
-            //TODO: if we are keeping it (at least as an option), replace noborder checking
-            //with a public API for setting windows to be on all activities.
-            //something like KWindowSystem::setOnAllActivities or
-            //KActivityConsumer::setOnAllActivities
-            setOnActivity(Activities::self()->current(), true);
-        }
-#endif
     }
 
     if (desk == 0)   // Assume window wants to be visible on the current desktop
@@ -226,11 +205,6 @@ bool Client::manage(xcb_window_t w, bool isMapped)
     workspace()->updateOnAllDesktopsOfTransients(this);   // SELI TODO
     //onAllDesktopsChange(); // Decoration doesn't exist here yet
 
-    QString activitiesList;
-    activitiesList = rules()->checkActivity(activitiesList, !isMapped);
-    if (!activitiesList.isEmpty())
-        setOnActivities(activitiesList.split(','));
-
     QRect geom(attr.x, attr.y, attr.width, attr.height);
     bool placementDone = false;
 
@@ -334,7 +308,7 @@ bool Client::manage(xcb_window_t w, bool isMapped)
             foreach (Client *other, workspace()->clientList()) {
                 if (other->maximizeMode() != MaximizeFull &&
                     geom == QRect(other->pos(), other->clientSize()) &&
-                    desk == other->desktop() && activities() == other->activities()) {
+                    desk == other->desktop()) {
 
                     tabBehind(other, autogroupInFg);
                     break;
@@ -582,9 +556,6 @@ bool Client::manage(xcb_window_t w, bool isMapped)
                 if (!isOnCurrentDesktop() && options->focusPolicyIsReasonable()) {
                     VirtualDesktopManager::self()->setCurrent(desktop());
                 }
-                /*if (!isOnCurrentActivity()) {
-                    workspace()->setCurrentActivity( activities().first() );
-                } FIXME no such method*/
             }
         }
 
@@ -730,8 +701,6 @@ Client* Client::findAutogroupCandidate() const
     QString wGId = rules()->checkAutogroupById(QString());
     if (!wGId.isEmpty()) {
         foreach (Client *c, workspace()->clientList()) {
-            if (activities() != c->activities())
-                continue; // don't cross activities
             if (wGId == c->rules()->checkAutogroupById(QString())) {
                 if (found && found->tabGroup() != c->tabGroup()) { // We've found two, ignore both
                     found = NULL;
@@ -752,7 +721,7 @@ Client* Client::findAutogroupCandidate() const
     if (rules()->checkAutogrouping(options->isAutogroupSimilarWindows())) {
         QByteArray wRole = truncatedWindowRole(windowRole());
         foreach (Client *c, workspace()->clientList()) {
-            if (desktop() != c->desktop() || activities() != c->activities())
+            if (desktop() != c->desktop())
                 continue;
             QByteArray wRoleB = truncatedWindowRole(c->windowRole());
             if (resourceClass() == c->resourceClass() &&  // Same resource class
