@@ -22,7 +22,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <fixx11h.h>
 #include <kconfig.h>
-#include <KDE/KXMessages>
+#include <KXMessages>
 #include <QRegExp>
 #include <ktemporaryfile.h>
 #include <QFile>
@@ -470,12 +470,6 @@ bool Rules::update(Client* c, int selection)
         updated = updated || screen != c->screen();
         screen = c->screen();
     }
-    if NOW_REMEMBER(Activity, activity) {
-        // TODO: ivan - multiple activities support
-        const QString & joinedActivities = c->activities().join(",");
-        updated = updated || activity != joinedActivities;
-        activity = joinedActivities;
-    }
     if NOW_REMEMBER(MaximizeVert, maximizevert) {
         updated = updated || maximizevert != bool(c->maximizeMode() & MaximizeVertical);
         maximizevert = c->maximizeMode() & MaximizeVertical;
@@ -860,7 +854,6 @@ void Client::applyWindowRules()
     // IgnoreGeometry
     setDesktop(desktop());
     workspace()->sendClientToScreen(this, screen());
-    setOnActivities(activities());
     // Type
     maximize(maximizeMode());
     // Minimize : functions don't check, and there are two functions
@@ -920,7 +913,7 @@ RuleBook::RuleBook(QObject *parent)
     : QObject(parent)
     , m_updateTimer(new QTimer(this))
     , m_updatesDisabled(false)
-    , m_temporaryRulesMessages(new KXMessages("_KDE_NET_WM_TEMPORARY_RULES", NULL, false)) // TODO KF5 - remove *then* obsolete last parameter which is *now* mandatory
+    , m_temporaryRulesMessages(new KXMessages("_KDE_NET_WM_TEMPORARY_RULES"))
 {
     connect(m_temporaryRulesMessages.data(), SIGNAL(gotMessage(QString)), SLOT(temporaryRulesMessage(QString)));
     connect(m_updateTimer, SIGNAL(timeout()), SLOT(save()));
@@ -978,7 +971,7 @@ void RuleBook::edit(Client* c, bool whole_app)
 void RuleBook::load()
 {
     deleteAll();
-    KConfig cfg(QLatin1String(KWIN_NAME) + "rulesrc", KConfig::NoGlobals);
+    KConfig cfg("kwinrulesrc", KConfig::NoGlobals);
     int count = cfg.group("General").readEntry("count", 0);
     for (int i = 1;
             i <= count;
@@ -992,7 +985,7 @@ void RuleBook::load()
 void RuleBook::save()
 {
     m_updateTimer->stop();
-    KConfig cfg(QLatin1String(KWIN_NAME) + "rulesrc", KConfig::NoGlobals);
+    KConfig cfg("kwinrulesrc", KConfig::NoGlobals);
     QStringList groups = cfg.groupList();
     for (QStringList::ConstIterator it = groups.constBegin();
             it != groups.constEnd();
