@@ -20,7 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 /*
  The base class for compositing, implementing shared functionality
- between the OpenGL and XRender backends.
+ between the OpenGL (that is no more) and XRender backends.
 
  Design:
 
@@ -93,7 +93,6 @@ namespace KWin
 
 Scene::Scene(Workspace* ws)
     : QObject(ws)
-    , wspace(ws)
 {
     last_time.invalidate(); // Initialize the timer
     connect(Workspace::self(), SIGNAL(deletedRemoved(KWin::Deleted*)), SLOT(windowDeleted(KWin::Deleted*)));
@@ -254,10 +253,7 @@ void Scene::paintSimpleScreen(int orig_mask, QRegion region)
 
     QRegion dirtyArea = region;
     bool opaqueFullscreen(false);
-    for (int i = 0;  // do prePaintWindow bottom to top
-            i < stacking_order.count();
-            ++i) {
-        Window* w = stacking_order[ i ];
+    foreach (Window *w, stacking_order) { // do prePaintWindow bottom to top
         Toplevel* topw = w->window();
         WindowPrePaintData data;
         data.mask = orig_mask | (w->isOpaque() ? PAINT_WINDOW_OPAQUE : PAINT_WINDOW_TRANSLUCENT);
@@ -402,6 +398,10 @@ void Scene::paintWindow(Window* w, int mask, QRegion region, WindowQuadList quad
     region &= QRect(0, 0, displayWidth(), displayHeight());
     if (region.isEmpty())  // completely clipped
         return;
+    if (w->window()->isDeleted() && w->window()->skipsCloseAnimation()) {
+        // should not get painted
+        return;
+    }
 
     if (s_recursionCheck == w) {
         return;
@@ -465,7 +465,7 @@ void Scene::paintWindowThumbnails(Scene::Window *w, QRegion region, qreal opacit
         y += (thumb->y()-visualThumbRect.y())*thumbData.yScale();
         thumbData.setXTranslation(x);
         thumbData.setYTranslation(y);
-        int thumbMask = PAINT_WINDOW_TRANSFORMED | PAINT_WINDOW_LANCZOS;
+        int thumbMask = PAINT_WINDOW_TRANSFORMED;
         if (thumbData.opacity() == 1.0) {
             thumbMask |= PAINT_WINDOW_OPAQUE;
         } else {
@@ -592,16 +592,6 @@ void Scene::extendPaintRegion(QRegion &region, bool opaqueFullscreen)
     Q_UNUSED(opaqueFullscreen);
 }
 
-bool Scene::blocksForRetrace() const
-{
-    return false;
-}
-
-bool Scene::syncsToVBlank() const
-{
-    return false;
-}
-
 void Scene::screenGeometryChanged(const QSize &size)
 {
     overlayWindow()->resize(size);
@@ -670,7 +660,7 @@ void Scene::Window::discardShape()
 const QRegion &Scene::Window::shape() const
 {
     if (!shape_valid) {
-        Client* c = dynamic_cast< Client* >(toplevel);
+        Client* c = qobject_cast< Client* >(toplevel);
         if (toplevel->shape() || (c != NULL && !c->mask().isEmpty())) {
             int count, order;
             XRectangle* rects = XShapeGetRectangles(display(), toplevel->frameId(),
@@ -713,8 +703,6 @@ bool Scene::Window::isVisible() const
         return false;
     if (!toplevel->isOnCurrentDesktop())
         return false;
-    if (!toplevel->isOnCurrentActivity())
-        return false;
     if (toplevel->isClient())
         return (static_cast< Client *>(toplevel))->isShown(true);
     return true; // Unmanaged is always visible
@@ -743,8 +731,6 @@ void Scene::Window::resetPaintingEnabled()
         if (!toplevel->isOnCurrentDesktop())
             disable_painting |= PAINT_DISABLED_BY_DESKTOP;
     }
-    if (!toplevel->isOnCurrentActivity())
-        disable_painting |= PAINT_DISABLED_BY_ACTIVITY;
     if (toplevel->isClient()) {
         Client *c = static_cast<Client*>(toplevel);
         if (c->isMinimized())
@@ -774,7 +760,7 @@ WindowQuadList Scene::Window::buildQuads(bool force) const
     if (toplevel->clientPos() == QPoint(0, 0) && toplevel->clientSize() == toplevel->decorationRect().size())
         ret = makeQuads(WindowQuadContents, shape());  // has no decoration
     else {
-        Client *client = dynamic_cast<Client*>(toplevel);
+        Client *client = qobject_cast<Client*>(toplevel);
         QRegion contents = clientShape();
         QRegion center = toplevel->transparentRect();
         QRegion decoration = (client && decorationPlugin()->hasAlpha() ?
@@ -887,7 +873,7 @@ void WindowPixmap::create()
     if (isValid() || toplevel()->isDeleted()) {
         return;
     }
-    XServerGrabber grabber();
+    XServerGrabber grabber;
     xcb_pixmap_t pix = xcb_generate_id(connection());
     xcb_void_cookie_t namePixmapCookie = xcb_composite_name_window_pixmap_checked(connection(), toplevel()->frameId(), pix);
     Xcb::WindowAttributes windowAttributes(toplevel()->frameId());
