@@ -27,7 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QElapsedTimer>
 
-class QGraphicsView;
+#include <QGraphicsView>
 
 namespace KWin
 {
@@ -92,17 +92,11 @@ public:
         PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS = 1 << 5,
         // Clear whole background as the very first step, without optimizing it
         PAINT_SCREEN_BACKGROUND_FIRST = 1 << 6,
-        // PAINT_DECORATION_ONLY = 1 << 7 has been removed
-        // Window will be painted with a lanczos filter.
-        PAINT_WINDOW_LANCZOS = 1 << 8
-        // PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS_WITHOUT_FULL_REPAINTS = 1 << 9 has been removed
     };
     // types of filtering available
     enum ImageFilterType { ImageFilterFast, ImageFilterGood };
     // there's nothing to paint (adjust time_diff later)
     virtual void idle();
-    virtual bool blocksForRetrace() const;
-    virtual bool syncsToVBlank() const;
     virtual OverlayWindow* overlayWindow() = 0;
 public Q_SLOTS:
     // a window has been destroyed
@@ -168,7 +162,6 @@ protected:
     // time since last repaint
     int time_diff;
     QElapsedTimer last_time;
-    Workspace* wspace;
 private:
     void paintWindowThumbnails(Scene::Window *w, QRegion region, qreal opacity, qreal brightness, qreal saturation);
     void paintDesktopThumbnails(Scene::Window *w);
@@ -217,8 +210,6 @@ public:
         PAINT_DISABLED_BY_MINIMIZE     = 1 << 3,
         // Window will not be painted because it is not the active window in a client group
         PAINT_DISABLED_BY_TAB_GROUP = 1 << 4,
-        // Window will not be painted because it's not on the current activity
-        PAINT_DISABLED_BY_ACTIVITY     = 1 << 5
     };
     void enablePainting(int reason);
     void disablePainting(int reason);
@@ -372,7 +363,6 @@ public:
     virtual void free() = 0;
     virtual void freeIconFrame() = 0;
     virtual void freeTextFrame() = 0;
-    virtual void freeSelection() = 0;
     virtual void crossFadeIcon() = 0;
     virtual void crossFadeText() = 0;
 
