@@ -19,9 +19,12 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
+
+#include "config-kwin.h"
+
 #include "scene_xrender.h"
 
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
+#ifdef KWIN_BUILD_COMPOSITE
 
 #include "toplevel.h"
 #include "client.h"
@@ -48,10 +51,6 @@ namespace KWin
 xcb_render_picture_t SceneXrender::buffer = XCB_RENDER_PICTURE_NONE;
 ScreenPaintData SceneXrender::screen_paint;
 
-#define DOUBLE_TO_FIXED(d) ((xcb_render_fixed_t) ((d) * 65536))
-#define FIXED_TO_DOUBLE(f) ((double) ((f) / 65536.0))
-
-
 static xcb_render_pictformat_t findFormatForVisual(xcb_visualid_t visual)
 {
     static QHash<xcb_visualid_t, xcb_render_pictformat_t> s_cache;
@@ -120,7 +119,7 @@ SceneXrender::~SceneXrender()
     buffer = XCB_RENDER_PICTURE_NONE;
     m_overlayWindow->destroy();
     foreach (Window * w, windows)
-    delete w;
+        delete w;
     delete m_overlayWindow;
 }
 
@@ -302,7 +301,6 @@ QRect SceneXrender::Window::temp_visibleRect;
 SceneXrender::Window::Window(Toplevel* c)
     : Scene::Window(c)
     , format(findFormatForVisual(c->visual()->visualid))
-    , alpha_cached_opacity(0.0)
 {
 }
 
@@ -432,8 +430,8 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
     qreal yscale = 1;
     bool scaled = false;
 
-    Client *client = dynamic_cast<Client*>(toplevel);
-    Deleted *deleted = dynamic_cast<Deleted*>(toplevel);
+    Client *client = qobject_cast<Client*>(toplevel);
+    Deleted *deleted = qobject_cast<Deleted*>(toplevel);
     const QRect decorationRect = toplevel->decorationRect();
     if (((client && !client->noBorder()) || (deleted && !deleted->noBorder())) &&
                                                         decorationPlugin()->hasAlpha()) {
@@ -451,14 +449,14 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
         transformed_shape |= toplevel->shadow()->shadowRegion();
 
     xcb_render_transform_t xform = {
-        DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
-        DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0),
-        DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1)
+        KWIN_DOUBLE_TO_FIXED(1), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0),
+        KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1), KWIN_DOUBLE_TO_FIXED(0),
+        KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1)
     };
     static xcb_render_transform_t identity = {
-        DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
-        DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0),
-        DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1)
+        KWIN_DOUBLE_TO_FIXED(1), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0),
+        KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1), KWIN_DOUBLE_TO_FIXED(0),
+        KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1)
     };
 
     if (mask & PAINT_WINDOW_TRANSFORMED) {
@@ -471,8 +469,8 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
     }
     if (!qFuzzyCompare(xscale, 1.0) || !qFuzzyCompare(yscale, 1.0)) {
         scaled = true;
-        xform.matrix11 = DOUBLE_TO_FIXED(1.0 / xscale);
-        xform.matrix22 = DOUBLE_TO_FIXED(1.0 / yscale);
+        xform.matrix11 = KWIN_DOUBLE_TO_FIXED(1.0 / xscale);
+        xform.matrix22 = KWIN_DOUBLE_TO_FIXED(1.0 / yscale);
 
         // transform the shape for clipping in paintTransformedScreen()
         QVector<QRect> rects = transformed_shape.rects();
@@ -650,9 +648,9 @@ xcb_render_composite(connection(), XCB_RENDER_PICT_OP_OVER, m_xrenderShadow->pic
                     }
                     if (previous->size() != pixmap->size()) {
                         xcb_render_transform_t xform2 = {
-                            DOUBLE_TO_FIXED(FIXED_TO_DOUBLE(xform.matrix11) * previous->size().width() / pixmap->size().width()), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
-                            DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(FIXED_TO_DOUBLE(xform.matrix22) * previous->size().height() / pixmap->size().height()), DOUBLE_TO_FIXED(0),
-                            DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1)
+                            KWIN_DOUBLE_TO_FIXED(KWIN_FIXED_TO_DOUBLE(xform.matrix11) * previous->size().width() / pixmap->size().width()), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0),
+                            KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(KWIN_FIXED_TO_DOUBLE(xform.matrix22) * previous->size().height() / pixmap->size().height()), KWIN_DOUBLE_TO_FIXED(0),
+                            KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(0), KWIN_DOUBLE_TO_FIXED(1)
                             };
                         xcb_render_set_picture_transform(connection(), previous->picture(), xform2);
                     }
@@ -798,7 +796,6 @@ SceneXrender::EffectFrame::EffectFrame(EffectFrameImpl* frame)
     m_picture = NULL;
     m_textPicture = NULL;
     m_iconPicture = NULL;
-    m_selectionPicture = NULL;
 }
 
 SceneXrender::EffectFrame::~EffectFrame()
@@ -806,7 +803,6 @@ SceneXrender::EffectFrame::~EffectFrame()
     delete m_picture;
     delete m_textPicture;
     delete m_iconPicture;
-    delete m_selectionPicture;
 }
 
 void SceneXrender::EffectFrame::cleanup()
@@ -823,8 +819,6 @@ void SceneXrender::EffectFrame::free()
     m_textPicture = NULL;
     delete m_iconPicture;
     m_iconPicture = NULL;
-    delete m_selectionPicture;
-    m_selectionPicture = NULL;
 }
 
 void SceneXrender::EffectFrame::freeIconFrame()
@@ -839,12 +833,6 @@ void SceneXrender::EffectFrame::freeTextFrame()
     m_textPicture = NULL;
 }
 
-void SceneXrender::EffectFrame::freeSelection()
-{
-    delete m_selectionPicture;
-    m_selectionPicture = NULL;
-}
-
 void SceneXrender::EffectFrame::crossFadeIcon()
 {
     // TODO: implement me
@@ -863,34 +851,7 @@ void SceneXrender::EffectFrame::render(QRegion region, double opacity, double fr
     }
 
     // Render the actual frame
-    if (m_effectFrame->style() == EffectFrameUnstyled) {
-        renderUnstyled(effects->xrenderBufferPicture(), m_effectFrame->geometry(), opacity * frameOpacity);
-    } else if (m_effectFrame->style() == EffectFrameStyled) {
-        if (!m_picture) { // Lazy creation
-            updatePicture();
-        }
-        if (m_picture) {
-            qreal left, top, right, bottom;
-            m_effectFrame->frame().getMargins(left, top, right, bottom);   // m_geometry is the inner geometry
-            QRect geom = m_effectFrame->geometry().adjusted(-left, -top, right, bottom);
-            xcb_render_composite(connection(), XCB_RENDER_PICT_OP_OVER, *m_picture,
-                                 XCB_RENDER_PICTURE_NONE, effects->xrenderBufferPicture(),
-                                 0, 0, 0, 0, geom.x(), geom.y(), geom.width(), geom.height());
-        }
-    }
-    if (!m_effectFrame->selection().isNull()) {
-        if (!m_selectionPicture) { // Lazy creation
-            const QPixmap pix = m_effectFrame->selectionFrame().framePixmap();
-            if (!pix.isNull()) // don't try if there's no content
-                m_selectionPicture = new XRenderPicture(m_effectFrame->selectionFrame().framePixmap());
-        }
-        if (m_selectionPicture) {
-            const QRect geom = m_effectFrame->selection();
-            xcb_render_composite(connection(), XCB_RENDER_PICT_OP_OVER, *m_selectionPicture,
-                                 XCB_RENDER_PICTURE_NONE, effects->xrenderBufferPicture(),
-                                 0, 0, 0, 0, geom.x(), geom.y(), geom.width(), geom.height());
-        }
-    }
+    renderUnstyled(effects->xrenderBufferPicture(), m_effectFrame->geometry(), opacity * frameOpacity);
 
     XRenderPicture fill = xRenderBlendPicture(opacity);
 
@@ -899,7 +860,7 @@ void SceneXrender::EffectFrame::render(QRegion region, double opacity, double fr
         QPoint topLeft(m_effectFrame->geometry().x(), m_effectFrame->geometry().center().y() - m_effectFrame->iconSize().height() / 2);
 
         if (!m_iconPicture)   // lazy creation
-            m_iconPicture = new XRenderPicture(m_effectFrame->icon());
+            m_iconPicture = new XRenderPicture(m_effectFrame->icon().toImage());
         QRect geom = QRect(topLeft, m_effectFrame->iconSize());
         xcb_render_composite(connection(), XCB_RENDER_PICT_OP_OVER, *m_iconPicture, fill,
                              effects->xrenderBufferPicture(),
@@ -964,12 +925,12 @@ void SceneXrender::EffectFrame::renderUnstyled(xcb_render_picture_t pict, const
 
         QVector<xcb_render_pointfix_t> points;
         xcb_render_pointfix_t point;
-        point.x = DOUBLE_TO_FIXED(roundness);
-        point.y = DOUBLE_TO_FIXED(roundness);
+        point.x = KWIN_DOUBLE_TO_FIXED(roundness);
+        point.y = KWIN_DOUBLE_TO_FIXED(roundness);
         points << point;
         for (int ii = 0; ii <= num_segments; ++ii) {
-            point.x = DOUBLE_TO_FIXED(x + roundness);
-            point.y = DOUBLE_TO_FIXED(y + roundness);
+            point.x = KWIN_DOUBLE_TO_FIXED(x + roundness);
+            point.y = KWIN_DOUBLE_TO_FIXED(y + roundness);
             points << point;
             //apply the rotation matrix
             t = x;
@@ -1009,16 +970,10 @@ void SceneXrender::EffectFrame::updatePicture()
 {
     delete m_picture;
     m_picture = 0L;
-    if (m_effectFrame->style() == EffectFrameStyled) {
-        const QPixmap pix = m_effectFrame->frame().framePixmap();
-        if (!pix.isNull())
-            m_picture = new XRenderPicture(pix);
-    }
 }
 
 void SceneXrender::EffectFrame::updateTextPicture()
 {
-    // Mostly copied from SceneOpenGL::EffectFrame::updateTextTexture() above
     delete m_textPicture;
     m_textPicture = 0L;
 
@@ -1039,19 +994,15 @@ void SceneXrender::EffectFrame::updateTextPicture()
         text = metrics.elidedText(text, Qt::ElideRight, rect.width());
     }
 
-    QPixmap pixmap(m_effectFrame->geometry().size());
-    pixmap.fill(Qt::transparent);
-    QPainter p(&pixmap);
+    QImage image(m_effectFrame->geometry().size(), QImage::Format_ARGB32_Premultiplied);
+    image.fill(Qt::transparent);
+    QPainter p(&image);
     p.setFont(m_effectFrame->font());
-    if (m_effectFrame->style() == EffectFrameStyled) {
-        p.setPen(m_effectFrame->styledTextColor());
-    } else {
-        // TODO: What about no frame? Custom color setting required
-        p.setPen(Qt::white);
-    }
+    // TODO: What about no frame? Custom color setting required
+    p.setPen(Qt::white);
     p.drawText(rect, m_effectFrame->alignment(), text);
     p.end();
-    m_textPicture = new XRenderPicture(pixmap);
+    m_textPicture = new XRenderPicture(image);
 }
 
 SceneXRenderShadow::SceneXRenderShadow(Toplevel *toplevel)
@@ -1116,7 +1067,7 @@ bool SceneXRenderShadow::prepareBackend()
     const uint32_t values[] = {XCB_RENDER_REPEAT_NORMAL};
     for (int i=0; i<ShadowElementsCount; ++i) {
         delete m_pictures[i];
-        m_pictures[i] = new XRenderPicture(shadowPixmap(ShadowElements(i)));
+        m_pictures[i] = new XRenderPicture(shadowImage(ShadowElements(i)));
         xcb_render_change_picture(connection(), *m_pictures[i], XCB_RENDER_CP_REPEAT, values);
     }
     return true;
@@ -1130,8 +1081,5 @@ xcb_render_picture_t SceneXRenderShadow::picture(Shadow::ShadowElements element)
     return *m_pictures[element];
 }
 
-#undef DOUBLE_TO_FIXED
-#undef FIXED_TO_DOUBLE
-
 } // namespace
 #endif
