@@ -191,17 +191,12 @@ void Edge::handle(const QPoint &cursorPos)
 bool Edge::handleAction()
 {
     switch (m_action) {
-    case ElectricActionDashboard: { // Display Plasma dashboard
-        QDBusInterface plasmaApp("org.kde.plasma-desktop", "/App");
-        plasmaApp.asyncCall("toggleDashboard");
-        return true;
-    }
     case ElectricActionShowDesktop: {
         Workspace::self()->setShowingDesktop(!Workspace::self()->showingDesktop());
         return true;
     }
     case ElectricActionLockScreen: { // Lock the screen
-        QDBusInterface screenSaver("org.kde.screensaver", "/ScreenSaver");
+        QDBusInterface screenSaver("org.freedesktop.ScreenSaver", "/ScreenSaver", "org.freedesktop.ScreenSaver");
         screenSaver.asyncCall("Lock");
         return true;
     }
@@ -577,14 +572,10 @@ void ScreenEdges::init()
 static ElectricBorderAction electricBorderAction(const QString& name)
 {
     QString lowerName = name.toLower();
-    if (lowerName == "dashboard") {
-        return ElectricActionDashboard;
-    } else if (lowerName == "showdesktop") {
+    if (lowerName == "showdesktop") {
         return ElectricActionShowDesktop;
     } else if (lowerName == "lockscreen") {
         return ElectricActionLockScreen;
-    } else if (lowerName == "preventscreenlocking") {
-        return ElectricActionPreventScreenLocking;
     }
     return ElectricActionNone;
 }
