@@ -113,7 +113,7 @@ protected:
         ShadowElementsCount
     };
 
-    inline const QPixmap &shadowPixmap(ShadowElements element) const {
+    inline const QImage& shadowImage(ShadowElements element) const {
         return m_shadowElements[element];
     };
 
@@ -144,8 +144,8 @@ private:
     static QVector<long> readX11ShadowProperty(WId id);
     bool init(const QVector<long> &data);
     Toplevel *m_topLevel;
-    // shadow pixmaps
-    QPixmap m_shadowElements[ShadowElementsCount];
+    // shadow images
+    QImage m_shadowElements[ShadowElementsCount];
     // shadow offsets
     int m_topOffset;
     int m_rightOffset;
