@@ -23,10 +23,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <unistd.h>
 #include <stdlib.h>
-#include <pwd.h>
 #include <fixx11h.h>
 #include <kconfig.h>
 #include <kglobal.h>
+#include <kuser.h>
 
 #include "workspace.h"
 #include "client.h"
@@ -149,7 +149,6 @@ void Workspace::storeClient(KConfigGroup &cg, int num, Client *c)
     cg.writeEntry(QString("stackingOrder") + n, unconstrained_stacking_order.indexOf(c));
     // KConfig doesn't support long so we need to live with less precision on 64-bit systems
     cg.writeEntry(QString("tabGroup") + n, static_cast<int>(reinterpret_cast<long>(c->tabGroup())));
-    cg.writeEntry(QString("activities") + n, c->activities());
 }
 
 void Workspace::storeSubSession(const QString &name, QSet<QByteArray> sessionIds)
@@ -158,8 +157,7 @@ void Workspace::storeSubSession(const QString &name, QSet<QByteArray> sessionIds
     KConfigGroup cg(KGlobal::config(), QString("SubSession: ") + name);
     int count =  0;
     int active_client = -1;
-    for (ClientList::Iterator it = clients.begin(); it != clients.end(); ++it) {
-        Client* c = (*it);
+    foreach (Client *c, clients) {
         QByteArray sessionId = c->sessionId();
         QByteArray wmCommand = c->wmCommand();
         if (sessionId.isEmpty())
@@ -229,7 +227,6 @@ void Workspace::addSessionInfo(KConfigGroup &cg)
         info->stackingOrder = cg.readEntry(QString("stackingOrder") + n, -1);
         info->tabGroup = cg.readEntry(QString("tabGroup") + n, 0);
         info->tabGroupClient = NULL;
-        info->activities = cg.readEntry(QString("activities") + n, QStringList());
     }
 }
 
@@ -260,7 +257,7 @@ SessionInfo* Workspace::takeSessionInfo(Client* c)
     // First search ``session''
     if (! sessionId.isEmpty()) {
         // look for a real session managed client (algorithm suggested by ICCCM)
-        foreach (SessionInfo * info, session) {
+        foreach (SessionInfo *info, session) {
             if (realInfo)
                 break;
             if (info->sessionId == sessionId && sessionInfoWindowTypeMatch(c, info)) {
@@ -317,7 +314,7 @@ bool Workspace::sessionInfoWindowTypeMatch(Client* c, SessionInfo* info)
 
 static const char* const window_type_names[] = {
     "Unknown", "Normal" , "Desktop", "Dock", "Toolbar", "Menu", "Dialog",
-    "Override", "TopMenu", "Utility", "Splash"
+    "TopMenu", "Utility", "Splash"
 };
 // change also the two functions below when adding new entries
 
@@ -431,9 +428,9 @@ SessionSaveDoneHelper::SessionSaveDoneHelper()
     props[ 0 ].type = const_cast< char* >(SmCARD8);
     props[ 0 ].num_vals = 1;
     props[ 0 ].vals = &propvalue[ 0 ];
-    struct passwd* entry = getpwuid(geteuid());
-    propvalue[ 1 ].length = entry != NULL ? strlen(entry->pw_name) : 0;
-    propvalue[ 1 ].value = (SmPointer)(entry != NULL ? entry->pw_name : "");
+    QByteArray username = KUser(KUser::UseEffectiveUID).loginName().toLocal8Bit();
+    propvalue[ 1 ].length = username.size();
+    propvalue[ 1 ].value = (SmPointer)(username.isEmpty() ? "" : username.data());
     props[ 1 ].name = const_cast< char* >(SmUserID);
     props[ 1 ].type = const_cast< char* >(SmARRAY8);
     props[ 1 ].num_vals = 1;
@@ -494,4 +491,4 @@ void Workspace::sessionSaveDone()
 
 } // namespace
 
-#include "sm.moc"
+#include "moc_sm.cpp"
