@@ -31,7 +31,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <X11/SM/SMlib.h>
 #include <fixx11h.h>
 
-class QSocketNotifier;
+#include <QSocketNotifier>
 
 namespace KWin
 {
@@ -69,7 +69,6 @@ struct SessionInfo {
     int tabGroup; // Unique identifier for the client group that this window is in
 
     Client* tabGroupClient; // The first client created that has an identical identifier
-    QStringList activities;
 };
 
 
