@@ -26,20 +26,20 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtDeclarative/QDeclarativeContext>
 #include <QtDeclarative/QDeclarativeEngine>
 #include <QDesktopWidget>
-#include <QGraphicsObject>
-#include <QtGui/QResizeEvent>
-#include <QX11Info>
+#include <QtGui/qgraphicsitem.h>
+#include <QtGui/qevent.h>
+#include <QtGui/qx11info_x11.h>
 
 // include KDE
-#include <KDE/KDebug>
-#include <KDE/KGlobal>
-#include <KDE/KIconEffect>
-#include <KDE/KIconLoader>
-#include <KDE/KServiceTypeTrader>
-#include <KDE/KStandardDirs>
-#include <KDE/Plasma/FrameSvg>
-#include <KDE/Plasma/Theme>
-#include <KDE/Plasma/WindowEffects>
+#include <KDebug>
+#include <KGlobal>
+#include <KIconEffect>
+#include <KIconLoader>
+#include <KServiceTypeTrader>
+#include <KStandardDirs>
+#include <Plasma/FrameSvg>
+#include <Plasma/Theme>
+#include <Plasma/WindowEffects>
 #include <kdeclarative.h>
 // KWin
 #include "thumbnailitem.h"
@@ -118,7 +118,6 @@ DeclarativeView::DeclarativeView(QAbstractItemModel *model, TabBoxConfig::TabBox
     , m_model(model)
     , m_mode(mode)
     , m_currentScreenGeometry()
-    , m_frame(new Plasma::FrameSvg(this))
     , m_currentLayout()
     , m_cachedWidth(0)
     , m_cachedHeight(0)
@@ -148,12 +147,7 @@ DeclarativeView::DeclarativeView(QAbstractItemModel *model, TabBoxConfig::TabBox
     } else if (m_mode == TabBoxConfig::DesktopTabBox) {
         rootContext()->setContextProperty("clientModel", model);
     }
-    setSource(QUrl(KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + QLatin1String("/tabbox/tabbox.qml"))));
-
-    // FrameSvg
-    m_frame->setImagePath("dialogs/background");
-    m_frame->setCacheAllRenderedFrames(true);
-    m_frame->setEnabledBorders(Plasma::FrameSvg::AllBorders);
+    setSource(QUrl(KStandardDirs::locate("data", QLatin1String("kwin/tabbox/tabbox.qml"))));
 
     connect(tabBox, SIGNAL(configChanged()), SLOT(updateQmlSource()));
     if (m_mode == TabBoxConfig::ClientTabBox) {
@@ -191,40 +185,6 @@ void DeclarativeView::showEvent(QShowEvent *event)
     QGraphicsView::showEvent(event);
 }
 
-void DeclarativeView::resizeEvent(QResizeEvent *event)
-{
-    if (tabBox->embedded()) {
-        Plasma::WindowEffects::enableBlurBehind(winId(), false);
-    } else {
-        const QString maskImagePath = rootObject()->property("maskImagePath").toString();
-        if (maskImagePath.isEmpty()) {
-            clearMask();
-            Plasma::WindowEffects::enableBlurBehind(winId(), false);
-        } else {
-            const double maskWidth = rootObject()->property("maskWidth").toDouble();
-            const double maskHeight = rootObject()->property("maskHeight").toDouble();
-            const int maskTopMargin = rootObject()->property("maskTopMargin").toInt();
-            const int maskLeftMargin = rootObject()->property("maskLeftMargin").toInt();
-            m_frame->setImagePath(maskImagePath);
-            m_frame->resizeFrame(QSizeF(maskWidth, maskHeight));
-            QRegion mask = m_frame->mask().translated(maskLeftMargin, maskTopMargin);
-#ifndef TABBOX_KCM
-            // notice: this covers an issue with plasma detecting the compositing state. see plasmaThemeVariant()
-            if (Workspace::self()->compositing() && effects) {
-                // blur background?!
-                Plasma::WindowEffects::enableBlurBehind(winId(), static_cast<EffectsHandlerImpl*>(effects)->provides(Effect::Blur), mask);
-                clearMask();
-            } else
-#endif
-            {
-                // do not trim to mask with compositing enabled, otherwise shadows are cropped
-                setMask(mask);
-            }
-        }
-    }
-    QDeclarativeView::resizeEvent(event);
-}
-
 void DeclarativeView::hideEvent(QHideEvent *event)
 {
     QWidget::hideEvent(event);
@@ -390,14 +350,14 @@ QString DeclarativeView::findWindowSwitcherScriptFile(KService::Ptr service)
 {
     const QString pluginName = service->property("X-KDE-PluginInfo-Name").toString();
     const QString scriptName = service->property("X-Plasma-MainScript").toString();
-    return KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + "/tabbox/" + pluginName + "/contents/" + scriptName);
+    return KStandardDirs::locate("data", "kwin/tabbox/" + pluginName + "/contents/" + scriptName);
 }
 
 QString DeclarativeView::findDesktopSwitcherScriptFile(KService::Ptr service)
 {
     const QString pluginName = service->property("X-KDE-PluginInfo-Name").toString();
     const QString scriptName = service->property("X-Plasma-MainScript").toString();
-    return KStandardDirs::locate("data", QLatin1String(KWIN_NAME) + "/desktoptabbox/" + pluginName + "/contents/" + scriptName);
+    return KStandardDirs::locate("data", "kwin/desktoptabbox/" + pluginName + "/contents/" + scriptName);
 }
 
 void DeclarativeView::slotEmbeddedChanged(bool enabled)
