@@ -20,7 +20,6 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
-//#define QT_CLEAN_NAMESPACE
 // own
 #include "tabbox.h"
 // tabbox
@@ -29,9 +28,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "tabbox/tabboxconfig.h"
 #include "tabbox/desktopchain.h"
 // kwin
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
 #include "client.h"
 #include "effects.h"
 #include "focuschain.h"
@@ -44,16 +40,16 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "workspace.h"
 // Qt
 #include <QAction>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <QtDBus/QDBusConnection>
 // KDE
 #include <KActionCollection>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KDE/KAction>
+#include <KAction>
 #include <KDebug>
-#include <KDE/KIcon>
-#include <KDE/KGlobal>
+#include <KIcon>
+#include <KGlobal>
 #include <KLocalizedString>
 #include <kkeyserver.h>
 // X11
@@ -80,9 +76,6 @@ TabBoxHandlerImpl::TabBoxHandlerImpl(TabBox* tabBox)
     VirtualDesktopManager *vds = VirtualDesktopManager::self();
     connect(vds, SIGNAL(countChanged(uint,uint)), m_desktopFocusChain, SLOT(resize(uint,uint)));
     connect(vds, SIGNAL(currentChanged(uint,uint)), m_desktopFocusChain, SLOT(addDesktop(uint,uint)));
-#ifdef KWIN_BUILD_ACTIVITIES
-    connect(Activities::self(), SIGNAL(currentChanged(QString)), m_desktopFocusChain, SLOT(useChain(QString)));
-#endif
 }
 
 TabBoxHandlerImpl::~TabBoxHandlerImpl()
@@ -172,20 +165,6 @@ bool TabBoxHandlerImpl::checkDesktop(TabBoxClient* client, int desktop) const
     }
 }
 
-bool TabBoxHandlerImpl::checkActivity(TabBoxClient* client) const
-{
-    Client* current = (static_cast< TabBoxClientImpl* >(client))->client();
-
-    switch (config().clientActivitiesMode()) {
-    case TabBoxConfig::AllActivitiesClients:
-        return true;
-    case TabBoxConfig::ExcludeCurrentActivityClients:
-        return !current->isOnCurrentActivity();
-    default:       // TabBoxConfig::OnlyCurrentActivityClients
-        return current->isOnCurrentActivity();
-    }
-}
-
 bool TabBoxHandlerImpl::checkApplications(TabBoxClient* client) const
 {
     Client* current = (static_cast< TabBoxClientImpl* >(client))->client();
@@ -259,7 +238,6 @@ QWeakPointer<TabBoxClient> TabBoxHandlerImpl::clientToAddToList(TabBoxClient* cl
     Client* current = (static_cast< TabBoxClientImpl* >(client))->client();
 
     bool addClient = checkDesktop(client, desktop)
-                  && checkActivity(client)
                   && checkApplications(client)
                   && checkMinimized(client)
                   && checkMultiScreen(client);
@@ -433,7 +411,6 @@ TabBox::TabBox(QObject *parent)
     m_defaultConfig = TabBoxConfig();
     m_defaultConfig.setTabBoxMode(TabBoxConfig::ClientTabBox);
     m_defaultConfig.setClientDesktopMode(TabBoxConfig::OnlyCurrentDesktopClients);
-    m_defaultConfig.setClientActivitiesMode(TabBoxConfig::OnlyCurrentActivityClients);
     m_defaultConfig.setClientApplicationsMode(TabBoxConfig::AllWindowsAllApplications);
     m_defaultConfig.setClientMinimizedMode(TabBoxConfig::IgnoreMinimizedStatus);
     m_defaultConfig.setShowDesktopMode(TabBoxConfig::DoNotShowDesktopClient);
@@ -443,7 +420,6 @@ TabBox::TabBox(QObject *parent)
     m_alternativeConfig = TabBoxConfig();
     m_alternativeConfig.setTabBoxMode(TabBoxConfig::ClientTabBox);
     m_alternativeConfig.setClientDesktopMode(TabBoxConfig::AllDesktopsClients);
-    m_alternativeConfig.setClientActivitiesMode(TabBoxConfig::OnlyCurrentActivityClients);
     m_alternativeConfig.setClientApplicationsMode(TabBoxConfig::AllWindowsAllApplications);
     m_alternativeConfig.setClientMinimizedMode(TabBoxConfig::IgnoreMinimizedStatus);
     m_alternativeConfig.setShowDesktopMode(TabBoxConfig::DoNotShowDesktopClient);
@@ -759,8 +735,6 @@ void TabBox::loadConfig(const KConfigGroup& config, TabBoxConfig& tabBoxConfig)
 {
     tabBoxConfig.setClientDesktopMode(TabBoxConfig::ClientDesktopMode(
                                        config.readEntry<int>("DesktopMode", TabBoxConfig::defaultDesktopMode())));
-    tabBoxConfig.setClientActivitiesMode(TabBoxConfig::ClientActivitiesMode(
-                                       config.readEntry<int>("ActivitiesMode", TabBoxConfig::defaultActivitiesMode())));
     tabBoxConfig.setClientApplicationsMode(TabBoxConfig::ClientApplicationsMode(
                                        config.readEntry<int>("ApplicationsMode", TabBoxConfig::defaultApplicationsMode())));
     tabBoxConfig.setClientMinimizedMode(TabBoxConfig::ClientMinimizedMode(
@@ -865,8 +839,9 @@ void TabBox::grabbedKeyEvent(QKeyEvent* event)
  */
 static bool areKeySymXsDepressed(bool bAll, const uint keySyms[], int nKeySyms) {
     char keymap[32];
+    ::memset(keymap, 0, sizeof(keymap) * sizeof(char));
 
-    kDebug(125) << "areKeySymXsDepressed: " << (bAll ? "all of " : "any of ") << nKeySyms;
+    kDebug(1212) << "areKeySymXsDepressed: " << (bAll ? "all of " : "any of ") << nKeySyms;
 
     XQueryKeymap(display(), keymap);
 
@@ -880,9 +855,9 @@ static bool areKeySymXsDepressed(bool bAll, const uint keySyms[], int nKeySyms)
         if (i < 0 || i >= 32)
             return false;
 
-        kDebug(125) << iKeySym << ": keySymX=0x" << QString::number(keySymX, 16)
+        kDebug(1212) << iKeySym << ": keySymX=0x" << QString::number(keySymX, 16)
                     << " i=" << i << " mask=0x" << QString::number(mask, 16)
-                    << " keymap[i]=0x" << QString::number(keymap[i], 16) << endl;
+                    << " keymap[i]=0x" << QString::number(keymap[i], 16);
 
         // If ALL keys passed need to be depressed,
         if (bAll) {
@@ -1259,7 +1234,7 @@ void TabBox::CDEWalkThroughWindows(bool forward)
             i >= 0 ;
             --i) {
         Client* it = qobject_cast<Client*>(Workspace::self()->stackingOrder().at(i));
-        if (it && it->isOnCurrentActivity() && it->isOnCurrentDesktop() && !it->isSpecialWindow()
+        if (it && it->isOnCurrentDesktop() && !it->isSpecialWindow()
                 && it->isShown(false) && it->wantsTabFocus()
                 && !it->keepAbove() && !it->keepBelow()) {
             c = it;
@@ -1287,7 +1262,7 @@ void TabBox::CDEWalkThroughWindows(bool forward)
         }
     } while (nc && nc != c &&
             ((!options_traverse_all && !nc->isOnDesktop(currentDesktop())) ||
-             nc->isMinimized() || !nc->wantsTabFocus() || nc->keepAbove() || nc->keepBelow() || !nc->isOnCurrentActivity()));
+             nc->isMinimized() || !nc->wantsTabFocus() || nc->keepAbove() || nc->keepBelow()));
     if (nc) {
         if (c && c != nc)
             Workspace::self()->lowerClient(c);
@@ -1363,7 +1338,7 @@ void TabBox::keyPress(int keyQt)
                 backwardShortcut = m_cutWalkThroughCurrentAppWindowsAlternativeReverse;
                 break;
             default:
-                kDebug(125) << "Invalid TabBoxMode";
+                kDebug(1212) << "Invalid TabBoxMode";
                 return;
         }
         forward = forwardShortcut.contains(keyQt);
@@ -1393,8 +1368,8 @@ void TabBox::keyPress(int keyQt)
             }
         }
         if (forward || backward) {
-            kDebug(125) << "== " << forwardShortcut.toString()
-                        << " or " << backwardShortcut.toString() << endl;
+            kDebug(1212) << "== " << forwardShortcut.toString()
+                        << " or " << backwardShortcut.toString();
             KDEWalkThroughWindows(forward);
         }
     } else if (m_desktopGrab) {
@@ -1605,4 +1580,4 @@ void TabBox::removeTabBoxGrab()
 } // namespace TabBox
 } // namespace
 
-#include "tabbox.moc"
+#include "moc_tabbox.cpp"
