@@ -24,14 +24,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define KWIN_TABBOX_H
 
 #include <QTimer>
-#include <QModelIndex>
-#include <KDE/KShortcut>
+#include <QtCore/qabstractitemmodel.h>
+#include <KShortcut>
 #include "utils.h"
 #include "tabbox/tabboxhandler.h"
 
 class KActionCollection;
 class KConfigGroup;
-class QKeyEvent;
+#include <QKeyEvent>
 
 namespace KWin
 {
@@ -70,7 +70,6 @@ public:
 
 private:
     bool checkDesktop(TabBoxClient* client, int desktop) const;
-    bool checkActivity(TabBoxClient* client) const;
     bool checkApplications(TabBoxClient* client) const;
     bool checkMinimized(TabBoxClient* client) const;
     bool checkMultiScreen(TabBoxClient* client) const;
