@@ -19,10 +19,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "../virtualdesktops.h"
 // KDE
-#include <KDE/KAction>
-#include <KDE/KActionCollection>
-#include <KDE/KConfigGroup>
+#include <KAction>
+#include <KActionCollection>
+#include <KConfigGroup>
 
+#include <QtCore/QScopedPointer>
 #include <QtTest/QtTest>
 
 namespace KWin {
