@@ -21,8 +21,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kwineffects.h>
 
 #include <QtGui/QVector2D>
-#include <QGraphicsRotation>
-#include <QGraphicsScale>
+#include <QtGui/qgraphicstransform.h>
+#include <QtGui/qgraphicstransform.h>
 
 #include <QtTest/QtTest>
 
