@@ -40,18 +40,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "screens.h"
 #include "virtualdesktops.h"
 
-#ifdef KWIN_BUILD_SCRIPTING
-#include "scripting/scripting.h"
-#endif
 
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#include <KActivities/Info>
-#endif
 
-#include <KDE/KKeySequenceWidget>
-#include <KDE/KProcess>
-#include <KDE/KToolInvocation>
+#include <KKeySequenceWidget>
+#include <KToolInvocation>
 
 #include <X11/extensions/Xrandr.h>
 #ifndef KWIN_NO_XF86VM
@@ -59,22 +51,23 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #endif
 #include <fixx11h.h>
 #include <QCheckBox>
+#include <QPointer>
 #include <QPushButton>
+#include <QProcess>
 
 #include <kglobalsettings.h>
-#include <KDE/KIcon>
+#include <KIcon>
 #include <kiconloader.h>
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 #include <kconfig.h>
-#include <KDE/KGlobal>
-#include <KDE/KPushButton>
+#include <KGlobal>
+#include <KPushButton>
 #include <kglobalaccel.h>
 #include <kapplication.h>
 #include <QRegExp>
 #include <QLabel>
 #include <QMenu>
 #include <QVBoxLayout>
-#include <kauthorized.h>
 #include <kactioncollection.h>
 #include <kaction.h>
 
@@ -91,12 +84,8 @@ UserActionsMenu::UserActionsMenu(QObject *parent)
     , m_menu(NULL)
     , m_desktopMenu(NULL)
     , m_screenMenu(NULL)
-    , m_activityMenu(NULL)
     , m_addTabsMenu(NULL)
     , m_switchToTabMenu(NULL)
-#ifdef KWIN_BUILD_SCRIPTING
-    , m_scriptsMenu(NULL)
-#endif
     , m_resizeOperation(NULL)
     , m_moveOperation(NULL)
     , m_maximizeOperation(NULL)
@@ -147,8 +136,6 @@ bool UserActionsMenu::isMenuClient(const Client *c) const
 
 void UserActionsMenu::show(const QRect &pos, const QWeakPointer<Client> &cl)
 {
-    if (!KAuthorized::authorizeKAction("kwin_rmb"))
-        return;
     if (cl.isNull())
         return;
     if (isShown())   // recursion
@@ -163,13 +150,9 @@ void UserActionsMenu::show(const QRect &pos, const QWeakPointer<Client> &cl)
     int x = pos.left();
     int y = pos.bottom();
     if (y == pos.top()) {
-        m_client.data()->blockActivityUpdates(true);
         m_menu->exec(QPoint(x, y));
-        if (!m_client.isNull())
-            m_client.data()->blockActivityUpdates(false);
     }
     else {
-        m_client.data()->blockActivityUpdates(true);
         QRect area = ws->clientArea(ScreenArea, QPoint(x, y), VirtualDesktopManager::self()->current());
         menuAboutToShow(); // needed for sizeHint() to be correct :-/
         int popupHeight = m_menu->sizeHint().height();
@@ -177,8 +160,6 @@ void UserActionsMenu::show(const QRect &pos, const QWeakPointer<Client> &cl)
             m_menu->exec(QPoint(x, y));
         else
             m_menu->exec(QPoint(x, pos.top() - popupHeight));
-        if (!m_client.isNull())
-            m_client.data()->blockActivityUpdates(true);
     }
 }
 
@@ -223,36 +204,30 @@ void UserActionsMenu::helperDialog(const QString& message, const QWeakPointer<Cl
     }
     if (!c.isNull())
         args << "--embed" << QString::number(c.data()->window());
-    KProcess::startDetached("kdialog", args);
+    QProcess::startDetached("kdialog", args);
 }
 
 
-QStringList configModules(bool controlCenter)
+static QStringList configModules()
 {
     QStringList args;
-    args <<  "kwindecoration";
-    if (controlCenter)
-        args << "kwinoptions";
-    else if (KAuthorized::authorizeControlModule("kde-kwinoptions.desktop"))
-        args << "kwinactions" << "kwinfocus" <<  "kwinmoving" << "kwinadvanced"
-             << "kwinrules" << "kwincompositing"
+    args << "kwindecoration";
+    args << "kwinactions" << "kwinfocus" <<  "kwinmoving" << "kwinadvanced"
+         << "kwinrules" << "kwincompositing"
 #ifdef KWIN_BUILD_TABBOX
-             << "kwintabbox"
+         << "kwintabbox"
 #endif
 #ifdef KWIN_BUILD_SCREENEDGES
-             << "kwinscreenedges"
+         << "kwinscreenedges"
 #endif
-#ifdef KWIN_BUILD_SCRIPTING
-             << "kwinscripts"
-#endif
-             ;
+        ;
     return args;
 }
 
 void UserActionsMenu::configureWM()
 {
     QStringList args;
-    args << "--icon" << "preferences-system-windows" << configModules(false);
+    args << "--icon" << "preferences-system-windows" << configModules();
     KToolInvocation::kdeinitExec("kcmshell4", args);
 }
 
@@ -337,8 +312,7 @@ void UserActionsMenu::init()
     action = advancedMenu->addAction(i18n("S&pecial Application Settings..."));
     action->setIcon(KIcon("preferences-system-windows-actions"));
     action->setData(Options::ApplicationRulesOp);
-    if (!KGlobal::config()->isImmutable() &&
-            !KAuthorized::authorizeControlModules(configModules(true)).isEmpty()) {
+    if (!KGlobal::config()->isImmutable()) {
         advancedMenu->addSeparator();
         action = advancedMenu->addAction(i18nc("Entry in context menu of window decoration to open the configuration module of KWin",
                                         "Window &Manager Settings..."));
@@ -400,12 +374,8 @@ void UserActionsMenu::discard()
     m_menu = NULL;
     m_desktopMenu = NULL;
     m_screenMenu = NULL;
-    m_activityMenu = NULL;
     m_switchToTabMenu = NULL;
     m_addTabsMenu = NULL;
-#ifdef KWIN_BUILD_SCRIPTING
-    m_scriptsMenu = NULL;
-#endif
 }
 
 void UserActionsMenu::menuAboutToShow()
@@ -425,9 +395,6 @@ void UserActionsMenu::menuAboutToShow()
     } else {
         initScreenPopup();
     }
-#ifdef KWIN_BUILD_ACTIVITIES
-    Activities::self()->update(true, false, this, "showHideActivityMenu");
-#endif
 
     m_resizeOperation->setEnabled(m_client.data()->isResizable());
     m_moveOperation->setEnabled(m_client.data()->isMovableAcrossScreens());
@@ -451,40 +418,6 @@ void UserActionsMenu::menuAboutToShow()
         m_addTabsMenu = 0;
     }
 
-#ifdef KWIN_BUILD_SCRIPTING
-    // drop the existing scripts menu
-    delete m_scriptsMenu;
-    m_scriptsMenu = NULL;
-    // ask scripts whether they want to add entries for the given Client
-    m_scriptsMenu = new QMenu(m_menu);
-    QList<QAction*> scriptActions = Scripting::self()->actionsForUserActionMenu(m_client.data(), m_scriptsMenu);
-    if (!scriptActions.isEmpty()) {
-        m_scriptsMenu->setFont(KGlobalSettings::menuFont());
-        m_scriptsMenu->addActions(scriptActions);
-
-        QAction *action = m_scriptsMenu->menuAction();
-        // set it as the first item after desktop
-        m_menu->insertAction(m_closeOperation, action);
-        action->setText(i18n("&Extensions"));
-    } else {
-        delete m_scriptsMenu;
-        m_scriptsMenu = NULL;
-    }
-#endif
-}
-
-void UserActionsMenu::showHideActivityMenu()
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    const QStringList &openActivities_ = Activities::self()->running();
-    kDebug() << "activities:" << openActivities_.size();
-    if (openActivities_.size() < 2) {
-        delete m_activityMenu;
-        m_activityMenu = 0;
-    } else {
-        initActivityPopup();
-    }
-#endif
 }
 
 void UserActionsMenu::selectPopupClientTab(QAction* action)
@@ -620,26 +553,8 @@ void UserActionsMenu::initScreenPopup()
 
     QAction *action = m_screenMenu->menuAction();
     // set it as the first item after desktop
-    m_menu->insertAction(m_activityMenu ? m_activityMenu->menuAction() : m_minimizeOperation, action);
-    action->setText(i18n("Move To &Screen"));
-}
-
-void UserActionsMenu::initActivityPopup()
-{
-    if (m_activityMenu)
-        return;
-
-    m_activityMenu = new QMenu(m_menu);
-    m_activityMenu->setFont(KGlobalSettings::menuFont());
-    connect(m_activityMenu, SIGNAL(triggered(QAction*)),
-            this, SLOT(slotToggleOnActivity(QAction*)));
-    connect(m_activityMenu, SIGNAL(aboutToShow()),
-            this, SLOT(activityPopupAboutToShow()));
-
-    QAction *action = m_activityMenu->menuAction();
-    // set it as the first item
     m_menu->insertAction(m_minimizeOperation, action);
-    action->setText(i18n("Ac&tivities"));   //FIXME is that a good string?
+    action->setText(i18n("Move To &Screen"));
 }
 
 void UserActionsMenu::desktopPopupAboutToShow()
@@ -706,50 +621,6 @@ void UserActionsMenu::screenPopupAboutToShow()
     }
 }
 
-void UserActionsMenu::activityPopupAboutToShow()
-{
-    if (!m_activityMenu)
-        return;
-
-#ifdef KWIN_BUILD_ACTIVITIES
-    m_activityMenu->clear();
-    QAction *action = m_activityMenu->addAction(i18n("&All Activities"));
-    action->setData(QString());
-    action->setCheckable(true);
-    static QActionGroup *allActivitiesGroup = NULL;
-    if (!allActivitiesGroup) {
-        allActivitiesGroup = new QActionGroup(m_activityMenu);
-    }
-    allActivitiesGroup->addAction(action);
-
-    if (!m_client.isNull() && m_client.data()->isOnAllActivities())
-        action->setChecked(true);
-    m_activityMenu->addSeparator();
-
-    foreach (const QString &id, Activities::self()->running()) {
-        KActivities::Info activity(id);
-        QString name = activity.name();
-        name.replace('&', "&&");
-        QWidgetAction *action = new QWidgetAction(m_activityMenu);
-        QCheckBox *box = new QCheckBox(name, m_activityMenu);
-        action->setDefaultWidget(box);
-        const QString icon = activity.icon();
-        if (!icon.isEmpty())
-            box->setIcon(KIcon(icon));
-        box->setBackgroundRole(m_activityMenu->backgroundRole());
-        box->setForegroundRole(m_activityMenu->foregroundRole());
-        box->setPalette(m_activityMenu->palette());
-        connect (box, SIGNAL(clicked(bool)), action, SIGNAL(triggered(bool)));
-        m_activityMenu->addAction(action);
-        action->setData(id);
-
-        if (!m_client.isNull() &&
-                !m_client.data()->isOnAllActivities() && m_client.data()->isOnActivity(id))
-            box->setChecked(true);
-    }
-#endif
-}
-
 void UserActionsMenu::slotWindowOperation(QAction *action)
 {
     if (!action->data().isValid())
@@ -812,38 +683,6 @@ void UserActionsMenu::slotSendToScreen(QAction *action)
     Workspace::self()->sendClientToScreen(m_client.data(), screen);
 }
 
-void UserActionsMenu::slotToggleOnActivity(QAction *action)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    QString activity = action->data().toString();
-    if (m_client.isNull())
-        return;
-    if (activity.isEmpty()) {
-        // the 'on_all_activities' menu entry
-        m_client.data()->setOnAllActivities(!m_client.data()->isOnAllActivities());
-        return;
-    }
-
-    Activities::self()->toggleClientOnActivity(m_client.data(), activity, false);
-    if (m_activityMenu && m_activityMenu->isVisible() && m_activityMenu->actions().count()) {
-        const bool isOnAll = m_client.data()->isOnAllActivities();
-        m_activityMenu->actions().at(0)->setChecked(isOnAll);
-        if (isOnAll) {
-            // toggleClientOnActivity interprets "on all" as "on none" and
-            // susequent toggling ("off") would move the client to only that activity.
-            // bug #330838 -> set all but "on all" off to "force proper usage"
-            for (int i = 1; i < m_activityMenu->actions().count(); ++i) {
-                if (QWidgetAction *qwa = qobject_cast<QWidgetAction*>(m_activityMenu->actions().at(i))) {
-                    if (QCheckBox *qcb = qobject_cast<QCheckBox*>(qwa->defaultWidget())) {
-                        qcb->setChecked(false);
-                    }
-                }
-            }
-        }
-    }
-#endif
-}
-
 //****************************************
 // ShortcutDialog
 //****************************************
@@ -1175,7 +1014,7 @@ Options::WindowOperation Client::mouseButtonToWindowOperation(Qt::MouseButtons b
 
     if (button == Qt::LeftButton)
         com = active ? options->commandActiveTitlebar1() : options->commandInactiveTitlebar1();
-    else if (button == Qt::MidButton)
+    else if (button == Qt::MiddleButton)
         com = active ? options->commandActiveTitlebar2() : options->commandInactiveTitlebar2();
     else if (button == Qt::RightButton)
         com = active ? options->commandActiveTitlebar3() : options->commandInactiveTitlebar3();
@@ -1239,7 +1078,7 @@ bool Client::performMouseCommand(Options::MouseCommand command, const QPoint &gl
                 Client *c = qobject_cast<Client*>(*it);
                 if (!c || (c->keepAbove() && !keepAbove()) || (keepBelow() && !c->keepBelow()))
                     continue; // can never raise above "it"
-                mustReplay = !(c->isOnCurrentDesktop() && c->isOnCurrentActivity() && c->geometry().intersects(geometry()));
+                mustReplay = !(c->isOnCurrentDesktop() && c->geometry().intersects(geometry()));
             }
         }
         workspace()->takeActivity(this, ActivityFocus | ActivityRaise, handled && replay);
@@ -1414,7 +1253,7 @@ static bool screenSwitchImpossible()
     QStringList args;
     args << "--passivepopup" << i18n("The window manager is configured to consider the screen with the mouse on it as active one.\n"
                                      "Therefore it is not possible to switch to a screen explicitly.") << "20";
-    KProcess::startDetached("kdialog", args);
+    QProcess::startDetached("kdialog", args);
     return true;
 }
 
@@ -1733,7 +1572,7 @@ void Workspace::switchWindow(Direction direction)
             continue;
         }
         if (client->wantsTabFocus() && *i != c &&
-                client->desktop() == d && !client->isMinimized() && (*i)->isOnCurrentActivity()) {
+                client->desktop() == d && !client->isMinimized()) {
             // Centre of the other window
             QPoint other(client->pos().x() + client->geometry().width() / 2,
                          client->pos().y() + client->geometry().height() / 2);
@@ -1916,15 +1755,7 @@ void Workspace::slotInvertScreen()
 
     if (succeeded)
         return;
-#endif
-
-    //BEGIN effect plugin inversion - atm only works with OpenGL and has an overhead to it
-    if (effects) {
-        if (Effect *inverter = static_cast<EffectsHandlerImpl*>(effects)->provides(Effect::ScreenInversion)) {
-            kDebug(1212) << "inverting screen using Effect plugin";
-            QMetaObject::invokeMethod(inverter, "toggleScreenInversion", Qt::DirectConnection);
-        }
-    }
+#endif // KWIN_NO_XF86VM
 
     if (!succeeded)
         kDebug(1212) << "sorry - neither Xrandr, nor XF86VidModeSetGammaRamp worked and there's no inversion supplying effect plugin either";
@@ -1953,11 +1784,9 @@ void Client::setShortcut(const QString& _cut)
     }
     QList< KShortcut > keys;
     QStringList groups = cut.split(" - ");
-    for (QStringList::ConstIterator it = groups.constBegin();
-            it != groups.constEnd();
-            ++it) {
+    foreach (const QString it, groups) {
         QRegExp reg("(.*\\+)\\((.*)\\)");
-        if (reg.indexIn(*it) > -1) {
+        if (reg.indexIn(it) > -1) {
             QString base = reg.cap(1);
             QString list = reg.cap(2);
             for (int i = 0;
@@ -1969,23 +1798,17 @@ void Client::setShortcut(const QString& _cut)
             }
         } else {
             // regexp doesn't match, so it should be a normal shortcut
-            KShortcut c(*it);
+            KShortcut c(it);
             if (!c.isEmpty()) {
                 keys.append(c);
             }
         }
     }
-    for (QList< KShortcut >::ConstIterator it = keys.constBegin();
-            it != keys.constEnd();
-            ++it) {
-        if (_shortcut == *it)   // current one is in the list
+    foreach (const KShortcut it, keys) {
+        if (_shortcut == it)   // current one is in the list
             return;
-    }
-    for (QList< KShortcut >::ConstIterator it = keys.constBegin();
-            it != keys.constEnd();
-            ++it) {
-        if (workspace()->shortcutAvailable(*it, this)) {
-            setShortcutInternal(*it);
+        if (workspace()->shortcutAvailable(it, this)) {
+            setShortcutInternal(it);
             return;
         }
     }
@@ -2017,15 +1840,13 @@ bool Workspace::shortcutAvailable(const KShortcut& cut, Client* ignore) const
 {
     if (ignore && cut == ignore->shortcut())
         return true;
-    Q_FOREACH (const QKeySequence &seq, cut.toList()) {
+    foreach (const QKeySequence &seq, cut.toList()) {
         if (!KGlobalAccel::getGlobalShortcutsByKey(seq).isEmpty()) {
             return false;
         }
     }
-    for (ClientList::ConstIterator it = clients.constBegin();
-            it != clients.constEnd();
-            ++it) {
-        if ((*it) != ignore && (*it)->shortcut() == cut)
+    foreach (const Client* it, clients) {
+        if (it != ignore && it->shortcut() == cut)
             return false;
     }
     return true;
