@@ -27,7 +27,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "utils.h"
 
-#include <kxerrorhandler.h>
 #include <X11/Xatom.h>
 
 #ifndef KCMRULES
@@ -37,7 +36,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <X11/Xlib.h>
 #include <X11/extensions/shape.h>
-#include <QX11Info>
+#include <QtGui/qwidget.h>
+#include <QtGui/qx11info_x11.h>
 
 #include <stdio.h>
 
@@ -276,7 +276,7 @@ int qtToX11Button(Qt::MouseButton button)
 {
     if (button == Qt::LeftButton)
         return XCB_BUTTON_INDEX_1;
-    else if (button == Qt::MidButton)
+    else if (button == Qt::MiddleButton)
         return XCB_BUTTON_INDEX_2;
     else if (button == Qt::RightButton)
         return XCB_BUTTON_INDEX_3;
@@ -288,13 +288,9 @@ Qt::MouseButton x11ToQtMouseButton(int button)
     if (button == XCB_BUTTON_INDEX_1)
         return Qt::LeftButton;
     if (button == XCB_BUTTON_INDEX_2)
-        return Qt::MidButton;
+        return Qt::MiddleButton;
     if (button == XCB_BUTTON_INDEX_3)
         return Qt::RightButton;
-    if (button == XCB_BUTTON_INDEX_4)
-        return Qt::XButton1;
-    if (button == XCB_BUTTON_INDEX_5)
-        return Qt::XButton2;
     return Qt::NoButton;
 }
 
@@ -303,7 +299,7 @@ int qtToX11State(Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers)
     int ret = 0;
     if (buttons & Qt::LeftButton)
         ret |= XCB_KEY_BUT_MASK_BUTTON_1;
-    if (buttons & Qt::MidButton)
+    if (buttons & Qt::MiddleButton)
         ret |= XCB_KEY_BUT_MASK_BUTTON_2;
     if (buttons & Qt::RightButton)
         ret |= XCB_KEY_BUT_MASK_BUTTON_3;
@@ -324,13 +320,9 @@ Qt::MouseButtons x11ToQtMouseButtons(int state)
     if (state & XCB_KEY_BUT_MASK_BUTTON_1)
         ret |= Qt::LeftButton;
     if (state & XCB_KEY_BUT_MASK_BUTTON_2)
-        ret |= Qt::MidButton;
+        ret |= Qt::MiddleButton;
     if (state & XCB_KEY_BUT_MASK_BUTTON_3)
         ret |= Qt::RightButton;
-    if (state & XCB_KEY_BUT_MASK_BUTTON_4)
-        ret |= Qt::XButton1;
-    if (state & XCB_KEY_BUT_MASK_BUTTON_5)
-        ret |= Qt::XButton2;
     return ret;
 }
 
@@ -351,6 +343,3 @@ Qt::KeyboardModifiers x11ToQtKeyboardModifiers(int state)
 #endif
 } // namespace
 
-#ifndef KCMRULES
-#include "utils.moc"
-#endif
