@@ -22,14 +22,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "workspace.h"
 // kwin libs
 #include <kdecorationfactory.h>
-#include <kwinglplatform.h>
 // kwin
-#ifdef KWIN_BUILD_ACTIVITIES
-#include "activities.h"
-#endif
-#ifdef KWIN_BUILD_KAPPMENU
-#include "appmenu.h"
-#endif
 #include "atoms.h"
 #include "client.h"
 #include "composite.h"
@@ -42,16 +35,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "group.h"
 #include "killwindow.h"
 #include "netinfo.h"
-#include "outline.h"
 #include "placement.h"
 #include "rules.h"
 #ifdef KWIN_BUILD_SCREENEDGES
 #include "screenedge.h"
 #endif
 #include "screens.h"
-#ifdef KWIN_BUILD_SCRIPTING
-#include "scripting/scripting.h"
-#endif
 #ifdef KWIN_BUILD_TABBOX
 #include "tabbox.h"
 #endif
@@ -61,21 +50,22 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "xcbutils.h"
 // KDE
 #include <kdeversion.h>
-#include <KDE/KActionCollection>
-#include <KDE/KCmdLineArgs>
-#include <KDE/KConfig>
-#include <KDE/KConfigGroup>
-#include <KDE/KGlobal>
-#include <KDE/KGlobalSettings>
-#include <KDE/KStartupInfo>
-#include <KDE/KWindowInfo>
-#include <KDE/KWindowSystem>
+#include <KActionCollection>
+#include <KCmdLineArgs>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KGlobal>
+#include <KGlobalSettings>
+#include <KStartupInfo>
+#include <KWindowInfo>
+#include <KWindowSystem>
 // Qt
-#include <QtConcurrentRun>
+#include <QtCore/qmetaobject.h>
 
 namespace KWin
 {
 
+// main.cpp
 extern int screen_number;
 extern bool is_multihead;
 
@@ -138,13 +128,6 @@ Workspace::Workspace(bool restore)
     , block_stacking_updates(0)
     , forced_global_mouse_grab(false)
 {
-    // If KWin was already running it saved its configuration after loosing the selection -> Reread
-    QFuture<void> reparseConfigFuture = QtConcurrent::run(options, &Options::reparseConfiguration);
-
-#ifdef KWIN_BUILD_KAPPMENU
-    ApplicationMenu::create(this);
-#endif
-
     _self = this;
 
     // first initialize the extensions
@@ -154,13 +137,8 @@ Workspace::Workspace(bool restore)
     // start the cursor support
     Cursor::create(this);
 
-#ifdef KWIN_BUILD_ACTIVITIES
-    Activities *activities = Activities::create(this);
-    connect(activities, SIGNAL(currentChanged(QString)), SLOT(updateCurrentActivity(QString)));
-#endif
-
-    // PluginMgr needs access to the config file, so we need to wait for it for finishing
-    reparseConfigFuture.waitForFinished();
+    // PluginMgr needs access to the config file, so we need to wait for
+    options->reparseConfiguration();
 
     // get screen support
     Screens *screens = Screens::create(this);
@@ -232,8 +210,6 @@ Workspace::Workspace(bool restore)
 
     client_keys = new KActionCollection(this);
 
-    Outline::create(this);
-
     initShortcuts();
 
     init();
@@ -296,9 +272,6 @@ void Workspace::init()
     }
     if (!VirtualDesktopManager::self()->setCurrent(initial_desktop))
         VirtualDesktopManager::self()->setCurrent(1);
-#ifdef KWIN_BUILD_ACTIVITIES
-    Activities::self()->update(false, true);
-#endif
 
     reconfigureTimer.setSingleShot(true);
     updateToolWindowsTimer.setSingleShot(true);
@@ -396,9 +369,6 @@ void Workspace::init()
         activateClient(new_active_client);
 
 
-#ifdef KWIN_BUILD_SCRIPTING
-    Scripting::create(this);
-#endif
 
     // SELI TODO: This won't work with unreasonable focus policies,
     // and maybe in rare cases also if the selected client doesn't
@@ -450,7 +420,7 @@ Workspace::~Workspace()
     delete Placement::self();
     delete client_keys_dialog;
     foreach (SessionInfo * s, session)
-    delete s;
+        delete s;
 
     // TODO: ungrabXServer();
 
@@ -537,10 +507,6 @@ void Workspace::addClient(Client* c)
     if (TabBox::TabBox::self()->isDisplayed())
         TabBox::TabBox::self()->reset(true);
 #endif
-#ifdef KWIN_BUILD_KAPPMENU
-        if (ApplicationMenu::self()->hasMenu(c->window()))
-            c->setAppMenuAvailable();
-#endif
 }
 
 void Workspace::addUnmanaged(Unmanaged* c)
@@ -940,7 +906,7 @@ void Workspace::updateClientVisibilityOnDesktopChange(uint oldDesktop, uint newD
         if (!c) {
             continue;
         }
-        if (!c->isOnDesktop(newDesktop) && c != movingClient && c->isOnCurrentActivity()) {
+        if (!c->isOnDesktop(newDesktop) && c != movingClient) {
             if (c->isShown(true) && c->isOnDesktop(oldDesktop) && !compositing())
                 obs_wins.create(c);
             (c)->updateVisibility();
@@ -958,7 +924,7 @@ void Workspace::updateClientVisibilityOnDesktopChange(uint oldDesktop, uint newD
         if (!c) {
             continue;
         }
-        if (c->isOnDesktop(newDesktop) && c->isOnCurrentActivity())
+        if (c->isOnDesktop(newDesktop))
             c->updateVisibility();
     }
     --block_showing_desktop;
@@ -1009,8 +975,7 @@ Client *Workspace::findClientToActivateOnDesktop(uint desktop)
                 continue;
             }
 
-            if (!(client->isShown(false) && client->isOnDesktop(desktop) &&
-                client->isOnCurrentActivity() && client->isOnActiveScreen()))
+            if (!(client->isShown(false) && client->isOnDesktop(desktop)))
                 continue;
 
             if (client->geometry().contains(Cursor::pos())) {
@@ -1023,106 +988,6 @@ Client *Workspace::findClientToActivateOnDesktop(uint desktop)
     return FocusChain::self()->getForActivation(desktop);
 }
 
-/**
- * Updates the current activity when it changes
- * do *not* call this directly; it does not set the activity.
- *
- * Shows/Hides windows according to the stacking order
- */
-
-void Workspace::updateCurrentActivity(const QString &new_activity)
-{
-#ifdef KWIN_BUILD_ACTIVITIES
-    //closeActivePopup();
-    ++block_focus;
-    // TODO: Q_ASSERT( block_stacking_updates == 0 ); // Make sure stacking_order is up to date
-    StackingUpdatesBlocker blocker(this);
-
-    ++block_showing_desktop; //FIXME should I be using that?
-    // Optimized Desktop switching: unmapping done from back to front
-    // mapping done from front to back => less exposure events
-    //Notify::raise((Notify::Event) (Notify::DesktopChange+new_desktop));
-
-    ObscuringWindows obs_wins;
-
-    const QString &old_activity = Activities::self()->previous();
-
-    for (ToplevelList::ConstIterator it = stacking_order.constBegin();
-            it != stacking_order.constEnd();
-            ++it) {
-        Client *c = qobject_cast<Client*>(*it);
-        if (!c) {
-            continue;
-        }
-        if (!c->isOnActivity(new_activity) && c != movingClient && c->isOnCurrentDesktop()) {
-            if (c->isShown(true) && c->isOnActivity(old_activity) && !compositing())
-                obs_wins.create(c);
-            c->updateVisibility();
-        }
-    }
-
-    // Now propagate the change, after hiding, before showing
-    //rootInfo->setCurrentDesktop( currentDesktop() );
-
-    /* TODO someday enable dragging windows to other activities
-    if ( movingClient && !movingClient->isOnDesktop( new_desktop ))
-        {
-        movingClient->setDesktop( new_desktop );
-        */
-
-    for (int i = stacking_order.size() - 1; i >= 0 ; --i) {
-        Client *c = qobject_cast<Client*>(stacking_order.at(i));
-        if (!c) {
-            continue;
-        }
-        if (c->isOnActivity(new_activity))
-            c->updateVisibility();
-    }
-
-    --block_showing_desktop;
-    //FIXME not sure if I should do this either
-    if (showingDesktop())   // Do this only after desktop change to avoid flicker
-        resetShowingDesktop(false);
-
-    // Restore the focus on this desktop
-    --block_focus;
-    Client* c = 0;
-
-    //FIXME below here is a lot of focuschain stuff, probably all wrong now
-    if (options->focusPolicyIsReasonable()) {
-        // Search in focus chain
-        c = FocusChain::self()->getForActivation(VirtualDesktopManager::self()->current());
-    }
-    // If "unreasonable focus policy" and active_client is on_all_desktops and
-    // under mouse (Hence == old_active_client), conserve focus.
-    // (Thanks to Volker Schatz <V.Schatz at thphys.uni-heidelberg.de>)
-    else if (active_client && active_client->isShown(true) && active_client->isOnCurrentDesktop() && active_client->isOnCurrentActivity())
-        c = active_client;
-
-    if (c == NULL && !desktops.isEmpty())
-        c = findDesktop(true, VirtualDesktopManager::self()->current());
-
-    if (c != active_client)
-        setActiveClient(NULL);
-
-    if (c)
-        requestFocus(c);
-    else if (!desktops.isEmpty())
-        requestFocus(findDesktop(true, VirtualDesktopManager::self()->current()));
-    else
-        focusToNull();
-
-    // Not for the very first time, only if something changed and there are more than 1 desktops
-
-    //if ( effects != NULL && old_desktop != 0 && old_desktop != new_desktop )
-    //    static_cast<EffectsHandlerImpl*>( effects )->desktopChanged( old_desktop );
-    if (compositing() && m_compositor)
-        m_compositor->addRepaintFull();
-#else
-    Q_UNUSED(new_activity)
-#endif
-}
-
 void Workspace::moveClientsFromRemovedDesktops()
 {
     for (ClientList::ConstIterator it = clients.constBegin(); it != clients.constEnd(); ++it) {
@@ -1195,7 +1060,6 @@ void Workspace::sendClientToDesktop(Client* c, int desk, bool dont_activate)
  * this is NOT in any way related to XRandR multiscreen
  *
  */
-extern bool is_multihead; // main.cpp
 bool Workspace::isOnCurrentHead()
 {
     if (!is_multihead) {
@@ -1225,12 +1089,6 @@ void Workspace::sendPingToWindow(xcb_window_t window, xcb_timestamp_t timestamp)
     rootInfo()->sendPing(window, timestamp);
 }
 
-void Workspace::sendTakeActivity(KWin::Client *c, xcb_timestamp_t timestamp, long int flags)
-{
-    rootInfo()->takeActivity(c->window(), timestamp, flags);
-    pending_take_activity = c;
-}
-
 /**
  * Delayed focus functions
  */
@@ -1270,6 +1128,12 @@ void Workspace::focusToNull()
     m_nullFocus->focus();
 }
 
+void Workspace::sendTakeActivity(KWin::Client *c, xcb_timestamp_t timestamp, long int flags)
+{
+    rootInfo()->takeActivity(c->window(), timestamp, flags);
+    pending_take_activity = c;
+}
+
 void Workspace::setShowingDesktop(bool showing)
 {
     rootInfo()->setShowingDesktop(showing);
@@ -1288,7 +1152,7 @@ void Workspace::setShowingDesktop(bool showing)
             if (!c) {
                 continue;
             }
-            if (c->isOnCurrentActivity() && c->isOnCurrentDesktop() && c->isShown(true) && !c->isSpecialWindow())
+            if (c->isOnCurrentDesktop() && c->isShown(true) && !c->isSpecialWindow())
                 showing_desktop_clients.prepend(c);   // Topmost first to reduce flicker
         }
         for (ClientList::ConstIterator it = showing_desktop_clients.constBegin();
@@ -1402,7 +1266,7 @@ QString Workspace::supportInformation() const
         if (QLatin1String(property.name()) == "objectName") {
             continue;
         }
-        support.append(QLatin1String(property.name()) % ": " % options->property(property.name()).toString() % '\n');
+        support.append(QLatin1String(property.name()) + ": " + options->property(property.name()).toString() + '\n');
     }
 #ifdef KWIN_BUILD_SCREENEDGES
     support.append("\nScreen Edges\n");
@@ -1413,7 +1277,7 @@ QString Workspace::supportInformation() const
         if (QLatin1String(property.name()) == "objectName") {
             continue;
         }
-        support.append(QLatin1String(property.name()) % ": " % ScreenEdges::self()->property(property.name()).toString() % '\n');
+        support.append(QLatin1String(property.name()) + ": " + ScreenEdges::self()->property(property.name()).toString() + '\n');
     }
 #endif
     support.append("\nScreens\n");
@@ -1445,101 +1309,9 @@ QString Workspace::supportInformation() const
     support.append(decorationPlugin()->supportInformation());
     support.append("\nCompositing\n");
     support.append(  "===========\n");
-    support.append("Qt Graphics System: ");
-    if (Extensions::nonNativePixmaps()) {
-        support.append("raster\n");
-    } else {
-        support.append("native\n");
-    }
     if (effects) {
         support.append("Compositing is active\n");
         switch (effects->compositingType()) {
-        case OpenGL1Compositing:
-        case OpenGL2Compositing:
-        case OpenGLCompositing: {
-#ifdef KWIN_HAVE_OPENGLES
-            support.append("Compositing Type: OpenGL ES 2.0\n");
-#else
-            support.append("Compositing Type: OpenGL\n");
-#endif
-
-            GLPlatform *platform = GLPlatform::instance();
-            support.append("OpenGL vendor string: " %   platform->glVendorString() % '\n');
-            support.append("OpenGL renderer string: " % platform->glRendererString() % '\n');
-            support.append("OpenGL version string: " %  platform->glVersionString() % '\n');
-
-            if (platform->supports(LimitedGLSL) || platform->supports(GLSL))
-                support.append("OpenGL shading language version string: " % platform->glShadingLanguageVersionString() % '\n');
-
-            support.append("Driver: " % GLPlatform::driverToString(platform->driver()) % '\n');
-            if (!platform->isMesaDriver())
-                support.append("Driver version: " % GLPlatform::versionToString(platform->driverVersion()) % '\n');
-
-            support.append("GPU class: " % GLPlatform::chipClassToString(platform->chipClass()) % '\n');
-
-            support.append("OpenGL version: " % GLPlatform::versionToString(platform->glVersion()) % '\n');
-
-            if (platform->supports(LimitedGLSL) || platform->supports(GLSL))
-                support.append("GLSL version: " % GLPlatform::versionToString(platform->glslVersion()) % '\n');
-
-            if (platform->isMesaDriver())
-                support.append("Mesa version: " % GLPlatform::versionToString(platform->mesaVersion()) % '\n');
-            if (platform->serverVersion() > 0)
-                support.append("X server version: " % GLPlatform::versionToString(platform->serverVersion()) % '\n');
-            if (platform->kernelVersion() > 0)
-                support.append("Linux kernel version: " % GLPlatform::versionToString(platform->kernelVersion()) % '\n');
-
-            support.append("Direct rendering: ");
-            if (platform->isDirectRendering()) {
-                support.append("yes\n");
-            } else {
-                support.append("no\n");
-            }
-            support.append("Requires strict binding: ");
-            if (!platform->isLooseBinding()) {
-                support.append("yes\n");
-            } else {
-                support.append("no\n");
-            }
-            support.append("GLSL shaders: ");
-            if (platform->supports(GLSL)) {
-                if (platform->supports(LimitedGLSL)) {
-                    support.append(" limited\n");
-                } else {
-                    support.append(" yes\n");
-                }
-            } else {
-                support.append(" no\n");
-            }
-            support.append("Texture NPOT support: ");
-            if (platform->supports(TextureNPOT)) {
-                if (platform->supports(LimitedNPOT)) {
-                    support.append(" limited\n");
-                } else {
-                    support.append(" yes\n");
-                }
-            } else {
-                support.append(" no\n");
-            }
-            support.append("Virtual Machine: ");
-            if (platform->isVirtualMachine()) {
-                support.append(" yes\n");
-            } else {
-                support.append(" no\n");
-            }
-
-            if (effects->compositingType() == OpenGL2Compositing) {
-                support.append("OpenGL 2 Shaders are used\n");
-            } else {
-                support.append("OpenGL 2 Shaders are not used. Legacy OpenGL 1.x code path is used.\n");
-            }
-            support.append("Painting blocks for vertical retrace: ");
-            if (m_compositor->scene()->blocksForRetrace())
-                support.append(" yes\n");
-            else
-                support.append(" no\n");
-            break;
-        }
         case XRenderCompositing:
             support.append("Compositing Type: XRender\n");
             break;
@@ -1550,12 +1322,12 @@ QString Workspace::supportInformation() const
         support.append("\nLoaded Effects:\n");
         support.append(  "---------------\n");
         foreach (const QString &effect, static_cast<EffectsHandlerImpl*>(effects)->loadedEffects()) {
-            support.append(effect % '\n');
+            support.append(effect + '\n');
         }
         support.append("\nCurrently Active Effects:\n");
         support.append(  "-------------------------\n");
         foreach (const QString &effect, static_cast<EffectsHandlerImpl*>(effects)->activeEffects()) {
-            support.append(effect % '\n');
+            support.append(effect + '\n');
         }
         support.append("\nEffect Settings:\n");
         support.append(  "----------------\n");
@@ -1578,4 +1350,4 @@ void Workspace::slotToggleCompositing()
 
 } // namespace
 
-#include "workspace.moc"
+#include "moc_workspace.cpp"
