@@ -23,38 +23,22 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KWIN_WORKSPACE_H
 #define KWIN_WORKSPACE_H
 
+// kwin
+#include <kdecoration.h>
+#include "sm.h"
+#include "utils.h"
+// Qt
 #include <QTimer>
 #include <QVector>
-#include <kshortcut.h>
-#include <QCursor>
-#include <netwm.h>
-#include <kxmessages.h>
-#include <QElapsedTimer>
-#include <kmanagerselection.h>
-
-// need to include utils.h before we use the ifdefs
-#include "utils.h"
-#ifdef KWIN_BUILD_ACTIVITIES
-#include <KActivities/Controller>
-#endif
-
-#include "plugins.h"
-#include "kdecoration.h"
-#include "kdecorationfactory.h"
-#ifdef KWIN_BUILD_SCREENEDGES
-#include "screenedge.h"
-#endif
-#include "sm.h"
-
+// X
 #include <X11/Xlib.h>
 
 // TODO: Cleanup the order of things in this .h file
 
-class QMenu;
-class QActionGroup;
-class QStringList;
+#include <QStringList>
 class KConfig;
 class KActionCollection;
+class KShortcut;
 class KStartupInfo;
 class KStartupInfoId;
 class KStartupInfoData;
@@ -62,29 +46,22 @@ class KStartupInfoData;
 namespace KWin
 {
 
-#ifdef KWIN_BUILD_TABBOX
-namespace TabBox
+namespace Xcb
 {
-class TabBox;
+class Window;
 }
-#endif
 
 class Client;
-class Outline;
-class RootInfo;
-class PluginMgr;
-class Placement;
-class Rules;
-class Scripting;
+class KillWindow;
+class ShortcutDialog;
 class UserActionsMenu;
-class WindowRules;
 class Compositor;
 
 class Workspace : public QObject, public KDecorationDefines
 {
     Q_OBJECT
 public:
-    Workspace(bool restore = false);
+    explicit Workspace(bool restore = false);
     virtual ~Workspace();
 
     static Workspace* self() {
@@ -94,9 +71,6 @@ public:
     bool workspaceEvent(XEvent*);
     bool workspaceEvent(QEvent*);
 
-    KDecoration* createDecoration(KDecorationBridge* bridge);
-    bool hasDecorationPlugin() const;
-
     bool hasClient(const Client*);
 
     template<typename T> Client* findClient(T predicate) const;
@@ -112,15 +86,6 @@ public:
 
     QRegion restrictedMoveArea(int desktop, StrutAreas areas = StrutAreaAll) const;
 
-    /**
-     * @internal
-     */
-    void killWindowId(Window window);
-
-    void killWindow() {
-        slotKillWindow();
-    }
-
     bool initializing() const;
 
     /**
@@ -140,8 +105,8 @@ public:
     void activateClient(Client*, bool force = false);
     void requestFocus(Client* c, bool force = false);
     void takeActivity(Client* c, int flags, bool handled);   // Flags are ActivityFlags
-    void handleTakeActivity(Client* c, Time timestamp, int flags);   // Flags are ActivityFlags
-    bool allowClientActivation(const Client* c, Time time = -1U, bool focus_in = false,
+    void handleTakeActivity(Client* c, xcb_timestamp_t timestamp, int flags);   // Flags are ActivityFlags
+    bool allowClientActivation(const Client* c, xcb_timestamp_t time = -1U, bool focus_in = false,
                                bool ignore_desktop = false);
     void restoreFocus();
     void gotFocusIn(const Client*);
@@ -151,22 +116,17 @@ public:
         return block_focus == 0;
     }
 
-    void updateColormap();
-
     /**
      * Indicates that the client c is being moved around by the user.
      */
     void setClientIsMoving(Client* c);
 
-    void place(Client* c, QRect& area);
-    void placeSmart(Client* c, const QRect& area);
-
     QPoint adjustClientPosition(Client* c, QPoint pos, bool unrestricted, double snapAdjust = 1.0);
     QRect adjustClientSize(Client* c, QRect moveResizeGeom, int mode);
     void raiseClient(Client* c, bool nogroup = false);
     void lowerClient(Client* c, bool nogroup = false);
-    void raiseClientRequest(Client* c, NET::RequestSource src, Time timestamp);
-    void lowerClientRequest(Client* c, NET::RequestSource src, Time timestamp);
+    void raiseClientRequest(Client* c, NET::RequestSource src, xcb_timestamp_t timestamp);
+    void lowerClientRequest(Client* c, NET::RequestSource src, xcb_timestamp_t timestamp);
     void restackClientUnderActive(Client*);
     void restack(Client *c, Client *under);
     void updateClientLayer(Client* c);
@@ -204,149 +164,21 @@ public:
         return deleted;
     }
 
-    Outline* outline();
 #ifdef KWIN_BUILD_SCREENEDGES
-    ScreenEdge* screenEdge();
     void stackScreenEdgesUnderOverrideRedirect();
 #endif
 
-    //-------------------------------------------------
-    // Desktop layout
-
 public:
-    /**
-     * @returns Total number of desktops currently in existence.
-     */
-    int numberOfDesktops() const;
-    /**
-     * @returns The maximum number of desktops that KWin supports.
-     */
-    int maxNumberOfDesktops() const;
-    /**
-     * Set the number of available desktops to @a count. This function overrides any previous
-     * grid layout.
-     */
-    void setNumberOfDesktops(int count);
-    /**
-     * Called from within setNumberOfDesktops() to ensure the desktop layout is still valid.
-     */
-    void updateDesktopLayout();
-
-    /**
-     * @returns The size of desktop layout in grid units.
-     */
-    QSize desktopGridSize() const;
-    /**
-     * @returns The width of desktop layout in grid units.
-     */
-    int desktopGridWidth() const;
-    /**
-     * @returns The height of desktop layout in grid units.
-     */
-    int desktopGridHeight() const;
-    /**
-     * @returns The width of desktop layout in pixels. Equivalent to gridWidth() *
-     * ::displayWidth().
-     */
-    int workspaceWidth() const;
-    /**
-     * @returns The height of desktop layout in pixels. Equivalent to gridHeight() *
-     * ::displayHeight().
-     */
-    int workspaceHeight() const;
-
-    /**
-     * @returns The ID of the current desktop.
-     */
-    int currentDesktop() const;
-    /**
-     * Set the current desktop to @a current.
-     * @returns True on success, false otherwise.
-     */
-    bool setCurrentDesktop(int current);
-
-    /**
-     * Generate a desktop layout from EWMH _NET_DESKTOP_LAYOUT property parameters.
-     */
-    void setNETDesktopLayout(Qt::Orientation orientation, int width, int height, int startingCorner);
-
-    /**
-     * @returns The ID of the desktop at the point @a coords or 0 if no desktop exists at that
-     * point. @a coords is to be in grid units.
-     */
-    int desktopAtCoords(QPoint coords) const;
-    /**
-     * @returns The coords of desktop @a id in grid units.
-     */
-    QPoint desktopGridCoords(int id) const;
-    /**
-     * @returns The coords of the top-left corner of desktop @a id in pixels.
-     */
-    QPoint desktopCoords(int id) const;
-
-    /**
-     * @returns The ID of the desktop above desktop @a id. Wraps around to the bottom of
-     * the layout if @a wrap is set. If @a id is not set use the current one.
-     */
-    int desktopAbove(int id = 0, bool wrap = true) const;
-    /**
-     * @returns The ID of the desktop to the right of desktop @a id. Wraps around to the
-     * left of the layout if @a wrap is set. If @a id is not set use the current one.
-     */
-    int desktopToRight(int id = 0, bool wrap = true) const;
-    /**
-     * @returns The ID of the desktop below desktop @a id. Wraps around to the top of the
-     * layout if @a wrap is set. If @a id is not set use the current one.
-     */
-    int desktopBelow(int id = 0, bool wrap = true) const;
-    /**
-     * @returns The ID of the desktop to the left of desktop @a id. Wraps around to the
-     * right of the layout if @a wrap is set. If @a id is not set use the current one.
-     */
-    int desktopToLeft(int id = 0, bool wrap = true) const;
-
     QPoint cascadeOffset(const Client *c) const;
 
 private:
-    int desktopCount_;
-    QSize desktopGridSize_;
-    int* desktopGrid_;
-    int currentDesktop_;
-    QString activity_;
-    QStringList allActivities_, openActivities_;
-#ifdef KWIN_BUILD_ACTIVITIES
-    KActivities::Controller activityController_;
-#endif
-
-    Outline* m_outline;
-#ifdef KWIN_BUILD_SCREENEDGES
-    ScreenEdge m_screenEdge;
-    Qt::Orientations m_screenEdgeOrientation;
-#endif
     Compositor *m_compositor;
 
     //-------------------------------------------------
     // Unsorted
 
 public:
-    int activeScreen() const;
-    int numScreens() const;
-    void checkActiveScreen(const Client* c);
-    void setActiveScreenMouse(const QPoint& mousepos);
-    QRect screenGeometry(int screen) const;
-    int screenNumber(const QPoint& pos) const;
-    QString currentActivity() const {
-        return activity_;
-    }
-    QStringList activityList() const {
-        return allActivities_;
-    }
-    const QStringList &openActivities() const {
-        return openActivities_;
-    }
-#ifdef KWIN_BUILD_ACTIVITIES
-    void updateActivityList(bool running, bool updateCurrent, QObject *target = NULL, QString slot = QString());
-#endif
+    bool isOnCurrentHead();
     // True when performing Workspace::updateClientArea().
     // The calls below are valid only in that case.
     bool inUpdateClientArea() const;
@@ -355,18 +187,6 @@ public:
     int oldDisplayWidth() const;
     int oldDisplayHeight() const;
 
-    // Tab box
-#ifdef KWIN_BUILD_TABBOX
-    TabBox::TabBox *tabBox() const;
-#endif
-    bool hasTabBox() const;
-
-    const QVector<int> &desktopFocusChain() const {
-        return m_desktopFocusChain.value();
-    }
-    const ClientList &globalFocusChain() const {
-        return global_focus_chain;
-    }
     KActionCollection* actionCollection() const {
         return keys;
     }
@@ -377,12 +197,6 @@ public:
         return client_keys;
     }
 
-#ifdef KWIN_BUILD_SCRIPTING
-    Scripting *scripting() {
-        return m_scripting;
-    }
-#endif
-
     /**
      * Returns the list of clients sorted in stacking order, with topmost client
      * at the last position
@@ -395,116 +209,65 @@ public:
                                bool only_normal = true) const;
     Client* findDesktop(bool topmost, int desktop) const;
     void sendClientToDesktop(Client* c, int desktop, bool dont_activate);
-    void toggleClientOnActivity(Client* c, const QString &activity, bool dont_activate);
     void windowToPreviousDesktop(Client* c);
     void windowToNextDesktop(Client* c);
     void sendClientToScreen(Client* c, int screen);
 
-    // KDE4 remove me - And it's also in the DCOP interface :(
-    void showWindowMenuAt(unsigned long id, int x, int y);
-
-
     /**
      * Shows the menu operations menu for the client and makes it active if
      * it's not already.
      */
     void showWindowMenu(const QRect& pos, Client* cl);
-    /**
-     * Backwards compatibility.
-     */
-    void showWindowMenu(int x, int y, Client* cl);
-    void showWindowMenu(QPoint pos, Client* cl);
     const UserActionsMenu *userActionsMenu() const {
         return m_userActionsMenu;
     }
 
-#ifdef KWIN_BUILD_KAPPMENU
-    void showApplicationMenu(const QPoint &, const WId);
-#endif
-
     void updateMinimizedOfTransients(Client*);
     void updateOnAllDesktopsOfTransients(Client*);
-    void updateOnAllActivitiesOfTransients(Client*);
-    void checkTransients(Window w);
+    void checkTransients(xcb_window_t w);
 
     void performWindowOperation(Client* c, WindowOperation op);
 
     void storeSession(KConfig* config, SMSavePhase phase);
     void storeClient(KConfigGroup &cg, int num, Client *c);
     void storeSubSession(const QString &name, QSet<QByteArray> sessionIds);
+    void loadSubSessionInfo(const QString &name);
 
     SessionInfo* takeSessionInfo(Client*);
-    WindowRules findWindowRules(const Client*, bool);
-    void rulesUpdated();
-    void discardUsedWindowRules(Client* c, bool withdraw);
-    void disableRulesUpdates(bool disable);
-    bool rulesUpdatesDisabled() const;
-
-    bool hasDecorationShadows() const;
-    Qt::Corner decorationCloseButtonCorner();
-    bool decorationHasAlpha() const;
-    bool decorationSupportsAnnounceAlpha() const;
-    bool decorationSupportsTabbing() const; // Returns true if the decoration supports tabs.
-    bool decorationSupportsFrameOverlap() const;
-    bool decorationSupportsBlurBehind() const;
 
     // D-Bus interface
-    void cascadeDesktop();
-    void unclutterDesktop();
-    void doNotManage(const QString&);
-    /**
-     * @deprecated
-     * @todo: remove KDE5
-     **/
-    QList<int> decorationSupportedColors() const;
-    void nextDesktop();
-    void previousDesktop();
     bool waitForCompositingSetup();
-    bool stopActivity(const QString &id);
-    bool startActivity(const QString &id);
     QString supportInformation() const;
 
     void setCurrentScreen(int new_screen);
 
-    QString desktopName(int desk) const;
     void setShowingDesktop(bool showing);
     void resetShowingDesktop(bool keep_hidden);
     bool showingDesktop() const;
 
-    bool isNotManaged(const QString& title);    // TODO: Setter or getter?
+    void sendPingToWindow(xcb_window_t w, xcb_timestamp_t timestamp);   // Called from Client::pingWindow()
+    void sendTakeActivity(Client* c, xcb_timestamp_t timestamp, long flags);   // Called from Client::takeActivity()
 
-    void sendPingToWindow(Window w, Time timestamp);   // Called from Client::pingWindow()
-    void sendTakeActivity(Client* c, Time timestamp, long flags);   // Called from Client::takeActivity()
-
-    void removeClient(Client*, allowed_t);   // Only called from Client::destroyClient() or Client::releaseWindow()
-    void setActiveClient(Client*, allowed_t);
-    Group* findGroup(Window leader) const;
-    void addGroup(Group* group, allowed_t);
-    void removeGroup(Group* group, allowed_t);
+    void removeClient(Client*);   // Only called from Client::destroyClient() or Client::releaseWindow()
+    void setActiveClient(Client*);
+    Group* findGroup(xcb_window_t leader) const;
+    void addGroup(Group* group);
+    void removeGroup(Group* group);
     Group* findClientLeaderGroup(const Client* c) const;
 
-    void removeUnmanaged(Unmanaged*, allowed_t);   // Only called from Unmanaged::release()
-    void removeDeleted(Deleted*, allowed_t);
-    void addDeleted(Deleted*, Toplevel*, allowed_t);
+    void removeUnmanaged(Unmanaged*);   // Only called from Unmanaged::release()
+    void removeDeleted(Deleted*);
+    void addDeleted(Deleted*, Toplevel*);
 
-    bool checkStartupNotification(Window w, KStartupInfoId& id, KStartupInfoData& data);
+    bool checkStartupNotification(xcb_window_t w, KStartupInfoId& id, KStartupInfoData& data);
 
     void focusToNull(); // SELI TODO: Public?
-    enum FocusChainChange {
-        FocusChainMakeFirst,
-        FocusChainMakeLast,
-        FocusChainUpdate
-    };
-    void updateFocusChains(Client* c, FocusChainChange change);
 
     bool forcedGlobalMouseGrab() const;
     void clientShortcutUpdated(Client* c);
     bool shortcutAvailable(const KShortcut& cut, Client* ignore = NULL) const;
     bool globalShortcutsDisabled() const;
-    void disableGlobalShortcuts(bool disable);
     void disableGlobalShortcutsForClient(bool disable);
-    QPoint cursorPos() const;
-    void checkCursorPos();
 
     void sessionSaveStarted();
     void sessionSaveDone();
@@ -533,14 +296,6 @@ public:
 
 public slots:
     // Keybindings
-    void slotSwitchDesktopNext();
-    void slotSwitchDesktopPrevious();
-    void slotSwitchDesktopRight();
-    void slotSwitchDesktopLeft();
-    void slotSwitchDesktopUp();
-    void slotSwitchDesktopDown();
-
-    void slotSwitchToDesktop();
     //void slotSwitchToWindow( int );
     void slotWindowToDesktop();
 
@@ -549,6 +304,8 @@ public slots:
     void slotWindowToScreen();
     void slotSwitchToNextScreen();
     void slotWindowToNextScreen();
+    void slotSwitchToPrevScreen();
+    void slotWindowToPrevScreen();
     void slotToggleShowDesktop();
 
     void slotWindowMaximize();
@@ -600,13 +357,10 @@ public slots:
     void slotWindowToDesktopUp();
     void slotWindowToDesktopDown();
 
-    void slotDisableGlobalShortcuts();
-
     void slotSettingsChanged(int category);
 
     void reconfigure();
     void slotReconfigure();
-    void slotCompositingToggled();
 
     void slotKillWindow();
 
@@ -623,26 +377,14 @@ public slots:
 
 private slots:
     void desktopResized();
-    void screenChangeTimeout();
     void slotUpdateToolWindows();
     void delayFocus();
-    void gotTemporaryRulesMessage(const QString&);
-    void cleanupTemporaryRules();
-    void writeWindowRules();
     void slotBlockShortcuts(int data);
     void slotReloadConfig();
-#ifdef KWIN_BUILD_KAPPMENU
-    void slotShowRequest(qulonglong wid);
-    void slotMenuAvailable(qulonglong wid);
-    void slotMenuHidden(qulonglong wid);
-    void slotClearMenus();
-#endif
-    void resetCursorPosTime();
-    void updateCurrentActivity(const QString &new_activity);
-    void slotActivityRemoved(const QString &activity);
-    void slotActivityAdded(const QString &activity);
-    void reallyStopActivity(const QString &id);   //dbus deadlocks suck
-    void handleActivityReply();
+    // virtual desktop handling
+    void moveClientsFromRemovedDesktops();
+    void slotDesktopCountChanged(uint previousCount, uint newCount);
+    void slotCurrentDesktopChanged(uint oldDesktop, uint newDesktop);
 
 Q_SIGNALS:
     /**
@@ -655,7 +397,6 @@ Q_SIGNALS:
 signals:
     void desktopPresenceChanged(KWin::Client*, int);
     void currentDesktopChanged(int, KWin::Client*);
-    void numberDesktopsChanged(int oldNumberOfDesktops);
     void clientAdded(KWin::Client*);
     void clientRemoved(KWin::Client*);
     void clientActivated(KWin::Client*);
@@ -663,29 +404,14 @@ signals:
     void groupAdded(KWin::Group*);
     void unmanagedAdded(KWin::Unmanaged*);
     void deletedRemoved(KWin::Deleted*);
-    void mouseChanged(const QPoint& pos, const QPoint& oldpos,
-                      Qt::MouseButtons buttons, Qt::MouseButtons oldbuttons,
-                      Qt::KeyboardModifiers modifiers, Qt::KeyboardModifiers oldmodifiers);
     void propertyNotify(long a);
     void configChanged();
     void reinitializeCompositing();
     /**
-     * This signal is emitted when the global
-     * activity is changed
-     * @param id id of the new current activity
+     * This signels is emitted when ever the stacking order is change, ie. a window is risen
+     * or lowered
      */
-    void currentActivityChanged(const QString &id);
-    /**
-     * This signal is emitted when a new activity is added
-     * @param id id of the new activity
-     */
-    void activityAdded(const QString &id);
-    /**
-     * This signal is emitted when the activity
-     * is removed
-     * @param id id of the removed activity
-     */
-    void activityRemoved(const QString &id);
+    void stackingOrderChanged();
 
 private:
     void init();
@@ -703,7 +429,7 @@ private:
     ToplevelList constrainedStackingOrder();
     void raiseClientWithinApplication(Client* c);
     void lowerClientWithinApplication(Client* c);
-    bool allowFullClientRaising(const Client* c, Time timestamp);
+    bool allowFullClientRaising(const Client* c, xcb_timestamp_t timestamp);
     bool keepTransientAbove(const Client* mainwindow, const Client* transient);
     void blockStackingUpdates(bool block);
     void updateToolWindows(bool also_hide);
@@ -711,42 +437,29 @@ private:
     void saveOldScreenSizes();
 
     /// This is the right way to create a new client
-    Client* createClient(Window w, bool is_mapped);
-    void addClient(Client* c, allowed_t);
-    Unmanaged* createUnmanaged(Window w);
-    void addUnmanaged(Unmanaged* c, allowed_t);
+    Client* createClient(xcb_window_t w, bool is_mapped);
+    void addClient(Client* c);
+    Unmanaged* createUnmanaged(xcb_window_t w);
+    void addUnmanaged(Unmanaged* c);
 
-    Window findSpecialEventWindow(XEvent* e);
-
-    // Desktop names and number of desktops
-    void loadDesktopSettings();
-    void saveDesktopSettings();
+    xcb_window_t findSpecialEventWindow(XEvent* e);
 
     //---------------------------------------------------------------------
 
     void closeActivePopup();
     void updateClientArea(bool force);
-
-    typedef QHash< QString, QVector<int> > DesktopFocusChains;
-    DesktopFocusChains::Iterator m_desktopFocusChain;
-    DesktopFocusChains m_activitiesDesktopFocusChain;
+    void resetClientAreas(uint desktopCount);
+    void updateClientVisibilityOnDesktopChange(uint oldDesktop, uint newDesktop);
+    void activateClientOnNewDesktop(uint desktop);
+    Client *findClientToActivateOnDesktop(uint desktop);
 
     QWidget* active_popup;
     Client* active_popup_client;
 
     void loadSessionInfo();
     void addSessionInfo(KConfigGroup &cg);
-    void loadSubSessionInfo(const QString &name);
-
-    void loadWindowRules();
-    void editWindowRules(Client* c, bool whole_app);
 
     QList<SessionInfo*> session;
-    QList<Rules*> rules;
-    KXMessages temporaryRulesMessages;
-    QTimer rulesUpdatedTimer;
-    QTimer screenChangedTimer;
-    bool rules_updates_disabled;
     static const char* windowTypeToTxt(NET::WindowType type);
     static NET::WindowType txtToWindowType(const char* txt);
     static bool sessionInfoWindowTypeMatch(Client* c, SessionInfo* info);
@@ -756,7 +469,6 @@ private:
     Client* most_recently_raised; // Used ONLY by raiseOrLowerClient()
     Client* movingClient;
     Client* pending_take_activity;
-    int active_screen;
 
     // Delay(ed) window focus timer and client
     QTimer* delayFocusTimer;
@@ -773,8 +485,6 @@ private:
     bool force_restacking;
     mutable ToplevelList x_stacking; // From XQueryTree()
     mutable bool x_stacking_dirty;
-    QVector< ClientList > focus_chain; // Currently ative last
-    ClientList global_focus_chain; // This one is only for things like tabbox's MRU
     ClientList should_get_focus; // Last is most recent
     ClientList attention_chain;
 
@@ -791,10 +501,6 @@ private:
 
     int block_focus;
 
-#ifdef KWIN_BUILD_TABBOX
-    TabBox::TabBox* tab_box;
-#endif
-
     /**
      * Holds the menu containing the user actions which is shown
      * on e.g. right click the window decoration.
@@ -808,21 +514,8 @@ private:
     KActionCollection* disable_shortcuts_keys;
     ShortcutDialog* client_keys_dialog;
     Client* client_keys_client;
-    bool global_shortcuts_disabled;
     bool global_shortcuts_disabled_for_client;
 
-    PluginMgr* mgr;
-
-    RootInfo* rootInfo;
-    QWidget* supportWindow;
-
-    // Swallowing
-    QStringList doNotManageList;
-
-    // Colormap handling
-    Colormap default_colormap;
-    Colormap installed_colormap;
-
     // Timer to collect requests for 'reconfigure'
     QTimer reconfigureTimer;
 
@@ -834,8 +527,6 @@ private:
 
     KStartupInfo* startup;
 
-    Placement* initPositioning;
-
     QVector<QRect> workarea; // Array of workareas for virtual desktops
     // Array of restricted areas that window cannot be moved into
     QVector<StrutRects> restrictedmovearea;
@@ -848,19 +539,15 @@ private:
     int set_active_client_recursion;
     int block_stacking_updates; // When > 0, stacking updates are temporarily disabled
     bool blocked_propagating_new_clients; // Propagate also new clients after enabling stacking updates?
-    Window null_focus_window;
+    QScopedPointer<Xcb::Window> m_nullFocus;
     bool forced_global_mouse_grab;
     friend class StackingUpdatesBlocker;
 
-#ifdef KWIN_BUILD_KAPPMENU
-    //used for menu available before window is mapped
-    QList<WId> m_windowsMenu;
-#endif
-
-    Scripting *m_scripting;
+    QScopedPointer<KillWindow> m_windowKiller;
 
 private:
     friend bool performTransiencyCheck();
+    friend Workspace *workspace();
 };
 
 /**
@@ -869,7 +556,7 @@ private:
 class StackingUpdatesBlocker
 {
 public:
-    StackingUpdatesBlocker(Workspace* w)
+    explicit StackingUpdatesBlocker(Workspace* w)
         : ws(w) {
         ws->blockStackingUpdates(true);
     }
@@ -881,77 +568,19 @@ private:
     Workspace* ws;
 };
 
-/**
- * NET WM Protocol handler class
- */
-class RootInfo : public NETRootInfo
+class ColorMapper : public QObject
 {
-private:
-    typedef KWin::Client Client;  // Because of NET::Client
-
+    Q_OBJECT
 public:
-    RootInfo(Workspace* ws, Display* dpy, Window w, const char* name, unsigned long pr[],
-             int pr_num, int scr = -1);
-
-protected:
-    virtual void changeNumberOfDesktops(int n);
-    virtual void changeCurrentDesktop(int d);
-    virtual void changeActiveWindow(Window w, NET::RequestSource src, Time timestamp, Window active_window);
-    virtual void closeWindow(Window w);
-    virtual void moveResize(Window w, int x_root, int y_root, unsigned long direction);
-    virtual void moveResizeWindow(Window w, int flags, int x, int y, int width, int height);
-    virtual void gotPing(Window w, Time timestamp);
-    virtual void restackWindow(Window w, RequestSource source, Window above, int detail, Time timestamp);
-    virtual void gotTakeActivity(Window w, Time timestamp, long flags);
-    virtual void changeShowingDesktop(bool showing);
-
+    ColorMapper(QObject *parent);
+    virtual ~ColorMapper();
+public Q_SLOTS:
+    void update();
 private:
-    Workspace* workspace;
+    xcb_colormap_t m_default;
+    xcb_colormap_t m_installed;
 };
 
-//---------------------------------------------------------
-// Desktop layout
-
-inline int Workspace::numberOfDesktops() const
-{
-    return desktopCount_;
-}
-
-inline QSize Workspace::desktopGridSize() const
-{
-    return desktopGridSize_;
-}
-
-inline int Workspace::desktopGridWidth() const
-{
-    return desktopGridSize_.width();
-}
-
-inline int Workspace::desktopGridHeight() const
-{
-    return desktopGridSize_.height();
-}
-
-inline int Workspace::workspaceWidth() const
-{
-    return desktopGridSize_.width() * displayWidth();
-}
-
-inline int Workspace::workspaceHeight() const
-{
-    return desktopGridSize_.height() * displayHeight();
-}
-
-inline int Workspace::currentDesktop() const
-{
-    return currentDesktop_;
-}
-
-inline int Workspace::desktopAtCoords(QPoint coords) const
-{
-    return desktopGrid_[coords.y() * desktopGridSize_.width() + coords.x()];
-}
-
 //---------------------------------------------------------
 // Unsorted
 
@@ -970,13 +599,13 @@ inline Client* Workspace::mostRecentlyActivatedClient() const
     return should_get_focus.count() > 0 ? should_get_focus.last() : active_client;
 }
 
-inline void Workspace::addGroup(Group* group, allowed_t)
+inline void Workspace::addGroup(Group* group)
 {
     emit groupAdded(group);
     groups.append(group);
 }
 
-inline void Workspace::removeGroup(Group* group, allowed_t)
+inline void Workspace::removeGroup(Group* group)
 {
     groups.removeAll(group);
 }
@@ -987,16 +616,6 @@ inline const ToplevelList& Workspace::stackingOrder() const
     return stacking_order;
 }
 
-inline void Workspace::showWindowMenu(QPoint pos, Client* cl)
-{
-    showWindowMenu(QRect(pos, pos), cl);
-}
-
-inline void Workspace::showWindowMenu(int x, int y, Client* cl)
-{
-    showWindowMenu(QRect(QPoint(x, y), QPoint(x, y)), cl);
-}
-
 inline void Workspace::setWasUserInteraction()
 {
     was_user_interaction = true;
@@ -1029,12 +648,7 @@ inline bool Workspace::showingDesktop() const
 
 inline bool Workspace::globalShortcutsDisabled() const
 {
-    return global_shortcuts_disabled || global_shortcuts_disabled_for_client;
-}
-
-inline bool Workspace::rulesUpdatesDisabled() const
-{
-    return rules_updates_disabled;
+    return global_shortcuts_disabled_for_client;
 }
 
 inline void Workspace::forceRestacking()
@@ -1107,68 +721,9 @@ inline bool Workspace::hasClient(const Client* c)
     return findClient(ClientMatchPredicate(c));
 }
 
-inline bool Workspace::hasDecorationPlugin() const
+inline Workspace *workspace()
 {
-    if (!mgr) {
-        return false;
-    }
-    return !mgr->hasNoDecoration();
-}
-
-inline bool Workspace::hasDecorationShadows() const
-{
-    if (!hasDecorationPlugin()) {
-        return false;
-    }
-    return mgr->factory()->supports(AbilityProvidesShadow);
-}
-
-inline Qt::Corner Workspace::decorationCloseButtonCorner()
-{
-    if (!hasDecorationPlugin()) {
-        return Qt::TopRightCorner;
-    }
-    return mgr->factory()->closeButtonCorner();
-}
-
-inline bool Workspace::decorationHasAlpha() const
-{
-    if (!hasDecorationPlugin()) {
-        return false;
-    }
-    return mgr->factory()->supports(AbilityUsesAlphaChannel);
-}
-
-inline bool Workspace::decorationSupportsAnnounceAlpha() const
-{
-    if (!hasDecorationPlugin()) {
-        return false;
-    }
-    return mgr->factory()->supports(AbilityAnnounceAlphaChannel);
-}
-
-inline bool Workspace::decorationSupportsTabbing() const
-{
-    if (!hasDecorationPlugin()) {
-        return false;
-    }
-    return mgr->factory()->supports(AbilityTabbing);
-}
-
-inline bool Workspace::decorationSupportsFrameOverlap() const
-{
-    if (!hasDecorationPlugin()) {
-        return false;
-    }
-    return mgr->factory()->supports(AbilityExtendIntoClientArea);
-}
-
-inline bool Workspace::decorationSupportsBlurBehind() const
-{
-    if (!hasDecorationPlugin()) {
-        return false;
-    }
-    return mgr->factory()->supports(AbilityUsesBlurBehind);
+    return Workspace::_self;
 }
 
 } // namespace
