@@ -30,6 +30,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <xcb/xcb.h>
 #include <xcb/composite.h>
 
+#define KWIN_DOUBLE_TO_FIXED(d) ((xcb_render_fixed_t) ((d) * 65536))
+#define KWIN_FIXED_TO_DOUBLE(f) ((double) ((f) / 65536.0))
+
 namespace KWin {
 
 namespace Xcb {
@@ -197,7 +200,7 @@ inline xcb_get_input_focus_cookie_t get_input_focus(xcb_connection_t *c, xcb_win
 class CurrentInput : public Wrapper<xcb_get_input_focus_reply_t, xcb_get_input_focus_cookie_t, &xcb_get_input_focus_reply, &get_input_focus>
 {
 public:
-    CurrentInput() : Wrapper<xcb_get_input_focus_reply_t, xcb_get_input_focus_cookie_t, &xcb_get_input_focus_reply, &get_input_focus>() {}
+    CurrentInput() : Wrapper<xcb_get_input_focus_reply_t, xcb_get_input_focus_cookie_t, &xcb_get_input_focus_reply, &get_input_focus>(XCB_WINDOW_NONE) {}
 
     inline xcb_window_t window() {
         if (isNull())
