@@ -36,13 +36,7 @@ namespace KSysGuard {
 
 class ProcessModelPrivate;
 
-#ifdef Q_OS_WIN
-// this workaround is needed to make krunner link under msvc
-// please keep it this way even if you port this library to have a _export.h header file
-#define KSYSGUARD_EXPORT
-#else
 #define KSYSGUARD_EXPORT KDE_EXPORT
-#endif
 
 class KSYSGUARD_EXPORT ProcessModel : public QAbstractItemModel
 {
