@@ -21,16 +21,15 @@
 
 */
 
-#include "ksysguardprocesslist.moc"
+#include "moc_ksysguardprocesslist.cpp"
 #include "ksysguardprocesslist.h"
 
-#include "../config-ksysguard.h"
+#include "config-X11.h"
 
 #include <QApplication>
 #include <QTimer>
 #include <QList>
-#include <QShowEvent>
-#include <QHideEvent>
+#include <QtGui/qevent.h>
 #include <QHeaderView>
 #include <QAction>
 #include <QMenu>
@@ -47,7 +46,7 @@
 
 #include <signal.h> //For SIGTERM
 
-#include <kauth.h>
+#include <kauthorization.h>
 #include <kaction.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -58,7 +57,6 @@
 
 #include "ReniceDlg.h"
 #include "ui_ProcessWidgetUI.h"
-#include "scripting.h"
 
 #include <sys/types.h>
 #include <unistd.h>
@@ -123,7 +121,7 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
 
                 painter->setFont(option.font);
                 QTextOption textOption;
-                textOption.setWrapMode(QTextOption::ManualWrap);
+                textOption.setWrapMode(QTextOption::NoWrap);
                 textOption.setTextDirection(option.direction);
                 textOption.setAlignment(QStyle::visualAlignment(option.direction, option.displayAlignment));
 
@@ -151,7 +149,6 @@ struct KSysGuardProcessListPrivate {
     KSysGuardProcessListPrivate(KSysGuardProcessList* q, const QString &hostName)
         : mModel(q, hostName), mFilterModel(q), mUi(new Ui::ProcessWidget()), mProcessContextMenu(NULL), mUpdateTimer(NULL)
     {
-        mScripting = NULL;
         mNeedToExpandInit = false;
         mNumItemsSelected = -1;
         mResortCountDown = 2; //The items added initially will be already sorted, but without CPU info.  On the second refresh we will have CPU usage, so /then/ we can resort
@@ -188,9 +185,6 @@ struct KSysGuardProcessListPrivate {
     /** The number rows and their children for the given parent in the mFilterModel model */
     int totalRowCount(const QModelIndex &parent) const;
 
-    /** Helper function to setup 'action' with the given pids */
-    void setupKAuthAction(KAuth::Action *action, const QList<long long> & pids) const;
-
     /** fire a timer event if we are set to use our internal timer*/
     void fireTimerEvent();
 
@@ -218,9 +212,6 @@ struct KSysGuardProcessListPrivate {
     /** Number of items that are selected */
     int mNumItemsSelected;
 
-    /** Class to deal with the scripting. NULL if scripting is disabled */
-    Scripting *mScripting;
-
     /** A counter to mark when to resort, so that we do not resort on every update */
     int mResortCountDown;
 
@@ -393,16 +384,6 @@ int KSysGuardProcessListPrivate::totalRowCount(const QModelIndex &parent ) const
     return total;
 }
 
-void KSysGuardProcessListPrivate::setupKAuthAction(KAuth::Action *action, const QList<long long> & pids) const
-{
-    action->setHelperID("org.kde.ksysguard.processlisthelper");
-
-    int processCount = pids.count();
-    for(int i = 0; i < processCount; i++) {
-        action->addArgument(QString("pid%1").arg(i), pids[i]);
-    }
-    action->addArgument("pidcount", processCount);
-}
 void KSysGuardProcessList::selectionChanged()
 {
     int numSelected =  d->mUi->treeView->selectionModel()->selectedRows().size();
@@ -488,11 +469,6 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
         d->mProcessContextMenu->addAction(d->resume);
     }
 
-    if(numProcesses == 1 && d->mScripting) {
-        foreach(QAction *action, d->mScripting->actions()) {
-            d->mProcessContextMenu->addAction(action);
-        }
-    }
     if (showSignalingEntries) {
         d->mProcessContextMenu->addSeparator();
         d->mProcessContextMenu->addAction(d->terminate);
@@ -916,9 +892,6 @@ void KSysGuardProcessList::hideEvent ( QHideEvent * event )  //virtual protected
     //Stop updating the process list if we are hidden
     if(d->mUpdateTimer)
         d->mUpdateTimer->stop();
-    //stop any scripts running, to save on memory
-    if(d->mScripting)
-        d->mScripting->stopAllScripts();
     QWidget::hideEvent(event);
 }
 
@@ -1022,20 +995,24 @@ bool KSysGuardProcessList::reniceProcesses(const QList<long long> &pids, int nic
     if(unreniced_pids.isEmpty()) return true; //All processes were reniced successfully
     if(!d->mModel.isLocalhost()) return false; //We can't use kauth to renice non-localhost processes
 
+    QVariantMap actionarguments;
+    int processCount = unreniced_pids.count();
+    for(int i = 0; i < processCount; i++) {
+        actionarguments.insert(QString("pid%1").arg(i), unreniced_pids[i]);
+    }
+    actionarguments.insert("pidcount", processCount);
+    actionarguments.insert("nicevalue", niceValue);
+    int reply = KAuthorization::execute(
+        "org.kde.ksysguard.processlisthelper", "renice", actionarguments 
+    );
 
-    KAuth::Action *action = new KAuth::Action("org.kde.ksysguard.processlisthelper.renice");
-    action->setParentWidget(window());
-    d->setupKAuthAction( action, unreniced_pids);
-    action->addArgument("nicevalue", niceValue);
-    KAuth::ActionReply reply = action->execute();
-
-    if (reply == KAuth::ActionReply::SuccessReply) {
+    if (reply == KAuthorization::NoError) {
         updateList();
-        delete action;
-    } else if (reply != KAuth::ActionReply::UserCancelled && reply != KAuth::ActionReply::AuthorizationDenied) {
-        KMessageBox::sorry(this, i18n("You do not have the permission to renice the process and there "
-                    "was a problem trying to run as root.  Error %1 %2", reply.errorCode(), reply.errorDescription()));
-        delete action;
+    } else if (reply == KAuthorization::AuthorizationError) {
+        KMessageBox::sorry(this, i18n("You do not have the permission to crenice the process."));
+        return false;
+    } else {
+        KMessageBox::sorry(this, i18n("There was a problem trying to renice the process"));
         return false;
     }
     return true;
@@ -1067,22 +1044,19 @@ void KSysGuardProcessList::reniceSelectedProcesses()
         }
 
         int sched = -2;
-        int iosched = -2;
         foreach(KSysGuard::Process *process, processes) {
             pids << process->pid;
             selectedAsStrings << d->mModel.getStringForProcess(process);
-            if(sched == -2) sched = (int)process->scheduler;
-            else if(sched != -1 && sched != (int)process->scheduler) sched = -1;  //If two processes have different schedulers, disable the cpu scheduler stuff
-            if(iosched == -2) iosched = (int)process->ioPriorityClass;
-            else if(iosched != -1 && iosched != (int)process->ioPriorityClass) iosched = -1;  //If two processes have different schedulers, disable the cpu scheduler stuff
-
+            if(sched == -2) {
+                sched = (int)process->scheduler;
+            } else if(sched != -1 && sched != (int)process->scheduler) {
+                // If two processes have different schedulers, disable the cpu scheduler stuff
+                sched = -1;
+            }
         }
         int firstPriority = processes.first()->niceLevel;
-        int firstIOPriority = processes.first()->ioniceLevel;
 
-        bool supportsIoNice = d->mModel.processController()->supportsIoNiceness();
-        if(!supportsIoNice) { iosched = -2; firstIOPriority = -2; }
-        reniceDlg = new ReniceDlg(d->mUi->treeView, selectedAsStrings, firstPriority, sched, firstIOPriority, iosched);
+        reniceDlg = new ReniceDlg(d->mUi->treeView, selectedAsStrings, firstPriority, sched);
         if(reniceDlg->exec() == QDialog::Rejected) {
             delete reniceDlg;
             return;
@@ -1094,7 +1068,6 @@ void KSysGuardProcessList::reniceSelectedProcesses()
 
     QList<long long> renicePids;
     QList<long long> changeCPUSchedulerPids;
-    QList<long long> changeIOSchedulerPids;
     foreach (long long pid, pids) {
         KSysGuard::Process *process = d->mModel.getProcess(pid);
         if (!process)
@@ -1120,32 +1093,6 @@ void KSysGuardProcessList::reniceSelectedProcesses()
                 }
                 break;
         }
-        switch(reniceDlg->newIOSched) {
-            case -2:
-            case -1:  //Invalid, not changed etc.
-                break;  //So do nothing
-            case KSysGuard::Process::None:
-                if(reniceDlg->newIOSched != (int)process->ioPriorityClass) {
-                    // Unfortunately linux doesn't actually let us set the ioniceness back to none after being set to something else
-                    if(process->ioPriorityClass != KSysGuard::Process::BestEffort || reniceDlg->newIOPriority != process->ioniceLevel)
-                        changeIOSchedulerPids << pid;
-                }
-                break;
-            case KSysGuard::Process::Idle:
-                if(reniceDlg->newIOSched != (int)process->ioPriorityClass) {
-                    changeIOSchedulerPids << pid;
-                }
-                break;
-            case KSysGuard::Process::BestEffort:
-                if(process->ioPriorityClass == KSysGuard::Process::None && reniceDlg->newIOPriority  == (process->niceLevel + 20)/5)
-                    break;  //Don't set to BestEffort if it's on None and the nicelevel wouldn't change
-            case KSysGuard::Process::RealTime:
-                if(reniceDlg->newIOSched != (int)process->ioPriorityClass || reniceDlg->newIOPriority != process->ioniceLevel) {
-                    changeIOSchedulerPids << pid;
-                }
-                break;
-        }
-
     }
     if(!changeCPUSchedulerPids.isEmpty()) {
         Q_ASSERT(reniceDlg->newCPUSched >= 0);
@@ -1162,51 +1109,10 @@ void KSysGuardProcessList::reniceSelectedProcesses()
             return;
         }
     }
-    if(!changeIOSchedulerPids.isEmpty()) {
-        if(!changeIoScheduler(changeIOSchedulerPids, (KSysGuard::Process::IoPriorityClass) reniceDlg->newIOSched, reniceDlg->newIOPriority)) {
-            delete reniceDlg;
-            return;
-        }
-    }
     delete reniceDlg;
     updateList();
 }
 
-bool KSysGuardProcessList::changeIoScheduler(const QList< long long> &pids, KSysGuard::Process::IoPriorityClass newIoSched, int newIoSchedPriority)
-{
-    if(newIoSched == KSysGuard::Process::None) newIoSched = KSysGuard::Process::BestEffort;
-    if(newIoSched == KSysGuard::Process::Idle) newIoSchedPriority = 0;
-    QList< long long> unchanged_pids;
-    for (int i = 0; i < pids.size(); ++i) {
-        bool success = d->mModel.processController()->setIoNiceness(pids.at(i), newIoSched, newIoSchedPriority);
-        if(!success) {
-            unchanged_pids << pids.at(i);
-        }
-    }
-    if(unchanged_pids.isEmpty()) return true;
-    if(!d->mModel.isLocalhost()) return false; //We can't use kauth to affect non-localhost processes
-
-    KAuth::Action *action = new KAuth::Action("org.kde.ksysguard.processlisthelper.changeioscheduler");
-    action->setParentWidget(window());
-
-    d->setupKAuthAction( action, unchanged_pids);
-    action->addArgument("ioScheduler", (int)newIoSched);
-    action->addArgument("ioSchedulerPriority", newIoSchedPriority);
-
-    KAuth::ActionReply reply = action->execute();
-
-    if (reply == KAuth::ActionReply::SuccessReply) {
-        updateList();
-        delete action;
-    } else if (reply != KAuth::ActionReply::UserCancelled && reply != KAuth::ActionReply::AuthorizationDenied) {
-        KMessageBox::sorry(this, i18n("You do not have the permission to change the I/O priority of the process and there "
-                    "was a problem trying to run as root.  Error %1 %2", reply.errorCode(), reply.errorDescription()));
-        delete action;
-        return false;
-    }
-    return true;
-}
-
 bool KSysGuardProcessList::changeCpuScheduler(const QList< long long> &pids, KSysGuard::Process::Scheduler newCpuSched, int newCpuSchedPriority)
 {
     if(newCpuSched == KSysGuard::Process::Other || newCpuSched == KSysGuard::Process::Batch) newCpuSchedPriority = 0;
@@ -1220,20 +1126,25 @@ bool KSysGuardProcessList::changeCpuScheduler(const QList< long long> &pids, KSy
     if(unchanged_pids.isEmpty()) return true;
     if(!d->mModel.isLocalhost()) return false; //We can't use KAuth to affect non-localhost processes
 
-    KAuth::Action *action = new KAuth::Action("org.kde.ksysguard.processlisthelper.changecpuscheduler");
-    action->setParentWidget(window());
-    d->setupKAuthAction( action, unchanged_pids);
-    action->addArgument("cpuScheduler", (int)newCpuSched);
-    action->addArgument("cpuSchedulerPriority", newCpuSchedPriority);
-    KAuth::ActionReply reply = action->execute();
+    QVariantMap actionarguments;
+    int processCount = unchanged_pids.count();
+    for(int i = 0; i < processCount; i++) {
+        actionarguments.insert(QString("pid%1").arg(i), unchanged_pids[i]);
+    }
+    actionarguments.insert("pidcount", processCount);
+    actionarguments.insert("cpuScheduler", (int)newCpuSched);
+    actionarguments.insert("cpuSchedulerPriority", newCpuSchedPriority);
+    int reply = KAuthorization::execute(
+        "org.kde.ksysguard.processlisthelper", "changecpuscheduler", actionarguments
+    );
 
-    if (reply == KAuth::ActionReply::SuccessReply) {
+    if (reply == KAuthorization::NoError) {
         updateList();
-        delete action;
-    } else if (reply != KAuth::ActionReply::UserCancelled && reply != KAuth::ActionReply::AuthorizationDenied) {
-        KMessageBox::sorry(this, i18n("You do not have the permission to change the CPU Scheduler for the process and there "
-                    "was a problem trying to run as root.  Error %1 %2", reply.errorCode(), reply.errorDescription()));
-        delete action;
+    } else if (reply == KAuthorization::AuthorizationError) {
+        KMessageBox::sorry(this, i18n("You do not have the permission to change the CPU Scheduler for the process."));
+        return false;
+    } else {
+        KMessageBox::sorry(this, i18n("There was a problem trying to change the CPU Scheduler for the process"));
         return false;
     }
     return true;
@@ -1253,25 +1164,9 @@ bool KSysGuardProcessList::killProcesses(const QList< long long> &pids, int sig)
     if(unkilled_pids.isEmpty()) return true;
     if(!d->mModel.isLocalhost()) return false; //We can't elevate privileges to kill non-localhost processes
 
-    KAuth::Action action("org.kde.ksysguard.processlisthelper.sendsignal");
-    action.setParentWidget(window());
-    d->setupKAuthAction( &action, unkilled_pids);
-    action.addArgument("signal", sig);
-    KAuth::ActionReply reply = action.execute();
 
-    if (reply == KAuth::ActionReply::SuccessReply) {
-        updateList();
-    } else if (reply.type() == KAuth::ActionReply::HelperError) {
-        if (reply.errorCode() > 0)
-            KMessageBox::sorry(this, i18n("You do not have the permission to kill the process and there "
-                        "was a problem trying to run as root. %1", reply.errorDescription()));
-        return false;
-    } else if (reply != KAuth::ActionReply::UserCancelled && reply != KAuth::ActionReply::AuthorizationDenied) {
-        KMessageBox::sorry(this, i18n("You do not have the permission to kill the process and there "
-                    "was a problem trying to run as root.  Error %1 %2", reply.errorCode(), reply.errorDescription()));
-        return false;
-    }
-    return true;
+    KMessageBox::sorry(this, i18n("You do not have the permission to send signal to the process."));
+    return false;
 }
 
 void KSysGuardProcessList::killSelectedProcesses()
@@ -1476,20 +1371,4 @@ bool KSysGuardProcessList::isKillButtonVisible() const
 {
     return d->mUi->btnKillProcess->isVisible();
 }
-bool KSysGuardProcessList::scriptingEnabled() const
-{
-    return !!d->mScripting;
-}
-void KSysGuardProcessList::setScriptingEnabled(bool enabled)
-{
-    if(!!d->mScripting == enabled)
-        return;  //Nothing changed
-    if(!enabled) {
-        delete d->mScripting;
-        d->mScripting = NULL;
-    } else {
-        d->mScripting = new Scripting(this);
-        d->mScripting->hide();
-    }
 
-}
