@@ -29,10 +29,11 @@
 #include <QtGui/QGraphicsWidget>
 #include <klocalizedstring.h>
 #include <kcomponentdata.h>
+#include <kdemacros.h>
 
-class QPaintEvent;
-class QResizeEvent;
-class QGraphicsSceneResizeEvent;
+#include <QPaintEvent>
+#include <QResizeEvent>
+#include <QGraphicsSceneResizeEvent>
 class KGraphicsSignalPlotterPrivate;
 
 //Make sure only declare KLocalizedString once
