@@ -1,10 +1,10 @@
 
 #include <QtTest>
-#include <Qt>
+#include <QtCore/qnamespace.h>
 
 class KGraphicsSignalPlotter;
-class QGraphicsView;
-class QGraphicsScene;
+#include <QGraphicsView>
+#include <QGraphicsScene>
 class BenchmarkGraphicsSignalPlotter : public QObject
 {
     Q_OBJECT
