@@ -29,11 +29,12 @@
 
 #include <QtGui/QWidget>
 #include <QtGui/QPainter>
+#include <QtGui/QPen>
 
 #include <math.h>
 
 #ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <fixx11h.h>
@@ -1089,7 +1090,7 @@ namespace Oxygen
             &data);
 
         // finish if no data is found
-        if( data == None || n != 1 ) return false;
+        if( data == NULL || n != 1 ) return false;
         else return *data;
 
     }
