@@ -1,8 +1,8 @@
-#ifndef oxygenutil_h
-#define oxygenutil_h
+#ifndef OXYGENUTIL_H
+#define OXYGENUTIL_H
 
 /*
- * Copyright 2012 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+ * Copyright 2012 Hugo Pereira Da Costa <hugo.pereira@free.fr>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
