@@ -25,18 +25,15 @@
 #include <math.h>
 
 #include <QtGui/QPainter>
-#include <QtGui/QStyleOptionGraphicsItem>
+#include <QtGui/qstyleoption.h>
 #include <QtGui/QSpinBox>
 #include <QtGui/QClipboard>
 #include <QtCore/QTimeLine>
 #include <QtGui/QGraphicsProxyWidget>
-#include <QtGui/QGraphicsSceneMouseEvent>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QtGui/QGraphicsView>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusPendingCall>
-#include <QtCore/QDate>
+#include <QtCore/QDateTime>
 #include <QtCore/QTimer>
-#include <QtDBus/QDBusConnectionInterface>
 
 #include <KColorScheme>
 #include <KConfigDialog>
@@ -54,6 +51,7 @@
 #include <KTimeZone>
 #include <KToolInvocation>
 #include <KMessageBox>
+#include <KSpeech>
 
 #include <Plasma/Containment>
 #include <Plasma/Corona>
@@ -73,11 +71,12 @@ public:
     Private(ClockApplet *clockapplet)
         : q(clockapplet),
           timezone(ClockApplet::localTimezoneUntranslated()),
-          clipboardMenu(0),
-          adjustSystemTimeAction(0),
-          label(0),
-          calendarWidget(0),
-          forceTzDisplay(false)
+          clipboardMenu(nullptr),
+          adjustSystemTimeAction(nullptr),
+          label(nullptr),
+          calendarWidget(nullptr),
+          forceTzDisplay(false),
+          kspeech(nullptr)
     {}
 
     ClockApplet *q;
@@ -96,6 +95,7 @@ public:
     QTime lastTimeSeen;
     bool forceTzDisplay : 1;
     bool kttsAvailable;
+    KSpeech *kspeech;
 
     QDate addTzToTipText(QString &subText, const Plasma::DataEngine::Data &data, const QDate &prevDate, bool highlight)
     {
@@ -186,17 +186,6 @@ void ClockApplet::speakTime(const QTime &time)
     }
 
     if ((time.minute() % d->announceInterval) == 0) {
-        // If KTTSD not running, start it.
-        if (!QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.kttsd")) {
-            QString error;
-            if (KToolInvocation::startServiceByDesktopName("kttsd", QStringList(), &error)) {
-                KPassivePopup::message(i18n("Starting Jovie Text-to-Speech Service Failed"), error, static_cast<QWidget *>(0));
-                return;
-            }
-        }
-
-        QDBusInterface ktts("org.kde.kttsd", "/KSpeech", "org.kde.KSpeech");
-        ktts.asyncCall("setApplicationName", "plasmaclock");
         QString text;
         if (time.minute() == 0) {
             if (KGlobal::locale()->use12Clock()) {
@@ -240,7 +229,11 @@ void ClockApplet::speakTime(const QTime &time)
                                 time.minute());
             }
         }
-        ktts.asyncCall("say", text, 0);
+        if (!d->kspeech) {
+            d->kspeech = new KSpeech(this);
+            d->kspeech->setSpeechID(QString::fromLatin1("plasmaclock"));
+        }
+        d->kspeech->say(text);
     }
 }
 
@@ -274,13 +267,11 @@ void ClockApplet::updateTipContent()
     QList<Plasma::DataEngine::Data> tzs;
     Plasma::DataEngine *engine = dataEngine("time");
     Plasma::DataEngine::Data data = engine->query("Local");
-    const QDate localDate = data["Date"].toDate();
     const QString localTz = data["Timezone"].toString();
     tzs.append(data);
     bool highlightLocal = false;
 
-    const bool hasEvents = d->calendarWidget ? d->calendarWidget->dateHasDetails(localDate) : false;
-    tipData.setMainText(hasEvents ? i18n("Current Time and Events") : i18n("Current Time"));
+    tipData.setMainText(i18n("Current Time"));
 
     foreach (const QString &tz, d->selectedTimezones) {
         if (tz != "UTC") {
@@ -302,11 +293,6 @@ void ClockApplet::updateTipContent()
 
     subText.append("</table>");
 
-    if (hasEvents) {
-        subText.append("<br /><br /><b>").append(i18n("Today's Events")).append("</b><br/>");
-        subText.append(d->calendarWidget->dateDetails(localDate).join("<br>"));
-    }
-
     tipData.setSubText(subText);
 
     // query for custom content
@@ -372,7 +358,7 @@ void ClockApplet::createConfigurationInterface(KConfigDialog *parent)
 {
     createClockConfigurationInterface(parent);
 
-    d->kttsAvailable = (QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.kttsd") || KService::serviceByDesktopName("kttsd"));
+    d->kttsAvailable = KSpeech::isSupported();
 
     if (d->kttsAvailable) {
         QWidget *generalWidget = new QWidget();
@@ -767,4 +753,4 @@ const KCalendarSystem *ClockApplet::calendar() const
     }
 }
 
-#include "clockapplet.moc"
+#include "moc_clockapplet.cpp"
