@@ -19,7 +19,7 @@
 
 #include "wheelytoolbutton.h"
 
-#include <QGraphicsSceneWheelEvent>
+#include <QtGui/qgraphicssceneevent.h>
 
 WheelyToolButton::WheelyToolButton(QGraphicsWidget *parent)
     : Plasma::ToolButton(parent)
@@ -35,5 +35,5 @@ void WheelyToolButton::wheelEvent(QGraphicsSceneWheelEvent *event)
     }
 }
 
-#include "wheelytoolbutton.moc"
+#include "moc_wheelytoolbutton.cpp"
 
