@@ -34,9 +34,6 @@
 #include <KShell>
 #include <KStandardDirs>
 
-// KIO
-#include <kemailsettings.h> // no camelcase include
-
 #include <Plasma/Applet>
 #include <Plasma/Containment>
 #include <Plasma/Corona>
@@ -74,38 +71,9 @@ ScriptEngine::~ScriptEngine()
 {
 }
 
-QScriptValue ScriptEngine::activityById(QScriptContext *context, QScriptEngine *engine)
-{
-    if (context->argumentCount() == 0) {
-        return context->throwError(i18n("activityById requires an id"));
-    }
-
-    const uint id = context->argument(0).toInt32();
-    ScriptEngine *env = envFor(engine);
-    foreach (Plasma::Containment *c, env->m_corona->containments()) {
-        if (c->id() == id && !isPanel(c)) {
-            return env->wrap(c);
-        }
-    }
-
-    return engine->undefinedValue();
-}
-
-QScriptValue ScriptEngine::activityForScreen(QScriptContext *context, QScriptEngine *engine)
-{
-    if (context->argumentCount() == 0) {
-        return context->throwError(i18n("activityForScreen requires a screen id"));
-    }
-
-    const uint screen = context->argument(0).toInt32();
-    const uint desktop = context->argumentCount() > 1 ? context->argument(1).toInt32() : -1;
-    ScriptEngine *env = envFor(engine);
-    return env->wrap(env->m_corona->containmentForScreen(screen, desktop));
-}
-
 QScriptValue ScriptEngine::newActivity(QScriptContext *context, QScriptEngine *engine)
 {
-    return createContainment("desktop", "desktop", context, engine);
+   return createContainment("desktop", "desktop", context, engine);
 }
 
 QScriptValue ScriptEngine::newPanel(QScriptContext *context, QScriptEngine *engine)
@@ -198,7 +166,7 @@ ScriptEngine *ScriptEngine::envFor(QScriptEngine *engine)
 QScriptValue ScriptEngine::panelById(QScriptContext *context, QScriptEngine *engine)
 {
     if (context->argumentCount() == 0) {
-        return context->throwError(i18n("activityById requires an id"));
+        return context->throwError(i18n("panelById requires an id"));
     }
 
     const uint id = context->argument(0).toInt32();
@@ -359,98 +327,6 @@ QString ScriptEngine::onlyExec(const QString &commandLine)
     return KShell::splitArgs(commandLine, KShell::TildeExpand).first();
 }
 
-QScriptValue ScriptEngine::defaultApplication(QScriptContext *context, QScriptEngine *engine)
-{
-    Q_UNUSED(engine)
-    if (context->argumentCount() == 0) {
-        return false;
-    }
-
-    const QString application = context->argument(0).toString();
-    if (application.isEmpty()) {
-        return false;
-    }
-
-    const bool storageId = context->argumentCount() < 2 ? false : context->argument(1).toBool();
-
-    // FIXME: there are some pretty horrible hacks below, in the sense that they assume a very
-    // specific implementation system. there is much room for improvement here. see
-    // kdebase-runtime/kcontrol/componentchooser/ for all the gory details ;)
-    if (application.compare("mailer", Qt::CaseInsensitive) == 0) {
-        KEMailSettings settings;
-
-        // in KToolInvocation, the default is kmail; but let's be friendlier :)
-        QString command = settings.getSetting(KEMailSettings::ClientProgram);
-        if (command.isEmpty()) {
-            if (KService::Ptr kontact = KService::serviceByStorageId("kontact")) {
-                return storageId ? kontact->storageId() : onlyExec(kontact->exec());
-            } else if (KService::Ptr kmail = KService::serviceByStorageId("kmail")) {
-                return storageId ? kmail->storageId() : onlyExec(kmail->exec());
-            }
-        }
-
-        if (!command.isEmpty()) {
-            if (settings.getSetting(KEMailSettings::ClientTerminal) == "true") {
-                KConfigGroup confGroup(KGlobal::config(), "General");
-                const QString preferredTerminal = confGroup.readPathEntry("TerminalApplication", QString::fromLatin1("konsole"));
-                command = preferredTerminal + QString::fromLatin1(" -e ") + command;
-            }
-
-            return command;
-        }
-    } else if (application.compare("browser", Qt::CaseInsensitive) == 0) {
-        KConfigGroup config(KGlobal::config(), "General");
-        QString browserApp = config.readPathEntry("BrowserApplication", QString());
-        if (browserApp.isEmpty()) {
-            const KService::Ptr htmlApp = KMimeTypeTrader::self()->preferredService(QLatin1String("text/html"));
-            if (htmlApp) {
-                browserApp = storageId ? htmlApp->storageId() : htmlApp->exec();
-            }
-        } else if (browserApp.startsWith('!')) {
-            browserApp = browserApp.mid(1);
-        }
-
-        return onlyExec(browserApp);
-    } else if (application.compare("terminal", Qt::CaseInsensitive) == 0) {
-        KConfigGroup confGroup(KGlobal::config(), "General");
-        return onlyExec(confGroup.readPathEntry("TerminalApplication", QString::fromLatin1("konsole")));
-    } else if (application.compare("filemanager", Qt::CaseInsensitive) == 0) {
-        KService::Ptr service = KMimeTypeTrader::self()->preferredService("inode/directory");
-        if (service) {
-            return storageId ? service->storageId() : onlyExec(service->exec());
-        }
-    } else if (application.compare("windowmanager", Qt::CaseInsensitive) == 0) {
-        KConfig cfg("ksmserverrc", KConfig::NoGlobals);
-        KConfigGroup confGroup(&cfg, "General");
-        return onlyExec(confGroup.readEntry("windowManager", QString::fromLatin1("kwin")));
-    } else if (KService::Ptr service = KMimeTypeTrader::self()->preferredService(application)) {
-        return storageId ? service->storageId() : onlyExec(service->exec());
-    } else {
-        // try the files in share/apps/kcm_componentchooser/
-        const QStringList services = KGlobal::dirs()->findAllResources("data","kcm_componentchooser/*.desktop", KStandardDirs::NoDuplicates);
-        //kDebug() << "ok, trying in" << services.count();
-        foreach (const QString &service, services) {
-            KConfig config(service, KConfig::SimpleConfig);
-            KConfigGroup cg = config.group(QByteArray());
-            const QString type = cg.readEntry("valueName", QString());
-            //kDebug() << "    checking" << service << type << application;
-            if (type.compare(application, Qt::CaseInsensitive) == 0) {
-                KConfig store(cg.readPathEntry("storeInFile", "null"));
-                KConfigGroup storeCg(&store, cg.readEntry("valueSection", QString()));
-                const QString exec = storeCg.readPathEntry(cg.readEntry("valueName", "kcm_componenchooser_null"),
-                                                           cg.readEntry("defaultImplementation", QString()));
-                if (!exec.isEmpty()) {
-                    return exec;
-                }
-
-                break;
-            }
-        }
-    }
-
-    return false;
-}
-
 QScriptValue ScriptEngine::applicationPath(QScriptContext *context, QScriptEngine *engine)
 {
     Q_UNUSED(engine)
@@ -512,8 +388,6 @@ QScriptValue ScriptEngine::userDataPath(QScriptContext *context, QScriptEngine *
 
     if (type.compare("desktop", Qt::CaseInsensitive) == 0) {
         return KGlobalSettings::desktopPath();
-    } else if (type.compare("autostart", Qt::CaseInsensitive) == 0) {
-        return KGlobalSettings::autostartPath();
     } else if (type.compare("documents", Qt::CaseInsensitive) == 0) {
         return KGlobalSettings::documentPath();
     } else if (type.compare("music", Qt::CaseInsensitive) == 0) {
@@ -600,15 +474,11 @@ void ScriptEngine::setupEngine()
     m_scriptSelf.setProperty("QRectF", constructQRectFClass(this));
     m_scriptSelf.setProperty("Activity", newFunction(ScriptEngine::newActivity));
     m_scriptSelf.setProperty("Panel", newFunction(ScriptEngine::newPanel));
-    m_scriptSelf.setProperty("activities", newFunction(ScriptEngine::activities));
-    m_scriptSelf.setProperty("activityById", newFunction(ScriptEngine::activityById));
-    m_scriptSelf.setProperty("activityForScreen", newFunction(ScriptEngine::activityForScreen));
     m_scriptSelf.setProperty("panelById", newFunction(ScriptEngine::panelById));
     m_scriptSelf.setProperty("panels", newFunction(ScriptEngine::panels));
     m_scriptSelf.setProperty("fileExists", newFunction(ScriptEngine::fileExists));
     m_scriptSelf.setProperty("loadTemplate", newFunction(ScriptEngine::loadTemplate));
     m_scriptSelf.setProperty("applicationExists", newFunction(ScriptEngine::applicationExists));
-    m_scriptSelf.setProperty("defaultApplication", newFunction(ScriptEngine::defaultApplication));
     m_scriptSelf.setProperty("userDataPath", newFunction(ScriptEngine::userDataPath));
     m_scriptSelf.setProperty("applicationPath", newFunction(ScriptEngine::applicationPath));
     m_scriptSelf.setProperty("knownWallpaperPlugins", newFunction(ScriptEngine::knownWallpaperPlugins));
@@ -627,25 +497,6 @@ bool ScriptEngine::isPanel(const Plasma::Containment *c)
            c->containmentType() == Plasma::Containment::CustomPanelContainment;
 }
 
-QScriptValue ScriptEngine::activities(QScriptContext *context, QScriptEngine *engine)
-{
-    Q_UNUSED(context)
-
-    QScriptValue containments = engine->newArray();
-    ScriptEngine *env = envFor(engine);
-    int count = 0;
-
-    foreach (Plasma::Containment *c, env->corona()->containments()) {
-        if (!isPanel(c)) {
-            containments.setProperty(count, env->wrap(c));
-            ++count;
-        }
-    }
-
-    containments.setProperty("length", count);
-    return containments;
-}
-
 Plasma::Corona *ScriptEngine::corona() const
 {
     return m_corona;
@@ -674,41 +525,6 @@ void ScriptEngine::exception(const QScriptValue &value)
     emit printError(value.toVariant().toString());
 }
 
-QStringList ScriptEngine::pendingUpdateScripts()
-{
-    const QString appName = KGlobal::activeComponent().aboutData()->appName();
-    QStringList scripts = KGlobal::dirs()->findAllResources("data", appName + "/updates/*.js");
-    QStringList scriptPaths;
-
-    if (scripts.isEmpty()) {
-        //kDebug() << "no update scripts";
-        return scriptPaths;
-    }
-
-    KConfigGroup cg(KGlobal::config(), "Updates");
-    QStringList performed = cg.readEntry("performed", QStringList());
-    const QString localDir = KGlobal::dirs()->localkdedir();
-    const QString localXdgDir = KGlobal::dirs()->localxdgdatadir();
-
-    foreach (const QString &script, scripts) {
-        if (performed.contains(script)) {
-            continue;
-        }
-
-        if (script.startsWith(localDir) || script.startsWith(localXdgDir)) {
-            kDebug() << "skipping user local script: " << script;
-            continue;
-        }
-
-        scriptPaths.append(script);
-        performed.append(script);
-    }
-
-    cg.writeEntry("performed", performed);
-    KGlobal::config()->sync();
-    return scriptPaths;
-}
-
 QStringList ScriptEngine::defaultLayoutScripts()
 {
     const QString appName = KGlobal::activeComponent().aboutData()->appName();
@@ -761,5 +577,5 @@ QStringList ScriptEngine::defaultLayoutScripts()
 
 }
 
-#include "scriptengine.moc"
+#include "moc_scriptengine.cpp"
 
