@@ -49,12 +49,6 @@
 
 #include "kcategorizeditemsviewmodels_p.h"
 #include "plasmaappletitemmodel_p.h"
-#include "openwidgetassistant_p.h"
-
-//getting the user local
-//KGlobal::dirs()->localkdedir();
-//Compare it to the entryPath of the KPluginInfo
-//and see if it can be uninstalled
 
 using namespace KCategorizedItemsViewModels;
 
@@ -110,7 +104,6 @@ public:
     QHash<QString, int> runningApplets; // applet name => count
     //extra hash so we can look up the names of deleted applets
     QHash<Plasma::Applet *,QString> appletNames;
-    QWeakPointer<Plasma::OpenWidgetAssistant> openAssistant;
     Plasma::Package *package;
 
     PlasmaAppletItemModel itemModel;
@@ -134,22 +127,15 @@ void WidgetExplorerPrivate::initFilters()
 
     filterModel.addSeparator(i18n("Categories:"));
 
-    typedef QPair<QString, QString> catPair;
-    QMap<QString, catPair > categories;
     QSet<QString> existingCategories = itemModel.categories();
     foreach (const QString &category, Plasma::Applet::listCategories(application)) {
         const QString lowerCaseCat = category.toLower();
         if (existingCategories.contains(lowerCaseCat)) {
             const QString trans = i18n(category.toLocal8Bit());
-            categories.insert(trans.toLower(), qMakePair(trans, lowerCaseCat));
+            filterModel.addFilter(trans,
+                                  KCategorizedItemsViewModels::Filter("category", lowerCaseCat));
         }
     }
-
-    foreach (const catPair &category, categories) {
-        filterModel.addFilter(category.first,
-                              KCategorizedItemsViewModels::Filter("category", category.second));
-    }
-
 }
 
 void WidgetExplorerPrivate::init(Plasma::Location loc)
@@ -249,38 +235,10 @@ QList <QObject *>  WidgetExplorer::widgetsMenuActions()
 {
     QList <QObject *> actionList;
 
-    QSignalMapper *mapper = new QSignalMapper(this);
-    QObject::connect(mapper, SIGNAL(mapped(QString)), this, SLOT(downloadWidgets(QString)));
-
-    WidgetAction *action = new WidgetAction(KIcon("applications-internet"),
-                                  i18n("Download New Plasma Widgets"), this);
-    QObject::connect(action, SIGNAL(triggered(bool)), mapper, SLOT(map()));
-    mapper->setMapping(action, QString());
-    actionList << action;
-
-    KService::List offers = KServiceTypeTrader::self()->query("Plasma/PackageStructure");
-    foreach (const KService::Ptr &service, offers) {
-        //kDebug() << service->property("X-Plasma-ProvidesWidgetBrowser");
-        if (service->property("X-Plasma-ProvidesWidgetBrowser").toBool()) {
-            WidgetAction *action = new WidgetAction(KIcon("applications-internet"),
-                                          i18nc("%1 is a type of widgets, as defined by "
-                                                "e.g. some plasma-packagestructure-*.desktop files",
-                                                "Download New %1", service->name()), this);
-            QObject::connect(action, SIGNAL(triggered(bool)), mapper, SLOT(map()));
-            mapper->setMapping(action, service->property("X-KDE-PluginInfo-Name").toString());
-            actionList << action;
-        }
-    }
-
-    action = new WidgetAction(this);
+    WidgetAction *action = new WidgetAction(this);
     action->setSeparator(true);
     actionList << action;
 
-    action = new WidgetAction(KIcon("package-x-generic"),
-                         i18n("Install Widget From Local File..."), this);
-    QObject::connect(action, SIGNAL(triggered(bool)), this, SLOT(openWidgetFile()));
-    actionList << action;
-
     return actionList;
 }
 
@@ -489,86 +447,6 @@ void WidgetExplorer::focusInEvent(QFocusEvent* event)
     Q_UNUSED(event);
 }
 
-void WidgetExplorer::downloadWidgets(const QString &type)
-{
-    Plasma::PackageStructure *installer = 0;
-
-    if (!type.isEmpty()) {
-        QString constraint = QString("'%1' == [X-KDE-PluginInfo-Name]").arg(type);
-        KService::List offers = KServiceTypeTrader::self()->query("Plasma/PackageStructure",
-                                                                  constraint);
-        if (offers.isEmpty()) {
-            kDebug() << "could not find requested PackageStructure plugin" << type;
-        } else {
-            KService::Ptr service = offers.first();
-            QString error;
-            installer = service->createInstance<Plasma::PackageStructure>(topLevelWidget(),
-                                                                          QVariantList(), &error);
-            if (installer) {
-                connect(installer, SIGNAL(newWidgetBrowserFinished()),
-                        installer, SLOT(deleteLater()));
-            } else {
-                kDebug() << "found, but could not load requested PackageStructure plugin" << type
-                         << "; reported error was" << error;
-            }
-        }
-    }
-
-    emit closeClicked();
-    if (installer) {
-        installer->createNewWidgetBrowser();
-    } else {
-        // we don't need to delete the default Applet::packageStructure as that
-        // belongs to the applet
-       Plasma::Applet::packageStructure()->createNewWidgetBrowser();
-        /**
-          for reference in a libplasma2 world, the above line equates to this:
-
-          KNS3::DownloadDialog *knsDialog = m_knsDialog.data();
-          if (!knsDialog) {
-          m_knsDialog = knsDialog = new KNS3::DownloadDialog("plasmoids.knsrc", parent);
-          connect(knsDialog, SIGNAL(accepted()), this, SIGNAL(newWidgetBrowserFinished()));
-          }
-
-          knsDialog->show();
-          knsDialog->raise();
-         */
-    }
-}
-
-void WidgetExplorer::openWidgetFile()
-{
-    emit closeClicked();
-
-    Plasma::OpenWidgetAssistant *assistant = d->openAssistant.data();
-    if (!assistant) {
-        assistant = new Plasma::OpenWidgetAssistant(0);
-        d->openAssistant = assistant;
-    }
-
-    KWindowSystem::setOnDesktop(assistant->winId(), KWindowSystem::currentDesktop());
-    assistant->setAttribute(Qt::WA_DeleteOnClose, true);
-    assistant->show();
-    assistant->raise();
-    assistant->setFocus();
-}
-
-void WidgetExplorer::uninstall(const QString &pluginName)
-{
-    Plasma::PackageStructure installer;
-    installer.uninstallPackage(pluginName,
-                               KStandardDirs::locateLocal("data", "plasma/plasmoids/"));
-
-    //FIXME: moreefficient way rather a linear scan?
-    for (int i = 0; i < d->itemModel.rowCount(); ++i) {
-        QStandardItem *item = d->itemModel.item(i);
-        if (item->data(PlasmaAppletItemModel::PluginNameRole).toString() == pluginName) {
-            d->itemModel.takeRow(i);
-            break;
-        }
-    }
-}
-
 QPoint WidgetExplorer::tooltipPosition(QGraphicsObject *item, int tipWidth, int tipHeight)
 {
     if (!item) {
@@ -643,4 +521,4 @@ QPoint WidgetExplorer::tooltipPosition(QGraphicsObject *item, int tipWidth, int
 
 } // namespace Plasma
 
-#include "widgetexplorer.moc"
+#include "moc_widgetexplorer.cpp"
