@@ -27,8 +27,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QtCore/QObject>
 #include <QtGui/QIcon>
 
-#include <KDE/KWindowSystem>
-#include <KDE/KUrl>
+#include <KWindowSystem>
+#include <KUrl>
 
 #include "taskmanager.h"
 #include "taskmanager_export.h"
@@ -84,10 +84,6 @@ public:
 
     bool isGroupMember(const GroupPtr group) const;
     virtual ItemType itemType() const = 0;
-    /**
-    * @deprecated: use itemType() instead
-    **/
-    KDE_DEPRECATED virtual bool isGroupItem() const = 0;
 
     virtual bool isStartupItem() const;
 
