@@ -271,5 +271,5 @@ QList <QIcon> AbstractGroupingStrategy::iconSuggestions(TaskGroup *)
 
 }//namespace
 
-#include "abstractgroupingstrategy.moc"
+#include "moc_abstractgroupingstrategy.cpp"
 
