@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "taskmanager.h"
 #include "abstractgroupableitem.h"
 
-#include <QtAlgorithms>
+#include <QtCore/qalgorithms.h>
 #include <QList>
 
 #include <KDebug>
@@ -91,7 +91,7 @@ void AbstractSortingStrategy::handleGroup(TaskGroup *group)
 
 void AbstractSortingStrategy::removeGroup()
 {
-    TaskGroup *group = dynamic_cast<TaskGroup*>(sender());
+    TaskGroup *group = qobject_cast<TaskGroup*>(sender());
 
     if (!group) {
         return;
@@ -117,7 +117,7 @@ void AbstractSortingStrategy::check(AbstractGroupableItem *itemToCheck)
 {
     AbstractGroupableItem *item;
     if (!itemToCheck) {
-        item = dynamic_cast<AbstractGroupableItem *>(sender());
+        item = qobject_cast<AbstractGroupableItem *>(sender());
     } else {
         item = itemToCheck;
     }
@@ -188,4 +188,4 @@ bool AbstractSortingStrategy::moveItem(AbstractGroupableItem *item, int newIndex
 
 } //namespace
 
-#include "abstractsortingstrategy.moc"
+#include "moc_abstractsortingstrategy.cpp"
