@@ -27,8 +27,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QList>
 #include <QStack>
 #include <QTimer>
-#include <QUuid>
 #include <QFile>
+#include <QImageWriter>
 
 #include <KDebug>
 #include <KService>
@@ -41,7 +41,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "taskitem.h"
 #include "taskgroup.h"
 #include "taskmanager.h"
-#include "strategies/activitysortingstrategy.h"
 #include "strategies/alphasortingstrategy.h"
 #include "strategies/desktopsortingstrategy.h"
 #include "strategies/programgroupingstrategy.h"
@@ -53,6 +52,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 namespace TaskManager
 {
 
+static const QByteArray pixmapFormat = QImageWriter::defaultImageFormat();
+
 class GroupManagerPrivate
 {
 public:
@@ -65,8 +66,7 @@ public:
           abstractSortingStrategy(0),
           currentScreen(-1),
           groupIsFullLimit(0),
-          showOnlyCurrentDesktop(false),
-          showOnlyCurrentActivity(false),
+          showOnlyCurrentDesktop(true),
           showOnlyCurrentScreen(false),
           showOnlyMinimized(false),
           onlyGroupWhenFull(false),
@@ -86,7 +86,6 @@ public:
     * Keep track of changes in Taskmanager
     */
     void currentDesktopChanged(int);
-    void currentActivityChanged(QString);
     void taskChanged(::TaskManager::Task *, ::TaskManager::TaskChanges);
     void checkScreenChange();
     void taskDestroyed(QObject *item);
@@ -124,15 +123,12 @@ public:
     QTimer checkIfFullTimer;
     QSet<Task *> geometryTasks;
     int groupIsFullLimit;
-    QUuid configToken;
 
-    QHash<QString, QHash<int, TaskGroup*> > rootGroups; //container for groups
+    QHash<int, TaskGroup*> rootGroups; //container for groups
     QList<LauncherItem *> launchers;
     int currentDesktop;
-    QString currentActivity;
 
     bool showOnlyCurrentDesktop : 1;
-    bool showOnlyCurrentActivity : 1;
     bool showOnlyCurrentScreen : 1;
     bool showOnlyMinimized : 1;
     bool onlyGroupWhenFull : 1;
@@ -155,9 +151,8 @@ GroupManager::GroupManager(QObject *parent)
     connect(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), this, SLOT(sycocaChanged(const QStringList &)));
 
     d->currentDesktop = TaskManager::self()->currentDesktop();
-    d->currentActivity = TaskManager::self()->currentActivity();
 
-    d->rootGroups[d->currentActivity][d->currentDesktop] = new TaskGroup(this, "RootGroup");
+    d->rootGroups[d->currentDesktop] = new TaskGroup(this, "RootGroup");
 
     d->reloadTimer.setSingleShot(true);
     d->reloadTimer.setInterval(0);
@@ -174,7 +169,7 @@ GroupManager::GroupManager(QObject *parent)
 
 GroupManager::~GroupManager()
 {
-    TaskManager::self()->setTrackGeometry(false, d->configToken);
+    TaskManager::self()->setTrackGeometry(false);
     delete d->abstractSortingStrategy;
     delete d->abstractGroupingStrategy;
     delete d;
@@ -182,7 +177,7 @@ GroupManager::~GroupManager()
 
 TaskGroup *GroupManagerPrivate::currentRootGroup()
 {
-    return rootGroups[currentActivity][currentDesktop];
+    return rootGroups[currentDesktop];
 }
 
 void GroupManagerPrivate::reloadTasks()
@@ -277,19 +272,13 @@ bool GroupManagerPrivate::addTask(::TaskManager::Task *task)
             skip = true;
         }
 
-        if (showOnlyCurrentActivity && !task->isOnCurrentActivity()) {
-            /* kDebug() << "Not on this desktop and showOnlyCurrentActivity"
-                     << KWindowSystem::currentActivity() << task->desktop(); */
-            skip = true;
-        }
-
         if (showOnlyMinimized && !task->isMinimized()) {
             //kDebug() << "Not minimized and only showing minimized";
             skip = true;
         }
 
         NET::WindowType type = task->info().windowType(NET::NormalMask | NET::DialogMask |
-                               NET::OverrideMask | NET::UtilityMask);
+                               NET::UtilityMask);
         if (type == NET::Utility) {
             //kDebug() << "skipping utility window" << task->name();
             skip = true;
@@ -443,43 +432,6 @@ GroupPtr GroupManager::rootGroup() const
     return d->currentRootGroup();
 }
 
-void GroupManagerPrivate::currentActivityChanged(QString newActivity)
-{
-    if (!showOnlyCurrentActivity || currentActivity == newActivity) {
-        return;
-    }
-
-    if (!rootGroups.contains(newActivity) || !rootGroups.value(newActivity).contains(currentDesktop)) {
-        kDebug() << "created new desk group";
-        rootGroups[newActivity][currentDesktop] = new TaskGroup(q, "RootGroup");
-        if (abstractSortingStrategy) {
-            abstractSortingStrategy->handleGroup(rootGroups[newActivity][currentDesktop]);
-        }
-    }
-
-    if (onlyGroupWhenFull) {
-        QObject::disconnect(currentRootGroup(), SIGNAL(itemAdded(AbstractGroupableItem*)), q, SLOT(checkIfFull()));
-        QObject::disconnect(currentRootGroup(), SIGNAL(itemRemoved(AbstractGroupableItem*)), q, SLOT(checkIfFull()));
-    }
-
-    currentActivity = newActivity;
-
-    foreach (LauncherItem * item, launchers) {
-        if (item->shouldShow(q)) {
-            rootGroups[currentActivity][currentDesktop]->add(item);
-        } else {
-            rootGroups[currentActivity][currentDesktop]->remove(item);
-        }
-    }
-
-    if (onlyGroupWhenFull) {
-        QObject::connect(currentRootGroup(), SIGNAL(itemAdded(AbstractGroupableItem*)), q, SLOT(checkIfFull()));
-        QObject::connect(currentRootGroup(), SIGNAL(itemRemoved(AbstractGroupableItem*)), q, SLOT(checkIfFull()));
-    }
-
-    actuallyReloadTasks();
-}
-
 void GroupManagerPrivate::currentDesktopChanged(int newDesktop)
 {
     //kDebug();
@@ -491,11 +443,11 @@ void GroupManagerPrivate::currentDesktopChanged(int newDesktop)
         return;
     }
 
-    if (!rootGroups[currentActivity].contains(newDesktop)) {
+    if (!rootGroups.contains(newDesktop)) {
         kDebug() << "created new desk group";
-        rootGroups[currentActivity][newDesktop] = new TaskGroup(q, "RootGroup");
+        rootGroups[newDesktop] = new TaskGroup(q, "RootGroup");
         if (abstractSortingStrategy) {
-            abstractSortingStrategy->handleGroup(rootGroups[currentActivity][newDesktop]);
+            abstractSortingStrategy->handleGroup(rootGroups[newDesktop]);
         }
     }
 
@@ -508,9 +460,9 @@ void GroupManagerPrivate::currentDesktopChanged(int newDesktop)
 
     foreach (LauncherItem * item, launchers) {
         if (item->shouldShow(q)) {
-            rootGroups[currentActivity][currentDesktop]->add(item);
+            rootGroups[currentDesktop]->add(item);
         } else {
-            rootGroups[currentActivity][currentDesktop]->remove(item);
+            rootGroups[currentDesktop]->remove(item);
         }
     }
 
@@ -539,12 +491,6 @@ void GroupManagerPrivate::taskChanged(::TaskManager::Task *task, ::TaskManager::
         //kDebug() << task->visibleName() << "on" << TaskManager::self()->currentDesktop();
     }
 
-    if (showOnlyCurrentActivity && changes & ::TaskManager::ActivitiesChanged) {
-        takeAction = true;
-        show = task->isOnCurrentActivity();
-        //kDebug() << task->visibleName() << "on" << TaskManager::self()->currentDesktop();
-    }
-
     if (showOnlyMinimized && changes & ::TaskManager::StateChanged) {
         //TODO: wouldn't it be nice to get notification of JUST minimization?
         takeAction = true;
@@ -625,26 +571,21 @@ void GroupManager::reconnect()
 {
     //kDebug();
     disconnect(TaskManager::self(), SIGNAL(desktopChanged(int)), this, SLOT(currentDesktopChanged(int)));
-    disconnect(TaskManager::self(), SIGNAL(activityChanged(QString)), this, SLOT(currentActivityChanged(QString)));
     disconnect(TaskManager::self(), SIGNAL(windowChanged(::TaskManager::Task *, ::TaskManager::TaskChanges)),
                this, SLOT(taskChanged(::TaskManager::Task *, ::TaskManager::TaskChanges)));
 
-    if (d->showOnlyCurrentDesktop || d->showOnlyMinimized || d->showOnlyCurrentScreen || d->showOnlyCurrentActivity) {
+    if (d->showOnlyCurrentDesktop || d->showOnlyMinimized || d->showOnlyCurrentScreen) {
         // listen to the relevant task manager signals
         if (d->showOnlyCurrentDesktop) {
             connect(TaskManager::self(), SIGNAL(desktopChanged(int)),
                     this, SLOT(currentDesktopChanged(int)));
         }
-        if (d->showOnlyCurrentActivity) {
-            connect(TaskManager::self(), SIGNAL(activityChanged(QString)),
-                    this, SLOT(currentActivityChanged(QString)));
-        }
 
         connect(TaskManager::self(), SIGNAL(windowChanged(::TaskManager::Task *, ::TaskManager::TaskChanges)),
                 this, SLOT(taskChanged(::TaskManager::Task *, ::TaskManager::TaskChanges)));
     }
 
-    TaskManager::self()->setTrackGeometry(d->showOnlyCurrentScreen, d->configToken);
+    TaskManager::self()->setTrackGeometry(d->showOnlyCurrentScreen);
 
     if (!d->showOnlyCurrentScreen) {
         d->geometryTasks.clear();
@@ -717,7 +658,7 @@ bool GroupManager::addLauncher(const KUrl &url, const QIcon &icon, const QString
 
         if (!d->separateLaunchers && d->abstractSortingStrategy && ManualSorting == d->abstractSortingStrategy->type()) {
             // Ensure item is placed where launcher would be...
-            foreach (AbstractGroupableItem * item, d->rootGroups[d->currentActivity][d->currentDesktop]->members()) {
+            foreach (AbstractGroupableItem * item, d->rootGroups[d->currentDesktop]->members()) {
                 if (LauncherItemType != item->itemType() && item->launcherUrl() == url) {
                     manualSortingRequest(item, launcherIndex(url));
                     break;
@@ -770,11 +711,8 @@ void GroupManager::removeLauncher(const KUrl &url)
     d->launchers.removeAt(index);
     d->saveLauncherConfig();
 
-    typedef QHash<int, TaskGroup*> Metagroup;
-    foreach (Metagroup metagroup, d->rootGroups) {
-        foreach (TaskGroup * rootGroup, metagroup) {
-            rootGroup->remove(launcher);
-        }
+    foreach (TaskGroup * rootGroup, d->rootGroups) {
+        rootGroup->remove(launcher);
     }
 
     d->unsaveLauncher(launcher);
@@ -782,7 +720,7 @@ void GroupManager::removeLauncher(const KUrl &url)
 
     if (!d->separateLaunchers && d->abstractSortingStrategy && ManualSorting == d->abstractSortingStrategy->type()) {
         // Ensure item is placed at end of launchers...
-        foreach (AbstractGroupableItem * item, d->rootGroups[d->currentActivity][d->currentDesktop]->members()) {
+        foreach (AbstractGroupableItem * item, d->rootGroups[d->currentDesktop]->members()) {
             if (LauncherItemType != item->itemType() && item->launcherUrl() == url) {
                 manualSortingRequest(item, d->launchers.count());
                 break;
@@ -797,11 +735,10 @@ void GroupManager::removeLauncher(const KUrl &url)
 
 void GroupManagerPrivate::sycocaChanged(const QStringList &types)
 {
-    if (types.contains("apps")) {
+    if (types.contains("apps") || types.contains("xdgdata-apps")) {
         KUrl::List removals;
         foreach (LauncherItem *launcher, launchers) {
-            if (launcher->launcherUrl().protocol() != "preferred" &&
-                !QFile::exists(launcher->launcherUrl().toLocalFile())) {
+            if (!QFile::exists(launcher->launcherUrl().toLocalFile())) {
                 removals << launcher->launcherUrl();
             }
         }
@@ -824,9 +761,9 @@ void GroupManagerPrivate::checkLauncherVisibility(LauncherItem *launcher)
     }
 
     if (launcher->shouldShow(q)) {
-        rootGroups[currentActivity][currentDesktop]->add(launcher);
+        rootGroups[currentDesktop]->add(launcher);
     } else {
-        rootGroups[currentActivity][currentDesktop]->remove(launcher);
+        rootGroups[currentDesktop]->remove(launcher);
     }
 }
 
@@ -870,7 +807,7 @@ void GroupManager::readLauncherConfig(const KConfigGroup &cg)
             } else if (item.length() >= 5) {
                 QPixmap pixmap;
                 QByteArray bytes = QByteArray::fromBase64(item.at(4).toAscii());
-                pixmap.loadFromData(bytes);
+                pixmap.loadFromData(bytes, pixmapFormat);
                 icon.addPixmap(pixmap);
             }
             QString name(item.at(2));
@@ -1061,7 +998,7 @@ bool GroupManagerPrivate::saveLauncher(LauncherItem *launcher, KConfigGroup &cg)
         QByteArray bytes;
         QBuffer buffer(&bytes);
         buffer.open(QIODevice::WriteOnly);
-        pixmap.save(&buffer, "PNG");
+        pixmap.save(&buffer, pixmapFormat);
         launcherProperties.append(bytes.toBase64());
     }
 
@@ -1076,13 +1013,7 @@ void GroupManagerPrivate::unsaveLauncher(LauncherItem *launcher)
         return;
     }
 
-    QString launcherKey;
-
-    if (launcher->launcherUrl().protocol() == "preferred")
-        // in default config the host of the preferred application url is used as key
-        launcherKey = launcher->launcherUrl().host();
-    else
-        launcherKey = launcher->name();
+    QString launcherKey = launcher->name();
 
     if (cg.hasKey(launcherKey)) {
         cg.deleteEntry(launcherKey);
@@ -1146,27 +1077,6 @@ int GroupManagerPrivate::launcherIndex(const KUrl &url)
         ++index;
     }
 
-    // .. and if that fails for preferred launcher matches
-    index = 0;
-    foreach (const LauncherItem * item, launchers) {
-        if (item->launcherUrl().protocol() == "preferred") {
-            KService::Ptr service = KService::serviceByStorageId(item->defaultApplication());
-
-            if (service) {
-                QUrl prefUrl(service->entryPath());
-                if (prefUrl.scheme().isEmpty()) {
-                    prefUrl.setScheme("file");
-                }
-
-                if (prefUrl == url) {
-                    return index;
-                }
-            }
-        }
-
-        ++index;
-    }
-
     return -1;
 }
 
@@ -1257,17 +1167,6 @@ void GroupManager::setShowOnlyCurrentDesktop(bool showOnlyCurrentDesktop)
     reconnect();
 }
 
-bool GroupManager::showOnlyCurrentActivity() const
-{
-    return d->showOnlyCurrentActivity;
-}
-
-void GroupManager::setShowOnlyCurrentActivity(bool showOnlyCurrentActivity)
-{
-    d->showOnlyCurrentActivity = showOnlyCurrentActivity;
-    reconnect();
-}
-
 bool GroupManager::showOnlyMinimized() const
 {
     return d->showOnlyMinimized;
@@ -1315,10 +1214,6 @@ void GroupManager::setSortingStrategy(TaskSortingStrategy sortOrder)
         d->abstractSortingStrategy = new DesktopSortingStrategy(this);
         break;
 
-    case ActivitySorting:
-        d->abstractSortingStrategy = new ActivitySortingStrategy(this);
-        break;
-
     case NoSorting: //manual and no grouping result both in non automatic grouping
         break;
 
@@ -1326,11 +1221,8 @@ void GroupManager::setSortingStrategy(TaskSortingStrategy sortOrder)
         kDebug() << "Invalid Strategy";
     }
     if (d->abstractSortingStrategy) {
-        typedef QHash<int, TaskGroup*> Metagroup;
-        foreach (Metagroup metagroup, d->rootGroups) {
-            foreach (TaskGroup * group, metagroup) {
-                d->abstractSortingStrategy->handleGroup(group);
-            }
+        foreach (TaskGroup * group, d->rootGroups) {
+            d->abstractSortingStrategy->handleGroup(group);
         }
     }
 
@@ -1400,4 +1292,4 @@ void GroupManager::setGroupingStrategy(TaskGroupingStrategy strategy)
 
 } // TaskManager namespace
 
-#include "groupmanager.moc"
+#include "moc_groupmanager.cpp"
