@@ -27,8 +27,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "taskmanager_export.h"
 
 // KDE
-#include <KDE/KIcon>
-#include <KDE/KUrl>
+#include <KIcon>
+#include <KUrl>
 
 
 namespace TaskManager
@@ -52,10 +52,6 @@ public:
     LauncherItem(QObject *parent, const KUrl &url);
     ~LauncherItem();
 
-    /**
-    * @deprecated: use itemType() instead
-    **/
-    KDE_DEPRECATED bool isGroupItem() const;
     ItemType itemType() const;
 
     bool isValid() const;
@@ -93,9 +89,6 @@ public:
     KUrl launcherUrl() const;
     void setLauncherUrl(const KUrl &url);
 
-    //preferred applications hack
-    QString defaultApplication() const;
-
 public Q_SLOTS:
     void toDesktop(int);
 
