@@ -25,7 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <QMap>
 #include <QString>
-#include <QtAlgorithms>
+#include <QtCore/qalgorithms.h>
 #include <QList>
 
 #include <KDebug>
@@ -96,5 +96,5 @@ void AlphaSortingStrategy::sortItems(ItemList &items)
 
 } //namespace
 
-#include "alphasortingstrategy.moc"
+#include "moc_alphasortingstrategy.cpp"
 
