@@ -50,7 +50,6 @@ Task::Task(WId w, QObject *parent, const char *name)
 
     // try to load icon via net_wm
     refreshIcon();
-    refreshActivities();
 }
 
 Task::~Task()
@@ -153,11 +152,6 @@ void Task::refreshIcon()
         refreshIcon();
     }
 
-    if (dirty.netWindowInfoProperties2 & NET::WM2Activities) {
-        refreshActivities();
-        changes |= ActivitiesChanged;
-    }
-
     if (changes != TaskUnchanged) {
         emit changed(changes);
     }
@@ -195,14 +189,9 @@ bool Task::isMinimized() const
     return d->info.valid(true) && d->info.isMinimized();
 }
 
-bool Task::isIconified() const
-{
-    return d->info.valid(true) && d->info.isMinimized();
-}
-
 bool Task::isAlwaysOnTop() const
 {
-    return d->info.valid(true) && (d->info.state() & NET::StaysOnTop);
+    return d->info.valid(true) && (d->info.state() & NET::KeepAbove);
 }
 
 bool Task::isKeptBelowOthers() const
@@ -406,69 +395,60 @@ QPixmap Task::bestIcon(int size, bool &isStaticIcon)
     isStaticIcon = false;
 
     switch (size) {
-    case KIconLoader::SizeSmall: {
-        pixmap = icon(16, 16, true);
+        case KIconLoader::SizeSmall: {
+            pixmap = icon(16, 16, true);
 
-        // Icon of last resort
-        if (pixmap.isNull()) {
-            pixmap = KIconLoader::global()->loadIcon("xorg",
-                     KIconLoader::NoGroup,
-                     KIconLoader::SizeSmall);
-            isStaticIcon = true;
+            // Icon of last resort
+            if (pixmap.isNull()) {
+                pixmap = KIconLoader::global()->loadIcon("xorg",
+                        KIconLoader::NoGroup,
+                        KIconLoader::SizeSmall);
+                isStaticIcon = true;
+            }
         }
-    }
-    break;
-    case KIconLoader::SizeMedium: {
-        //
-        // Try 34x34 first for KDE 2.1 icons with shadows, if we don't
-        // get one then try 32x32.
-        //
-        pixmap = icon(34, 34, false);
-
-        if (((pixmap.width() != 34) || (pixmap.height() != 34)) &&
-                ((pixmap.width() != 32) || (pixmap.height() != 32))) {
+        break;
+        case KIconLoader::SizeMedium: {
             pixmap = icon(32, 32, true);
-        }
 
-        // Icon of last resort
-        if (pixmap.isNull()) {
-            pixmap = KIconLoader::global()->loadIcon("xorg",
-                     KIconLoader::NoGroup,
-                     KIconLoader::SizeMedium);
-            isStaticIcon = true;
+            // Icon of last resort
+            if (pixmap.isNull()) {
+                pixmap = KIconLoader::global()->loadIcon("xorg",
+                        KIconLoader::NoGroup,
+                        KIconLoader::SizeMedium);
+                isStaticIcon = true;
+            }
         }
-    }
-    break;
-    case KIconLoader::SizeLarge: {
-        // If there's a 48x48 icon in the hints then use it
-        pixmap = icon(size, size, false);
+        break;
+        case KIconLoader::SizeLarge: {
+            // If there's a 48x48 icon in the hints then use it
+            pixmap = icon(size, size, false);
 
-        // If not, try to get one from the classname
-        if (pixmap.isNull() || pixmap.width() != size || pixmap.height() != size) {
-            pixmap = KIconLoader::global()->loadIcon(className(),
-                     KIconLoader::NoGroup,
-                     size,
-                     KIconLoader::DefaultState,
-                     QStringList(), 0L,
-                     true);
-            isStaticIcon = true;
-        }
+            // If not, try to get one from the classname
+            if (pixmap.isNull() || pixmap.width() != size || pixmap.height() != size) {
+                pixmap = KIconLoader::global()->loadIcon(className(),
+                        KIconLoader::NoGroup,
+                        size,
+                        KIconLoader::DefaultState,
+                        QStringList(), 0L,
+                        true);
+                isStaticIcon = true;
+            }
 
-        // If we still don't have an icon then scale the one in the hints
-        if (pixmap.isNull() || (pixmap.width() != size) || (pixmap.height() != size)) {
-            pixmap = icon(size, size, true);
-            isStaticIcon = false;
-        }
+            // If we still don't have an icon then scale the one in the hints
+            if (pixmap.isNull() || (pixmap.width() != size) || (pixmap.height() != size)) {
+                pixmap = icon(size, size, true);
+                isStaticIcon = false;
+            }
 
-        // Icon of last resort
-        if (pixmap.isNull()) {
-            pixmap = KIconLoader::global()->loadIcon("xorg",
-                     KIconLoader::NoGroup,
-                     size);
-            isStaticIcon = true;
+            // Icon of last resort
+            if (pixmap.isNull()) {
+                pixmap = KIconLoader::global()->loadIcon("xorg",
+                        KIconLoader::NoGroup,
+                        size);
+                isStaticIcon = true;
+            }
         }
     }
-    }
 
     return pixmap;
 }
@@ -478,10 +458,10 @@ bool Task::idMatch(const QString& id1, const QString& id2)
     if (id1.isEmpty() || id2.isEmpty())
         return false;
 
-    if (id1.contains(id2) > 0)
+    if (id1.contains(id2))
         return true;
 
-    if (id2.contains(id1) > 0)
+    if (id2.contains(id1))
         return true;
 
     return false;
@@ -515,18 +495,18 @@ void Task::setIconified(bool iconify)
 
 void Task::toggleIconified()
 {
-    setIconified(!isIconified());
+    setIconified(!isMinimized());
 }
 
 void Task::raise()
 {
-//    kDebug(1210) << "Task::raise(): " << name();
+//    kDebug() << "Task::raise(): " << name();
     KWindowSystem::raiseWindow(d->win);
 }
 
 void Task::lower()
 {
-//    kDebug(1210) << "Task::lower(): " << name();
+//    kDebug() << "Task::lower(): " << name();
     KWindowSystem::lowerWindow(d->win);
 }
 
@@ -552,14 +532,14 @@ void Task::activate()
     }
 
 
-    //kDebug(1210) << "Task::activate():" << name() << d->win << w;
+    //kDebug() << "Task::activate():" << name() << d->win << w;
     KWindowSystem::forceActiveWindow(w);
 }
 
 void Task::activateRaiseOrIconify()
 {
-    //kDebug() << isActive() << isIconified() << isOnTop();
-    if (!isActive() || isIconified()) {
+    //kDebug() << isActive() << isMinimized() << isOnTop();
+    if (!isActive() || isMinimized()) {
         activate();
     } else if (!isOnTop()) {
         raise();
@@ -700,21 +680,6 @@ WId Task::idFromMimeData(const QMimeData *mimeData, bool *ok)
     return id;
 }
 
-bool Task::isOnCurrentActivity() const
-{
-    return d->activities.isEmpty() || d->activities.contains(TaskManager::self()->currentActivity());
-}
-
-bool Task::isOnAllActivities() const
-{
-    return d->activities.isEmpty();
-}
-
-QStringList Task::activities() const
-{
-    return d->activities;
-}
-
 Task::WindowProperties::WindowProperties(unsigned int netWinInfoProperties, unsigned int netWinInfoProperties2)
     : netWindowInfoProperties(netWinInfoProperties), netWindowInfoProperties2(netWinInfoProperties2)
 {
@@ -722,5 +687,5 @@ Task::WindowProperties::WindowProperties(unsigned int netWinInfoProperties, unsi
 
 } // TaskManager namespace
 
-#include "task.moc"
+#include "moc_task.cpp"
 
