@@ -44,9 +44,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <NETRootInfo>
 
 #include <QtCore/QMap>
-#include <QtGui/QHelpEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QToolTip>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 ///////////////////////////////////////////////////////////////////////////////
 // NOTE: if you change the menu, keep kde-workspace/kwin/useractions.cpp in sync
@@ -520,7 +520,7 @@ void AppSelectorDialog::launcherSelected()
 }
 
 NewInstanceActionImpl::NewInstanceActionImpl(QObject *parent, AbstractGroupableItem *item)
-    : QAction(parent), m_abstractItem(item)
+    : QAction(parent)
 {
     if (LauncherItemType == item->itemType()) {
         setVisible(false);
@@ -645,9 +645,9 @@ BasicMenu::BasicMenu(QWidget *parent, TaskGroup* group, GroupManager *strategy,
 
     foreach (AbstractGroupableItem * item, group->members()) {
         if (item->itemType() == GroupItemType) {
-            addMenu(new BasicMenu(this, dynamic_cast<TaskGroup*>(item), strategy));
+            addMenu(new BasicMenu(this, qobject_cast<TaskGroup*>(item), strategy));
         } else {
-            addMenu(new BasicMenu(this, dynamic_cast<TaskItem*>(item), strategy, QList <QAction*>(), QList <QAction*>(), maxWidth));
+            addMenu(new BasicMenu(this, qobject_cast<TaskItem*>(item), strategy, QList <QAction*>(), QList <QAction*>(), maxWidth));
         }
     }
     addSeparator();
@@ -727,6 +727,6 @@ GroupPopupMenu::GroupPopupMenu(QWidget *parent, TaskGroup *group, GroupManager *
 
 } // TaskManager namespace
 
-#include "taskactions.moc"
-#include "taskactions_p.moc"
+#include "moc_taskactions.cpp"
+#include "moc_taskactions_p.cpp"
 
