@@ -28,7 +28,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QTimer>
-#include <QUuid>
 
 // KDE
 #include <KConfig>
@@ -41,15 +40,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <NETWinInfo>
 
 #ifdef Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #endif
 
-#ifdef Q_WS_WIN
-#include <windows.h>
-#endif
-
-#include <KActivities/Consumer>
-
 namespace TaskManager
 {
 
@@ -99,8 +92,7 @@ public:
     QHash<WId, Task *> tasksByWId;
     QList<Startup *> startups;
     WindowList skiptaskbarWindows;
-    QSet<QUuid> trackGeometryTokens;
-    KActivities::Consumer activityConsumer;
+    bool trackGeometry;
 };
 
 TaskManager::TaskManager()
@@ -118,14 +110,10 @@ TaskManager::TaskManager()
             this,       SLOT(currentDesktopChanged(int)));
     connect(KWindowSystem::self(), SIGNAL(windowChanged(WId, const ulong*)),
             this,       SLOT(windowChanged(WId, const ulong*)));
-    connect(&d->activityConsumer, SIGNAL(currentActivityChanged(QString)),
-            this,       SIGNAL(activityChanged(QString)));
     if (QCoreApplication::instance()) {
         connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(onAppExitCleanup()));
     }
 
-    emit activityChanged(d->activityConsumer.currentActivity());
-
     // register existing windows
     const QList<WId> windows = KWindowSystem::windows();
     QList<WId>::ConstIterator end(windows.end());
@@ -184,7 +172,7 @@ void TaskManager::configureStartup()
     }
 
     c = KConfigGroup(&_c, "TaskbarButtonSettings");
-    d->startupInfo->setTimeout(c.readEntry("Timeout", 30));
+    d->startupInfo->setTimeout(c.readEntry("Timeout", 10));
 }
 
 Task *TaskManager::findTask(WId w)
@@ -211,9 +199,8 @@ Task *TaskManager::findTask(int desktop, const QPoint& p)
         if (!t->isOnAllDesktops() && t->desktop() != desktop) {
             continue;
         }
-        //FIXME activities?
 
-        if (t->isIconified() || t->isShaded()) {
+        if (t->isMinimized() || t->isShaded()) {
             continue;
         }
 
@@ -239,7 +226,6 @@ void TaskManager::windowAdded(WId w)
     // ignore NET::Tool and other special window types
     NET::WindowType wType = info.windowType(NET::NormalMask | NET::DesktopMask | NET::DockMask |
                                             NET::ToolbarMask | NET::MenuMask | NET::DialogMask |
-                                            NET::OverrideMask | NET::TopMenuMask |
                                             NET::UtilityMask | NET::SplashMask);
 
     if (info.transientFor() > 0) {
@@ -263,7 +249,7 @@ void TaskManager::windowAdded(WId w)
         }
     }
 
-    if (wType != NET::Normal && wType != NET::Override && wType != NET::Unknown &&
+    if (wType != NET::Normal && wType != NET::Unknown &&
         wType != NET::Dialog && wType != NET::Utility) {
         return;
     }
@@ -350,8 +336,7 @@ void TaskManager::windowChanged(WId w, const unsigned long *dirty)
     if (!(dirty[NETWinInfo::PROTOCOLS] & (NET::WMVisibleName | NET::WMName |
                                           NET::WMState | NET::WMIcon |
                                           NET::XAWMState | NET::WMDesktop) ||
-            (trackGeometry() && dirty[NETWinInfo::PROTOCOLS] & NET::WMGeometry) ||
-            (dirty[NETWinInfo::PROTOCOLS2] & NET::WM2Activities))) {
+            (trackGeometry() && dirty[NETWinInfo::PROTOCOLS] & NET::WMGeometry))) {
         return;
     }
 
@@ -517,30 +502,22 @@ bool TaskManager::isOnTop(const Task *task) const
             continue;
         }
 
-#ifndef Q_WS_WIN
-        if (!t->isIconified() && (t->isAlwaysOnTop() == task->isAlwaysOnTop())) {
+        if (!t->isMinimized() && (t->isAlwaysOnTop() == task->isAlwaysOnTop())) {
             return false;
         }
-#endif
     }
 
     return false;
 }
 
-void TaskManager::setTrackGeometry(bool track, const QUuid &token)
+void TaskManager::setTrackGeometry(bool track)
 {
-    if (track) {
-        if (!d->trackGeometryTokens.contains(token)) {
-            d->trackGeometryTokens.insert(token);
-        }
-    } else {
-        d->trackGeometryTokens.remove(token);
-    }
+    d->trackGeometry = track;
 }
 
 bool TaskManager::trackGeometry() const
 {
-    return !d->trackGeometryTokens.isEmpty();
+    return d->trackGeometry;
 }
 
 bool TaskManager::isOnScreen(int screen, const WId wid)
@@ -566,12 +543,7 @@ int TaskManager::currentDesktop() const
     return KWindowSystem::currentDesktop();
 }
 
-QString TaskManager::currentActivity() const
-{
-    return d->activityConsumer.currentActivity();
-}
-
 } // TaskManager namespace
 
 
-#include "taskmanager.moc"
+#include "moc_taskmanager.cpp"
