@@ -25,9 +25,10 @@
 #include <kglobal.h>
 #include <kaboutdata.h>
 #include <kdebug.h>
-
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
+#include <kdeversion.h>
+
 #include "statusnotifierwatcheradaptor.h"
 #include "statusnotifieritem_interface.h"
 #include <config-workspace.h>
@@ -35,7 +36,7 @@
 
 static inline KAboutData aboutData()
 {
-    return KAboutData("statusnotifierwatcher", 0, ki18n("statusnotifierwatcher"), WORKSPACE_VERSION_STRING);
+    return KAboutData("statusnotifierwatcher", 0, ki18n("statusnotifierwatcher"), KDE_VERSION_STRING);
 }
 
 K_PLUGIN_FACTORY(StatusNotifierWatcherFactory,
@@ -145,4 +146,4 @@ int StatusNotifierWatcher::ProtocolVersion() const
     return 0;
 }
 
-#include "statusnotifierwatcher.moc"
+#include "moc_statusnotifierwatcher.cpp"
