@@ -25,7 +25,7 @@
 #include <QPainter>
 #include <QVBoxLayout>
 #include <QStylePainter>
-#include <QStyleOptionFrame>
+#include <QtGui/qstyleoption.h>
 
 // For the blurred tooltip background
 #include <plasma/windoweffects.h>
@@ -55,10 +55,4 @@ void KToolTipWindow::paintEvent(QPaintEvent* event)
    QWidget::paintEvent(event);
 }
 
-void KToolTipWindow::showEvent(QShowEvent *)
-{
-    Plasma::WindowEffects::overrideShadow(winId(), true);
-    Plasma::WindowEffects::enableBlurBehind(winId(), true, mask());
-}
-
-#include "ktooltipwindow_p.moc"
+#include "moc_ktooltipwindow_p.cpp"
